/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
    this.grow = function(amount) {
      var ret = __growWasmMemory(amount);
      return ret;
    };
  },

  // Table is not a normal constructor and instead returns the array object.
  // That lets us use the length property automatically, which is simpler and
  // smaller (but instanceof will not report that an instance of Table is an
  // instance of this function).
  Table: /** @constructor */ function(opts) {
    var ret = new Array(opts['initial']);
    ret.set = function(i, func) {
      ret[i] = func;
    };
    ret.get = function(i) {
      return ret[i];
    };
    return ret;
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function a(asmLibraryArg,wasmMemory,wasmTable){var scratchBuffer=new ArrayBuffer(16);var b=new Int32Array(scratchBuffer);var c=new Float32Array(scratchBuffer);var d=new Float64Array(scratchBuffer);function e(index){return b[index]}function f(index,value){b[index]=value}function g(){return d[0]}function h(value){d[0]=value}function i(value){c[2]=value}function j(){return c[2]}function k(global,env,buffer){var l=env.memory;var m=wasmTable;var n=new global.Int8Array(buffer);var o=new global.Int16Array(buffer);var p=new global.Int32Array(buffer);var q=new global.Uint8Array(buffer);var r=new global.Uint16Array(buffer);var s=new global.Uint32Array(buffer);var t=new global.Float32Array(buffer);var u=new global.Float64Array(buffer);var v=global.Math.imul;var w=global.Math.fround;var x=global.Math.abs;var y=global.Math.clz32;var z=global.Math.min;var A=global.Math.max;var B=global.Math.floor;var C=global.Math.ceil;var D=global.Math.sqrt;var E=env.abort;var F=global.NaN;var G=global.Infinity;var H=env.a;var I=env.b;var J=env.c;var K=env.d;var L=env.e;var M=env.f;var N=env.g;var O=env.h;var P=env.i;var Q=env.j;var R=env.k;var S=env.l;var T=env.m;var U=env.n;var V=env.o;var W=env.p;var X=env.q;var Y=env.r;var Z=env.s;var _=env.t;var $=env.u;var aa=env.v;var ba=env.w;var ca=env.x;var da=env.y;var ea=env.z;var fa=env.A;var ga=env.B;var ha=env.C;var ia=env.D;var ja=env.E;var ka=env.F;var la=env.G;var ma=env.H;var na=env.I;var oa=env.J;var pa=env.K;var qa=env.L;var ra=env.M;var sa=env.N;var ta=env.O;var ua=env.P;var va=env.Q;var wa=env.R;var xa=env.S;var ya=env.T;var za=env.U;var Aa=env.V;var Ba=env.W;var Ca=env.X;var Da=env.Y;var Ea=env.Z;var Fa=env._;var Ga=env.$;var Ha=env.aa;var Ia=env.ba;var Ja=env.ca;var Ka=env.da;var La=env.ea;var Ma=env.fa;var Na=env.ga;var Oa=env.ha;var Pa=env.ia;var Qa=env.ja;var Ra=env.ka;var Sa=env.la;var Ta=env.ma;var Ua=env.na;var Va=env.oa;var Wa=env.pa;var Xa=env.qa;var Ya=env.ra;var Za=env.sa;var _a=env.ta;var $a=env.ua;var ab=env.va;var bb=env.wa;var cb=env.xa;var db=env.ya;var eb=env.za;var fb=5707232;var gb=0;var hb=0;var ib=0;
// EMSCRIPTEN_START_FUNCS
function PHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=fb-608|0;fb=d;Ac(b);e=d+416|0;g=mGa(b,e);if(!g){jQ(e)}a:{b:{c:{if(!g){break c}if(!MQ(d+416|0)){break c}if(!Hb(b,dd(LQ(d+416|0),ib))){break c}if(!c){f=1;break c}xd(a,32);n[d+415|0]=0;k=Xc(d+400|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{if(p[d+416>>2]==778924148){p[114610]=0;K(624,a|0,16777216);e=p[114610];p[114610]=0;if((e|0)==1){break b}p[114610]=0;e=M(255,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}p[114610]=0;J(256,b|0,e+ -4|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}p[114610]=0;y=M(390,b|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break K}break b}L:{M:{N:{O:{if((q[d+456|0]|q[d+457|0]<<8)>>>0<2185|(q[d+456|0]|q[d+457|0]<<8)>>>0>4095){break O}p[114610]=0;e=M(255,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}p[114610]=0;J(256,b|0,e+ -4|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}p[114610]=0;y=M(390,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}if(y>>>0<256){break O}p[114610]=0;e=M(255,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}if(y>>>0>=e>>>0){break O}p[114610]=0;e=J(256,b|0,y|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}if(!e){break O}p[114610]=0;e=J(625,b|0,13434)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}if(!e){break O}p[114610]=0;K(624,a|0,16777216);e=p[114610];p[114610]=0;if((e|0)==1){break b}if((q[d+456|0]|q[d+457|0]<<8)>>>0>=4096){p[114610]=0;b=J(626,d+224|0,13438)|0;c=p[114610];p[114610]=0;if((c|0)==1){break J}p[114610]=0;K(627,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);f=0;break d}f=I()|0;H()|0;pb(b);break a}if((q[d+456|0]|q[d+457|0]<<8)>>>0<2194){break O}p[114610]=0;e=J(626,d+224|0,13534)|0;f=p[114610];p[114610]=0;if((f|0)==1){break N}p[114610]=0;K(627,a|0,e|0);f=p[114610];p[114610]=0;if((f|0)==1){break M}pb(e)}if(p[a+480180>>2]!=32){break K}if(((q[d+456|0]|q[d+457|0]<<8)&61440)!=20480){break L}p[a+1074304>>2]=((q[d+456|0]|q[d+457|0]<<8)&4095)<<16;if(p[d+476>>2]!=1414548815){break K}n[d+415|0]=1;break K}f=I()|0;H()|0;break a}f=I()|0;H()|0;pb(e);break a}if(!((q[d+456|0]|q[d+457|0]<<8)!=2184?(q[d+458|0]|q[d+459|0]<<8)!=2184:0)){n[d+415|0]=1;p[a+1074304>>2]=18284544;break K}if(!((q[d+456|0]|q[d+457|0]<<8)!=535|(q[d+458|0]|q[d+459|0]<<8)!=512|(q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24)))){p[114610]=0;e=P(628,d+480|0,255,64)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}P:{if(e){p[a+1074304>>2]=18219008;p[114610]=0;e=J(2,d+224|0,13680)|0;f=p[114610];p[114610]=0;if((f|0)!=1){break P}f=I()|0;H()|0;break a}p[a+1074304>>2]=18284544;p[114610]=0;e=J(2,d+224|0,13708)|0;f=p[114610];p[114610]=0;if((f|0)==1){break I}}xb(k,e);pb(e);n[d+415|0]=1;break K}if(!((q[d+456|0]|q[d+457|0]<<8)!=532|(q[d+458|0]|q[d+459|0]<<8)!=514|(q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24)))){p[a+1074304>>2]=17367040;p[114610]=0;e=J(2,d+224|0,13744)|0;f=p[114610];p[114610]=0;if((f|0)!=1){xb(k,e);pb(e);n[d+415|0]=1;break K}f=I()|0;H()|0;break a}if((q[d+456|0]|q[d+457|0]<<8)!=768|(q[d+458|0]|q[d+459|0]<<8)!=768|(q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24)|(q[d+448|0]|q[d+449|0]<<8)!=256)){break K}if(q[d+469|0]|q[d+468|0]!=128){break K}p[a+1074304>>2]=18285088;n[d+415|0]=1}p[a+480208>>2]=p[a+480208>>2]&-17|(q[d+460|0]|q[d+461|0]<<8)<<1&16;p[a+480208>>2]=p[a+480208>>2]&-5|(q[d+460|0]|q[d+461|0]<<8)>>>2&4;p[a+480208>>2]=p[a+480208>>2]&-9|(q[d+460|0]|q[d+461|0]<<8)>>>2&8;p[a+480208>>2]=p[a+480208>>2]&-32769|(q[d+460|0]|q[d+461|0]<<8)<<3&32768;p[114610]=0;N(629,d+328|0,3,d+416|4);e=p[114610];p[114610]=0;if((e|0)==1){break H}p[114610]=0;K(415,d+224|0,d+328|0);e=p[114610];p[114610]=0;if((e|0)==1){break H}xb(a+1304400|0,d+224|0);pb(d+224|0);if(!(!(q[d+462|0]&4)|(s[a+1074304>>2]<18285314?p[a+1074304>>2]:0))){p[a+480216>>2]=q[d+446|0];p[a+480220>>2]=q[d+447|0]}e=q[d+464|0];p[a+480200>>2]=e>>>0>128?256:e<<1;if(q[d+466|0]){p[a+480196>>2]=q[d+466|0]}n[d+224|0]=31;e=q[d+467|0];p[114610]=0;n[d+328|0]=e;e=J(453,d+224|0,d+328|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}p[a+480204>>2]=v(q[e|0],1e4);e=q[d+465|0];p[114610]=0;n[d+224|0]=e;n[d+328|0]=128;e=J(391,d+224|0,d+328|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break f}p[a+480228>>2]=q[e|0];f=0;while(1){j=(d+416|0)+f|0;g=j- -64|0;Q:{if(q[g|0]==255){break Q}p[114610]=0;i=(f<<5)+a|0;e=i+480280|0;S(432,e|0);h=p[114610];p[114610]=0;if((h|0)==1){break G}C=i+480286|0,D=sd(q[j+128|0],0,64),o[C>>1]=D;if(n[g|0]<=-1){p[e>>2]=p[e>>2]|1024}g=q[g|0]&127;if(g>>>0<=64){o[i+480284>>1]=g<<2;break Q}if((g|0)!=100){break Q}p[e>>2]=p[e>>2]|256}f=f+1|0;if((f|0)!=64){continue}break}p[114610]=0;J(256,b|0,192)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}R:{if(!(p[a+480180>>2]!=16777216|(q[d+456|0]|q[d+457|0]<<8)>>>0<2187|(q[d+456|0]|q[d+457|0]<<8)>>>0>2189)){f=0;p[114610]=0;e=M(357,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break F}if(e){break d}p[114610]=0;e=M(390,b|0)|0;g=p[114610];p[114610]=0;S:{if((g|0)==1){break S}if(e>>>0>r[p[19847]+12>>1]){break d}g=Ob(a+484360|0);p[114610]=0;e=Z(630,g|0,b|0,e|0,65535,65535)|0;g=p[114610];p[114610]=0;if((g|0)==1){break S}if(!e){break d}break R}f=I()|0;H()|0;break a}e=Ob(a+484360|0);f=q[d+448|0]|q[d+449|0]<<8;p[114610]=0;Z(584,e|0,b|0,f|0,255,254)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}}x=pp(d+384|0);w=pp(d+368|0);m=pp(d+352|0);e=q[d+450|0]|q[d+451|0]<<8;f=0;p[114610]=0;e=P(631,b|0,x|0,e|0)|0;g=p[114610];p[114610]=0;T:{if((g|0)==1){break T}if(!e){break D}e=q[d+452|0]|q[d+453|0]<<8;p[114610]=0;e=P(631,b|0,w|0,e|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break T}if(!e){break D}e=q[d+454|0]|q[d+455|0]<<8;p[114610]=0;e=P(631,b|0,m|0,e|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break T}if(!e){break D}p[d+348>>2]=-1;C=d,D=Ub(x),p[C+224>>2]=D;C=d,D=Vb(x),p[C+328>>2]=D;if(!Ab(d+224|0,d+328|0)){break E}while(1){e=p[d+224>>2];e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);if(!(!e|e>>>0>=s[d+348>>2])){p[d+348>>2]=e}Rd(d+224|0);if(Ab(d+224|0,d+328|0)){continue}break}break E}f=I()|0;H()|0;break g}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}C=d,D=Ub(w),p[C+224>>2]=D;C=d,D=Vb(w),p[C+328>>2]=D;if(Ab(d+224|0,d+328|0)){while(1){e=p[d+224>>2];e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);if(!(!e|e>>>0>=s[d+348>>2])){p[d+348>>2]=e}Rd(d+224|0);if(Ab(d+224|0,d+328|0)){continue}break}}C=d,D=Ub(m),p[C+224>>2]=D;C=d,D=Vb(m),p[C+328>>2]=D;if(Ab(d+224|0,d+328|0)){while(1){e=p[d+224>>2];e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);if(!(!e|e>>>0>=s[d+348>>2])){p[d+348>>2]=e}Rd(d+224|0);if(Ab(d+224|0,d+328|0)){continue}break}}U:{V:{if(n[d+462|0]&1){e=q[d+472|0]|q[d+473|0]<<8|(q[d+474|0]<<16|q[d+475|0]<<24);p[114610]=0;p[d+224>>2]=e;e=J(632,d+348|0,d+224|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break V}p[d+348>>2]=p[e>>2]}f=0;W:{X:{Y:{Z:{if((q[d+458|0]|q[d+459|0]<<8)!=532|(q[d+456|0]|q[d+457|0]<<8?(q[d+456|0]|q[d+457|0]<<8)!=532:0)|(q[d+447|0]|q[d+446|0])){break Z}if(q[d+460|0]&192|(q[d+469|0]|(q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24)))){break Z}_:{if(!(q[d+452|0]|q[d+453|0]<<8)|(q[d+450|0]|q[d+451|0]<<8)){break _}if((p[b+8>>2]+(Bb(w)<<2)|0)+2>>>0>s[d+348>>2]){break _}if(q[d+452|0]|q[d+453|0]<<8){e=0;while(1){p[114610]=0;f=M(390,b|0)|0;g=p[114610];p[114610]=0;$:{if((g|0)!=1){if(!f){break $}jg(b,(e<<2)+4|0);break _}f=I()|0;H()|0;break g}e=e+1|0;if(e>>>0<(q[d+452|0]|q[d+453|0]<<8)>>>0){continue}break}}p[114610]=0;e=J(2,d+224|0,13772)|0;f=p[114610];p[114610]=0;if((f|0)==1){break X}xb(k,e);pb(e)}f=1;if(q[d+456|0]|q[d+457|0]<<8){break Z}p[114610]=0;e=J(2,d+224|0,13785)|0;g=p[114610];p[114610]=0;if((g|0)==1){break Y}xb(k,e);pb(e)}aa:{ba:{ca:{if(q[d+462|0]&2){p[114610]=0;e=M(357,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break aa}p[114610]=0;g=e<<3;i=J(258,b|0,g|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break aa}if(!(!i|g+p[b+8>>2]>>>0>s[d+348>>2])){p[114610]=0;g=a+1304500|0;K(633,g|0,e|0);i=p[114610];p[114610]=0;if((i|0)==1){break aa}C=d,D=Ub(g),p[C+328>>2]=D;C=d,D=Vb(g),p[C+312>>2]=D;if(Ab(d+328|0,d+312|0)){while(1){g=p[d+328>>2];p[114610]=0;J(634,b|0,d+224|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break ba}p[114610]=0;K(635,d+224|0,g|0);g=p[114610];p[114610]=0;if((g|0)==1){break ba}p[d+328>>2]=p[d+328>>2]+48;if(Ab(d+328|0,d+312|0)){continue}break}}if(!(!e&f)){break ca}if(q[d+462|0]&4){p[114610]=0;e=J(2,d+224|0,13796)|0;f=p[114610];p[114610]=0;if((f|0)!=1){xb(k,e);pb(e);break ca}f=I()|0;H()|0;break g}p[114610]=0;e=J(2,d+224|0,13813)|0;f=p[114610];p[114610]=0;if((f|0)!=1){xb(k,e);pb(e);break ca}f=I()|0;H()|0;break g}jg(b,2);break ca}if(!f|(q[d+462|0]|q[d+463|0]<<8)>>>0>1){break ca}p[114610]=0;e=M(357,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break W}if(!e){p[114610]=0;e=J(2,d+224|0,13772)|0;f=p[114610];p[114610]=0;if((f|0)!=1){xb(k,e);pb(e);break ca}f=I()|0;H()|0;break g}jg(b,2)}da:{if(q[d+462|0]&8?0:!(q[d+460|0]&128)){break da}p[114610]=0;e=a+901404|0;f=J(636,b|0,e|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break h}if(!f){break da}p[114610]=0;S(637,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break h}}if((q[d+456|0]|q[d+457|0]<<8)>>>0<=531){p[114610]=0;S(638,a+901404|0);e=p[114610];p[114610]=0;if((e|0)==1){break h}}p[114610]=0;z=M(277,d+328|0)|0;e=p[114610];p[114610]=0;ea:{fa:{ga:{ha:{ia:{ja:{ka:{if((e|0)!=1){p[114610]=0;e=J(621,b|0,13819)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ka}if(e){p[114610]=0;e=M(390,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ja}p[114610]=0;N(341,d+224|0,b|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break ja}Nd(z,d+224|0);sb(d+224|0)}o[a+480188>>1]=1;p[114610]=0;e=J(621,b|0,13824)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ka}if(e){p[114610]=0;e=M(390,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ia}p[114610]=0;N(341,d+224|0,b|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break ia}p[114610]=0;e=M(255,d+224|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ha}p[114610]=0;o[d+312>>1]=(e>>>0)/20;e=J(477,13830,d+312|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ha}e=r[e>>1];o[a+480188>>1]=e;if(e){f=0;while(1){p[114610]=0;P(639,d+224|0,((f<<5)+a|0)+480289|0,20)|0;g=p[114610];p[114610]=0;if((g|0)==1){break ha}f=f+1|0;if((e|0)!=(f|0)){continue}break}}sb(d+224|0)}if(s[d+348>>2]<s[b+8>>2]){break ga}e=p[d+348>>2]-p[b+8>>2]|0;break fa}f=I()|0;H()|0;break g}f=I()|0;H()|0;break i}f=I()|0;H()|0;break i}f=I()|0;H()|0;break i}f=I()|0;H()|0;sb(d+224|0);break i}p[114610]=0;e=M(548,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ea}}p[114610]=0;N(341,d+312|0,b|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break ea}p[114610]=0;B=J(640,a|0,d+312|0)|0;e=p[114610];p[114610]=0;la:{ma:{if((e|0)==1){break ma}if(!(n[d+462|0]&1)|!(q[d+470|0]|q[d+471|0]<<8)){break la}e=q[d+472|0]|q[d+473|0]<<8|(q[d+474|0]<<16|q[d+475|0]<<24);p[114610]=0;e=J(256,b|0,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ma}if(!e){break la}e=q[d+470|0]|q[d+471|0]<<8;p[114610]=0;U(587,a+1304424|0,b|0,e|0,4)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break la}}f=I()|0;H()|0;break j}o[a+480192>>1]=0;na:{if(q[d+460|0]&4){e=q[d+450|0]|q[d+451|0]<<8;p[114610]=0;o[d+224>>1]=e;o[d+208>>1]=255;e=J(477,d+224|0,d+208|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break na}o[a+480192>>1]=r[e>>1]}oa:{pa:{if(r[a+480192>>1]){f=0;while(1){e=Fb(x,f);qa:{if(!(q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))){break qa}e=Fb(x,f);e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);p[114610]=0;e=J(256,b|0,e|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break oa}if(!e){break qa}p[114610]=0;e=J(258,b|0,554)|0;g=p[114610];p[114610]=0;if((g|0)==1){break oa}if(!e){break qa}p[114610]=0;e=P(454,a|0,f+1&65535,0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break pa}if(!e){break qa}g=q[d+458|0]|q[d+459|0]<<8;p[114610]=0;U(641,a|0,b|0,e|0,g|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break pa}n[e+33|0]=q[d+469|0]}f=f+1|0;if(f>>>0<r[a+480192>>1]){continue}break}}p[d+308>>2]=0;if(q[d+452|0]|q[d+453|0]<<8){e=Fb(w,(q[d+452|0]|q[d+453|0]<<8)+ -1|0);p[d+308>>2]=(q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))+80}e=q[d+452|0]|q[d+453|0]<<8;p[114610]=0;o[d+224>>1]=e;o[d+208>>1]=3999;e=J(477,d+224|0,d+208|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){o[a+480190>>1]=r[e>>1];i=0;ra:{if(r[a+480190>>1]){j=c&2;t=d+244|0;f=0;while(1){e=Fb(w,f);sa:{if(!(q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))){break sa}e=Fb(w,f);e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);p[114610]=0;e=J(256,b|0,e|0)|0;g=p[114610];p[114610]=0;ta:{ua:{va:{wa:{xa:{ya:{za:{if((g|0)==1){break za}if(!e){break sa}p[114610]=0;e=J(642,b|0,d+224|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break za}if(!e){break sa}p[114610]=0;h=f+1|0;e=v(h,104)+a|0;g=e+484380|0;u=J(643,d+224|0,g|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break ya}p[114610]=0;N(629,d+192|0,3,t|0);l=p[114610];p[114610]=0;if((l|0)==1){break xa}p[114610]=0;K(415,d+208|0,d+192|0);l=p[114610];p[114610]=0;if((l|0)==1){break xa}p[114610]=0;J(369,((h<<5)+a|0)+946300|0,d+208|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break wa}pb(d+208|0);p[114610]=0;u=J(256,b|0,u|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break ya}if(!u){break sa}e=r[e+484414>>1];if(!(e&512)){break va}p[114610]=0;e=J(644,b|0,d+208|0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){if(!e){break ua}p[114610]=0;p[d+16>>2]=p[d+216>>2];e=p[d+212>>2];p[d+8>>2]=p[d+208>>2];p[d+12>>2]=e;N(645,g|0,1,d+8|0);e=p[114610];p[114610]=0;if((e|0)!=1){break ua}}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;pb(d+208|0);break j}if(!(e&16384)){e=q[d+456|0]|q[d+457|0]<<8;p[114610]=0;N(646,d+208|0,d+224|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break k}Aa:{if(j){e=0;p[114610]=0;P(400,d+208|0,g|0,b|0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){break Aa}break k}e=1;h=q[d+211|0];if(h>>>0>18){break Aa}h=1<<h;Ba:{if(!(h&126991)){if(h&396800){break Ba}break Aa}if(!q[d+208|0]){break Aa}}e=p[g>>2];p[114610]=0;h=J(647,d+208|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}e=0;p[114610]=0;J(338,b|0,h|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break k}}if(q[d+211|0]!=1){break ta}i=p[g>>2]!=0|i;break ta}p[114610]=0;J(648,b|0,d+188|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break l}e=p[d+188>>2];if(!(!j|!e)){e=Lb(d+208|0);p[114610]=0;P(481,b|0,e|0,p[d+188>>2])|0;g=p[114610];p[114610]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((g|0)!=1){p[114610]=0;g=J(2,d+160|0,13832)|0;u=p[114610];p[114610]=0;if((u|0)==1){break Ka}p[114610]=0;K(219,d+176|0,g|0);u=p[114610];p[114610]=0;if((u|0)==1){break Ja}p[114610]=0;p[d+156>>2]=h;N(13,d+144|0,0,e|0);h=p[114610];p[114610]=0;if((h|0)==1){break Ia}p[114610]=0;Q(649,d+192|0,d+176|0,d+156|0,d+144|0);h=p[114610];p[114610]=0;if((h|0)==1){break Ha}p[114610]=0;N(650,a|0,2,d+192|0);h=p[114610];p[114610]=0;if((h|0)==1){break Ga}pb(d+192|0);pb(d+144|0);yb(d+176|0);pb(g);pb(e);break ua}f=I()|0;H()|0;break Ca}f=I()|0;H()|0;break Ca}f=I()|0;H()|0;break Da}f=I()|0;H()|0;break Ea}f=I()|0;H()|0;break Fa}f=I()|0;H()|0;pb(d+192|0)}pb(d+144|0)}yb(d+176|0)}pb(g)}pb(e);break j}p[114610]=0;J(338,b|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break l}}e=0}g=p[b+8>>2];p[114610]=0;p[d+208>>2]=g;g=J(651,d+308|0,d+208|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break ra}p[d+308>>2]=p[g>>2];A=(e|0)!=0}f=f+1|0;if(f>>>0<r[a+480190>>1]){continue}break}}o[d+224>>1]=1;e=r[a+480190>>1];p[114610]=0;o[d+208>>1]=e;e=J(452,d+224|0,d+208|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){o[a+480190>>1]=r[e>>1];La:{Ma:{if(!(i&1)|(q[d+456|0]|q[d+457|0]<<8)!=516|(q[d+462|0]|q[d+463|0]<<8|(q[d+458|0]|q[d+459|0]<<8)!=512)){break Ma}if(q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24)|((q[d+460|0]|q[d+461|0]<<8)&65527)!=21|(q[d+464|0]!=128|q[d+465|0]!=48)){break Ma}if(q[d+469|0]|q[d+468|0]!=128|(q[d+470|0]|q[d+471|0]<<8)){break Ma}g=d+544|0;e=d+480|0;f=1;while(1){f=(q[e|0]|128)!=160?0:f;e=e+1|0;if((g|0)!=(e|0)){continue}break}g=d+608|0;e=d+544|0;while(1){f=q[e|0]==64&f;e=e+1|0;if((g|0)!=(e|0)){continue}break}e=20;while(1){f=!q[(d+e|0)+420|0]&f;e=e+1|0;if(e>>>0<26){continue}break}if(!f){break Ma}p[114610]=0;e=J(2,d+224|0,13910)|0;f=p[114610];p[114610]=0;if((f|0)==1){break La}xb(k,e);pb(e)}p[a+480260>>2]=0;p[a+480264>>2]=2147483647;C=d,D=Bb(m),o[C+224>>1]=D;e=p[a+8>>2];p[114610]=0;e=J(477,d+224|0,e+10|0)|0;f=p[114610];p[114610]=0;Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{if((f|0)!=1){e=r[e>>1];o[d+188>>1]=e;if((Bb(m)|0)!=(e|0)){p[114610]=0;K(509,d+208|0,13924);e=p[114610];p[114610]=0;if((e|0)==1){break Va}e=Bb(m);p[114610]=0;p[d+192>>2]=e;Q(652,d+128|0,d+208|0,d+192|0,d+188|0);e=p[114610];p[114610]=0;if((e|0)==1){break Ua}p[114610]=0;e=J(653,d+224|0,d+128|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Ta}p[114610]=0;K(627,a|0,e|0);f=p[114610];p[114610]=0;if((f|0)==1){break Sa}pb(e);pb(d+128|0);yb(d+208|0)}if(c&1){break Pa}o[d+188>>1]=0;break Oa}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break Qa}f=I()|0;H()|0;break Ra}f=I()|0;H()|0;pb(e)}pb(d+128|0)}yb(d+208|0);break j}if(!r[d+188>>1]){break Oa}e=0;while(1){c=Fb(m,e);Wa:{if(!(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))){break Wa}c=Fb(m,e);c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[114610]=0;c=J(256,b|0,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Na}if(!c){break Wa}p[114610]=0;c=M(357,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break m}p[114610]=0;i=M(357,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break n}if((i+ -1&65535)>>>0>1023){break Wa}p[114610]=0;f=J(338,b|0,4)|0;g=p[114610];p[114610]=0;if((g|0)==1){break n}if(!f){break Wa}p[114610]=0;N(341,d+224|0,b|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break o}c=0;f=r[a+480188>>1];p[114610]=0;g=J(654,d+208|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break q}while(1){Xa:{p[114610]=0;f=J(258,d+224|0,1)|0;j=p[114610];p[114610]=0;Ya:{Za:{if((j|0)!=1){if(!f){break Xa}p[114610]=0;f=M(387,d+224|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break r}j=f<<24>>24;if(j){break Za}c=c+1|0;break Ya}break r}_a:{f=j&127;h=f?f+ -1|0:0;f=h&65535;if(f>>>0<Cc(g)>>>0){break _a}p[114610]=0;n[d+192|0]=0;N(655,g|0,f+1|0,d+192|0);t=p[114610];p[114610]=0;if((t|0)!=1){break _a}break r}if((j|0)<=-1){p[114610]=0;j=M(387,d+224|0)|0;t=p[114610];p[114610]=0;if((t|0)==1){break r}C=oc(g,f),D=j,n[C|0]=D}if(!(!(q[oc(g,f)|0]&15)|f>>>0<r[a+480188>>1])){o[a+480188>>1]=h+1}if(n[oc(g,f)|0]&1){p[114610]=0;J(338,d+224|0,1)|0;j=p[114610];p[114610]=0;if((j|0)==1){break r}}if(q[oc(g,f)|0]&2){p[114610]=0;J(338,d+224|0,1)|0;j=p[114610];p[114610]=0;if((j|0)==1){break r}}if(q[oc(g,f)|0]&4){p[114610]=0;J(338,d+224|0,1)|0;j=p[114610];p[114610]=0;if((j|0)==1){break r}}if(!(q[oc(g,f)|0]&8)){break Ya}p[114610]=0;J(338,d+224|0,2)|0;f=p[114610];p[114610]=0;if((f|0)==1){break r}}if(c>>>0<i>>>0){continue}}break}c=p[b+8>>2];p[114610]=0;p[d+192>>2]=c;c=J(651,d+308|0,d+192|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break r}p[d+308>>2]=p[c>>2];Xd(g);sb(d+224|0)}e=e+1|0;if(e>>>0<r[d+188>>1]){continue}break}}c=p[d+308>>2];if(!c){break U}p[114610]=0;J(256,b|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break s}if(!A){break U}while(1){$a:{p[114610]=0;c=J(258,b|0,4)|0;e=p[114610];p[114610]=0;if((e|0)==1){break $a}if(!c){break U}p[114610]=0;c=J(621,b|0,14016)|0;e=p[114610];p[114610]=0;if((e|0)==1){break $a}ab:{if(!c){p[114610]=0;c=J(621,b|0,14021)|0;e=p[114610];p[114610]=0;if((e|0)==1){break $a}if(!c){break ab}}p[114610]=0;c=M(390,b|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){jg(b,8);if(!(c&1616928864)|c&-2139062144){break ab}break U}f=I()|0;H()|0;break j}p[114610]=0;c=M(357,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break $a}p[114610]=0;J(338,b|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break i}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}p[114610]=0;c=J(656,a|0,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break s}c=c|q[d+415|0];n[d+415|0]=c;if(!(!c|B)){bt(a+1074308|0);p[a+1074368>>2]=0}p[114610]=0;Q(657,a|0,b|0,0,d+415|0);c=p[114610];p[114610]=0;if((c|0)==1){break s}p[114610]=0;t=a+484344|0;K(401,t|0,r[d+188>>1]);c=p[114610];p[114610]=0;if((c|0)==1){break s}o[d+156>>1]=0;bb:{if(!r[d+188>>1]){break bb}f=0;while(1){cb:{db:{c=Fb(m,f&65535);eb:{if(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24)){c=Fb(m,r[d+156>>1]);c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[114610]=0;c=J(256,b|0,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break eb}if(c){break db}}p[114610]=0;c=P(402,t|0,r[d+156>>1],64)|0;e=p[114610];p[114610]=0;if((e|0)==1){break eb}if(!c){p[114610]=0;K(509,d+208|0,14026);c=p[114610];p[114610]=0;fb:{gb:{hb:{ib:{jb:{if((c|0)!=1){p[114610]=0;N(658,d+112|0,d+208|0,d+156|0);c=p[114610];p[114610]=0;if((c|0)==1){break jb}p[114610]=0;c=J(653,d+224|0,d+112|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break ib}p[114610]=0;K(627,a|0,c|0);e=p[114610];p[114610]=0;if((e|0)==1){break hb}pb(c);pb(d+112|0);yb(d+208|0);break bb}f=I()|0;H()|0;break j}f=I()|0;H()|0;break fb}f=I()|0;H()|0;break gb}f=I()|0;H()|0;pb(c)}pb(d+112|0)}yb(d+208|0);break j}c=Rb(t,r[d+156>>1]);p[114610]=0;K(659,c|0,z|0);c=p[114610];p[114610]=0;if((c|0)!=1){break cb}}f=I()|0;H()|0;break j}p[114610]=0;c=M(357,b|0)|0;e=p[114610];p[114610]=0;kb:{lb:{if((e|0)!=1){p[114610]=0;u=M(357,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break lb}p[114610]=0;e=J(338,b|0,4)|0;f=p[114610];p[114610]=0;if((f|0)==1){break lb}if(!e){break cb}p[114610]=0;e=P(402,t|0,r[d+156>>1],u|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break lb}if(e){break kb}break cb}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}p[114610]=0;N(341,d+224|0,b|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){c=Rb(t,r[d+156>>1]);p[114610]=0;K(659,c|0,z|0);c=p[114610];p[114610]=0;mb:{if((c|0)!=1){c=r[a+480188>>1];p[114610]=0;h=J(654,d+208|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){c=r[a+480188>>1];ch(d+176|0);p[114610]=0;j=P(660,d+192|0,c|0,d+176|0)|0;c=p[114610];p[114610]=0;nb:{if((c|0)!=1){C=d,D=Ub(Rb(t,r[d+156>>1])),p[C+144>>2]=D;l=0;ob:{if(!u){break ob}while(1){p[114610]=0;c=J(258,d+224|0,1)|0;e=p[114610];p[114610]=0;pb:{if((e|0)!=1){qb:{if(!c){break ob}p[114610]=0;c=M(387,d+224|0)|0;e=p[114610];p[114610]=0;rb:{if((e|0)!=1){c=c<<24>>24;if(c){break rb}HQ(d+144|0,r[a+480188>>1]);l=l+1|0;break pb}break qb}sb:{e=c&127;i=e?e+ -1&65535:0;if(i>>>0<Cc(h)>>>0){break sb}p[114610]=0;n[d+176|0]=0;e=i+1|0;N(655,h|0,e|0,d+176|0);f=p[114610];p[114610]=0;if((f|0)==1){break qb}ch(d+176|0);p[114610]=0;N(661,j|0,e|0,d+176|0);e=p[114610];p[114610]=0;if((e|0)!=1){break sb}break qb}if((c|0)<=-1){p[114610]=0;c=M(387,d+224|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break qb}C=oc(h,i),D=c,n[C|0]=D}ch(d+176|0);e=d+176|0;if(i>>>0<r[a+480188>>1]){e=Fc(d+144|0,i)}if(q[oc(h,i)|0]&16){C=e,D=q[Fc(j,i)|0],n[C|0]=D}if(q[oc(h,i)|0]&32){C=e,D=q[Fc(j,i)+1|0],n[C+1|0]=D}if(q[oc(h,i)|0]&64){C=e,D=q[Fc(j,i)+2|0],n[C+2|0]=D;C=e,D=q[Fc(j,i)+4|0],n[C+4|0]=D}if(n[oc(h,i)|0]<=-1){C=e,D=q[Fc(j,i)+3|0],n[C+3|0]=D;C=e,D=q[Fc(j,i)+5|0],n[C+5|0]=D}if(n[oc(h,i)|0]&1){p[114610]=0;c=M(387,d+224|0)|0;f=p[114610];p[114610]=0;A=e;tb:{ub:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(p[a+480180>>2]&16777216)){break ub}f=c;break tb}break qb}f=253;if((c+ -121&255)>>>0<132){break tb}f=(c&255)==253?0:c}n[A|0]=f;C=Fc(j,i),D=f,n[C|0]=D}if(q[oc(h,i)|0]&2){p[114610]=0;c=M(387,d+224|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break qb}n[e+1|0]=c;C=Fc(j,i),D=c,n[C+1|0]=D}if(q[oc(h,i)|0]&4){p[114610]=0;c=M(387,d+224|0)|0;f=p[114610];p[114610]=0;vb:{wb:{if((f|0)!=1){if(c>>>0>64){break wb}n[e+4|0]=c;n[e+2|0]=1;break vb}break qb}if(!(c<<24>>24>-1|c>>>0>192)){n[e+2|0]=2;n[e+4|0]=c^128;break vb}if(c>>>0<=74){n[e+2|0]=5;n[e+4|0]=c+ -65;break vb}if(c>>>0<=84){n[e+2|0]=6;n[e+4|0]=c+ -75;break vb}if(c>>>0<=94){n[e+2|0]=3;n[e+4|0]=c+ -85;break vb}if(c>>>0<=104){n[e+2|0]=4;n[e+4|0]=c+ -95;break vb}if(c>>>0<=114){n[e+2|0]=13;n[e+4|0]=c+ -105;break vb}if(c>>>0<=124){n[e+2|0]=12;n[e+4|0]=c+ -115;break vb}f=c+63|0;if((f&255)>>>0<=9){n[e+4|0]=f;n[e+2|0]=11;break vb}f=c+53|0;g=f&255;if(g>>>0<=9){n[e+4|0]=f;n[e+2|0]=8;if(!g|!p[a+1074304>>2]|s[a+1074304>>2]>18285140){break vb}n[e+2|0]=7;break vb}c=c+33|0;if((c&255)>>>0>9){break vb}n[e+4|0]=c;n[e+2|0]=15}c=q[e+2|0];C=Fc(j,i),D=c,n[C+2|0]=D;c=q[e+4|0];C=Fc(j,i),D=c,n[C+4|0]=D}if(!(q[oc(h,i)|0]&8)){break pb}p[114610]=0;K(472,d+104|0,d+224|0);c=p[114610];p[114610]=0;if((c|0)!=1){xb:{c=Zc(d+104|0);n[e+3|0]=q[d+104|0];n[e+5|0]=q[c|0];p[114610]=0;K(662,e|0,1);c=p[114610];p[114610]=0;if((c|0)==1){break xb}c=q[e+3|0];C=Fc(j,i),D=c,n[C+3|0]=D;c=q[e+5|0];C=Fc(j,i),D=c,n[C+5|0]=D;break pb}}}}f=I()|0;H()|0;wl(j);break nb}if(l>>>0<u>>>0){continue}break}}wl(j);Xd(h);sb(d+224|0);break cb}f=I()|0;H()|0}Xd(h);break mb}f=I()|0;H()|0;break mb}f=I()|0;H()|0}sb(d+224|0);break j}f=I()|0;H()|0;break j}f=r[d+156>>1]+1|0;o[d+156>>1]=f;if((f&65535)>>>0<r[d+188>>1]){continue}break}}c=a+1074304|0;yb:{zb:{if(!p[a+1074304>>2]){Ab:{if((q[d+456|0]|q[d+457|0]<<8)==2184){p[c>>2]=18284544;f=18284544;break Ab}f=p[c>>2]}if(!f){break zb}}if(!Pc(k)){break zb}p[114610]=0;e=J(2,d+208|0,14078)|0;f=p[114610];p[114610]=0;Bb:{Cb:{Db:{Eb:{Fb:{Gb:{if((f|0)!=1){p[114610]=0;K(242,d+192|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break Gb}p[114610]=0;N(3,d+224|0,e|0,d+192|0);f=p[114610];p[114610]=0;if((f|0)==1){break Fb}xb(k,d+224|0);pb(d+224|0);pb(d+192|0);pb(e);if(p[d+476>>2]==1414548815|((q[d+456|0]|q[d+457|0]<<8)&61440)!=20480){break Bb}p[114610]=0;c=J(2,d+224|0,14087)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Db}p[114610]=0;J(192,k|0,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Cb}pb(c);break yb}f=I()|0;H()|0;break j}f=I()|0;H()|0;break Eb}f=I()|0;H()|0;pb(d+192|0)}pb(e);break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;pb(c);break j}if(!KB(c)){break yb}p[114610]=0;c=J(2,d+224|0,14111)|0;e=p[114610];p[114610]=0;Hb:{if((e|0)!=1){p[114610]=0;J(192,k|0,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Hb}pb(c);break yb}f=I()|0;H()|0;break j}f=I()|0;H()|0;pb(c);break j}Ib:{switch((q[d+456|0]|q[d+457|0]<<8)>>>12|0){case 0:if(B){p[114610]=0;c=J(2,d+224|0,14125)|0;e=p[114610];p[114610]=0;if((e|0)!=1){xb(k,c);pb(c);break yb}f=I()|0;H()|0;break j}Jb:{if((q[d+456|0]|q[d+457|0]<<8)!=532|(q[d+458|0]|q[d+459|0]<<8)!=512|(q[d+462|0]|q[d+463|0]<<8|(q[d+460|0]|q[d+461|0]<<8)!=9)){break Jb}if(q[d+447|0]|q[d+446|0]|(q[d+450|0]|q[d+451|0]<<8|((q[d+454|0]|q[d+455|0]<<8)+1|0)!=(q[d+448|0]|q[d+449|0]<<8))){break Jb}if(q[d+464|0]!=128|q[d+465|0]!=100|(q[d+466|0]!=1|q[d+468|0]!=128)){break Jb}if(q[d+469|0]|(q[d+470|0]|q[d+471|0]<<8)|(q[d+472|0]|q[d+473|0]<<8|(q[d+474|0]<<16|q[d+475|0]<<24)|(q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24)))){break Jb}p[114610]=0;c=J(2,d+224|0,14137)|0;e=p[114610];p[114610]=0;if((e|0)!=1){xb(k,c);pb(c);break yb}f=I()|0;H()|0;break j}Kb:{if((q[d+456|0]|q[d+457|0]<<8)!=532|(q[d+458|0]|q[d+459|0]<<8)!=512|(q[d+447|0]|q[d+446|0])){break Kb}if(q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24)){break Kb}p[c>>2]=16777381;p[114610]=0;c=J(2,d+224|0,14156)|0;e=p[114610];p[114610]=0;if((e|0)!=1){xb(k,c);pb(c);n[d+415|0]=1;break yb}f=I()|0;H()|0;break j}if(!((q[d+456|0]|q[d+457|0]<<8)!=532|(q[d+458|0]|q[d+459|0]<<8)!=532|p[d+476>>2]!=1229080643)){p[114610]=0;c=J(2,d+224|0,14179)|0;e=p[114610];p[114610]=0;if((e|0)!=1){xb(k,c);pb(c);p[114610]=0;J(479,a+1074308|0,38)|0;c=p[114610];p[114610]=0;if((c|0)==1){break s}break yb}f=I()|0;H()|0;break j}Lb:{if((q[d+456|0]|q[d+457|0]<<8)!=532|(q[d+458|0]|q[d+459|0]<<8)!=532|(q[d+469|0]|(q[d+462|0]|q[d+463|0]<<8)>>>0>1)){break Lb}if(!r[a+480190>>1]|(q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24)|((q[d+460|0]|q[d+461|0]<<8)&4294)!=4)){break Lb}p[114610]=0;c=J(85,d+224|0,14192)|0;e=p[114610];p[114610]=0;Mb:{Nb:{if((e|0)!=1){p[114610]=0;e=J(663,a+484527|0,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Nb}pb(c);if(!e){break Lb}p[114610]=0;c=J(2,d+224|0,14205)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Mb}xb(k,c);pb(c);break yb}f=I()|0;H()|0;break j}f=I()|0;H()|0;pb(c);break j}f=I()|0;H()|0;break j}Ob:{if(q[d+456|0]|q[d+457|0]<<8){break Ob}if(!Pc(k)){break Ob}p[114610]=0;c=J(2,d+224|0,14219)|0;e=p[114610];p[114610]=0;if((e|0)!=1){xb(k,c);pb(c);break yb}f=I()|0;H()|0;break j}if((q[d+458|0]|q[d+459|0]<<8)>>>0>767){break yb}if(!Pc(k)){break yb}Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if((q[d+458|0]|q[d+459|0]<<8)>>>0>=533){p[114610]=0;c=J(2,d+224|0,14227)|0;e=p[114610];p[114610]=0;if((e|0)!=1){xb(k,c);break Vb}f=I()|0;H()|0;break j}if((q[d+456|0]|q[d+457|0]<<8)>>>0>=533){p[114610]=0;c=J(2,d+88|0,14248)|0;e=p[114610];p[114610]=0;Wb:{Xb:{Yb:{if((e|0)!=1){p[114610]=0;K(219,d+208|0,c|0);e=p[114610];p[114610]=0;if((e|0)==1){break Yb}e=q[d+456|0]|q[d+457|0]<<8;p[114610]=0;p[d+192>>2]=e+ -532;N(245,d+224|0,d+208|0,d+192|0);e=p[114610];p[114610]=0;if((e|0)==1){break Xb}xb(k,d+224|0);pb(d+224|0);yb(d+208|0);break Vb}f=I()|0;H()|0;break j}f=I()|0;H()|0;break Wb}f=I()|0;H()|0;yb(d+208|0)}pb(c);break j}p[114610]=0;c=J(2,d+72|0,14272)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Ub}p[114610]=0;K(219,d+208|0,c|0);e=p[114610];p[114610]=0;if((e|0)==1){break Tb}p[d+176>>2]=q[d+457|0]&15;e=q[d+456|0];p[114610]=0;p[d+144>>2]=e;K(664,d+192|0,d+144|0);e=p[114610];p[114610]=0;if((e|0)==1){break Sb}p[114610]=0;Q(649,d+224|0,d+208|0,d+176|0,d+192|0);e=p[114610];p[114610]=0;if((e|0)==1){break Rb}xb(k,d+224|0);pb(d+224|0);pb(d+192|0);yb(d+208|0)}pb(c);c=a+1304500|0;if(!cd(c)|!(q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24))){break yb}e=q[d+456|0]|q[d+457|0]<<8;f=q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24);p[114610]=0;e=J(665,e|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break w}f=wp(d+224|0);p[f+44>>2]=e;p[114610]=0;K(666,c|0,f|0);c=p[114610];p[114610]=0;if((c|0)!=1){break yb}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break Pb}f=I()|0;H()|0;break Qb}f=I()|0;H()|0;pb(d+192|0)}yb(d+208|0)}pb(c);break j;case 1:c=q[d+456|0]|q[d+457|0]<<8;e=q[d+476|0]|q[d+477|0]<<8|(q[d+478|0]<<16|q[d+479|0]<<24);p[114610]=0;N(667,d+224|0,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break v}xb(k,d+224|0);pb(d+224|0);if(6092>(q[d+456|0]|q[d+457|0]<<8)){p[114610]=0;J(479,a+1074308|0,7)|0;c=p[114610];p[114610]=0;if((c|0)==1){break s}}if(6562<=(q[d+456|0]|q[d+457|0]<<8)){break yb}p[114610]=0;J(479,a+1074308|0,38)|0;c=p[114610];p[114610]=0;if((c|0)==1){break s}break yb;case 4:p[114610]=0;c=J(2,d+56|0,14294)|0;e=p[114610];p[114610]=0;Zb:{_b:{$b:{ac:{bc:{if((e|0)!=1){p[114610]=0;K(219,d+208|0,c|0);e=p[114610];p[114610]=0;if((e|0)==1){break bc}p[d+176>>2]=q[d+457|0]&15;e=q[d+456|0];p[114610]=0;p[d+144>>2]=e;K(664,d+192|0,d+144|0);e=p[114610];p[114610]=0;if((e|0)==1){break ac}p[114610]=0;Q(649,d+224|0,d+208|0,d+176|0,d+192|0);e=p[114610];p[114610]=0;if((e|0)==1){break $b}xb(k,d+224|0);pb(d+224|0);pb(d+192|0);yb(d+208|0);pb(c);break yb}f=I()|0;H()|0;break j}f=I()|0;H()|0;break Zb}f=I()|0;H()|0;break _b}f=I()|0;H()|0;pb(d+192|0)}yb(d+208|0)}pb(c);break j;case 6:p[114610]=0;c=J(2,d+224|0,14125)|0;e=p[114610];p[114610]=0;if((e|0)!=1){xb(k,c);pb(c);break yb}f=I()|0;H()|0;break j;case 7:if(!((q[d+456|0]|q[d+457|0]<<8)!=32767|(q[d+458|0]|q[d+459|0]<<8)!=533)){p[114610]=0;c=J(2,d+224|0,14305)|0;e=p[114610];p[114610]=0;if((e|0)!=1){xb(k,c);pb(c);break yb}f=I()|0;H()|0;break j}p[114610]=0;c=J(2,d+40|0,14314)|0;e=p[114610];p[114610]=0;cc:{dc:{ec:{if((e|0)!=1){p[114610]=0;K(219,d+208|0,c|0);e=p[114610];p[114610]=0;if((e|0)==1){break ec}p[d+192>>2]=q[d+457|0]&15;p[d+176>>2]=(q[d+456|0]|q[d+457|0]<<8)>>>4&15;e=q[d+456|0]|q[d+457|0]<<8;p[114610]=0;p[d+144>>2]=e&15;_(239,d+224|0,d+208|0,d+192|0,d+176|0,d+144|0);e=p[114610];p[114610]=0;if((e|0)==1){break dc}xb(k,d+224|0);pb(d+224|0);yb(d+208|0);pb(c);break yb}f=I()|0;H()|0;break j}f=I()|0;H()|0;break cc}f=I()|0;H()|0;yb(d+208|0)}pb(c);break j;case 13:break Ib;default:break yb}}p[114610]=0;c=J(2,d+224|0,14329)|0;e=p[114610];p[114610]=0;if((e|0)==1){break u}xb(k,c);pb(c)}fc:{if(p[a+480180>>2]!=16777216|(q[d+456|0]|q[d+457|0]<<8)>>>0<2186){break fc}p[114610]=0;c=J(256,b|0,y|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break s}if(!c){break fc}c=q[d+456|0]|q[d+457|0]<<8;p[114610]=0;N(668,a|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break s}}c=p[a+480180>>2];gc:{if((c|0)==16777216){p[114610]=0;J(2,d+224|0,14336)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break gc}f=I()|0;H()|0;break j}p[114610]=0;b=J(2,d+24|0,14272)|0;e=p[114610];p[114610]=0;if((e|0)==1){break C}p[114610]=0;K(219,d+208|0,b|0);e=p[114610];p[114610]=0;if((e|0)==1){break B}p[d+176>>2]=q[d+459|0];e=q[d+458|0];p[114610]=0;p[d+144>>2]=e;K(664,d+192|0,d+144|0);e=p[114610];p[114610]=0;if((e|0)==1){break A}p[114610]=0;Q(649,d+224|0,d+208|0,d+176|0,d+192|0);e=p[114610];p[114610]=0;if((e|0)==1){break z}}xb(a+1304436|0,d+224|0);pb(d+224|0);if((c|0)!=16777216){pb(d+192|0);yb(d+208|0);pb(d+24|0)}hc:{if(p[a+480180>>2]==16777216){p[114610]=0;J(2,d+224|0,14349)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break hc}break t}p[114610]=0;J(2,d+224|0,14354)|0;b=p[114610];p[114610]=0;if((b|0)==1){break t}}xb(a+1304448|0,d+224|0);pb(d+224|0);xb(a+1304460|0,k);p[a+1304496>>2]=p[a+1074304>>2]?7:4;sb(d+312|0);sb(z);f=1}qi(m);qi(w);qi(x);break d}f=I()|0;H()|0;break j}f=I()|0;H()|0;break x}f=I()|0;H()|0;break y}f=I()|0;H()|0;pb(d+192|0)}yb(d+208|0)}pb(b);break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;Xd(g);break p}f=I()|0;H()|0}sb(d+224|0);break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0;break j}f=I()|0;H()|0}sb(d+312|0)}sb(z);break g}f=I()|0;H()|0}qi(m);qi(w);qi(x);break a}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}pb(k)}fb=d+608|0;return f|0}f=I()|0;H()|0}pb(k);L(f|0);E()}function sDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,R=0,T=0,V=0,W=0,X=0,Y=0;e=fb-1600|0;fb=e;Ac(b);a:{b:{if(!bf(b,e+1592|0)){break b}if(!iP(e+1592|0)){break b}if(!c){f=1;break b}n[e+1591|0]=q[e+1592|3];d=e+1592|4;g=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=-1;if(q[e+1591|0]>=5){d=Lf(b);if(!Hb(b,d)){break b}}F=pz(e+1576|0,g);h=p[F>>2];p[114610]=0;g=P(835,b|0,h|0,g|0)|0;h=p[114610];p[114610]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{if((h|0)==1){break L}if(!g){break G}if(q[e+1591|0]>=5){p[114610]=0;J(256,b|0,d+12|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break L}}p[114610]=0;K(447,a|0,0);d=p[114610];p[114610]=0;if((d|0)==1){break L}p[114610]=0;S(476,a|0);d=p[114610];p[114610]=0;if((d|0)==1){break L}p[114610]=0;K(836,e+1552|0,F|0);g=p[114610];p[114610]=0;d=a;M:{N:{O:{P:{Q:{if((g|0)==1){break Q}p[114610]=0;k=P(837,e+1560|0,e+1552|0,0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break Q}p[114610]=0;P(600,k|0,a+1304400|0,-1)|0;g=p[114610];p[114610]=0;if((g|0)==1){break P}p[114610]=0;P(600,k|0,a+1304424|0,-1)|0;g=p[114610];p[114610]=0;if((g|0)==1){break P}p[114610]=0;g=J(838,k|0,e+1128|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break M}if(!g|!q[e+1128|0]|n[e+1128|0]<0){break H}g=e+1137|0;if((q[g|0]|q[g+1|0]<<8)>>>0>255){break H}h=e+1139|0;if((q[h|0]|q[h+1|0]<<8)>>>0>3999){break H}o[a+480188>>1]=q[e+1128|0];u=a+484360|0;i=e+1128|3;Pe(Ob(u),q[i|0]|q[i+1|0]<<8);o[a+480192>>1]=q[g|0]|q[g+1|0]<<8;o[a+480190>>1]=q[h|0]|q[h+1|0]<<8;g=e+1141|0;if(q[g|0]){break O}g=6;break N}d=I()|0;H()|0;break c}d=I()|0;H()|0;break d}g=q[g|0]}p[d+480196>>2]=g;d=a;h=e+1142|0;g=125;R:{if(!q[h|0]){break R}g=q[h|0]}p[d+480204>>2]=v(g,1e4);C=Xc(e+1112|0);G=Xc(e+1096|0);w=e+1143|0;if(n[w+1|0]&1){p[114610]=0;K(624,a|0,32);d=p[114610];p[114610]=0;if((d|0)==1){break J}p[114610]=0;d=J(2,e+192|0,15162)|0;g=p[114610];p[114610]=0;S:{if((g|0)!=1){xb(C,d);pb(d);p[114610]=0;g=J(2,e+192|0,15165)|0;d=p[114610];p[114610]=0;if((d|0)==1){break S}break K}d=I()|0;H()|0;break e}d=I()|0;H()|0;break e}if(q[w|0]&2){p[114610]=0;K(624,a|0,2);d=p[114610];p[114610]=0;if((d|0)==1){break J}p[114610]=0;d=J(2,e+192|0,15181)|0;g=p[114610];p[114610]=0;T:{if((g|0)!=1){xb(C,d);pb(d);p[114610]=0;g=J(2,e+192|0,15185)|0;d=p[114610];p[114610]=0;if((d|0)==1){break T}break K}d=I()|0;H()|0;break e}d=I()|0;H()|0;break e}if(q[w|0]&128){p[114610]=0;K(624,a|0,1);d=p[114610];p[114610]=0;if((d|0)==1){break J}p[114610]=0;d=J(2,e+192|0,15201)|0;g=p[114610];p[114610]=0;U:{if((g|0)!=1){xb(C,d);pb(d);p[114610]=0;g=J(2,e+192|0,15205)|0;d=p[114610];p[114610]=0;if((d|0)==1){break U}break K}d=I()|0;H()|0;break e}d=I()|0;H()|0;break e}if(q[w|0]&8){p[114610]=0;K(624,a|0,16);d=p[114610];p[114610]=0;if((d|0)==1){break J}p[114610]=0;d=J(2,e+192|0,15217)|0;g=p[114610];p[114610]=0;V:{if((g|0)!=1){xb(C,d);pb(d);p[114610]=0;g=J(2,e+192|0,15221)|0;d=p[114610];p[114610]=0;if((d|0)==1){break V}break K}d=I()|0;H()|0;break e}d=I()|0;H()|0;break e}p[114610]=0;K(624,a|0,4);d=p[114610];p[114610]=0;if((d|0)==1){break J}p[114610]=0;d=J(2,e+192|0,15234)|0;g=p[114610];p[114610]=0;W:{if((g|0)!=1){xb(C,d);pb(d);p[114610]=0;g=J(2,e+192|0,15237)|0;d=p[114610];p[114610]=0;if((d|0)==1){break W}break K}d=I()|0;H()|0;break e}d=I()|0;H()|0;break e}d=I()|0;H()|0;break d}d=I()|0;H()|0;break c}xb(G,g);pb(g);if(n[w|0]&1){p[a+480208>>2]=p[a+480208>>2]|16}if(!(!(q[w|0]&16)|p[a+480180>>2]!=2)){p[a+480208>>2]=p[a+480208>>2]|65536}if(!(!(q[w|0]&4)|p[a+480180>>2]!=2)){p[a+480208>>2]=p[a+480208>>2]|2}if(!(q[w+1|0]&8|p[a+480180>>2]!=32)){p[a+480208>>2]=p[a+480208>>2]|4}if(!(q[w+1|0]&4|p[a+480180>>2]!=32)){p[a+480208>>2]=p[a+480208>>2]|8}if(q[w+2|0]&32){p[a+480208>>2]=p[a+480208>>2]|32768}if(!(q[w+2|0]&8)){break I}p[114610]=0;P(478,a+1074308|0,5,1)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break I}}d=I()|0;H()|0;break e}d=p[a+480180>>2];X:{if((d|0)!=2){if((d|0)!=32){break X}d=q[e+1147|0];p[114610]=0;n[e+192|0]=d;n[e+120|0]=128;d=J(391,e+192|0,e+120|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){p[a+480200>>2]=q[d|0]<<1;break X}d=I()|0;H()|0;break e}d=q[e+1147|0];p[114610]=0;n[e+192|0]=d;n[e+120|0]=64;d=J(391,e+192|0,e+120|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break t}p[a+480200>>2]=q[d|0]<<2}V=a+480188|0;h=e+1149|0;g=n[h|0];d=a;if(n[h|0]<=-1){g=g+52|0}else{T=Gv(+(g|0)*.15500000000000003);Y:{if(T<4294967296&T>=0){g=~~T>>>0;break Y}g=0}g=g+51|0}p[d+480228>>2]=g;p[114610]=0;o[e+192>>1]=64;d=J(477,V|0,e+192|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break u}g=r[d>>1];if(g){while(1){d=p[a+480180>>2];if((d|0)==32){d=q[(e+f|0)+1150|0];p[114610]=0;n[e+192|0]=d;n[e+120|0]=64;d=J(391,e+192|0,e+120|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break v}o[((f<<5)+a|0)+480286>>1]=q[d|0];d=p[a+480180>>2]}Z:{if((d|0)==4){break Z}d=(e+f|0)+1214|0;if(q[d|0]==127){p[((f<<5)+a|0)+480280>>2]=256;break Z}if(q[d|0]==255){o[((f<<5)+a|0)+480284>>1]=256;break Z}o[((f<<5)+a|0)+480284>>1]=q[d|0]}f=f+1|0;if((g|0)!=(f|0)){continue}break}}d=0;f=0;i=0;while(1){f=q[(e+i|0)+1278|0]!=0|f;i=i+1|0;if((i|0)!=16){continue}break}while(1){f=q[((d<<1)+e|0)+1295|0]!=0|f;d=d+1|0;if((d|0)!=128){continue}break}if(f&1){f=0;while(1){_:{d=(e+f|0)+1278|0;if(q[d|0]){p[114610]=0;K(509,e+120|0,15251);g=p[114610];p[114610]=0;$:{aa:{ba:{ca:{da:{if((g|0)!=1){d=q[d|0];p[114610]=0;p[e+144>>2]=d+ -1;K(839,e+1080|0,e+144|0);d=p[114610];p[114610]=0;if((d|0)==1){break da}p[114610]=0;N(511,e+192|0,e+120|0,e+1080|0);d=p[114610];p[114610]=0;if((d|0)==1){break ca}p[114610]=0;K(512,e+1064|0,((f<<5)+a|0)+901692|0);d=p[114610];p[114610]=0;if((d|0)==1){break ba}p[114610]=0;J(470,e+1064|0,e+192|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ba}pb(e+192|0);pb(e+1080|0);yb(e+120|0);break _}d=I()|0;H()|0;break e}d=I()|0;H()|0;break $}d=I()|0;H()|0;break aa}d=I()|0;H()|0;pb(e+192|0)}pb(e+1080|0)}yb(e+120|0);break e}p[114610]=0;g=J(85,e+192|0,15259)|0;d=p[114610];p[114610]=0;ea:{if((d|0)!=1){p[114610]=0;K(512,e+120|0,((f<<5)+a|0)+901692|0);d=p[114610];p[114610]=0;if((d|0)==1){break ea}p[114610]=0;J(470,e+120|0,g|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ea}pb(g);break _}d=I()|0;H()|0;break e}d=I()|0;H()|0;pb(g);break e}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){d=(e+1128|0)+(f<<1)|0;g=d;fa:{if(q[d+167|0]){p[114610]=0;K(509,e+120|0,15260);h=p[114610];p[114610]=0;ga:{ha:{ia:{ja:{ka:{la:{ma:{if((h|0)!=1){g=q[g+167|0];p[114610]=0;p[e+96>>2]=g+ -1;K(839,e+1080|0,e+96|0);g=p[114610];p[114610]=0;if((g|0)==1){break ma}d=q[d+166|0];p[114610]=0;n[e+1048|0]=d;K(840,e+1064|0,e+1048|0);d=p[114610];p[114610]=0;if((d|0)==1){break la}p[114610]=0;Q(841,e+192|0,e+120|0,e+1080|0,e+1064|0);d=p[114610];p[114610]=0;if((d|0)==1){break ka}p[114610]=0;K(512,e+144|0,((f<<5)+a|0)+902204|0);d=p[114610];p[114610]=0;if((d|0)==1){break ja}p[114610]=0;J(470,e+144|0,e+192|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ja}pb(e+192|0);pb(e+1064|0);pb(e+1080|0);yb(e+120|0);break fa}d=I()|0;H()|0;break e}d=I()|0;H()|0;break ga}d=I()|0;H()|0;break ha}d=I()|0;H()|0;break ia}d=I()|0;H()|0;pb(e+192|0)}pb(e+1064|0)}pb(e+1080|0)}yb(e+120|0);break e}p[114610]=0;g=J(85,e+192|0,15259)|0;d=p[114610];p[114610]=0;na:{if((d|0)!=1){p[114610]=0;K(512,e+120|0,((f<<5)+a|0)+902204|0);d=p[114610];p[114610]=0;if((d|0)==1){break na}p[114610]=0;J(470,e+120|0,g|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break na}pb(g);break fa}d=I()|0;H()|0;break e}d=I()|0;H()|0;pb(g);break e}f=f+1|0;if((f|0)!=128){continue}break}}d=Ob(u);g=e+1128|1;g=q[g|0]|q[g+1|0]<<8;p[114610]=0;Z(584,d|0,k|0,g|0,255,254)|0;d=p[114610];p[114610]=0;oa:{pa:{qa:{ra:{sa:{ta:{if((d|0)!=1){g=e+1128|5;d=q[g|0]|q[g+1|0]<<8;h=q[e+1128|0];p[114610]=0;N(341,e+1080|0,k|0,v(d,h)<<1);d=p[114610];p[114610]=0;if((d|0)==1){break ta}d=q[g|0]|q[g+1|0]<<8;p[114610]=0;N(341,e+1064|0,k|0,d<<1);d=p[114610];p[114610]=0;if((d|0)==1){break sa}d=e+1128|7;d=q[d|0]|q[d+1|0]<<8;p[114610]=0;D=J(395,e+1048|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ra}X=e,Y=Ub(D),p[X+120>>2]=Y;X=e,Y=Vb(D),p[X+144>>2]=Y;if(Ab(e+120|0,e+144|0)){while(1){d=p[e+120>>2];p[114610]=0;h=M(390,k|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break qa}p[114610]=0;N(341,e+192|0,k|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break pa}Nd(d,e+192|0);sb(e+192|0);Ff(e+120|0);if(Ab(e+120|0,e+144|0)){continue}break}}d=p[a+480180>>2];m=1;l=c&1;if(!l){break oa}h=q[g|0]|q[g+1|0]<<8;p[114610]=0;K(401,a+484344|0,h|0);h=p[114610];p[114610]=0;if((h|0)!=1){break oa}d=I()|0;H()|0;break h}d=I()|0;H()|0;break e}d=I()|0;H()|0;break e}d=I()|0;H()|0;break f}d=I()|0;H()|0;break g}d=I()|0;H()|0;break h}d=I()|0;H()|0;break h}ua:{va:{wa:{xa:{if(q[g|0]|q[g+1|0]<<8){x=(d|0)==16?14:(d|0)==32?1:13;y=a+484344|0;while(1){p[114610]=0;d=M(357,e+1064|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break w}p[e+120>>2]=d;ya:{if(!l){break ya}p[114610]=0;d=P(402,y|0,j&65535,d|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break w}if(!d){break ya}u=0;if(!q[e+1128|0]){break ya}while(1){p[114610]=0;d=M(357,e+1080|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break x}za:{if(gd(D)>>>0<=d>>>0){break za}A=jc(D,d);Ac(A);d=Rb(y,j);p[114610]=0;f=P(471,d|0,0,u&65535)|0;d=p[114610];p[114610]=0;if((d|0)==1){break i}h=0;if(!p[e+120>>2]){break za}while(1){p[114610]=0;z=M(387,A|0)|0;d=p[114610];p[114610]=0;Aa:{Ba:{if((d|0)!=1){if(!z){break za}ch(e+192|0);i=0;B=z&15;if(B){break Ba}break Aa}d=I()|0;H()|0;break h}while(1){Ca:{p[114610]=0;J(842,A|0,e+144|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break Ca}Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{d=q[e+144|0];switch(d+ -1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break Fa;case 33:break Ja;case 30:case 31:break Ka;case 29:break La;case 28:break Ma;case 26:break Na;case 19:case 20:break Oa;case 17:break Pa;case 15:break Qa;case 14:break Ra;case 10:break Sa;case 6:break Ta;case 5:break Ua;case 1:break Va;case 0:break Wa;default:break Xa}}switch(d+ -48|0){case 4:break Ga;case 1:case 2:break Ha;case 0:break Ia;default:break Fa}}d=q[e+145|0];n[e+192|0]=d;Ya:{if(d>>>0<=119){n[e+192|0]=d+x;break Ya}Za:{switch(d+ -254|0){case 1:n[e+192|0]=255;break Ya;case 0:n[e+192|0]=254;break Ya;default:break Za}}n[e+192|0]=253}p[114610]=0;d=M(614,e+192|0)|0;t=p[114610];p[114610]=0;if((t|0)==1){break Ca}m=d&m;break Da}n[e+193|0]=q[e+145|0]+1;break Da}_a:{if(q[e+194|0]){break _a}d=p[a+480180>>2];if((d|0)!=32){if((d|0)!=4){break _a}d=q[e+145|0];if(d&15){break _a}n[e+194|0]=11;n[e+196|0]=d>>>4;break Da}d=0;t=q[e+145|0];while(1){if((t|0)==q[d+20768|0]){n[e+196|0]=d;n[e+194|0]=11;break Da}d=d+1|0;if((d|0)!=10){continue}break}}n[e+195|0]=4;n[e+197|0]=q[e+145|0];break Da}d=q[e+145|0];if(!(q[e+194|0]|d>>>0>9|p[a+480180>>2]!=32)){n[e+196|0]=d;n[e+194|0]=8;break Da}n[e+197|0]=d;n[e+195|0]=5;break Da}$a:{if(q[e+194|0]){break $a}ab:{d=p[a+480180>>2];if((d|0)!=4){if((d|0)!=32){break $a}d=q[e+145|0];if((d|0)!=255){break ab}n[e+196|0]=64;n[e+194|0]=2;break Da}d=q[e+145|0];if(d&15){break $a}break Ea}if(!(d&3)){break Ea}}n[e+195|0]=9;n[e+197|0]=q[e+145|0];break Da}d=q[e+145|0];if(!(q[e+194|0]|d>>>0>64|p[a+480180>>2]==1)){n[e+196|0]=d;n[e+194|0]=1;break Da}n[e+197|0]=d;n[e+195|0]=13;break Da}n[e+195|0]=14;d=q[e+145|0];n[e+197|0]=d;if(p[a+480180>>2]==32){break Da}n[e+197|0]=v((d&240)>>>4|0,10)+(d&15);break Da}d=q[e+145|0];n[e+197|0]=d;if(d>>>0<=31){n[e+195|0]=16;break Da}n[e+195|0]=17;break Da}t=q[e+145|0];if(t>>>0>=16){n[e+196|0]=t>>>4;n[e+194|0]=(d|0)==20?3:5;break Da}n[e+196|0]=t;n[e+194|0]=(d|0)==20?4:6;break Da}d=q[e+145|0];if(d>>>0>=16){n[e+194|0]=10;n[e+196|0]=d>>>4;break Da}n[e+196|0]=d;n[e+194|0]=9;break Da}n[e+195|0]=28;n[e+197|0]=q[e+145|0]|16;break Da}n[e+195|0]=28;n[e+197|0]=q[e+145|0]|32;break Da}n[e+196|0]=q[e+145|0];n[e+194|0]=q[d+15280|0];break Da}n[e+197|0]=q[e+145|0];d=q[e+195|0];n[e+195|0]=(d|0)==4?6:(d|0)==5?7:11;break Da}d=q[e+145|0];n[e+196|0]=(d>>>0)%10;if(d>>>0<=9){n[e+194|0]=5;break Da}if(d>>>0<=19){n[e+194|0]=6;break Da}if(d>>>0<=29){n[e+194|0]=3;break Da}if(d>>>0>39){break Da}n[e+194|0]=4;break Da}n[e+196|0]=q[e+145|0];n[e+194|0]=q[d+15280|0];break Da}d=q[e+145|0]+33|0;if((d&255)>>>0>9){break Da}n[e+196|0]=d;n[e+194|0]=15;break Da}if(d>>>0>55){break Da}n[e+197|0]=q[e+145|0];n[e+195|0]=q[d+15280|0];break Da}n[e+194|0]=2;n[e+196|0]=d>>>2}i=i+1|0;if((i&255)>>>0<B>>>0){continue}break Aa}break}d=I()|0;H()|0;break h}p[114610]=0;p[e+144>>2]=(z>>>4|0)+h;d=J(632,e+144|0,e+120|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break xa}d=p[d>>2];if(h>>>0<d>>>0){while(1){i=p[e+192>>2];n[f|0]=i;n[f+1|0]=i>>>8;n[f+2|0]=i>>>16;n[f+3|0]=i>>>24;i=r[e+196>>1];n[f+4|0]=i;n[f+5|0]=i>>>8;f=v(q[e+1128|0],6)+f|0;h=h+1|0;if((d|0)!=(h|0)){continue}break}h=d}if(h>>>0<s[e+120>>2]){continue}break}}u=u+1|0;if((u&65535)>>>0<q[e+1128|0]){continue}break}}j=j+1|0;if(j>>>0<(q[g|0]|q[g+1|0]<<8)>>>0){continue}break}}if(!((m^1)&1|r[a+480188>>1]!=4|p[a+480180>>2]!=1)){p[a+480208>>2]=p[a+480208>>2]|8454144}if(p[a+480180>>2]!=4){break wa}i=0;break va}d=I()|0;H()|0;break h}i=!((q[w|0]|q[w+1|0]<<8|(q[w+2|0]<<16|q[w+3|0]<<24))&512);d=0;if(p[a+480180>>2]!=4){break ua}}d=r[a+480192>>1]}p[114610]=0;z=J(843,e+1032|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break y}bb:{cb:{db:{if(r[a+480192>>1]){h=1;d=1;while(1){eb:{fb:{gb:{if(!i){p[114610]=0;f=P(454,a|0,d&65535,0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break gb}if(f){break fb}}while(1){p[114610]=0;g=M(387,k|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break k}if(g){continue}break}if(q[e+1591|0]>=5){while(1){p[114610]=0;g=M(387,k|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){d=I()|0;H()|0;break j}if(g){continue}break}}p[114610]=0;J(338,k|0,826)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break eb}}d=I()|0;H()|0;break j}g=Lb(e+120|0);p[114610]=0;P(600,k|0,g|0,-1)|0;j=p[114610];p[114610]=0;if((j|0)==1){break db}p[114610]=0;J(369,f+492|0,g|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break db}hb:{if(q[e+1591|0]<5){break hb}p[114610]=0;P(600,k|0,g|0,-1)|0;j=p[114610];p[114610]=0;if((j|0)==1){break db}p[114610]=0;J(369,f+524|0,g|0)|0;j=p[114610];p[114610]=0;if((j|0)!=1){break hb}break db}p[114610]=0;j=J(844,k|0,e+192|0)|0;u=p[114610];p[114610]=0;if((u|0)==1){break db}if(!j){break cb}j=p[a+480180>>2];p[114610]=0;N(845,e+192|0,f|0,j|0);f=p[114610];p[114610]=0;if((f|0)==1){break db}if(p[a+480180>>2]==4){h=Fb(z,h+ -1|0);f=r[e+994>>1]|r[e+996>>1]<<16;n[h|0]=f;n[h+1|0]=f>>>8;n[h+2|0]=f>>>16;n[h+3|0]=f>>>24}pb(g)}d=d+1|0;h=d&65535;if(h>>>0<=r[a+480192>>1]){continue}break}}if(!i){break bb}o[a+480192>>1]=0;break bb}d=I()|0;H()|0;pb(g);break j}pb(g)}d=r[a+480190>>1];p[114610]=0;A=J(846,e+176|0,d|0)|0;d=p[114610];p[114610]=0;u=1;ib:{jb:{if((d|0)!=1){u=q[e+1591|0]<=4?!(n[w|0]&1):u;if(r[a+480190>>1]){break jb}j=c&2;g=0;break ib}d=I()|0;H()|0;break j}j=c&2;i=1;d=0;h=1;while(1){g=d;y=Lb(e+160|0);p[114610]=0;P(600,k|0,y|0,-1)|0;c=p[114610];p[114610]=0;kb:{lb:{mb:{nb:{ob:{if((c|0)==1){break ob}p[114610]=0;J(369,((i<<5)+a|0)+946300|0,y|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ob}l=v(i,104);m=l+a|0;if(q[e+1591|0]<5){break nb}p[114610]=0;P(600,k|0,y|0,-1)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ob}p[114610]=0;J(370,m+484423|0,y|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break nb}}d=I()|0;H()|0;break mb}p[114610]=0;c=J(847,k|0,e+192|0)|0;d=p[114610];p[114610]=0;pb:{qb:{rb:{sb:{tb:{ub:{vb:{if((d|0)==1){break vb}if(!c){break ub}c=p[a+480180>>2];p[114610]=0;f=m+484380|0;Q(848,e+192|0,f|0,c|0,u|0);c=p[114610];p[114610]=0;if((c|0)==1){break vb}d=0;wb:{if(((q[e+212|0]|q[e+213|0]<<8)&61440)!=28672|q[e+1591|0]<5){break wb}p[114610]=0;d=M(849,k|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break wb}d=I()|0;H()|0;break mb}if(!j){break lb}B=q[e+212|0]|q[e+213|0]<<8;t=B&61440;if(!(t|(q[e+227|0]|q[e+228|0]<<8|(q[e+229|0]<<16|q[e+230|0]<<24)))){c=Tc(e+120|0,(q[e+212|0]|q[e+213|0]<<8)&1?16:8,(q[e+212|0]|q[e+213|0]<<8)&1024?3:1,0,0);p[114610]=0;P(400,c|0,f|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break lb}d=I()|0;H()|0;break mb}if(!(((q[e+227|0]|q[e+228|0]<<8|(q[e+229|0]<<16|q[e+230|0]<<24))+i|0)<1|(q[e+227|0]|q[e+228|0]<<8|(q[e+229|0]<<16|q[e+230|0]<<24))>-1)){d=a+484380|0;t=v((q[e+227|0]|q[e+228|0]<<8|(q[e+229|0]<<16|q[e+230|0]<<24))+i|0,104);c=d+t|0;vc(f,p[c>>2]);d=d+l|0;i=r[d+34>>1]&-2|o[c+34>>1]&1;o[d+34>>1]=i;o[d+34>>1]=r[c+34>>1]&64|i&65471;if(!ue(c)){break lb}p[114610]=0;c=M(465,f|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){if(!c){break lb}c=p[m+484400>>2];p[114610]=0;c=M(466,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[(a+t|0)+484400>>2];p[114610]=0;d=M(850,d|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break a}ac(c,d,sk(f));break lb}d=I()|0;H()|0;break mb}if((q[e+227|0]|q[e+228|0]<<8|(q[e+229|0]<<16|q[e+230|0]<<24))<1){break lb}if(n[e+212|0]&1){c=m+484414|0;o[c>>1]=r[c>>1]|1}if(q[e+213|0]&4){c=m+484414|0;o[c>>1]=r[c>>1]|64}c=q[e+227|0]|q[e+228|0]<<8|(q[e+229|0]<<16|q[e+230|0]<<24);p[114610]=0;N(341,e+144|0,b|0,c|0);l=p[114610];p[114610]=0;xb:{yb:{W=e;zb:{Ab:{if((l|0)!=1){l=le(f);c=(t|0)==16384;if((t|0)!=8192?!c:0){break yb}p[114610]=0;x=M(255,e+144|0)|0;R=p[114610];p[114610]=0;if((R|0)==1){break xb}p[e+120>>2]=x;x=4/(l>>>0)|0;R=p[e+120>>2];if(4294967295/(x>>>0)>>>0<R>>>0){break Ab}x=v(x,R);break zb}d=I()|0;H()|0;break mb}x=-1}p[W+120>>2]=x;vc(f,x);if(!c){if((t|0)!=8192){break yb}p[114610]=0;c=M(465,f|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break qb}if(!c){break sb}if(n[e+212|0]&1){c=p[m+484400>>2];d=p[f>>2];p[114610]=0;Q(851,e+144|0,c|0,d|0,l|0);c=p[114610];p[114610]=0;d=g;if((c|0)!=1){break rb}break qb}c=p[m+484400>>2];d=p[f>>2];p[114610]=0;Q(852,e+144|0,c|0,d|0,l|0);c=p[114610];p[114610]=0;d=g;if((c|0)==1){break qb}break rb}p[114610]=0;c=M(465,f|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break qb}if(!c){break sb}if(n[e+212|0]&1){c=p[m+484400>>2];d=p[f>>2];p[114610]=0;Q(853,e+144|0,c|0,d|0,l|0);c=p[114610];p[114610]=0;d=g;if((c|0)==1){break qb}break rb}c=p[m+484400>>2];d=p[f>>2];p[114610]=0;Q(854,e+144|0,c|0,d|0,l|0);c=p[114610];p[114610]=0;d=g;if((c|0)==1){break qb}break rb}if((B&45056)==12288){c=hP(e+120|0,e+144|0,q[e+231|0]|q[e+232|0]<<8,d);d=My(A,i+ -1|0);Nd(d,c);p[d+16>>2]=p[c+16>>2];sb(c);break sb}if((t|0)!=32768){d=1;if((t|0)!=4096){break rb}c=Re(e+120|0,e+144|0);p[114610]=0;J(855,e+112|0,e+144|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){Bb:{if(!q[e+117|0]){break Bb}d=r[e+114>>1]<<1;if((q[e+231|0]|q[e+232|0]<<8)>>>0<(d&65535)>>>0){break Bb}d=(q[e+231|0]|q[e+232|0]<<8)-d|0;n[e+231|0]=d;n[e+232|0]=d>>>8;p[114610]=0;J(256,e+144|0,r[e+112>>1])|0;d=p[114610];p[114610]=0;if((d|0)==1){break tb}p[114610]=0;d=M(548,e+144|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break tb}p[114610]=0;N(341,e+96|0,e+144|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break tb}Nd(c,e+96|0);sb(e+96|0)}p[114610]=0;d=h&65535;i=Z(856,a|0,d|0,c|0,1,1)|0;t=p[114610];p[114610]=0;if((t|0)==1){break tb}Cb:{if(!i){p[114610]=0;i=U(857,a|0,d|0,c|0,1)|0;d=p[114610];p[114610]=0;if((d|0)==1){break tb}d=1;if(!i){break Cb}}Db:{if(!(q[e+231|0]|q[e+232|0]<<8)){break Db}d=q[e+231|0]|q[e+232|0]<<8;if(sk(f)>>>0<=d>>>0){break Db}d=q[e+231|0]|q[e+232|0]<<8;i=Fn(f);m=m+484400|0;t=p[m>>2];p[114610]=0;t=M(466,t|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break a}m=p[m>>2];p[114610]=0;m=M(466,m|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break a}Ji(t,m+(q[e+231|0]|q[e+232|0]<<8)|0,sk(f)-(q[e+231|0]|q[e+232|0]<<8)|0);p[f>>2]=p[f>>2]-((d>>>0)/(i>>>0)|0)}d=p[e+200>>2];p[e+92>>2]=d;p[e+12>>2]=d;if(s[f>>2]>(q[e+12|0]|q[e+13|0]<<8|(q[e+14|0]<<16|q[e+15|0]<<24))>>>0){p[f>>2]=q[e+12|0]|q[e+13|0]<<8|(q[e+14|0]<<16|q[e+15|0]<<24)}d=g}sb(c);break rb}break tb}p[114610]=0;c=J(644,e+144|0,e+120|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){if(!c){break sb}p[114610]=0;p[e+24>>2]=p[e+128>>2];c=p[e+124>>2];p[e+16>>2]=p[e+120>>2];p[e+20>>2]=c;N(645,f|0,1,e+16|0);c=p[114610];p[114610]=0;if((c|0)!=1){break sb}}d=I()|0;H()|0;break pb}d=I()|0;H()|0;break pb}d=I()|0;H()|0;break mb}pb(y);break ib}d=I()|0;H()|0;sb(c);break pb}d=g}sb(e+144|0);break kb}d=I()|0;H()|0}sb(e+144|0)}pb(y);break l}d=g}pb(y);h=h+1|0;i=h&65535;if(i>>>0<=r[a+480190>>1]){continue}break}g=d}if(!(!j|!r[a+480190>>1])){d=1;h=1;while(1){c=My(A,d+ -1|0);p[114610]=0;b=M(337,c|0)|0;f=p[114610];p[114610]=0;Eb:{Fb:{Gb:{if((f|0)!=1){if(!b){break Eb}Hb:{Ib:{Jb:{b=r[c+18>>1];Kb:{if(!b){break Kb}b=b+h&65535;if(!b){break Kb}if(b>>>0<=r[a+480190>>1]){break Jb}}p[114610]=0;M(255,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break Ib}break m}b=My(A,b+ -1|0);f=r[c+16>>1];Ac(b);i=r[c+16>>1];p[114610]=0;i=J(258,b|0,i|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break m}if(!i){break Eb}p[114610]=0;p[e+120>>2]=0;p[e+144>>2]=0;N(858,e+192|0,b|0,f|0);f=p[114610];p[114610]=0;Lb:{if((f|0)!=1){p[114610]=0;f=M(412,e+192|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break Lb}p[114610]=0;f=M(859,f|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break Lb}i=p[e+192>>2];p[114610]=0;i=M(860,i|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break Lb}p[114610]=0;u=Z(861,f|0,i|0,e+120|0,e+144|0,0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Lb}p[114610]=0;J(338,b|0,p[e+120>>2])|0;b=p[114610];p[114610]=0;if((b|0)==1){break Lb}uc(e+192|0);b=1;break Hb}d=I()|0;H()|0;break l}d=I()|0;H()|0;uc(e+192|0);break l}Ac(c);p[e+120>>2]=0;p[e+144>>2]=0;u=0;b=0}p[114610]=0;K(862,e+192|0,c|0);f=p[114610];p[114610]=0;Mb:{Nb:{if((f|0)!=1){p[114610]=0;j=M(412,e+192|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Mb}m=p[e+192>>2];if(!b){p[114610]=0;b=M(859,j|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Gb}p[114610]=0;f=M(860,m|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break Gb}p[114610]=0;u=Z(861,b|0,f|0,e+120|0,e+144|0,0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break Gb}p[114610]=0;J(338,c|0,p[e+120>>2])|0;b=p[114610];p[114610]=0;if((b|0)==1){break Gb}b=p[e+120>>2];m=m-b|0;j=b+j|0}if(u){break Nb}g=1;break Fb}d=I()|0;H()|0;break l}p[114610]=0;d=v(d,104)+a|0;b=d+484380|0;M(465,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Gb}y=d+484400|0;t=d+484414|0;i=0;f=p[e+144>>2];Ob:{while(1){if(i>>>0>=s[b>>2]|(!m|(f|0)!=1?f:0)){break Ob}if(!ue(b)){break Ob}p[114610]=0;p[e+96>>2]=0;p[e+160>>2]=0;d=M(859,j|0)|0;f=p[114610];p[114610]=0;Pb:{if((f|0)==1){break Pb}p[114610]=0;f=M(860,m|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break Pb}p[114610]=0;d=da(863,u|0,d|0,f|0,e+96|0,e+112|0,e+160|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Pb}p[114610]=0;p[e+120>>2]=d;J(338,c|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break Pb}f=p[b>>2];p[114610]=0;d=p[e+120>>2];f=M(864,f-i|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break Pb}fk(e+160|0,f);Qb:{if(p[e+160>>2]<1){break Qb}if(p[e+96>>2]!=(le(b)|0)){break Qb}f=0;if(p[e+96>>2]<=0){break Qb}while(1){Rb:{if(n[t|0]&1){l=p[y>>2];x=le(b);B=p[p[e+112>>2]+(f<<2)>>2];p[114610]=0;_(865,l+(v(i,x)<<1)|0,B|0,p[e+96>>2],p[e+160>>2],f|0);l=p[114610];p[114610]=0;if((l|0)!=1){break Rb}break Gb}l=p[y>>2];x=le(b);B=p[p[e+112>>2]+(f<<2)>>2];p[114610]=0;_(866,l+v(i,x)|0,B|0,p[e+96>>2],p[e+160>>2],f|0);l=p[114610];p[114610]=0;if((l|0)==1){break Gb}}f=f+1|0;if((f|0)<p[e+96>>2]){continue}break}}p[114610]=0;l=p[e+160>>2];f=M(867,u|0)|0;x=p[114610];p[114610]=0;if((x|0)==1){break Pb}m=m-d|0;j=d+j|0;p[e+144>>2]=f;i=i+l|0;continue}break}break Gb}p[114610]=0;S(868,u|0);b=p[114610];p[114610]=0;if((b|0)!=1){break Fb}break Gb}break Gb}d=I()|0;H()|0;break l}d=I()|0;H()|0;uc(e+192|0);break l}uc(e+192|0)}h=h+1|0;d=h&65535;if(d>>>0<=r[a+480190>>1]){continue}break}}Sb:{if(p[a+480180>>2]!=4){break Sb}f=0;while(1){if(f>>>0>=r[a+480192>>1]){break Sb}b=q[Fb(z,f)|0];c=q[Fb(z,f)+1|0];d=q[Fb(z,f)+2|0];h=q[Fb(z,f)+3|0];p[114610]=0;f=f+1|0;fa(869,a|0,f&65535,b|0,c|0,d|0,h|0);b=p[114610];p[114610]=0;if((b|0)!=1){continue}break}d=I()|0;H()|0;break l}Tb:{if(!(q[w+2|0]&16)){break Tb}p[114610]=0;b=J(258,k|0,1)|0;c=p[114610];p[114610]=0;if((c|0)==1){break n}if(!b){break Tb}p[114610]=0;b=M(387,k|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break o}if(!(!(b&1)|!r[V>>1])){f=0;while(1){p[114610]=0;b=M(390,k|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break C}n[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<r[a+480188>>1]){continue}break}}while(1){p[114610]=0;b=J(258,k|0,1)|0;c=p[114610];p[114610]=0;Ub:{if((c|0)!=1){if(!b){break Tb}p[114610]=0;b=M(387,k|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break B}if(!b){break Tb}p[114610]=0;c=M(390,k|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break A}p[114610]=0;N(341,e+192|0,k|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break A}if(b>>>0>250){break Ub}p[114610]=0;K(670,e+192|0,(v(b,160)+a|0)+906140|0);b=p[114610];p[114610]=0;if((b|0)!=1){break Ub}d=I()|0;H()|0;sb(e+192|0);break l}d=I()|0;H()|0;break l}sb(e+192|0);continue}}h=a+901404|0;j=a+1074304|0;u=a+484344|0;b=Xc(e+96|0);i=0;Vb:{while(1){Wb:{p[114610]=0;c=J(258,k|0,8)|0;d=p[114610];p[114610]=0;Xb:{Yb:{Zb:{_b:{$b:{ac:{bc:{cc:{dc:{ec:{fc:{gc:{hc:{ic:{jc:{kc:{if((d|0)!=1){if(!c){break Vb}p[114610]=0;c=M(390,k|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break D}p[114610]=0;d=M(390,k|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break kc}p[114610]=0;N(341,e+120|0,k|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break jc}if((c|0)<=1397900629){if((c|0)==1229211981){break hc}if((c|0)!=1229476432){break Xb}p[114610]=0;c=M(387,e+120|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break s}p[a+480216>>2]=c;p[114610]=0;c=M(387,e+120|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break s}p[a+480220>>2]=c;break Xb}if((c|0)==1397900630){break ic}if((c|0)!=1414548815){break Xb}p[114610]=0;c=J(621,e+120|0,15355)|0;d=p[114610];p[114610]=0;if((d|0)==1){break s}if(!c){break fc}p[114610]=0;c=M(390,e+120|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;N(341,e+144|0,e+120|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){break gc}}d=I()|0;H()|0;break r}d=I()|0;H()|0;break p}d=I()|0;H()|0;break p}d=I()|0;H()|0;break p}lc:{mc:{nc:{c=p[a+480180>>2];switch(c+ -2|0){case 1:break Xb;case 0:break Yb;case 2:break mc;default:break nc}}if((c|0)==16){break lc}if((c|0)!=32){break Xb}p[114610]=0;i=M(357,e+120|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break s}p[114610]=0;M(357,e+120|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break Xb}break s}p[114610]=0;p[e+192>>2]=32;c=M(255,e+120|0)|0;d=p[114610];p[114610]=0;oc:{if((d|0)==1){break oc}p[114610]=0;p[e+144>>2]=c;c=J(33,e+192|0,e+144|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break oc}c=p[c>>2];p[114610]=0;U(870,e+120|0,b|0,4,c|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break Xb}}d=I()|0;H()|0;break r}p[114610]=0;d=M(387,e+120|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Wb}p[114610]=0;c=J(2,e+80|0,15336)|0;f=p[114610];p[114610]=0;pc:{qc:{rc:{if((f|0)!=1){p[114610]=0;K(219,e+144|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break rc}p[114610]=0;p[e+160>>2]=d>>>4;p[e+112>>2]=d&15;Q(534,e+192|0,e+144|0,e+160|0,e+112|0);d=p[114610];p[114610]=0;if((d|0)==1){break qc}xb(b,e+192|0);pb(e+192|0);yb(e+144|0);pb(c);break Xb}d=I()|0;H()|0;break r}d=I()|0;H()|0;break pc}d=I()|0;H()|0;yb(e+144|0)}pb(c);break r}p[114610]=0;J(636,e+120|0,h|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break s}p[114610]=0;S(637,h|0);c=p[114610];p[114610]=0;if((c|0)==1){break s}break Xb}p[114610]=0;c=M(255,e+144|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ec}o[e+192>>1]=c>>>5;c=ke(u);p[114610]=0;o[e+160>>1]=c;c=J(477,e+192|0,e+160|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ec}c=r[c>>1];if(c){d=0;while(1){p[114610]=0;P(871,e+144|0,e+192|0,32)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ec}f=Rb(u,d);p[114610]=0;J(872,f|0,e+192|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ec}d=d+1|0;if((c|0)!=(d|0)){continue}break}}sb(e+144|0)}p[114610]=0;c=J(621,e+120|0,15360)|0;d=p[114610];p[114610]=0;if((d|0)==1){break s}if(!c){break cc}p[114610]=0;c=M(390,e+120|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;N(341,e+192|0,e+120|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){break dc}}d=I()|0;H()|0;break r}d=I()|0;H()|0;sb(e+144|0);break r}p[114610]=0;c=M(255,e+192|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break bc}o[e+144>>1]=(c>>>0)/20;c=r[a+480188>>1];p[114610]=0;o[e+160>>1]=c;c=J(477,e+144|0,e+160|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break bc}c=r[c>>1];if(c){f=0;while(1){p[114610]=0;P(639,e+192|0,((f<<5)+a|0)+480289|0,20)|0;d=p[114610];p[114610]=0;if((d|0)==1){break bc}f=f+1|0;if((c|0)!=(f|0)){continue}break}}sb(e+192|0)}p[114610]=0;J(656,a|0,e+120|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break s}p[114610]=0;Q(657,a|0,e+120|0,1,0);c=p[114610];p[114610]=0;if((c|0)==1){break s}if((i+ -2186&65535)>>>0<=117){p[a+480180>>2]=16777216;p[114610]=0;N(668,a|0,e+120|0,i&65535);c=p[114610];p[114610]=0;if((c|0)==1){break s}}if(!p[j>>2]){break Xb}p[114610]=0;c=J(2,e+144|0,15365)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ac}p[114610]=0;K(242,e+160|0,j|0);d=p[114610];p[114610]=0;if((d|0)==1){break $b}p[114610]=0;N(3,e+192|0,c|0,e+160|0);d=p[114610];p[114610]=0;if((d|0)==1){break _b}xb(b,e+192|0);pb(e+192|0);pb(e+160|0);pb(c);break Xb}d=I()|0;H()|0;sb(e+192|0);break r}d=I()|0;H()|0;break r}d=I()|0;H()|0;break Zb}d=I()|0;H()|0;pb(e+160|0)}pb(c);break r}p[114610]=0;i=M(357,e+120|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break s}}sb(e+120|0);continue}break}d=I()|0;H()|0;break r}if(!((i&65504)!=4864|p[a+480180>>2]!=2?!((p[a+480180>>2]==32?(i+ -256&65535)>>>0<=275:0)|(p[a+480180>>2]==2?(i+ -12544&65535)>>>0<=275:0)):0)){p[114610]=0;S(638,h|0);c=p[114610];p[114610]=0;if((c|0)==1){break q}}sc:{if(!(n[w+2|0]&1)){break sc}if(r[a+480192>>1]){f=1;while(1){c=p[(((f&65535)<<2)+a|0)+900380>>2];tc:{if(!c){break tc}uc:{if(s[a+1074304>>2]>=18874368){break uc}p[114610]=0;d=J(374,c|0,2)|0;h=p[114610];p[114610]=0;if((h|0)==1){break z}h=p[a+480180>>2];p[114610]=0;N(873,d|0,4,h|0);d=p[114610];p[114610]=0;if((d|0)!=1){break uc}d=I()|0;H()|0;break p}if(s[a+1074304>>2]>=19267584){break tc}n[c+19|0]=q[c+19|0]+3>>>2}f=f+1|0;if((f&65535)>>>0<=r[a+480192>>1]){continue}break}}if(s[a+1074304>>2]<18350080){p[114610]=0;c=a+1074308|0;J(479,c|0,27)|0;d=p[114610];p[114610]=0;if((d|0)==1){break q}p[114610]=0;J(479,c|0,57)|0;c=p[114610];p[114610]=0;if((c|0)==1){break q}}if(s[a+1074304>>2]<19070976){p[114610]=0;J(479,a+1074308|0,73)|0;c=p[114610];p[114610]=0;if((c|0)==1){break q}}if(s[a+1074304>>2]>=19267584){break sc}p[114610]=0;J(479,a+1074308|0,50)|0;c=p[114610];p[114610]=0;if((c|0)==1){break q}}vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{Dc:{Ec:{Fc:{Gc:{if(Pc(b)){p[114610]=0;c=J(2,e- -64|0,15374)|0;d=p[114610];p[114610]=0;Hc:{Ic:{Jc:{if((d|0)!=1){p[114610]=0;K(219,e+120|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break Jc}p[114610]=0;N(537,e+192|0,e+120|0,e+1591|0);d=p[114610];p[114610]=0;if((d|0)==1){break Ic}break Gc}d=I()|0;H()|0;break p}d=I()|0;H()|0;break Hc}d=I()|0;H()|0;yb(e+120|0)}pb(c);break p}p[114610]=0;c=J(2,e+48|0,15382)|0;d=p[114610];p[114610]=0;if((d|0)==1){break Fc}p[114610]=0;K(219,e+120|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break Ec}p[114610]=0;Q(451,e+192|0,e+120|0,e+1591|0,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break Dc}}xb(b,e+192|0);pb(e+192|0);yb(e+120|0);pb(c);p[114610]=0;c=J(2,e+32|0,15395)|0;d=p[114610];p[114610]=0;if((d|0)==1){break Bc}p[114610]=0;K(219,e+120|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break Ac}p[114610]=0;N(537,e+192|0,e+120|0,e+1591|0);d=p[114610];p[114610]=0;if((d|0)==1){break zc}xb(a+1304436|0,e+192|0);pb(e+192|0);yb(e+120|0);pb(c);p[114610]=0;c=J(2,e+192|0,15411)|0;d=p[114610];p[114610]=0;if((d|0)==1){break xc}xb(a+1304448|0,c);pb(c);xb(a+1304484|0,C);xb(a+1304472|0,G);xb(a+1304460|0,b);if(!p[a+1074304>>2]){break wc}p[a+1304496>>2]=7;break vc}d=I()|0;H()|0;break p}d=I()|0;H()|0;break Cc}d=I()|0;H()|0;yb(e+120|0)}pb(c);break p}d=I()|0;H()|0;break p}d=I()|0;H()|0;break yc}d=I()|0;H()|0;yb(e+120|0)}pb(c);break p}d=I()|0;H()|0;break p}if(p[a+480180>>2]==1){p[a+1304496>>2]=2;break vc}p[a+1304496>>2]=4}f=1;if(g&1){p[114610]=0;c=J(2,e+192|0,15415)|0;d=p[114610];p[114610]=0;if((d|0)==1){break F}p[114610]=0;N(650,a|0,2,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break E}pb(c)}pb(b);gP(A);eP(z);$c(D);sb(e+1064|0);sb(e+1080|0);pb(G);pb(C)}sb(k)}Xd(F);break b}d=I()|0;H()|0;break p}d=I()|0;H()|0;pb(c);break p}d=I()|0;H()|0;break p}d=I()|0;H()|0;break l}d=I()|0;H()|0;break l}d=I()|0;H()|0;break l}d=I()|0;H()|0;break p}d=I()|0;H()|0;break h}d=I()|0;H()|0;break h}d=I()|0;H()|0;break h}d=I()|0;H()|0;break e}d=I()|0;H()|0;break e}d=I()|0;H()|0;break e}d=I()|0;H()|0}sb(e+120|0);break p}d=I()|0;H()|0}pb(b);break l}d=I()|0;H()|0;break l}d=I()|0;H()|0;break l}d=I()|0;H()|0}gP(A);break j}d=I()|0;H()|0}eP(z);break h}d=I()|0;H()|0}$c(D)}sb(e+1064|0)}sb(e+1080|0)}pb(G);pb(C)}sb(k)}Xd(F);L(d|0);E()}fb=e+1600|0;return f|0}a=O(0)|0;H()|0;rb(a);E()}function wEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,O=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;d=fb-896|0;fb=d;Ac(b);a:{b:{c:{if(!EP(b,d+840|0)){break c}if(!GP(d+840|0)){break c}if(!Hb(b,dd(FP(d+840|0),ib))){break c}if(!c){f=1;break c}xd(a,8);ei(a);n[d+839|0]=q[d+840|3]+ -48;e=q[d+848|0]|q[d+849|0]<<8|(q[d+850|0]<<16|q[d+851|0]<<24);Jc(b,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));ld(d+816|0,b,504);p[114610]=0;J(775,b|0,d+528|0)|0;e=p[114610];p[114610]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((e|0)!=1){if(q[d+528|0]&128|q[d+811|0]>63){break d}Jb(d+448|0,0,80);q:{if(!(q[d+872|0]|q[d+873|0]<<8|(q[d+874|0]<<16|q[d+875|0]<<24))){break q}e=q[d+872|0]|q[d+873|0]<<8|(q[d+874|0]<<16|q[d+875|0]<<24);p[114610]=0;g=J(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}if(!g){break q}p[114610]=0;J(776,b|0,d+448|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}}p[114610]=0;g=q[d+839|0];X=J(777,b|0,g|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}o[a+480188>>1]=X;if((X+ -1&65535)>>>0>126){break d}Y=d+432|0;eEa(Y);e=q[d+864|0]|q[d+865|0]<<8|(q[d+866|0]<<16|q[d+867|0]<<24);p[114610]=0;J(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=p[114610];p[114610]=0;if((e|0)==1){break p}e=q[d+811|0];p[114610]=0;P(778,b|0,Y|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break p}f=q[d+811|0];o[a+480192>>1]=f;o[a+480190>>1]=f;if(g>>>0<=1){X=r[a+480188>>1]==4}else{f=r[a+480192>>1];X=n[d+792|0]>-1}if(f&65535){$=c&2;ga=X^1;V=d+72|2;aa=d+72|7;ca=d+72|6;W=d+72|5;A=d+72|4;D=d+48|4;i=1;z=1;F=1;while(1){p[114610]=0;G=F&65535;g=P(454,a|0,z&65535,G|0)|0;e=p[114610];p[114610]=0;r:{if((e|0)!=1){if(g){break r}break f}f=I()|0;H()|0;break g}B=p[((i<<2)+a|0)+900380>>2];p[114610]=0;o[d+52>>1]=0;p[d+48>>2]=0;O=M(277,d+144|0)|0;e=p[114610];p[114610]=0;s:{t:{u:{v:{w:{if((e|0)!=1){e=i+ -1|0;g=Fb(Y,e);x:{if(!(q[g|0]|q[g+1|0]<<8|(q[g+2|0]<<16|q[g+3|0]<<24))){break x}e=Fb(Y,e);e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);p[114610]=0;g=J(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=p[114610];p[114610]=0;if((e|0)==1){break h}if(!g){break x}p[114610]=0;J(779,b|0,d+48|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break h}e=q[d+48|0]|q[d+49|0]<<8|(q[d+50|0]<<16|q[d+51|0]<<24);p[114610]=0;N(341,d+72|0,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));e=p[114610];p[114610]=0;if((e|0)==1){break h}Nd(O,d+72|0);sb(d+72|0)}h=q[D+1|0]&15;C=(q[D|0]|q[D+1|0]<<8)&128;if(!C){break w}p[114610]=0;K(780,B|0,0);e=p[114610];p[114610]=0;ma=1;if((e|0)!=1){break v}break h}f=I()|0;H()|0;break g}if(7<=h>>>0){break v}g=q[h+14806|0];if(!h){e=g;break t}o[a+480190>>1]=(r[a+480190>>1]+g|0)+ -1;j=B+108|0;x=B+236|0;y=g+ -2|0;m=4;while(1){e=m+ -4|0;h=y<<3;l=e+(h+14864|0)|0;k=q[e+(h+14816|0)|0]+F|0;h=v(m,12);f=0;while(1){e=f+h|0;na=Yc(x,e),oa=k,o[na>>1]=oa;e=Yb(j,e);n[e|0]=q[e|0]+q[l|0];f=f+1|0;if((f|0)!=12){continue}break}t=1;m=m+1|0;if((m|0)!=10){continue}break}e=g;break u}g=1;if((h|0)!=7){e=1;break t}t=0;p[114610]=0;K(781,B|0,-24);g=p[114610];p[114610]=0;e=1;if((g|0)==1){break h}g=1}da=1;break s}t=0;if(C|ga){break s}y=B+108|0;m=7;while(1){l=v(m,12);k=v(m,-12)+72|0;f=0;while(1){h=Yb(y,f+l|0);n[h|0]=k+q[h|0];f=f+1|0;if((f|0)!=12){continue}break}m=m+1|0;if((m|0)!=10){continue}break}}p[114610]=0;J(782,d+816|0,d+72|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break h}if(!(!q[A|0]|q[A|0]>16)){n[B+31|0]=q[A|0];da=1}if(!(!q[W|0]|q[W|0]>128)){n[B+30|0]=q[W|0]}if(e){i=0;j=0;while(1){p[114610]=0;l=v(i+G|0,104)+a|0;K(386,l+484380|0,8);h=p[114610];p[114610]=0;if((h|0)==1){break h}h=q[ca|0];p[114610]=0;n[d+400|0]=h;n[d+128|0]=64;k=J(391,d+400|0,d+128|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break h}o[l+484410>>1]=q[k|0]<<2;n[l+484416|0]=q[aa|0];j=j+1|0;i=j&65535;if(e>>>0>i>>>0){continue}break}}y:{if(C|!$){break y}x=Tc(d+400|0,8,1,1,0);y=q[V|0]|q[V+1|0]<<8;l=q[d+72|0]|q[d+73|0]<<8;k=q[V|0]|q[V+1|0]<<8;p[114610]=0;f=M(255,O|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break h}if(q[D+1|0]&16){Az(x);f=f>>>1|0}if(q[D+1|0]&32){uA(x);f=f>>>1|0}if(q[D+1|0]&64){lj(x,2)}f=t?(f>>>0)/((-1<<e^-1)>>>0)|0:f;if(!e){break y}j=(l<<8&16711680|l<<24)>>>15|0;t=j+((k<<8&16711680|k<<24)>>>15|0)|0;k=(y<<8&16711680|y<<24)>>>16|0;i=0;m=0;while(1){l=v(i+G|0,104)+a|0;h=l+484380|0;p[h>>2]=f;p[114610]=0;P(400,x|0,h|0,O|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break h}if(k>>>0>=2){p[l+484388>>2]=t;p[l+484384>>2]=j;h=l+484414|0;o[h>>1]=r[h>>1]|2}t=t<<1;j=j<<1;f=f<<1;m=m+1|0;i=m&65535;if(e>>>0>i>>>0){continue}break}}sb(O);F=g+F|0;z=z+1|0;i=z&65535;if(i>>>0<=r[a+480192>>1]){continue}break}}e=d+448|4;z:{if(!(q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))|!(q[d+456|0]|q[d+457|0]<<8)){break z}e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);p[114610]=0;g=J(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}if(!g){break z}e=q[d+456|0]|q[d+457|0]<<8;o[d+144>>1]=(e<<24|e<<8&16711680)>>>16;e=q[d+811|0];p[114610]=0;o[d+72>>1]=e;g=J(477,d+144|0,d+72|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break j}aa=r[g>>1];if(!aa){break z}G=d+144|5;ca=d+144|3;$=d+144|6;A=d+144|1;g=d+80|0;j=d+72|4;e=q[d+458|0]|q[d+459|0]<<8;C=(e<<24|e<<8&16711680)>>>16|0;x=C>>>0<7;y=C>>>0<15;i=0;while(1){p[114610]=0;P(783,b|0,d+144|0,C|0)|0;e=p[114610];p[114610]=0;A:{B:{C:{if((e|0)!=1){i=i+1|0;h=p[((i<<2)+a|0)+900380>>2];if(!q[d+144|0]){break A}l=kp(d+72|0,0,64);kp(j,q[d+144|0]+ -1&65535,64);k=q[d+144|0];kp(g,k+(q[A|0]?64/q[A|0]|0:0)|0,0);p[114610]=0;p[d+428>>2]=3;p[d+424>>2]=l;e=p[d+428>>2];p[d>>2]=p[d+424>>2];p[d+4>>2]=e;k=h+48|0;K(784,k|0,d|0);e=p[114610];p[114610]=0;if((e|0)==1){break C}if(q[d+144|0]!=1){break B}na=d,oa=Ub(k),p[na+72>>2]=oa;Ld(d+416|0,d+72|0);p[114610]=0;J(785,k|0,p[d+416>>2])|0;e=p[114610];p[114610]=0;if((e|0)!=1){break B}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}e=h;if(q[A|0]){f=q[A|0]<<9}else{f=32767}p[e>>2]=f;da=1;n[h+60|0]=q[h+60|0]|1}if(!x){e=q[$|0]|q[$+1|0]<<8;o[h+28>>1]=(e<<24|e<<8&16711680)>>>16}h=v(r[Yc(h+236|0,61)>>1],104)+a|0;n[h+484417|0]=q[ca|0]<<4;D:{E:{if(!y){e=q[d+154|0]|q[d+155|0]<<8|(q[d+156|0]<<16|q[d+157|0]<<24);p[h+484384>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=q[d+158|0]|q[d+159|0]<<8|(q[d+160|0]<<16|q[d+161|0]<<24);f=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=q[d+154|0]|q[d+155|0]<<8|(q[d+156|0]<<16|q[d+157|0]<<24);p[h+484388>>2]=f+(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));break E}if(C>>>0<6){break D}}if(n[G|0]&1){e=h+484414|0;o[e>>1]=r[e>>1]|2}if(q[G|0]&8){e=h+484414|0;o[e>>1]=r[e>>1]|6}if(!(q[G|0]&4)){break D}o[h+484412>>1]=0}if((i|0)!=(aa|0)){continue}break}}if(!(q[d+468|0]|q[d+469|0]<<8|(q[d+470|0]<<16|q[d+471|0]<<24))|!(q[d+472|0]|q[d+473|0]<<8)){break k}e=q[d+468|0]|q[d+469|0]<<8|(q[d+470|0]<<16|q[d+471|0]<<24);p[114610]=0;g=J(256,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}if(!g){break k}e=q[d+472|0]|q[d+473|0]<<8;o[d+144>>1]=(e<<24|e<<8&16711680)>>>16;e=q[d+811|0];p[114610]=0;o[d+72>>1]=e;g=J(477,d+144|0,d+72|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){l=r[g>>1];if(!l){break k}e=q[d+474|0]|q[d+475|0]<<8;k=(e<<24|e<<8&16711680)>>>16|0;g=0;F:while(1){G:{p[114610]=0;P(786,b|0,d+144|0,k|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break l}p[114610]=0;N(787,d+48|0,2,d+144|0);e=p[114610];p[114610]=0;if((e|0)==1){break m}p[114610]=0;K(415,d+72|0,d+48|0);e=p[114610];p[114610]=0;if((e|0)==1){break m}g=g+1|0;y=((g<<2)+a|0)+900380|0;e=p[y>>2];p[114610]=0;J(369,e+492|0,d+72|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break n}pb(d+72|0);e=p[y>>2];p[114610]=0;K(788,d+72|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break o}na=d,oa=fn(d+72|0),p[na+48>>2]=oa;na=d,oa=pi(d+72|0),p[na+400>>2]=oa;while(1){p[114610]=0;h=J(789,d+48|0,d+400|0)|0;e=p[114610];p[114610]=0;H:{if((e|0)!=1){if(h){break H}ip(d+72|0);if((g|0)!=(l|0)){continue F}break k}break G}p[114610]=0;h=M(790,d+48|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){j=p[y>>2];e=p[j+520>>2];x=(r[h>>1]<<5)+a|0;h=x+946324|0;p[h>>2]=p[j+516>>2];p[h+4>>2]=e;e=p[j+512>>2];h=x+946316|0;p[h>>2]=p[j+508>>2];p[h+4>>2]=e;e=p[j+504>>2];h=x+946308|0;p[h>>2]=p[j+500>>2];p[h+4>>2]=e;e=p[j+496>>2];h=x+946300|0;p[h>>2]=p[j+492>>2];p[h+4>>2]=e;Vs(d+48|0);continue}break}}break}f=I()|0;H()|0;ip(d+72|0);break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break a}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;pb(d+72|0);break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}i=1;i=q[d+872|0]|q[d+873|0]<<8|(q[d+874|0]<<16|q[d+875|0]<<24)?q[d+891|0]+1|0:i;p[114610]=0;n[d+144|0]=i;g=J(391,14912,d+144|0)|0;e=p[114610];p[114610]=0;I:{J:{K:{L:{M:{N:{if((e|0)!=1){ka=q[g|0];Ac(b);O:{if(!ka){break O}G=c&1;ba=a+484344|0;ea=a+1304424|0;B=a+1304400|0;D=a+484360|0;C=d+144|1;u=d+144|4;R=d+24|4;O=d+24|2;V=d- -64|2;$=d- -64|3;S=d+528|2;while(1){p[114610]=0;Q(791,b|0,d+840|0,d+448|0,d+528|0);c=p[114610];p[114610]=0;P:{Q:{R:{S:{T:{if((c|0)==1){break T}g=la&255;if(g){p[114610]=0;e=M(485,D|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break T}if((e|0)==255){break f}}w=li(D,g);T=mEa(d+400|0);Bp(w);U:{V:{if(q[d+839|0]<=1){c=q[S|0]|q[S+1|0]<<8;if((c<<24|c<<8&16711680)>>>16>>>0>256|r[a+480188>>1]>16){break U}BP(d+144|0,d+528|0);c=q[S|0]|q[S+1|0]<<8;p[114610]=0;Z(792,w|0,d+144|0,(c<<8&16711680|c<<24)>>>16|0,65535,65535)|0;c=p[114610];p[114610]=0;if((c|0)==1){break V}na=d,oa=Ub(w),p[na+144>>2]=oa;na=d,oa=Vb(w),p[na+72>>2]=oa;if(!Ab(d+144|0,d+72|0)){break R}while(1){c=p[d+144>>2];o[c>>1]=r[c>>1]+fa;te(d+144|0);if(Ab(d+144|0,d+72|0)){continue}break}break R}BP(d+144|0,d+528|0);if(!(q[d+156|0]|q[d+157|0]<<8)){break U}c=q[d+156|0]|q[d+157|0]<<8;if((c<<24|c<<8&16711680)>>>16>>>0>64|r[a+480188>>1]>64){break U}h=q[d+164|0]|q[d+165|0]<<8|(q[d+166|0]<<16|q[d+167|0]<<24);if(!(q[d+168|0]|q[d+169|0]<<8)){m=32;break S}c=q[d+168|0]|q[d+169|0]<<8;p[114610]=0;o[d+72>>1]=(c<<8&16711680|c<<24)>>>16;o[d+48>>1]=800;e=J(477,d+72|0,d+48|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){c=r[e>>1];p[114610]=0;m=rg(793,((c<<5)+50>>>0)/100|0,0);c=p[114610];p[114610]=0;if((c|0)!=1){break S}}f=I()|0;H()|0;break I}f=I()|0;H()|0;break I}hp(T);break f}f=I()|0;H()|0;break g}c=q[d+152|0]|q[d+153|0]<<8|(q[d+154|0]<<16|q[d+155|0]<<24);p[114610]=0;e=J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;W:{if((c|0)==1){break W}X:{if(!e){break X}f=0;if(!r[a+480188>>1]){break X}Y:{while(1){Z:{p[114610]=0;e=M(387,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Z}p[114610]=0;n[d+72|0]=e;n[d+48|0]=64;e=J(391,d+72|0,d+48|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Y}o[((f<<5)+a|0)+480286>>1]=q[e|0];f=f+1|0;if(f>>>0<r[a+480188>>1]){continue}break X}break}f=I()|0;H()|0;break I}f=I()|0;H()|0;break I}_:{$:{if(!(q[d+160|0]|q[d+161|0]<<8|(q[d+162|0]<<16|q[d+163|0]<<24))){break $}c=q[d+160|0]|q[d+161|0]<<8|(q[d+162|0]<<16|q[d+163|0]<<24);p[114610]=0;e=J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)==1){break W}if(!e){break $}f=0;if(!r[a+480188>>1]){break _}while(1){aa:{p[114610]=0;e=M(794,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break aa}na=((f<<5)+a|0)+480284|0,oa=(Pb(e,-16,16)<<3)+128|0,o[na>>1]=oa;f=f+1|0;if(f>>>0<r[a+480188>>1]){continue}break _}break}f=I()|0;H()|0;break I}p[114610]=0;K(449,a|0,1);c=p[114610];p[114610]=0;if((c|0)==1){break W}}l=d+128|0;ZDa(l);c=q[u|0]|q[u+1|0]<<8|(q[u+2|0]<<16|q[u+3|0]<<24);p[114610]=0;e=J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;ba:{ca:{da:{ea:{fa:{if((c|0)==1){break fa}i=1;f=0;if(!e){break ba}c=q[S|0]|q[S+1|0]<<8;p[114610]=0;e=J(258,b|0,(c<<8&16711680|c<<24)>>>15|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break fa}if(!e){break ba}c=q[S|0]|q[S+1|0]<<8;p[114610]=0;e=P(795,b|0,l|0,(c<<8&16711680|c<<24)>>>16|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break fa}if(!e){break ba}na=d,oa=Ub(l),p[na+24>>2]=oa;na=d,oa=Vb(l),p[na+120>>2]=oa;if(!Ab(d+24|0,d+120|0)){break ca}while(1){c=p[d+24>>2];c=q[c|0]|q[c+1|0]<<8;e=(c<<24|c<<8&16711680)>>>16|0;c=q[d+158|0]|q[d+159|0]<<8;ga:{if(e>>>0>(c<<24|c<<8&16711680)>>>16>>>0){break ga}c=q[d+144|0]|q[d+145|0]<<8|(q[d+146|0]<<16|q[d+147|0]<<24);p[114610]=0;J(256,b|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+(e<<2)|0)|0;c=p[114610];p[114610]=0;ha:{ia:{ja:{ka:{la:{if((c|0)==1){break la}p[114610]=0;e=M(494,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break la}p[114610]=0;e=J(256,b|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break la}if(!e){p[114610]=0;e=J(258,b|0,42)|0;c=p[114610];p[114610]=0;if((c|0)==1){break la}if(e){break ga}}p[114610]=0;J(796,b|0,d+72|0)|0;c=p[114610];p[114610]=0;ma:{if((c|0)!=1){if(cd(w)){break ma}p[114610]=0;K(797,w|0,65534);c=p[114610];p[114610]=0;if((c|0)!=1){break ma}}f=I()|0;H()|0;break da}c=q[d+112|0]|q[d+113|0]<<8;p[114610]=0;c=(c<<8&16711680|c<<24)>>>16|0;p[d+68>>2]=c;e=J(258,b|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ka}if(!e){p[114610]=0;e=M(548,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ka}vc(d+68|0,e)}vc(d+68|0,65534);k=fc(w);p[114610]=0;K(798,w|0,k+p[d+68>>2]|0);c=p[114610];p[114610]=0;if((c|0)==1){break ia}i=0;if(!p[d+68>>2]){break ja}while(1){na:{p[114610]=0;e=M(484,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break na}c=e<<16>>16;if((c|0)>=0){p[114610]=0;K(797,w|0,c+fa&65535);c=p[114610];p[114610]=0;if((c|0)==1){break na}}i=i+1|0;if(i>>>0<s[d+68>>2]){continue}break ja}break}f=I()|0;H()|0;break da}f=I()|0;H()|0;break da}f=I()|0;H()|0;break da}oa:{if(!q[d+72|0]){break oa}p[114610]=0;K(799,d+48|0,d+72|0);c=p[114610];p[114610]=0;pa:{if((c|0)!=1){p[114610]=0;K(487,w|0,d+48|0);c=p[114610];p[114610]=0;if((c|0)==1){break pa}pb(d+48|0);break oa}f=I()|0;H()|0;break da}f=I()|0;H()|0;pb(d+48|0);break da}if(!(q[d+104|0]|q[d+105|0]<<8|(q[d+106|0]<<16|q[d+107|0]<<24))){break ga}c=q[d+104|0]|q[d+105|0]<<8|(q[d+106|0]<<16|q[d+107|0]<<24);p[114610]=0;e=J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)!=1){break ha}}f=I()|0;H()|0;break da}if(!e){break ga}while(1){qa:{p[114610]=0;e=J(800,b|0,d- -64|0)|0;c=p[114610];p[114610]=0;ra:{sa:{if((c|0)!=1){if(!e){break ga}c=q[$|0];p[114610]=0;N(341,d+48|0,b|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break sa}c=d- -64|0;c=q[c|0]|q[c+1|0]<<8;p[114610]=0;e=M(801,k+((c<<8&16711680|c<<24)>>>16|0)|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ea}o[d+46>>1]=e;c=d- -64|0;if((q[c|0]|q[c+1|0]<<8)==65535){break qa}c=r[d+46>>1];if(fc(w)>>>0>c>>>0){break ra}sb(d+48|0);break ga}f=I()|0;H()|0;break da}f=I()|0;H()|0;break da}ta:{if(q[V|0]==1){c=65535}else{if(q[V|0]!=2){break ta}p[114610]=0;g=M(484,d+48|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ea}p[114610]=0;e=J(802,T|0,d+46|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ea}o[e>>1]=g;c=65534}na=kc(w,r[d+46>>1]),oa=c,o[na>>1]=oa}sb(d+48|0);continue}break}sb(d+48|0)}te(d+24|0);if(Ab(d+24|0,d+120|0)){continue}break}break ca}f=I()|0;H()|0;break da}f=I()|0;H()|0;sb(d+48|0)}zP(l);break I}i=0;f=1}zP(l);if(f){g=m>>>(h>>>25&1)|0;break Q}hp(T);if(!i){break f}break P}f=I()|0;H()|0;break I}p[114610]=0;K(449,a|0,1);c=p[114610];p[114610]=0;ua:{if((c|0)!=1){f=0;g=32;if(!r[a+480188>>1]){break Q}while(1){c=q[(d+f|0)+794|0];p[114610]=0;n[d+144|0]=c;n[d+72|0]=64;e=J(391,d+144|0,d+72|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ua}o[((f<<5)+a|0)+480286>>1]=q[e|0];f=f+1|0;if(f>>>0<r[a+480188>>1]){continue}break}break Q}f=I()|0;H()|0;break I}f=I()|0;H()|0;break I}k=q[d+791|0];c=q[d+788|0]|q[d+789|0]<<8;ga=q[d+791|0]&64;W=q[d+792|0]&32;ha=(q[d+792|0]&31)+1|0;na=a,oa=yP((c<<24|c<<8&16711680)>>>16|0,ga>>>6|0,W>>>5|0,ha),p[na+480204>>2]=oa;na=a,oa=sd(q[d+793|0],1,32),p[na+480196>>2]=oa;if(W){p[a+480216>>2]=ha;p[a+480220>>2]=ha<<2}va:{wa:{if(q[d+810|0]){c=q[d+810|0];p[114610]=0;n[d+144|0]=c;n[d+72|0]=64;e=J(391,d+144|0,d+72|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break wa}p[a+480200>>2]=q[e|0]<<2}p[a+480228>>2]=g;p[a+480232>>2]=g;p[a+480208>>2]=p[a+480208>>2]&-3|(q[d+791|0]>>>4^-1)&2;xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{if(!(q[d+492|0]|q[d+493|0]<<8|(q[d+494|0]<<16|q[d+495|0]<<24))){break Ia}c=q[d+492|0]|q[d+493|0]<<8|(q[d+494|0]<<16|q[d+495|0]<<24);p[114610]=0;e=J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ha}if(!e){break Ia}c=q[d+496|0]|q[d+497|0]<<8|(q[d+498|0]<<16|q[d+499|0]<<24);p[114610]=0;P(481,b|0,B|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ha}if((ka|0)==1){break Ia}p[114610]=0;N(13,d+144|0,2,B|0);c=p[114610];p[114610]=0;if((c|0)==1){break Ga}p[114610]=0;K(487,w|0,d+144|0);c=p[114610];p[114610]=0;if((c|0)==1){break Fa}pb(d+144|0)}c=q[d+464|0]|q[d+465|0]<<8|(q[d+466|0]<<16|q[d+467|0]<<24);Ja:{if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<2){break Ja}c=q[d+460|0]|q[d+461|0]<<8|(q[d+462|0]<<16|q[d+463|0]<<24);p[114610]=0;e=J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ha}if(!e){break Ja}c=q[d+464|0]|q[d+465|0]<<8|(q[d+466|0]<<16|q[d+467|0]<<24);p[114610]=0;U(587,ea|0,b|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+ -1|0,4)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ha}}if(!(q[d+504|0]|q[d+505|0]<<8|(q[d+506|0]<<16|q[d+507|0]<<24))){break va}c=q[d+504|0]|q[d+505|0]<<8|(q[d+506|0]<<16|q[d+507|0]<<24);p[114610]=0;e=J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ha}if(!e){break va}p[114610]=0;J(338,b|0,6)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ha}p[114610]=0;e=M(484,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ha}if((e|0)!=1){break va}p[114610]=0;g=M(494,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Da}if(!g){break va}p[114610]=0;e=J(258,b|0,g|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Da}if(e){break Ea}break va}f=I()|0;H()|0;break I}f=I()|0;H()|0;break I}f=I()|0;H()|0;pb(d+144|0);break I}Wc(d+144|0,ea);p[114610]=0;U(587,ea|0,b|0,g|0,4)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ya}if(!Pc(d+144|0)){p[114610]=0;e=P(803,d+48|0,2,13)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ca}p[114610]=0;N(804,d+72|0,d+144|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break Ba}p[114610]=0;N(805,d+32|0,d+72|0,ea|0);c=p[114610];p[114610]=0;if((c|0)==1){break Aa}xb(ea,d+32|0);pb(d+32|0);pb(d+72|0);pb(e)}pb(d+144|0);break va}f=I()|0;H()|0;break I}f=I()|0;H()|0;break xa}f=I()|0;H()|0;break za}f=I()|0;H()|0;pb(d+72|0)}pb(e);break xa}f=I()|0;H()|0}pb(d+144|0);break I}f=I()|0;H()|0;break I}Ka:{if(!(q[d+516|0]|q[d+517|0]<<8|(q[d+518|0]<<16|q[d+519|0]<<24))|q[d+839|0]<2){break Ka}t=0;if(!r[a+480188>>1]){break Ka}while(1){c=q[d+516|0]|q[d+517|0]<<8|(q[d+518|0]<<16|q[d+519|0]<<24);p[114610]=0;e=J(256,b|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+(t<<2)|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break J}La:{if(!e){break La}p[114610]=0;e=M(494,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break J}p[114610]=0;h=J(256,b|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break J}g=0;e=0;if(!h){break La}while(1){Ma:{p[114610]=0;h=J(258,b|0,8)|0;c=p[114610];p[114610]=0;Na:{Oa:{Pa:{if((c|0)!=1){if(!h){break Ma}p[114610]=0;J(806,b|0,d+144|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Pa}if(!(q[d+144|0]|q[d+145|0]<<8|(q[d+146|0]<<16|q[d+147|0]<<24))){break Ma}c=(q[d+144|0]|q[d+145|0]<<8|(q[d+146|0]<<16|q[d+147|0]<<24))&-225;switch((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))+ -1|0){case 1:break Na;case 0:break Oa;default:continue}}f=I()|0;H()|0;break I}f=I()|0;H()|0;break I}c=q[u|0]|q[u+1|0]<<8|(q[u+2|0]<<16|q[u+3|0]<<24);g=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);continue}c=q[u|0]|q[u+1|0]<<8|(q[u+2|0]<<16|q[u+3|0]<<24);e=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);continue}break}if(!g|!e){break La}p[114610]=0;g=J(256,b|0,g|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break K}if(!g){break La}p[114610]=0;P(639,b|0,((t<<5)+a|0)+480289|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break K}}t=t+1|0;if(t>>>0<r[a+480188>>1]){continue}break}}e=q[d+528|0]|q[d+529|0]<<8;p[114610]=0;z=(e<<8&16711680|e<<24)>>>16|0;K(401,ba|0,z+fa&65535);c=p[114610];p[114610]=0;Qa:{if((c|0)==1){break Qa}Ra:{if(e){aa=k&16;ca=fa&65535;j=z>>>0>1?z:1;e=0;while(1){Sa:{if(!G){break Sa}c=q[d+856|0]|q[d+857|0]<<8|(q[d+858|0]<<16|q[d+859|0]<<24);p[114610]=0;g=J(256,b|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+(e<<2)|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ra}if(!g){break Sa}p[114610]=0;g=M(494,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ra}p[114610]=0;g=J(256,b|0,g|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ra}if(!g){break Sa}ia=Lb(d+128|0);p[114610]=0;ja=M(277,d+72|0)|0;c=p[114610];p[114610]=0;Ta:{Ua:{if((c|0)!=1){l=q[d+839|0];if(l){break Ua}p[114610]=0;J(807,b|0,d+144|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break M}o[d+120>>1]=q[d+144|0];m=q[C|0]+1|0;c=48;break Ta}f=I()|0;H()|0;break L}k=n[d+790|0];p[114610]=0;J(808,b|0,d+24|0)|0;c=p[114610];p[114610]=0;Va:{Wa:{if((c|0)!=1){c=q[d+24|0]|q[d+25|0]<<8;o[d+120>>1]=(c<<24|c<<8&16711680)>>>16;c=q[O|0]|q[O+1|0]<<8;m=((c<<24|c<<8&16711680)>>>16|0)+1|0;if(!(q[R|0]|q[R+1|0]<<8|(q[R+2|0]<<16|q[R+3|0]<<24))){break Va}h=p[b+8>>2];c=q[R|0]|q[R+1|0]<<8|(q[R+2|0]<<16|q[R+3|0]<<24);p[114610]=0;J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)==1){break M}p[114610]=0;J(809,b|0,d+144|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break M}c=q[u|0]|q[u+1|0]<<8|(q[u+2|0]<<16|q[u+3|0]<<24);p[114610]=0;g=J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)==1){break M}if(!g){break Wa}c=q[d+152|0]|q[d+153|0]<<8|(q[d+154|0]<<16|q[d+155|0]<<24);p[114610]=0;P(481,b|0,ia|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)!=1){break Wa}break M}break M}Xa:{if(!(q[d+160|0]|q[d+161|0]<<8|(q[d+162|0]<<16|q[d+163|0]<<24))){break Xa}c=q[d+160|0]|q[d+161|0]<<8|(q[d+162|0]<<16|q[d+163|0]<<24);p[114610]=0;g=J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)==1){break M}if(!g){break Xa}p[114610]=0;g=M(494,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break M}p[114610]=0;g=J(256,b|0,g|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break M}if(!g){break Xa}p[114610]=0;N(341,d+48|0,b|0,v(r[d+120>>1],m)|0);c=p[114610];p[114610]=0;if((c|0)==1){break M}Nd(ja,d+48|0);sb(d+48|0)}p[114610]=0;J(256,b|0,h|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break M}}c=k+(l>>>0<3?48:24)|0}p[114610]=0;k=e+ca|0;h=P(402,ba|0,k&65535,m|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break M}if(h){A=Rb(ba,k);p[114610]=0;J(496,A|0,ia|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break M}Lg(d+120|0,r[a+480188>>1]);F=0;while(1){p[114610]=0;f=P(471,A|0,F|0,0)|0;g=p[114610];p[114610]=0;Ya:{Za:{if((g|0)!=1){t=0;if(r[d+120>>1]){break Za}break Ya}break M}_a:{while(1){$a:{if(!q[d+839|0]){p[114610]=0;K(810,d+144|0,b|0);g=p[114610];p[114610]=0;if((g|0)!=1){k=Zc(d+144|0);g=Tf(d+144|0);h=q[d+144|0];n[f+1|0]=h>>>3&16|q[k|0]>>>4|h>>>1&32;n[f+3|0]=q[k|0]&15;n[f+5|0]=q[g|0];g=h&63;i=g?g+c|0:0;break $a}break M}p[114610]=0;K(598,d+144|0,b|0);g=p[114610];p[114610]=0;if((g|0)==1){break _a}x=d+144|0;y=Zc(d+144|0);l=Tf(d+144|0);k=vi(d+144|0);p[114610]=0;h=M(387,ja|0)|0;g=p[114610];p[114610]=0;ab:{bb:{if((g|0)!=1){n[f+4|0]=h;h=q[x|0];g=h&127;if(!g){break bb}i=c+g|0;break ab}break M}i=0;if((h|0)!=128){break ab}n[f|0]=254}n[f+1|0]=q[y|0]&63;n[f+3|0]=q[l|0];n[f+5|0]=q[k|0]}if(i+ -1>>>0<=119){n[f|0]=i}p[114610]=0;_(811,f|0,(ga|0)!=0|0,(W|0)!=0|0,ha|0,(aa|0)!=0|0);g=p[114610];p[114610]=0;if((g|0)!=1){da=(i|0)>84&X|da;f=f+6|0;t=t+1|0;if((t&65535)>>>0>=r[d+120>>1]){break Ya}continue}break}break M}break M}F=F+1|0;if((F|0)!=(m|0)){continue}break}}sb(ja);pb(ia)}e=e+1|0;if((j|0)!=(e|0)){continue}break}}na=d,oa=fn(T),p[na+72>>2]=oa;na=d,oa=pi(T),p[na+48>>2]=oa;cb:{while(1){p[114610]=0;e=J(812,d+72|0,d+48|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break N}db:{eb:{fb:{gb:{hb:{ib:{if(!e){if(!(q[d+448|0]|q[d+449|0]<<8|(q[d+450|0]<<16|q[d+451|0]<<24))){break ib}c=q[d+448|0]|q[d+449|0]<<8|(q[d+450|0]<<16|q[d+451|0]<<24);p[114610]=0;e=J(256,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=p[114610];p[114610]=0;if((c|0)==1){break Qa}if(!e){break ib}fa=z+fa|0;hp(T);break P}p[114610]=0;g=M(813,d+72|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break hb}h=g+2|0;c=r[g>>1];if(!c){f=0;break gb}p[114610]=0;e=J(546,w|0,c+ -1&65535)|0;c=p[114610];p[114610]=0;if((c|0)==1){break db}f=r[g>>1];if(!e){break gb}p[114610]=0;f=J(814,w|0,f+ -1&65535)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break fb}break db}hp(T);break O}f=I()|0;H()|0;break I}if(r[h>>1]==((f&65535)+1|0)){break eb}p[114610]=0;f=P(815,ba|0,1,0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break db}if((f|0)==65535){break eb}na=kc(w,r[g>>1]),oa=f,o[na>>1]=oa}g=Rb(ba,f);c=r[h>>1];p[114610]=0;e=M(816,c|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break cb}p[114610]=0;e=P(498,d+144|0,12,e|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break cb}c=on(Oe(e,p[Rb(ba,f)+12>>2]+ -1|0));p[114610]=0;J(499,g|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break cb}z=f>>>0<(z&65535)>>>0?z:f+1|0}p[114610]=0;M(817,d+72|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}break N}break}f=I()|0;H()|0;break I}f=I()|0;H()|0;break I}f=I()|0;H()|0;break I}f=I()|0;H()|0;break I}la=la+1|0;if((la&255)>>>0<ka>>>0){continue}break}}p[114610]=0;K(489,a+484360|0,0);b=p[114610];p[114610]=0;if((b|0)!=1){if(!(da&1)){j=r[a+480192>>1];if(j){f=1;while(1){c=(((f&65535)<<2)+a|0)+900380|0;b=p[c>>2];if(b){Nb(Us(b));j=r[a+480192>>1]}p[c>>2]=0;f=f+1|0;if((f&65535)>>>0<=(j&65535)>>>0){continue}break}}o[a+480192>>1]=0}jb:{kb:{lb:{mb:{nb:{ob:{pb:{if(ma){p[114610]=0;c=J(2,d+144|0,14913)|0;b=p[114610];p[114610]=0;if((b|0)==1){break pb}p[114610]=0;N(650,a|0,2,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break ob}pb(c)}j=14960;switch(q[d+839|0]){case 3:break kb;case 2:break lb;case 1:break mb;case 0:break nb;default:break jb}}f=I()|0;H()|0;break g}f=I()|0;H()|0;pb(c);break g}j=r[a+480188>>1]>4?14961:14982;break jb}j=14996;break jb}j=15014;break jb}j=15032}p[114610]=0;c=J(2,d+8|0,15059)|0;b=p[114610];p[114610]=0;qb:{rb:{sb:{tb:{ub:{if((b|0)!=1){p[114610]=0;K(219,d+72|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break ub}p[114610]=0;N(537,d+144|0,d+72|0,d+839|0);b=p[114610];p[114610]=0;if((b|0)==1){break tb}xb(a+1304436|0,d+144|0);pb(d+144|0);yb(d+72|0);pb(c);p[114610]=0;c=J(2,d+144|0,15075)|0;b=p[114610];p[114610]=0;if((b|0)==1){break rb}xb(a+1304448|0,c);pb(c);p[114610]=0;J(238,a+1304460|0,j|0)|0;b=p[114610];p[114610]=0;f=1;if((b|0)==1){break qb}p[a+1304496>>2]=2;break e}f=I()|0;H()|0;break g}f=I()|0;H()|0;break sb}f=I()|0;H()|0;yb(d+72|0)}pb(c);break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break I}f=I()|0;H()|0;sb(ja)}pb(ia);break I}f=I()|0;H()|0;break I}f=I()|0;H()|0}hp(T);break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;break g}f=I()|0;H()|0;sb(O)}vP(Y);break a}f=0}vP(Y)}sb(d+816|0)}fb=d+896|0;return f|0}f=I()|0;H()|0}sb(d+816|0);L(f|0);E()}function ds(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,O=0,R=0,T=0,V=0,W=0,X=0,Y=0,_=0,$=0,aa=0,ba=0,da=0,ea=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;g=fb-176|0;fb=g;Zpa(a);C=mqa(g+144|0);e=r[d+4>>1];o[C+24>>1]=e;j=p[d>>2];p[C+16>>2]=j;_=p[d+16>>2];ga=q[d+6|0];la=b+484360|0;if(ga>>>0>=Ah(la)>>>0){ga=q[la+16|0]}ma=a;R=li(la,ga);p[114610]=0;x=J(1333,g+104|0,b|0)|0;a=p[114610];p[114610]=0;a:{if((a|0)!=1){ta=x+4|0;f=p[ta>>2];p[114610]=0;$=P(1334,g+72|0,b|0,ga|0)|0;a=p[114610];p[114610]=0;b:{if((a|0)!=1){o[f+64>>1]=e;o[f+62>>1]=e;p[f+52>>2]=j;p[f+48>>2]=j;X=g- -64|0;Df(X);pa=ct(g+56|0);c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{qa=c&7;ua=(qa|0)!=7;n:{if(ua){break n}p[114610]=0;P(1335,X|0,1,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;P(1335,X|0,2,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;P(1335,X|0,3,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;P(1335,X|0,28,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;P(1335,X|0,35,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;P(1335,X|0,37,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;P(1335,X|0,36,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;P(1335,X|0,38,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;P(1336,pa|0,12,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;P(1336,pa|0,13,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}if(r[b+480188>>1]){e=x+20|0;a=0;while(1){if(q[((a<<5)+b|0)+480281|0]&4){Ca=Gc(e,a),Da=-1,p[Ca+16>>2]=Da}a=a+1|0;if(a>>>0<r[b+480188>>1]){continue}break}}if((_|0)!=2){break n}a=r[d+12>>1];if(fc(R)>>>0<=a>>>0){break n}a=r[kc(R,a)>>1];p[114610]=0;e=b+484344|0;j=J(442,e|0,a|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break d}if(!j){break n}h=Rb(e,a);j=p[d+8>>2];p[114610]=0;h=J(1337,h|0,j|0)|0;B=p[114610];p[114610]=0;if((B|0)==1){break d}if(!h){break n}a=Rb(e,a);p[114610]=0;a=P(471,a|0,j|0,0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break e}if(!r[b+480188>>1]){break n}j=x+20|0;e=0;while(1){o:{p:{q:{switch(q[a|0]+ -253|0){case 0:if(r[b+480192>>1]){break p}break;case 1:case 2:break p;default:break q}}p[114610]=0;h=M(556,a|0)|0;B=p[114610];p[114610]=0;if((B|0)==1){break f}if(!h){break o}if(es(a)){break o}}Ca=Gc(j,e),Da=-1,p[Ca+16>>2]=Da}a=a+6|0;e=e+1|0;if(e>>>0<r[b+480188>>1]){continue}break}}ba=f- -64|0;T=f+48|0;aa=f+68|0;xa=f+44|0;ra=x+8|0;ha=c&1;z=x+20|0;D=b+1074308|0;W=b+484344|0;ya=(_|0)!=3;va=(_|0)!=2;B=0;while(1){if(!(u[x+32>>3]<u[d+8>>3]|ya)){n[C+26|0]=1;break g}p[f+48>>2]=p[f+52>>2];a=r[f+64>>1];o[f+62>>1]=a;p[114610]=0;a=J(546,R|0,a|0)|0;e=p[114610];p[114610]=0;r:{s:{t:{u:{v:{if((e|0)!=1){w:{if(!a){break w}if(s[f+48>>2]<s[Rb(W,r[kc(R,r[f+62>>1])>>1])+12>>2]){break w}p[T>>2]=0;vb(g,D,63);if(tb(g)){a=p[f+56>>2];p[f+56>>2]=0;p[f+48>>2]=a}a=r[f+64>>1]+1|0;o[f+62>>1]=a;o[f+64>>1]=a}e=r[f+62>>1];a=f;x:{if(fc(R)>>>0>e>>>0){e=r[kc(R,r[f+62>>1])>>1];break x}e=65535}o[a+60>>1]=e;p[114610]=0;a=J(442,W|0,e&65535)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}if(!(r[f+60>>1]==65535|va|a|r[f+62>>1]!=r[d+12>>1])){n[C+26|0]=1;break g}y:{if(r[f+60>>1]<ke(W)>>>0){break y}while(1){a=f;h=a;z:{A:{if(r[a+60>>1]!=65535){e=r[f+62>>1];if(fc(R)>>>0>e>>>0){break A}}if(r[R+28>>1]==r[f+62>>1]){break y}e=r[R+28>>1];break z}e=r[f+62>>1]+1|0}o[h+62>>1]=e;a=f;B:{if(fc(R)>>>0>(e&65535)>>>0){e=r[kc(R,r[f+62>>1])>>1];break B}e=65535}o[a+60>>1]=e;o[f+64>>1]=r[f+62>>1];p[114610]=0;a=J(442,W|0,e&65535)|0;e=p[114610];p[114610]=0;if((e|0)==1){break h}C:{if(a){break C}a=r[f+62>>1];p[114610]=0;a=U(1338,$|0,a|0,0,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break h}if(!a){break C}if(!_){break y}p[114610]=0;a=U(1339,$|0,ba|0,T|0,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}if(!a){break y}a=p[x+36>>2];p[C>>2]=p[x+32>>2];p[C+4>>2]=a;p[114610]=0;K(1340,ma|0,C|0);a=p[114610];p[114610]=0;if((a|0)==1){break i}p[C+16>>2]=p[T>>2];o[C+24>>1]=r[ba>>1];p[114610]=0;S(1341,x|0);a=p[114610];p[114610]=0;if((a|0)==1){break i}a=r[f+64>>1];o[f+62>>1]=a;Ca=f,Da=r[kc(R,a)>>1],o[Ca+60>>1]=Da;p[f+52>>2]=p[f+48>>2];break y}if(r[f+60>>1]>=ke(W)>>>0){continue}break}}if(r[ba>>1]==65535){break g}a=r[f+60>>1];p[114610]=0;a=J(442,W|0,a|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}if(!a){if(r[R+28>>1]==r[f+62>>1]){if(!_){break g}p[114610]=0;a=U(1339,$|0,ba|0,T|0,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}if(!a){break g}a=p[x+36>>2];p[C>>2]=p[x+32>>2];p[C+4>>2]=a;p[114610]=0;K(1340,ma|0,C|0);a=p[114610];p[114610]=0;if((a|0)==1){break i}p[C+16>>2]=p[T>>2];o[C+24>>1]=r[ba>>1];p[114610]=0;S(1341,x|0);a=p[114610];p[114610]=0;if((a|0)==1){break i}p[f+52>>2]=p[f+48>>2];continue}o[f+64>>1]=r[f+62>>1]+1;continue}if(s[f+48>>2]>=s[Rb(W,r[f+60>>1])+12>>2]){p[T>>2]=0}a=r[f+62>>1];if(!((a|0)!=r[d+12>>1]|va|p[T>>2]!=p[d+8>>2])){n[C+26|0]=1;break g}e=p[T>>2];p[114610]=0;a=U(1338,$|0,a|0,e|0,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}if(a){if(!_){break g}p[114610]=0;a=U(1339,$|0,ba|0,T|0,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}if(!a){break g}a=p[x+36>>2];p[C>>2]=p[x+32>>2];p[C+4>>2]=a;p[114610]=0;K(1340,ma|0,C|0);a=p[114610];p[114610]=0;if((a|0)==1){break i}p[C+16>>2]=p[T>>2];o[C+24>>1]=r[ba>>1];p[114610]=0;S(1341,x|0);a=p[114610];p[114610]=0;if((a|0)==1){break i}p[f+52>>2]=p[f+48>>2];continue}o[C+22>>1]=r[f+62>>1];a=p[f+48>>2];p[C+12>>2]=a;p[f+52>>2]=a+1;D:{E:{if(a>>>0>=s[Rb(W,r[f+60>>1])+12>>2]){p[T>>2]=0;break E}if(p[T>>2]){break D}}a=0;if(!r[b+480188>>1]){break D}while(1){e=p[x+36>>2];j=p[x+32>>2];h=Gc(z,a);p[h>>2]=j;p[h+4>>2]=e;e=p[f>>2];Ca=Gc(z,a),Da=e,p[Ca+8>>2]=Da;a=a+1|0;if(a>>>0<r[b+480188>>1]){continue}break}}a=Rb(W,r[f+60>>1]);e=p[f+48>>2];p[114610]=0;a=P(471,a|0,e|0,0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break u}e=0;Y=0;ia=0;if(!r[b+480188>>1]){break s}while(1){vb(g,D,77);F:{if(Ca=tb(g),Da=0,Ea=p[((e<<5)+b|0)+480280>>2]&1024,Ea?Ca:Da){break F}p[114610]=0;j=M(1342,a|0)|0;h=p[114610];p[114610]=0;G:{H:{I:{if((h|0)==1){break I}if(j){J:{if(!ha){break J}j=q[a+1|0];if(j+ -251>>>0<5|!j){break J}p[114610]=0;j=M(1343,a|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break I}p[114610]=0;h=M(1344,a|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break v}o[g+48>>1]=h;n[g|0]=q[a+1|0];o[g+2>>1]=r[g+48>>1];p[114610]=0;h=J(1345,ra|0,g|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break v}o[h>>1]=j}Gs((v(e,896)+f|0)+1418|0);break F}j=v(e,896)+f|0;h=j+1422|0;k=q[a+4|0]|q[a+5|0]<<8;n[h|0]=k;n[h+1|0]=k>>>8;j=j+1418|0;h=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);n[j|0]=h;n[j+1|0]=h>>>8;n[j+2|0]=h>>>16;n[j+3|0]=h>>>24;K:{switch(q[a+3|0]+ -16|0){case 0:j=q[a+5|0];p[114610]=0;N(1346,b|0,f|0,j|0);j=p[114610];p[114610]=0;if((j|0)==1){break I}break F;case 3:break G;case 4:break H;case 1:break K;default:break F}}vb(g,D,5);if(!tb(g)){break F}j=q[a+5|0];if(!j){break F}p[114610]=0;N(1346,b|0,f|0,j|0);j=p[114610];p[114610]=0;if((j|0)!=1){break F}}a=I()|0;H()|0;break c}j=q[a+5|0];h=j&240;if((h|0)==96){ia=(j&15)+ia|0;break F}if((h|0)!=224|Y){break F}j=q[a+5|0]&15;if(p[b+480180>>2]&2){Y=0;if(!j){break F}}Y=j+1|0;break F}j=q[a+5|0];if((j&240)!=224){break F}Y=(j&15)+1|0}a=a+6|0;e=e+1|0;if(e>>>0<r[b+480188>>1]){continue}break}break t}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}e=ia;if(Y){break r}}Y=1;ia=e}G=v(p[f+40>>2]+ia|0,Y);L:{if(!r[b+480188>>1]){j=0;ja=0;na=0;da=0;ka=0;break L}m=G+ -1|0;h=G-Y|0;O=v(h,1e4);e=0;ka=0;da=0;na=0;ja=0;j=0;while(1){M:{V=v(e,896);k=V+f|0;l=k+1418|0;N:{if(eqa(l)){break N}vb(g,D,77);if(Ca=tb(g),Da=0,Ea=p[((e<<5)+b|0)+480280>>2]&1024,Ea?Ca:Da){break N}i=q[k+1423|0];ea=k+1421|0;A=q[ea|0];y=q[l|0];a=k+1419|0;t=q[a|0];if(t){n[k+1429|0]=0;n[k+1433|0]=t;Ca=Gc(z,e),Da=255,n[Ca+21|0]=Da}p[114610]=0;t=M(556,l|0)|0;F=p[114610];p[114610]=0;if((F|0)==1){break M}if(t){n[k+1429|0]=y}p[114610]=0;F=M(556,l|0)|0;t=p[114610];p[114610]=0;if((t|0)==1){break M}t=k+608|0;O:{P:{Q:{R:{S:{T:{if(q[a|0]?0:!F){break T}F=k+1433|0;a=q[F|0];if(r[b+480192>>1]){if(r[b+480192>>1]<a>>>0){break T}a=p[((q[F|0]<<2)+b|0)+900380>>2];if(!a){break T}U:{if(!(n[a+15|0]&1)){break U}F=p[a+8>>2];p[114610]=0;N(1347,t|0,F|0,b|0);F=p[114610];p[114610]=0;if((F|0)!=1){break U}a=I()|0;H()|0;break c}if(!Ud(y)){break T}a=r[Yc(a+236|0,y+ -1|0)>>1]}a=a&65535;if(!a|a>>>0>r[b+480190>>1]){break T}y=v(a,104)+b|0;F=y+484414|0;a=r[F>>1];if(a&32){a=r[y+484408>>1];p[114610]=0;N(1347,t|0,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break S}a=r[F>>1]}if(!(a&512)){break T}a=p[ta>>2];p[114610]=0;S(1348,(a+V|0)+608|0);a=p[114610];p[114610]=0;if((a|0)==1){break S}Ca=Gc(z,e),Da=0,p[Ca+16>>2]=Da}V:{W:{X:{V=k+1420|0;a=q[V|0];switch(a+ -1|0){case 1:break Q;case 2:case 3:break W;case 0:break X;default:break V}}a=q[k+1422|0];Ca=Gc(z,e),Da=a,n[Ca+21|0]=Da;break Q}a=q[k+1422|0];if(!a){break Q}n[k+1462|0]=a;break Q}if((a|0)==11){break R}break Q}a=I()|0;H()|0;break c}if(!q[k+1422|0]){break Q}Fx(g,b,l,0);a=_b(g);p[k+1384>>2]=p[g>>2]<<2;if(!q[a|0]){break Q}A=0;break P}Y:{Z:{_:{switch(A+ -12|0){case 0:a=p[f+48>>2];i=r[f+60>>1];p[114610]=0;a=Z(1349,b|0,i|0,a|0,e&65535,0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break M}p[f+56>>2]=0;o[f+64>>1]=a;if(!(p[b+480180>>2]&5?0:na)){p[f+52>>2]=0}da=1;if(!ha){ka=1;break N}p[k+1412>>2]=0;n[k+1469|0]=0;ka=1;break O;case 2:p[114610]=0;a=U(1350,b|0,f|0,e&65535,i|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break Z}if((a|0)==-1){A=14;break P}p[f+52>>2]=a;if(!ka){o[f+64>>1]=r[f+62>>1]+1}na=1;if(!ha){break N}p[k+1412>>2]=0;n[k+1469|0]=0;break O;case 5:vb(g,D,5);A=17;if(tb(g)){break P}a=p[f+48>>2];l=r[f+60>>1];p[114610]=0;a=Z(1349,b|0,l|0,a|0,e&65535,0)|0;l=p[114610];p[114610]=0;$:{aa:{if((l|0)!=1){a=v(a,1e4);if(!ha|!(p[b+480180>>2]&16777250)){break $}if(a>>>0<1e4){break aa}n[k+1463|0]=(a>>>0)/1e4;break $}a=I()|0;H()|0;break c}a=v(q[k+1463|0],1e4)}l=(a>>>0)/1e4|0;ba:{if(a>>>0>319999){break ba}y=v(O,l&15);a=p[f+44>>2];if((l&240)==16){a=a+y|0;break ba}l=a-y|0;a=l>>>0>a>>>0?0:l}p[f+44>>2]=a;a=p[p[b+8>>2]+20>>2];l=p[p[b+8>>2]+24>>2];vb(g,D,8);En(xa,v(a,1e4),tb(g)?255e4:v(l,1e4));break P;case 8:A=20;ca:{switch((i&240)+ -144>>>4|0){case 0:if(i>>>0>145){break P}p[k+696>>2]=p[k+696>>2]&-257|((i|0)==145)<<8;break P;case 1:n[k+1464|0]=i&15;break P;case 2:l=e;a=e;if(p[b+480180>>2]==2){l=r[b+480188>>1]+ -1|0;a=0}if(!(i&15)){da=0;j=1;l=l&65535;if((a&65535)>>>0>l>>>0){break P}while(1){y=p[x+36>>2];F=p[x+32>>2];j=a&65535;oa=Gc(z,j);p[oa>>2]=F;p[oa+4>>2]=y;y=p[f>>2];Ca=Gc(z,j),Da=y,p[Ca+8>>2]=Da;y=p[f+48>>2];Ca=Gc(z,j),Da=y,p[Ca+12>>2]=Da;p[(v(j,896)+f|0)+1412>>2]=p[f+48>>2];j=1;a=a+1|0;if((a&65535)>>>0<=l>>>0){continue}break}break P}vb(g,D,16);if(!tb(g)){da=0;ja=1;if(p[b+480180>>2]!=2|(a&65535)>>>0>(l&65535)>>>0){break P}break Y}if((a&65535)>>>0<=(l&65535)>>>0){break Y}da=0;ja=1;break P;case 6:break ca;default:break P}}n[k+1472|0]=i&15;break P;case 7:A=19;a=i&240;if((a|0)!=240){if((a|0)!=96){break P}if(i&15){Ca=f,Da=p[Gc(z,e)+12>>2],p[Ca+56>>2]=Da;ja=1;break P}a=p[x+36>>2];j=p[x+32>>2];l=Gc(z,e);p[l>>2]=j;p[l+4>>2]=a;a=p[f>>2];Ca=Gc(z,e),Da=a,p[Ca+8>>2]=Da;a=p[f+48>>2];Ca=Gc(z,e),Da=a,p[Ca+12>>2]=Da;p[k+1412>>2]=p[f+48>>2];j=1;break P}n[k+1472|0]=i&15;break P;case 1:case 3:case 4:case 6:break P;default:break _}}if((A|0)!=28){break P}if((i&240)==160){vb(g,D,58);A=28;if(tb(g)){break P}n[k+1464|0]=i&15;break P}A=28;break P}a=I()|0;H()|0;break c}y=p[T>>2]+1|0;while(1){p[(v(a&65535,896)+f|0)+1412>>2]=y;ja=1;da=0;a=a+1|0;if((a&65535)>>>0<=(l&65535)>>>0){continue}break}}if(!ha){break N}da:{ea:{fa:{ga:{ha:{ia:{ja:{switch(A+ -2|0){case 0:if(!i){break O}vb(g,D,90);if(!tb(g)){n[k+1440|0]=i}n[k+1439|0]=i;break O;case 1:if(!i){break O}vb(g,D,90);if(!tb(g)){n[k+1439|0]=i}n[k+1440|0]=i;break O;case 2:if(!i){break O}p[k+1384>>2]=i<<2;break O;case 8:if(!i){break O}p[k+1272>>2]=i<<8;break O;case 4:case 9:if(!i){break O}n[k+1437|0]=i;break O;case 11:Ca=Gc(z,e),Da=i,n[Ca+21|0]=Da;break O;case 21:a=i<<(!(p[b+480180>>2]&59593760)&i<<24>>24>-1)&255;if(a>>>0<=128){p[aa>>2]=a<<1;break O}if(p[b+480180>>2]&16777250){break O}p[aa>>2]=256;break O;case 22:vb(g,D,9);ka:{if(tb(g)){a=k+1445|0;if(i){n[a|0]=i;break ka}i=q[a|0];break ka}if(i){n[f+1445|0]=i;break ka}i=q[f+1445|0]}a=aa;l=i&240;i=i&15;la:{if(!(!l|(i|0)!=15)){y=p[aa>>2]+(l>>>4<<!(p[b+480180>>2]&59593760)<<1&254)|0;break la}y=p[aa>>2]-(i<<(p[b+480180>>2]&59593760?1:2))|0;if(!(!i|(l|0)!=240)){break la}y=p[aa>>2]+v(h,l>>>4<<(p[b+480180>>2]&59593760?1:2)&255)|0;if(l){break la}y=p[aa>>2]-v(h,i<<(p[b+480180>>2]&59593760?1:2))|0}p[a>>2]=y;Vd(aa,0,256);break O;case 19:if(i>>>0>64){break O}p[k+1368>>2]=i;break O;case 20:a=k+1444|0;ma:{if(i){n[a|0]=i;break ma}i=q[a|0]}y=k+1368|0;l=p[y>>2];p[g>>2]=l;a=i;A=a&240;i=a&15;na:{if(!(!A|(i|0)!=15)){p[g>>2]=l+(a>>>4|0);break na}if(!(!i|(A|0)!=240)){p[g>>2]=l-i;break na}if(i){p[g>>2]=l-v(i,h);break na}p[g>>2]=l+v(h,a>>>4|0)}Vd(g,0,64);p[y>>2]=p[g>>2];break O;case 7:kl(b,t,i,8);break O;case 25:break da;case 6:break ea;case 24:break fa;case 3:break ga;case 5:break ha;case 18:break ia;case 17:break ja;default:break O}}if(!r[b+480188>>1]|i>>>0>15){break ia}l=(i&1)<<14;a=0;while(1){y=v(a,896)+f|0;p[y+696>>2]=(l|p[y+696>>2]&-16385)^16384;a=a+1|0;if(a>>>0<r[b+480188>>1]){continue}break}}if((i&240)!=128){break O}kl(b,t,i&15,4);break O}if(i){n[k+1437|0]=i}i=0}Uj(t,i);break O}aL(b,t,i);break O}$K(t,i);break O}_K(t,i)}oa:{pa:{switch(q[V|0]+ -2|0){case 0:kl(b,t,q[k+1422|0],6);break oa;case 5:vb(g,D,53);i=tb(g);a=q[k+1422|0];if(i){n[k+1451|0]=a&15;break oa}Uj(t,a<<4);break oa;case 6:break pa;default:break oa}}Uj(t,q[k+1422|0])}qa:{ra:{sa:{ta:{a=q[ea|0];switch(a+ -5|0){case 3:break ra;case 0:case 2:break sa;case 1:break N;default:break ta}}switch(a+ -26|0){case 1:break qa;case 0:break sa;default:break N}}ua:{if(p[b+480180>>2]&16777248){a=G;if(!(q[b+480208|0]&4)){break ua}}a=h}i=q[k+1451|0];vb(g,D,21);t=tb(g);k=k+1447|0;a=v(a,i);n[k|0]=q[k|0]+(t?a<<2:a);break N}va:{if(p[b+480180>>2]&16777248){a=G;if(!(q[b+480208|0]&4)){break va}}a=h}i=q[k+1454|0];vb(g,D,21);t=tb(g);k=k+1448|0;a=v(a,i);n[k|0]=q[k|0]+(t?a<<2:a);break N}a=k+1449|0;n[a|0]=q[a|0]+v(m,q[k+1457|0]);p[114610]=0;K(1351,b|0,t|0);a=p[114610];p[114610]=0;if((a|0)==1){break M}}e=e+1|0;if(e>>>0<r[b+480188>>1]){continue}break L}break}a=I()|0;H()|0;break c}if(p[f+40>>2]==65535?p[b+480180>>2]==4:0){break g}p[f+32>>2]=p[b+480216>>2];if(ZK(Rb(W,r[f+60>>1]))){Ca=f,Da=p[Rb(W,r[f+60>>1])+16>>2],p[Ca+32>>2]=Da}p[114610]=0;k=J(1352,b|0,f|0)|0;a=p[114610];p[114610]=0;wa:{xa:{if((a|0)!=1){a=v(k,G);u[x+32>>3]=+(a>>>0)/+s[b+24620>>2]+u[x+32>>3];p[f>>2]=a+p[f>>2];if(!(!r[b+480188>>1]|ua)){A=0;F=(B|0)!=0&(k|0)!=(B|0);oa=G>>>0>1?G:1;za=Y+ -1|0;while(1){ya:{if(p[Gc(z,A)+16>>2]==-1){break ya}m=v(A,896)+f|0;O=m+1423|0;a=q[O|0];l=1;za:{Aa:{V=m+1421|0;switch(q[V|0]+ -4|0){case 0:case 2:break za;default:break Aa}}l=q[m+1420|0]==11}if(q[m+1419|0]){p[m+1268>>2]=0}p[114610]=0;ea=m+1418|0;e=M(556,ea|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break k}t=m+608|0;h=a&15;i=0;Ba:{if(!e){break Ba}Ca:{Da:{Ea:{if(!l){break Ea}if(!q[Gc(z,A)+20|0]){break Ea}e=p[m+1308>>2];p[114610]=0;e=Qn(1353,b,t,e,0);i=ib;y=p[114610];p[114610]=0;if((y|0)==1){break Da}p[m+616>>2]=e;p[m+620>>2]=i}n[m+1432|0]=q[m+1429|0];y=m+1300|0;Aa=p[y>>2];e=q[m+1433|0];if(!e){break Ca}p[114610]=0;fa(1354,b|0,t|0,e|0,l|0,1,1);e=p[114610];p[114610]=0;if((e|0)!=1){break Ca}break j}a=I()|0;H()|0;break c}e=q[ea|0];p[114610]=0;ca(1355,b|0,t|0,e|0,l|0,1,0,65535);e=p[114610];p[114610]=0;if((e|0)==1){break j}a=a>>>4|0;Ca=Gc(z,A),Da=1,n[Ca+20|0]=Da;Ba=!(p[b+480180>>2]&16777250);e=q[V|0];Fa:{if(!((e+ -19&255)>>>0>1|h>>>0>=G>>>0)){i=h;if((q[O|0]&-16)==208){break Fa}}i=a>>>0<G>>>0?(e|0)==33?a:0:0}if(!(Ba|(!i|Y>>>0<2))){i=v(p[f+40>>2]+ia|0,za)+i|0}if(!l){Ca=Gc(z,A),Da=0,p[Ca+16>>2]=Da}e=q[V|0];Ga:{Ha:{Ia:{if(e+ -19>>>0>=2){if((e|0)!=9){break Ia}break Ha}if((a|0)==8){break Ha}}if(q[m+1420|0]!=2){break Ga}}p[y>>2]=Aa}Ja:{Ka:{switch(e+ -39|0){default:if((e|0)!=10){break Ja}n[g|0]=0;a=p[f+48>>2];e=r[f+60>>1];p[114610]=0;a=Z(1349,b|0,e|0,a|0,A&65535,g|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){if(!q[g|0]){a=a<<8;if(!a){a=p[m+1272>>2]}a=(q[m+1464|0]<<16)+a|0}p[114610]=0;N(1356,b|0,t|0,a|0);a=p[114610];p[114610]=0;if((a|0)!=1){break Ba}}a=I()|0;H()|0;break c;case 2:a=p[m+684>>2];e=q[O|0];p[114610]=0;a=rg(793,QNa(NNa(a,0,e,0),ib,255,0),ib);e=p[114610];p[114610]=0;if((e|0)==1){break j}p[114610]=0;N(1356,b|0,t|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break j}break Ba;case 1:break Ja;case 0:break Ka}}if(!p[m+712>>2]){break Ja}p[114610]=0;Q(1357,x|0,A&65535,B|0,-1);a=p[114610];p[114610]=0;if((a|0)==1){break j}a=q[O|0];p[114610]=0;N(1358,f|0,t|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break j}i=p[f+40>>2]+ -1|0;break Ba}if(q[m+1420|0]!=15){break Ba}a=q[m+1422|0];if(a>>>0>9){break Ba}e=p[m+712>>2];if(!e){break Ba}La:{if(!a){a=p[m+1272>>2];break La}a=p[(e+(a<<2)|0)- -64>>2];p[m+1272>>2]=a}p[114610]=0;N(1356,b|0,t|0,a|0);a=p[114610];p[114610]=0;if((a|0)!=1){break Ba}a=I()|0;H()|0;break c}Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{switch(q[ea|0]+ -253|0){case 0:if(r[b+480192>>1]){break Ua}break;case 1:case 2:break Ua;default:break Va}}e=q[V|0];if((e+ -19&255)>>>0<=1){if(h>>>0>=G>>>0){a=j;break Sa}a=j;if((q[O|0]&-16)==192){break Ua}break Sa}y=e;if((e|0)==25){break Ua}a=j;if(!((y|0)==33&(h|0)!=0&i+h>>>0<G>>>0)){break Ta}}e=q[V|0];a=1}if((e|0)==13){break Ra}}if(q[m+1420|0]==1){p[m+1296>>2]=q[m+1422|0]<<2}if((!p[m+712>>2]|a)&1){break Qa}h=0;if(e>>>0>42){break Oa}break Pa}p[m+1296>>2]=q[O|0]<<2;e=13;if(!((!p[m+712>>2]|a)&1)){break Pa}}if(!(a&1)){break Na}break Ma}vb(g,X,e);h=1;if(tb(g)){break Oa}h=a;if(q[V|0]!=19){break Oa}e=q[O|0]&240;if((e|0)!=32){h=a;if((e|0)!=16){break Oa}}h=1}a=m+1420|0;if(16>q[a|0]){uj(g,pa,q[a|0]);if((tb(g)|h)&1){break Ma}break Na}if(h&1){break Ma}}if(F){p[114610]=0;Q(1357,x|0,A&65535,B|0,-1);a=p[114610];p[114610]=0;if((a|0)==1){break k}}Wa:{Xa:{Ya:{a=q[V|0];if(a+ -6>>>0>=2){Za:{switch(a+ -19|0){case 1:break Xa;case 0:break Ya;default:break Za}}if((a|0)!=11){break Wa}}if(!G|(p[b+480180>>2]==1?!q[O|0]:0)){break Wa}a=m+1480|0;e=0;while(1){n[a|0]=!e|q[a|0]&254;Om(b,t,q[O|0]);e=e+1|0;if((oa|0)!=(e|0)){continue}break}break Wa}e=q[O|0];if(!(e&15)){if(!(p[b+480180>>2]&1048580)){break Wa}e=q[O|0]}a=m+1480|0;n[a|0]=q[a|0]|1;a=e&240;if((a|0)!=176){if((a|0)!=160){break Wa}Ko(b,t,e&15,0);break Wa}Jo(b,t,e&15,0);break Wa}_a:{switch(q[O|0]+ -158|0){case 0:p[114610]=0;Q(1357,x|0,A&65535,B|0,-1);a=p[114610];p[114610]=0;if((a|0)==1){break k}p[m+696>>2]=p[m+696>>2]&-129;break Wa;case 1:break _a;default:break Wa}}p[114610]=0;Q(1357,x|0,A&65535,B|0,-1);a=p[114610];p[114610]=0;if((a|0)==1){break k}p[m+696>>2]=p[m+696>>2]|128;if(!p[m+684>>2]|s[t+4>>2]>0){break Wa}p[114610]=0;a=M(556,ea|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}if(q[m+696|0]&2?!a:0){break Wa}e=p[m+684>>2]+ -1|0;a=t;p[a>>2]=-1;p[a+4>>2]=e}e=m+1480|0;n[e|0]=q[e|0]|1;$a:{ab:{bb:{cb:{h=m+1420|0;switch(q[h|0]+ -3|0){case 0:case 1:break ab;case 3:break bb;case 2:break cb;default:break $a}}a=q[m+1422|0];vb(g,D,41);Ko(b,t,a,tb(g));break $a}a=q[m+1422|0];vb(g,D,41);Jo(b,t,a,tb(g));break $a}a=q[m+1422|0];db:{if(a){break db}vb(g,D,41);a=0;if(!tb(g)){break db}a=q[m+1462|0];if(!a){break $a}}if(!G){break $a}h=q[h|0]==3?a<<4:a;a=0;while(1){n[e|0]=!a|q[e|0]&254;Om(b,t,h&255);a=a+1|0;if((G|0)!=(a|0)){continue}break}}if(l){a=p[Gc(z,A)+16>>2];e=Gc(z,A);p[e+16>>2]=p[e+16>>2]+G;p[114610]=0;Q(1357,x|0,A&65535,k|0,(a+i|0)+1|0);a=p[114610];p[114610]=0;if((a|0)!=1){break ya}a=I()|0;H()|0;break c}a=Gc(z,A);p[a+16>>2]=p[a+16>>2]+(G-i|0);break ya}p[114610]=0;S(1348,t|0);a=p[114610];p[114610]=0;if((a|0)==1){break k}Ca=Gc(z,A),Da=0,p[Ca+16>>2]=Da}A=A+1|0;if(A>>>0<r[b+480188>>1]){continue}break}}if(!ja){break wa}vb(g,D,68);if(Ca=tb(g),Da=0,Ea=ka|na,Ea?Ca:Da){break wa}vb(g+48|0,D,49);if(tb(g+48|0)&ka){break wa}vb(g+40|0,D,103);B=k;if(tb(g+40|0)&da){continue}a=0;e=bqa(g);if(!r[b+480188>>1]){break xa}while(1){eb:{h=v(a,896)+f|0;j=q[h+1423|0];h=q[h+1421|0];if(!((h|0)!=19|(j+ -97&255)>>>0>14?!((j+79&255)>>>0<15?(h|0)==20:0):0)){h=Gc(z,a);B=p[h+4>>2];h=p[h>>2];p[114610]=0;p[g+48>>2]=h;p[g+52>>2]=B;h=J(1359,e|0,g+48|0)|0;B=p[114610];p[114610]=0;if((B|0)==1){break eb}if(!p[h>>2]){p[114610]=0;h=J(1359,e|0,g+48|0)|0;B=p[114610];p[114610]=0;if((B|0)==1){break eb}p[h>>2]=1}p[114610]=0;h=J(1359,e|0,g+48|0)|0;B=p[114610];p[114610]=0;if((B|0)==1){break eb}h=p[h>>2];p[114610]=0;j=J(1360,h|0,(j&15)+1|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break eb}p[114610]=0;h=J(1359,e|0,g+48|0)|0;B=p[114610];p[114610]=0;if((B|0)==1){break eb}p[h>>2]=j}a=a+1|0;if(a>>>0<r[b+480188>>1]){continue}break xa}break}break l}a=I()|0;H()|0;break c}Ca=g,Da=fn(e),p[Ca+40>>2]=Da;Ca=g,Da=pi(e),p[Ca+32>>2]=Da;while(1){p[114610]=0;a=J(1361,g+40|0,g+32|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break l}if(!a){fb:{if(p[b+480180>>2]!=32){break fb}a=0;if(!r[b+480188>>1]){break fb}while(1){j=v(a,896)+f|0;if(!(q[j+1421|0]!=20|(q[j+1423|0]+79&255)>>>0>14)){j=p[x+36>>2];h=p[x+32>>2];B=Gc(z,a);p[B>>2]=h;p[B+4>>2]=j;j=p[f>>2];Ca=Gc(z,a),Da=j,p[Ca+8>>2]=Da}a=a+1|0;if(a>>>0<r[b+480188>>1]){continue}break}}QK(e);break wa}p[114610]=0;j=M(1362,g+40|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){wa=u[x+32>>3];u[x+32>>3]=(wa-u[j>>3])*+(p[j+8>>2]+ -1|0)+wa;a=0;gb:{if(!r[b+480188>>1]){break gb}while(1){if(u[Gc(z,a)>>3]!=u[j>>3]){a=a+1|0;if(a>>>0<r[b+480188>>1]){continue}break gb}break}h=p[f>>2];B=Gc(z,a);p[f>>2]=p[f>>2]+v(p[j+8>>2]+ -1|0,h-p[B+8>>2]|0);vb(g+48|0,D,16);if(Ca=!tb(g+48|0),Da=0,Ea=p[b+480180>>2]!=2,Ea?Ca:Da){break gb}j=p[x+36>>2];h=p[x+32>>2];B=Gc(z,a);p[B>>2]=h;p[B+4>>2]=j;j=p[f>>2];Ca=Gc(z,a),Da=j,p[Ca+8>>2]=Da;j=p[f+48>>2];Ca=Gc(z,a),Da=j+1|0,p[Ca+12>>2]=Da}p[114610]=0;M(1363,g+40|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){continue}break l}break}break l}B=k;continue}}a=I()|0;H()|0;break c}a=I()|0;H()|0;QK(e);break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}hb:{if(!(!r[b+480188>>1]|(qa|0)!=7)){a=0;while(1){if(p[Gc(z,a)+16>>2]!=-1){p[114610]=0;Q(1357,x|0,a&65535,B|0,-1);d=p[114610];p[114610]=0;if((d|0)==1){break hb}}a=a+1|0;if(a>>>0<r[b+480188>>1]){continue}break}}if(!(_?!q[C+26|0]:0)){o[C+20>>1]=r[f+62>>1];p[C+8>>2]=p[f+48>>2]}a=p[x+36>>2];p[C>>2]=p[x+32>>2];p[C+4>>2]=a;p[114610]=0;K(1340,ma|0,C|0);a=p[114610];p[114610]=0;ib:{if((a|0)==1){break ib}jb:{if(ha){kb:{if(!(q[C+26|0]?0:_)){a=b+1074376|0;WK(a,f);Ex(a);a=b+1074396|0;p[a>>2]=0;p[a+4>>2]=0;p[b+1074428>>2]=p[b+1074424>>2];n[b+1074464|0]=1;p[b+1074392>>2]=-2;lb:{if(r[b+480188>>1]){a=0;d=(qa|0)==7;while(1){c=v(a,896)+b|0;e=q[c+1075805|0];if(e){n[c+1075808|0]=e}if(!(q[Gc(z,a)+21|0]==255|d)){e=Gc(z,a);p[114610]=0;n[g|0]=64;e=J(391,e+21|0,g|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break lb}p[c+1075672>>2]=q[e|0]<<2}a=a+1|0;if(a>>>0<r[b+480188>>1]){continue}break}}a=b+1304392|0;if(kd(a)){a=p[a>>2];p[114610]=0;S(1364,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break ib}}c=By(g);Ca=g,Da=fn(ra),p[Ca+40>>2]=Da;Ca=g,Da=pi(ra),p[Ca+32>>2]=Da;mb:{while(1){nb:{p[114610]=0;a=J(1365,g+40|0,g+32|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break nb}if(!a){if(!Ppa(c)){break kb}a=0;while(1){vb(g+48|0,c,a);ob:{if(!tb(g+48|0)){break ob}d=p[(v(a,160)+b|0)+906300>>2];e=p[p[d>>2]+172>>2];p[114610]=0;S(e|0,d|0);d=p[114610];p[114610]=0;if((d|0)!=1){break ob}a=I()|0;H()|0;break c}a=a+1|0;if((a|0)!=250){continue}break}break kb}p[114610]=0;d=M(1366,g+40|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break mb}e=q[d|0]+ -1&255;a=p[(v(e,160)+b|0)+906300>>2];if(a){vb(g+48|0,c,e);if(!tb(g+48|0)){p[114610]=0;P(1367,c|0,e|0,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break jb}e=p[p[a>>2]+168>>2];p[114610]=0;K(e|0,a|0,-1);e=p[114610];p[114610]=0;if((e|0)==1){break jb}}e=r[d+2>>1];f=p[p[a>>2]+44>>2];d=r[d+4>>1];p[114610]=0;sa(f|0,a|0,e|0,w(w(w(d>>>0)*w(.0010010009864345193))));a=p[114610];p[114610]=0;if((a|0)==1){break jb}}p[114610]=0;M(1368,g+40|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){continue}}break}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}if((c|0)==3){break kb}p[b+1074416>>2]=p[b+480196>>2];p[b+1074420>>2]=p[b+480204>>2];p[b+1074444>>2]=p[b+480200>>2]}if(q[la+16|0]!=(ga|0)){p[114610]=0;K(489,la|0,ga|0);a=p[114610];p[114610]=0;if((a|0)==1){break ib}}p[114610]=0;K(1369,b+1304360|0,$|0);a=p[114610];p[114610]=0;if((a|0)==1){break ib}}Io($);VK(x);fb=g+176|0;return}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}a=I()|0;H()|0}Io($);break b}a=I()|0;H()|0}VK(x);break a}a=I()|0;H()|0}ck(ma);L(a|0);E()}function PBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,O=0,R=0,S=0;e=fb-1728|0;fb=e;Ac(b);f=e+1600|0;i=vBa(b,f);if(!i){vO(f)}a:{if(!i){break a}if(!BO(e+1600|0)){break a}if(!Hb(b,dd(256,0))){break a}b:{if(!c){break b}xd(a,1048576);ei(a);d=Mb(e+1584|0,16335);p[114610]=0;K(219,e+1328|0,d|0);f=p[114610];p[114610]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((f|0)!=1){x=e+1608|0;p[e+160>>2]=q[x+1|0];f=q[x|0];p[114610]=0;p[e+24>>2]=f;K(664,e+88|0,e+24|0);f=p[114610];p[114610]=0;if((f|0)==1){break r}p[114610]=0;Q(649,e+240|0,e+1328|0,e+160|0,e+88|0);f=p[114610];p[114610]=0;if((f|0)==1){break q}xb(a+1304436|0,e+240|0);pb(e+240|0);pb(e+88|0);yb(e+1328|0);pb(d);d=Mb(e+240|0,16352);xb(a+1304448|0,d);pb(d);Eg(e+88|0,2,e+1610|0);zc(e+1328|0,e+88|0);p[114610]=0;N(13,e+240|0,7,e+1328|0);d=p[114610];p[114610]=0;if((d|0)==1){break k}xb(a+1304460|0,e+240|0);pb(e+240|0);pb(e+1328|0);p[a+1304496>>2]=7;tt(e+1328|0,2,e+1642|0);zc(e+240|0,e+1328|0);xb(a+1304400|0,e+240|0);pb(e+240|0);d=e+1712|0;o[a+480188>>1]=q[d|0]|q[d+1|0]<<8;d=sd(q[e+1716|0],1,31);p[a+480204>>2]=125e4;p[a+480208>>2]=32792;p[a+480196>>2]=d;B=e+1722|0;o[a+480192>>1]=q[B|0]|q[B+1|0]<<8;C=e+1724|0;o[a+480190>>1]=q[C|0]|q[C+1|0]<<8;d=sd(q[e+1717|0],1,32);p[a+480216>>2]=d;p[a+480228>>2]=96;p[a+480232>>2]=48;p[a+480220>>2]=d<<2;hA(b,e+1328|0);D=a+484360|0;y=e+1706|0;Et(Ob(D),e+1328|0,q[y|0]|q[y+1|0]<<8,65535,65535);d=e+1708|0;Pe(Ob(D),q[d|0]|q[d+1|0]<<8);ld(e+1312|0,b,kg(b));p[114610]=0;d=M(390,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break n}p[114610]=0;N(341,e+1296|0,b|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break n}u=r[a+480188>>1];p[114610]=0;w=J(258,e+1312|0,274)|0;d=p[114610];p[114610]=0;if((d|0)==1){break m}if(w){o[a+480188>>1]=r[a+480188>>1]+8}z=c&1;if(!z){break l}d=e+1710|0;d=q[d|0]|q[d+1|0]<<8;p[114610]=0;K(401,a+484344|0,d|0);d=p[114610];p[114610]=0;if((d|0)!=1){break l}break f}f=I()|0;H()|0;break o}f=I()|0;H()|0;break p}f=I()|0;H()|0;pb(e+88|0)}yb(e+1328|0)}pb(d);break c}f=I()|0;H()|0;break d}f=I()|0;H()|0;break e}t=e+1710|0;if(!(q[t|0]|q[t+1|0]<<8)){break g}F=a+484344|0;G=e+1718|0;while(1){p[114610]=0;d=M(357,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break h}p[114610]=0;p[e+160>>2]=d;d=M(390,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break i}p[114610]=0;N(341,e+240|0,b|0,d+1&-2);d=p[114610];p[114610]=0;if((d|0)==1){break i}vc(e+160|0,1024);s:{if(!z){break s}d=p[e+160>>2];if(!d){break s}p[114610]=0;d=P(402,F|0,h&65535,d|0)|0;f=p[114610];p[114610]=0;t:{if((f|0)!=1){if(!d){break s}j=0;if(n[G|0]&1){g=0;while(1){p[114610]=0;d=J(258,e+240|0,1)|0;f=p[114610];p[114610]=0;u:{if((f|0)!=1){if(!d){break s}p[114610]=0;d=M(387,e+240|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break j}f=0;if((d|0)!=255){break u}p[114610]=0;f=M(387,e+240|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;d=M(387,e+240|0)|0;i=p[114610];p[114610]=0;if((i|0)!=1){break u}}break j}break j}v:{if(!(d&127)){break v}i=Rb(F,h);p[114610]=0;i=P(471,i|0,g|0,j&65535)|0;k=p[114610];p[114610]=0;if((k|0)==1){break j}n[e+88|0]=0;n[e+89|0]=0;n[e+90|0]=0;n[e+91|0]=0;n[e+91|0]=0;n[e+92|0]=0;n[e+93|0]=0;n[e+94|0]=0;if(d&1){p[114610]=0;k=M(387,e+240|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break j}n[e+88|0]=k}if(d&2){p[114610]=0;k=M(387,e+240|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break j}n[e+89|0]=k}if(d&4){p[114610]=0;k=M(387,e+240|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break j}n[e+90|0]=k}if(d&8){p[114610]=0;k=M(387,e+240|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break j}n[e+91|0]=k}if(d&16){p[114610]=0;k=M(387,e+240|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break j}n[e+92|0]=k}if(d&32){p[114610]=0;k=M(387,e+240|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break j}n[e+93|0]=k}if(d&64){p[114610]=0;d=M(387,e+240|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break j}n[e+94|0]=d}p[114610]=0;d=J(897,i|0,e+88|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break j}p[114610]=0;p[e+24>>2]=f;p[e+224>>2]=p[e+160>>2]+(g^-1);k=J(632,e+24|0,e+224|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break j}m=d|m;O=p[k>>2];if(!O){break v}k=0;d=i;while(1){d=v(r[a+480188>>1],6)+d|0;l=q[i|0]|q[i+1|0]<<8|(q[i+2|0]<<16|q[i+3|0]<<24);n[d|0]=l;n[d+1|0]=l>>>8;n[d+2|0]=l>>>16;n[d+3|0]=l>>>24;l=q[i+4|0]|q[i+5|0]<<8;n[d+4|0]=l;n[d+5|0]=l>>>8;k=k+1|0;if((O|0)!=(k|0)){continue}break}}g=(f+g|0)+1|0;d=p[e+160>>2];if(g>>>0>=d>>>0){while(1){j=j+1|0;g=g-d|0;if(g>>>0>=d>>>0){continue}break}}if((j&65535)>>>0<u>>>0){continue}break}break s}f=0;if(p[e+160>>2]){break t}break s}break j}while(1){d=Rb(F,h);p[114610]=0;i=J(497,d|0,f|0)|0;d=p[114610];p[114610]=0;w:{x:{if((d|0)!=1){d=0;if(u){break x}break w}break j}while(1){y:{p[114610]=0;J(898,e+240|0,e+88|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break y}p[114610]=0;g=J(897,i+v(d,6)|0,e+88|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break y}m=g|m;d=d+1|0;if((u|0)!=(d|0)){continue}break w}break}break j}f=f+1|0;if(f>>>0<s[e+160>>2]){continue}break}}sb(e+240|0);h=h+1|0;if(h>>>0<(q[t|0]|q[t+1|0]<<8)>>>0){continue}break}break g}f=I()|0;H()|0;pb(e+1328|0);break c}f=I()|0;H()|0;sb(e+240|0);break e}f=I()|0;H()|0;break e}f=I()|0;H()|0;break e}d=e+1714|0;z:{if((q[d|0]|q[d+1|0]<<8)>>>0<=1|(q[d|0]|q[d+1|0]<<8)>>>0>4999){break z}if(m&1){d=q[d|0]|q[d+1|0]<<8;p[114610]=0;d=rg(458,((d>>>1|0)+11025e5>>>0)/(d>>>0)|0,0);f=p[114610];p[114610]=0;if((f|0)==1){break f}p[a+480224>>2]=0;p[a+480204>>2]=d;break z}f=p[a+480216>>2];i=p[a+480196>>2];h=q[d|0]|q[d+1|0]<<8;p[a+480224>>2]=2;d=a;A=2646e7/+(v(h,v(f,i))>>>0);A:{if(A<4294967296&A>=0){f=~~A>>>0;break A}f=0}p[d+480204>>2]=f}d=r[a+480188>>1];p[114610]=0;n[e+240|0]=0;F=P(899,e+1280|0,d|0,e+240|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){g=a+1304412|0;i=a+484344|0;l=a+1304424|0;z=e+240|3;k=0;B:{C:{D:{E:{F:{while(1){p[114610]=0;d=J(258,e+1296|0,8)|0;f=p[114610];p[114610]=0;G:{if((f|0)!=1){if(d){break G}if(r[a+480188>>1]){d=0;while(1){f=n[oc(F,d)|0];H:{if((d|0)>=(f|0)|(f|0)>=r[a+480188>>1]){break H}h=((f<<5)+a|0)+480288|0;f=q[h|0];if(!f){break H}g=((d<<5)+a|0)+480288|0;j=q[g|0];if(!j){n[g|0]=f;break H}g=(v(j+ -1&255,160)+a|0)+906300|0;if((mj(g)|0)!=255){while(1){g=(v(mj(g),160)+a|0)+906300|0;if((mj(g)|0)!=255){continue}break}}f=g+28|0;h=q[h|0]+ -1&255;h=h>>>0<250?h+128|0:0;n[f|0]=h;n[f+1|0]=h>>>8;n[f+2|0]=h>>>16;n[f+3|0]=h>>>24}d=d+1|0;if(d>>>0<r[a+480188>>1]){continue}break}}p[e+232>>2]=0;p[e+236>>2]=0;p[e+224>>2]=0;p[e+228>>2]=0;p[e+216>>2]=0;p[e+220>>2]=0;p[e+208>>2]=0;p[e+212>>2]=0;I:{J:{K:{L:{M:{N:{if(w){p[114610]=0;J(900,e+1312|0,e+240|0)|0;d=p[114610];p[114610]=0;O:{if((d|0)!=1){g=0;while(1){d=r[a+480192>>1];p[114610]=0;d=J(901,a|0,d+1&65535)|0;f=p[114610];p[114610]=0;P:{Q:{R:{S:{T:{U:{V:{if((f|0)!=1){f=g<<1;h=f+(e+224|0)|0;o[h>>1]=d;l=f+(e+208|0)|0;f=e+f|0;j=f+242|0;o[l>>1]=q[j|0]|q[j+1|0]<<8;if((d|0)==65535){break Q}f=q[f+242|0]|q[f+243|0]<<8;p[114610]=0;d=P(454,a|0,d|0,f+1&65535)|0;f=p[114610];p[114610]=0;if((f|0)==1){break V}if(!d){break P}p[114610]=0;K(509,e+160|0,16369);f=p[114610];p[114610]=0;if((f|0)==1){break U}p[114610]=0;p[e+24>>2]=g+1;N(902,e+88|0,e+160|0,e+24|0);f=p[114610];p[114610]=0;if((f|0)==1){break T}p[114610]=0;J(369,d+492|0,e+88|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break S}pb(e+88|0);yb(e+160|0);break P}f=I()|0;H()|0;break B}f=I()|0;H()|0;break B}f=I()|0;H()|0;break B}f=I()|0;H()|0;break R}f=I()|0;H()|0;pb(e+88|0)}yb(e+160|0);break B}o[h>>1]=0}g=g+1|0;if((g|0)!=8){continue}break}break O}f=I()|0;H()|0;break B}d=q[e+240|0]|q[e+241|0]<<8;p[114610]=0;l=J(395,e+160|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break I}if(q[e+240|0]|q[e+241|0]<<8){d=0;while(1){p[114610]=0;f=M(357,b|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break K}p[114610]=0;N(341,e+88|0,b|0,f<<5);f=p[114610];p[114610]=0;if((f|0)==1){break L}Nd(jc(l,d),e+88|0);sb(e+88|0);d=d+1|0;if(d>>>0<(q[e+240|0]|q[e+241|0]<<8)>>>0){continue}break}}d=q[t|0]|q[t+1|0]<<8;p[114610]=0;m=P(903,e+88|0,d|0,16378)|0;d=p[114610];p[114610]=0;if((d|0)==1){break M}if(q[y|0]|q[y+1|0]<<8){h=0;while(1){g=e+h|0;W:{if((q[e+240|0]|q[e+241|0]<<8)>>>0<=q[g+258|0]){break W}if(r[kc(Ob(D),h)>>1]>=(q[t|0]|q[t+1|0]<<8)>>>0){break W}f=r[kc(Ob(D),h)>>1];X:{if(r[kc(m,f)>>1]==65535){d=q[g+258|0];R=kc(m,f),S=d,o[R>>1]=S;break X}if(r[kc(m,f)>>1]==q[g+258|0]){break X}p[114610]=0;d=P(904,i|0,f|0,0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break N}if((d|0)==65535){break X}R=kc(Ob(D),h),S=d,o[R>>1]=S;f=d}p[114610]=0;d=J(442,i|0,f|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break N}if(!d){break W}z=jc(l,q[g+258|0]);Ac(z);p[114610]=0;d=M(255,z|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break N}if(!p[Rb(i,f)+12>>2]){break W}G=d>>>5|0;j=0;while(1){d=Rb(i,f);g=r[a+480188>>1];p[114610]=0;d=P(471,d|0,j|0,g+ -8&65535)|0;g=p[114610];p[114610]=0;if((g|0)==1){break N}g=0;while(1){ch(e+24|0);w=r[e+28>>1];n[d+4|0]=w;n[d+5|0]=w>>>8;w=p[e+24>>2];n[d|0]=w;n[d+1|0]=w>>>8;n[d+2|0]=w>>>16;n[d+3|0]=w>>>24;Y:{if(j>>>0>=G>>>0){break Y}p[114610]=0;J(905,z|0,e+24|0)|0;w=p[114610];p[114610]=0;if((w|0)==1){break N}if(n[e+24|0]>-1){break Y}n[d|0]=61;n[d+1|0]=q[(e+224|0)+(g<<1)|0];w=q[e+24|0]&31;n[e+72|0]=w;if(w){Ke(e+72|0,15);n[d+3|0]=20;n[d+5|0]=q[e+72|0]|208}n[d+2|0]=1;n[d+4|0]=q[e+25|0]+3>>>2}d=d+6|0;g=g+1|0;if((g|0)!=8){continue}break}j=j+1|0;if(j>>>0<s[Rb(i,f)+12>>2]){continue}break}}h=h+1|0;if(h>>>0<(q[y|0]|q[y+1|0]<<8)>>>0){continue}break}}qf(m);$c(l)}d=e+1718|0;Z:{if(!(q[d|0]&2)){break Z}u=q[d|0]&8?r[a+480188>>1]:u;if(!(q[t|0]|q[t+1|0]<<8)){break Z}d=((u&65535)+((q[x|0]|q[x+1|0]<<8)>>>0>591?k:0)|0)+((q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24))>>>4&1)|0;u=0;while(1){g=0;_:{if(!d){break _}while(1){$:{p[114610]=0;f=J(258,b|0,4)|0;i=p[114610];p[114610]=0;if((i|0)==1){break $}if(!f){break _}f=q[x|0]|q[x+1|0]<<8;p[114610]=0;K(906,f|0,b|0);f=p[114610];p[114610]=0;if((f|0)==1){break $}g=g+1|0;if((d|0)!=(g|0)){continue}break _}break}f=I()|0;H()|0;break B}u=u+1|0;if(u>>>0<(q[t|0]|q[t+1|0]<<8)>>>0){continue}break}}p[114610]=0;t=J(395,e+192|0,255)|0;d=p[114610];p[114610]=0;aa:{ba:{ca:{da:{ea:{fa:{if((d|0)!=1){w=e+88|7;D=e+88|1;l=e+88|4;y=e+88|2;z=e+88|3;h=0;while(1){d=h;p[114610]=0;J(907,b|0,e+160|0)|0;f=p[114610];p[114610]=0;ga:{ha:{ia:{ja:{if((f|0)!=1){p[114610]=0;f=M(390,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break ja}i=q[x|0]|q[x+1|0]<<8;p[114610]=0;f=(f|0)==32?428:f;f=f?i>>>0>513?f+4|0:f:f;N(341,e+240|0,b|0,f|0);i=p[114610];p[114610]=0;if((i|0)==1){break ia}h=d+1|0;j=Re(e+24|0,Nd(jc(t,d),e+240|0));sb(e+240|0);if(d>>>0>=(q[B|0]|q[B+1|0]<<8)>>>0){break ga}p[114610]=0;d=h&65535;g=P(454,a|0,d|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break ha}f=I()|0;H()|0;break ba}f=I()|0;H()|0;break aa}f=I()|0;H()|0;break aa}f=I()|0;H()|0;break aa}if(!g){break ga}p[114610]=0;N(748,e+88|0,2,e+160|0);d=p[114610];p[114610]=0;ka:{la:{ma:{if((d|0)==1){break ma}p[114610]=0;K(415,e+240|0,e+88|0);d=p[114610];p[114610]=0;if((d|0)==1){break ma}p[114610]=0;J(369,g+492|0,e+240|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break la}pb(e+240|0);if(!f){break ga}p[114610]=0;J(908,j|0,e+240|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break da}m=0;if((q[x|0]|q[x+1|0]<<8)>>>0<513){break ka}p[114610]=0;m=M(357,j|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break ka}f=I()|0;H()|0;break ba}f=I()|0;H()|0;break ba}f=I()|0;H()|0;pb(e+240|0);break ba}f=3;na:{if((q[x|0]|q[x+1|0]<<8)>>>0<514){break na}p[114610]=0;f=M(390,j|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break na}f=I()|0;H()|0;break ba}p[g>>2]=q[e+342|0]|q[e+343|0]<<8;n[g+16|0]=q[((q[e+344|0]|q[e+345|0]<<8)&3)+16380|0];n[g+17|0]=q[(q[e+345|0]&3)+16380|0];n[g+18|0]=q[((q[e+344|0]|q[e+345|0]<<8)>>>12&3)+16384|0];u=0;oa:{pa:{qa:{ra:{while(1){sa:{if(!(f&1)){break sa}p[114610]=0;J(909,j|0,e+88|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ra}p[114610]=0;i=J(374,g|0,q[u+16388|0])|0;d=p[114610];p[114610]=0;if((d|0)==1){break qa}d=i;if(!(n[e+88|0]&1)|(u|0)!=3){k=q[i+12|0]&-17}else{k=q[i+12|0]|16}n[d+12|0]=k;n[i+12|0]=q[i+12|0]&254|n[e+88|0]&1;n[i+12|0]=q[i+12|0]&251|q[e+88|0]<<1&4;n[i+12|0]=q[i+12|0]&253|q[e+88|0]>>>1&2;d=q[D|0];p[114610]=0;n[e+72|0]=d;n[e+56|0]=16;d=J(391,e+72|0,e+56|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break pa}d=q[d|0];p[114610]=0;K(594,i|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break pa}d=q[y|0];n[i+15|0]=d;n[i+16|0]=d;n[i+13|0]=q[z|0];n[i+14|0]=q[l|0];d=0;if(!Bb(i)){break sa}while(1){k=(e+88|0)+(d<<2)|0;G=q[k+8|0]|q[k+9|0]<<8;R=Fb(i,d),S=G,o[R>>1]=S;k=sd(q[k+10|0]|q[k+11|0]<<8,0,64);R=Fb(i,d),S=k,n[R+2|0]=S;d=d+1|0;if(d>>>0<Bb(i)>>>0){continue}break}}f=f>>>1|0;u=u+1|0;if((u|0)!=4){continue}break}if(!(n[g+60|0]&1|q[g+16|0]==3)){p[g>>2]=32767}p[114610]=0;N(910,g|0,127,1);d=p[114610];p[114610]=0;if((d|0)==1){break fa}p[114610]=0;N(911,g|0,0,1);d=p[114610];p[114610]=0;if((d|0)==1){break fa}if(!m){break ga}p[114610]=0;J(912,j|0,e+88|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ca}if(!(m&2)){break oa}d=q[y|0]|q[y+1|0]<<8;p[114610]=0;d=eb(913,a|0,+(d>>>0))|0;f=p[114610];p[114610]=0;if((f|0)==1){break ca}p[114610]=0;N(910,g|0,d|0,1);d=p[114610];p[114610]=0;if((d|0)==1){break ca}d=q[l|0];p[114610]=0;N(911,g|0,d|0,1);d=p[114610];p[114610]=0;if((d|0)!=1){break oa}break ca}f=I()|0;H()|0;break ba}f=I()|0;H()|0;break ba}f=I()|0;H()|0;break ba}n[g+25|0]=q[D|0]==1;if(!(m&4)){break ga}n[g+31|0]=q[w|0]+1;n[g+34|0]=q[e+96|0]+1;if(n[e+96|0]<=-1){n[g+30|0]=q[e+103|0]+1}if(q[e+100|0]){d=0;i=g+108|0;while(1){f=d+1|0;p[e+72>>2]=f+n[e+100|0];yO(e+72|0);u=p[e+72>>2];R=Yb(i,d),S=u,n[R|0]=S;d=f;if(d>>>0<128){continue}break}}p[114610]=0;K(780,g|0,0);d=p[114610];p[114610]=0;if((d|0)==1){break ca}}sb(j);if((h|0)!=255){continue}break}u=By(e+88|0);i=e+24|4;x=By(e+160|0);g=0;ta:{ua:{while(1){p[114610]=0;J(907,b|0,e+240|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ta}p[114610]=0;d=M(390,b|0)|0;f=p[114610];p[114610]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{if((f|0)!=1){p[114610]=0;N(341,e+72|0,b|0,d|0);f=p[114610];p[114610]=0;if((f|0)==1){break Ca}if(g>>>0<(q[C|0]|q[C+1|0]<<8)>>>0){p[114610]=0;N(748,e+56|0,2,e+240|0);f=p[114610];p[114610]=0;if((f|0)==1){break va}p[114610]=0;K(415,e+24|0,e+56|0);f=p[114610];p[114610]=0;if((f|0)==1){break va}p[114610]=0;J(369,((g<<5)+a|0)+946332|0,e+24|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Ba}pb(e+24|0)}if(!d|g>>>0>=(q[C|0]|q[C+1|0]<<8)>>>0){break wa}p[114610]=0;d=v(g+1|0,104)+a|0;f=d+484380|0;K(386,f|0,32);h=p[114610];p[114610]=0;if((h|0)==1){break Aa}p[114610]=0;J(914,e+72|0,e+24|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break za}p[f>>2]=q[e+24|0]|q[e+25|0]<<8|(q[e+26|0]<<16|q[e+27|0]<<24);p[d+484404>>2]=q[i|0]|q[i+1|0]<<8|(q[i+2|0]<<16|q[i+3|0]<<24);if(q[e+32|0]>=2){h=d+484414|0;o[h>>1]=r[h>>1]|1;p[f>>2]=p[f>>2]>>>1}if(q[e+33|0]>=2){h=d+484414|0;o[h>>1]=r[h>>1]|64;p[f>>2]=p[f>>2]>>>1}m=2;Da:{if(q[e+35|0]!=1){m=6;if(q[e+35|0]!=2){break Da}}f=d+484414|0;o[f>>1]=r[f>>1]|m}p[d+484384>>2]=q[e+36|0]|q[e+37|0]<<8|(q[e+38|0]<<16|q[e+39|0]<<24);p[d+484388>>2]=q[e+40|0]|q[e+41|0]<<8|(q[e+42|0]<<16|q[e+43|0]<<24);o[d+484410>>1]=(q[e+44|0]|q[e+45|0]<<8)>>>7;if(q[e+46|0]!=128){break ya}f=d+484414|0;j=r[f>>1]|256;o[f>>1]=j;break xa}f=I()|0;H()|0;break aa}f=I()|0;H()|0;break aa}f=I()|0;H()|0;pb(e+24|0);break ua}f=I()|0;H()|0;break ua}f=I()|0;H()|0;break ua}o[d+484408>>1]=n[e+46|0]+128;j=r[d+484414>>1]}f=d+484414|0;o[f>>1]=j|32;n[d+484416|0]=q[e+47|0];if(q[e+34|0]&2){vb(e+56|0,x,g);Zd(e+56|0,1)}if(q[e+34|0]&5){o[f>>1]=r[f>>1]|16384}if(!(q[e+34|0]&8)){break wa}vb(e+56|0,u,g);Zd(e+56|0,1);d=0;while(1){f=d<<1;Ea:{if(r[f+(e+208|0)>>1]!=(g|0)){break Ea}f=p[((r[f+(e+224|0)>>1]<<2)+a|0)+900380>>2];if(!f){break Ea}n[f+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}sb(e+72|0);g=g+1|0;if((g|0)==256){break ea}continue}break}f=I()|0;H()|0}sb(e+72|0);break aa}f=I()|0;H()|0;break aa}f=I()|0;H()|0;break B}f=I()|0;H()|0;break ba}Fa:{if(!(q[B|0]|q[B+1|0]<<8)){break Fa}f=0;Ga:{Ha:{while(1){Ia:{d=jc(t,f);p[114610]=0;d=M(255,d|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break Ia}Ja:{if(!d){f=f+1|0;break Ja}d=jc(t,f);Ac(d);p[114610]=0;J(908,d|0,e+240|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break Ha}g=e+24|0;yBa(g);d=q[e+240|0]|q[e+241|0]<<8;p[114610]=0;P(915,b|0,g|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break Ga}f=f+1|0;i=p[((f<<2)+a|0)+900380>>2];if(!(!i|q[i+34|0])){p[i+4>>2]=32;p[114610]=0;K(780,i|0,0);d=p[114610];p[114610]=0;if((d|0)==1){break Ga}C=i+108|0;y=i+236|0;d=0;while(1){h=d+e|0;Ka:{if((q[e+240|0]|q[e+241|0]<<8)>>>0<=q[h+242|0]){break Ka}m=Fk(g,q[h+242|0]);h=q[m|0];j=h+1|0;k=d+12|0;R=Yc(y,k),S=j,o[R>>1]=S;if(r[a+480190>>1]<=h>>>0){break Ka}h=v(j,104)+a|0;n[h+484418|0]=q[e+338|0]&3;n[h+484419|0]=q[e+339|0];n[h+484420|0]=q[e+340|0];n[h+484421|0]=q[e+341|0];o[h+484412>>1]=q[m+1|0]<<1;n[h+484417|0]=q[m+2|0];h=j+ -1|0;vb(e+72|0,u,h);if(tb(e+72|0)){n[i+14|0]=0}vb(e+72|0,x,h);if(!tb(e+72|0)){break Ka}R=Yb(C,k),S=61,n[R|0]=S}d=d+1|0;if((d|0)!=96){continue}break}}xO(g)}if(f>>>0<(q[B|0]|q[B+1|0]<<8)>>>0){continue}break Fa}break}f=I()|0;H()|0;break aa}f=I()|0;H()|0;break aa}f=I()|0;H()|0;xO(g);break aa}La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{if(!(!(c&2)|!r[a+480190>>1])){g=0;while(1){g=g+1|0;d=v(g,104)+a|0;c=d+484416|0;f=n[c|0];i=d+484417|0;h=n[i|0];p[114610]=0;j=d+484380|0;ka(916,j|0,+((+(h|0)*.0078125- +(f+ -49|0))*.08333333333333333));f=p[114610];p[114610]=0;if((f|0)==1){break La}n[i|0]=0;n[c|0]=0;c=r[d+484414>>1];Xa:{if(!(c&16384)){c=Tc(e+240|0,c&1?16:8,c&64?3:1,0,12);p[114610]=0;P(400,c|0,j|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break Xa}f=I()|0;H()|0;break aa}p[114610]=0;f=M(390,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Wa}p[114610]=0;J(338,b|0,12)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Wa}c=Lb(e+240|0);p[114610]=0;P(481,b|0,c|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Va}p[114610]=0;J(370,d+484423|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break Va}p[114610]=0;d=J(2,e+8|0,16392)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Ua}p[114610]=0;K(219,e+72|0,d|0);f=p[114610];p[114610]=0;if((f|0)==1){break Ta}p[e+4>>2]=g;f=gz(a);p[114610]=0;N(13,e+56|0,f|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break Sa}p[114610]=0;Q(649,e+24|0,e+72|0,e+4|0,e+56|0);f=p[114610];p[114610]=0;if((f|0)==1){break Ra}p[114610]=0;N(650,a|0,2,e+24|0);f=p[114610];p[114610]=0;if((f|0)==1){break Qa}pb(e+24|0);pb(e+56|0);yb(e+72|0);pb(d);pb(c)}if(g>>>0<r[a+480190>>1]){continue}break}}$c(t);Up(F);sb(e+1296|0);sb(e+1312|0);break b}f=I()|0;H()|0;break aa}f=I()|0;H()|0;break Ma}f=I()|0;H()|0;break Ma}f=I()|0;H()|0;break Na}f=I()|0;H()|0;break Oa}f=I()|0;H()|0;break Pa}f=I()|0;H()|0;pb(e+24|0)}pb(e+56|0)}yb(e+72|0)}pb(d)}pb(c);break aa}f=I()|0;H()|0;break aa}f=I()|0;H()|0;break ba}f=I()|0;H()|0}sb(j)}$c(t);break B}f=I()|0;H()|0;qf(m);break J}f=I()|0;H()|0;break J}f=I()|0;H()|0;break J}f=I()|0;H()|0}$c(l);break B}f=I()|0;H()|0;break B}f=I()|0;H()|0;break B}p[114610]=0;f=M(390,e+1296|0)|0;h=p[114610];p[114610]=0;d=a;Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{if((h|0)!=1){p[114610]=0;h=M(390,e+1296|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break kb}p[114610]=0;N(341,e+88|0,e+1296|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break kb}if((f|0)<=844387157){if((f|0)==4674381){break ab}if((f|0)==5068115){break $a}if(m&1|(f|0)!=726487106){break Za}p[a+480224>>2]=2;p[114610]=0;A=+ea(917,e+88|0);f=p[114610];p[114610]=0;if((f|0)==1){break Ya}if(A==0){break Za}A=2646e7/(A*+(v(p[a+480216>>2],p[a+480196>>2])>>>0));if(!(A<4294967296&A>=0)){break jb}f=~~A>>>0;break ib}if((f|0)<=1314144591){if((f|0)==844387158){break _a}if((f|0)!=1280004692){break Za}j=0;if(!r[a+480188>>1]){break Za}while(1){p[114610]=0;d=J(258,e+88|0,1)|0;f=p[114610];p[114610]=0;if((f|0)==1){break E}if(!d){break Za}d=Lb(e+240|0);p[114610]=0;P(600,e+88|0,d|0,-1)|0;f=p[114610];p[114610]=0;if((f|0)==1){break gb}f=Ib(d);h=wb(d);p[114610]=0;Q(414,e+24|0,3,f|0,h|0);f=p[114610];p[114610]=0;if((f|0)==1){break fb}p[114610]=0;K(415,e+160|0,e+24|0);f=p[114610];p[114610]=0;if((f|0)==1){break fb}p[114610]=0;J(378,((j<<5)+a|0)+480289|0,e+160|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break eb}pb(e+160|0);pb(d);j=j+1|0;if(j>>>0<r[a+480188>>1]){continue}break}break Za}if((f|0)==1397445204){break hb}if((f|0)!=1314144592){break Za}d=0;if(!(q[t|0]|q[t+1|0]<<8)){break Za}while(1){p[114610]=0;f=J(258,e+88|0,1)|0;h=p[114610];p[114610]=0;if((h|0)==1){break cb}if(!f){break Za}p[114610]=0;f=J(918,i|0,d&65535)|0;h=p[114610];p[114610]=0;if((h|0)==1){break cb}if(!f){break Za}h=Lb(e+240|0);p[114610]=0;P(600,e+88|0,h|0,-1)|0;f=p[114610];p[114610]=0;if((f|0)==1){break bb}f=Rb(i,d);p[114610]=0;J(496,f|0,h|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break bb}pb(h);d=d+1|0;if(d>>>0<(q[t|0]|q[t+1|0]<<8)>>>0){continue}break}break Za}f=I()|0;H()|0;break B}f=I()|0;H()|0;break B}f=0}p[d+480204>>2]=f;break Za}p[114610]=0;d=M(357,e+88|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break D}p[a+480232>>2]=d>>>9;p[a+480228>>2]=d>>>8;d=0;if(!r[a+480188>>1]){break Za}while(1){p[114610]=0;f=J(919,e+88|0,e+240|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break F}if(f){o[((d<<5)+a|0)+480286>>1]=(q[e+240|0]|q[e+241|0]<<8)>>>10;f=q[z|0];R=oc(F,d),S=f,n[R|0]=S}d=d+1|0;if(d>>>0<r[a+480188>>1]){continue}break}break Za}f=I()|0;H()|0;break db}f=I()|0;H()|0;break db}f=I()|0;H()|0;pb(e+160|0)}pb(d);break C}f=I()|0;H()|0;break C}f=I()|0;H()|0;pb(h);break C}p[114610]=0;J(338,e+88|0,1)|0;d=p[114610];p[114610]=0;if((d|0)==1){break D}p[114610]=0;d=M(548,e+88|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break D}p[114610]=0;U(587,l|0,e+88|0,d|0,2)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break Za}break D}p[114610]=0;J(920,e+88|0,e+24|0)|0;d=p[114610];p[114610]=0;lb:{if((d|0)!=1){d=Lb(e+240|0);p[114610]=0;P(600,e+88|0,d|0,-1)|0;f=p[114610];p[114610]=0;if((f|0)==1){break lb}if(tz(d,16356)){p[114610]=0;N(13,e+160|0,7,d|0);f=p[114610];p[114610]=0;if((f|0)==1){break lb}xb(g,e+160|0);pb(e+160|0)}pb(d);break Za}f=I()|0;H()|0;break C}f=I()|0;H()|0;pb(d);break C}p[114610]=0;k=M(390,e+88|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break D}}sb(e+88|0);continue}break}f=I()|0;H()|0;break C}f=I()|0;H()|0;break C}f=I()|0;H()|0;break C}f=I()|0;H()|0}sb(e+88|0)}Up(F);break e}f=I()|0;H()|0;break e}f=I()|0;H()|0}sb(e+1296|0)}sb(e+1312|0)}L(f|0);E()}d=1}fb=e+1728|0;return d|0}function fg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=w(0),m=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;d=fb-2912|0;fb=d;a:{b:{c:{d:{e:{if(Zp(c)){vc(b,268435456);y=p[c+8>>2];j=d+2888|0;f=j;p[f>>2]=0;p[f+4>>2]=0;xi(f+8|0);p[d+2884>>2]=0;f:{g:{f=d;h:{i:{j:{k:{l:{if(q[a+3|0]+ -4>>>0<=4){p[114610]=0;e=M(548,c|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break k}p[d+2884>>2]=e;break l}e=q[a+3|0];if(e>>>0>18){break l}e=1<<e;m:{if(!(e&126991)){if(e&396800){break m}break l}if(!q[a|0]){break l}}e=p[b>>2];p[114610]=0;e=J(647,a|0,e|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break j}p[114610]=0;N(858,d+736|0,c|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break j}e=d+736|0;g=p[e+4>>2];p[j>>2]=p[e>>2];p[j+4>>2]=g;qqa(j+8|0,e+8|0);uc(d+736|0);p[114610]=0;g=M(412,j|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}p[d+2884>>2]=p[j>>2]}e=q[a+3|0];if(e>>>0>18){break g}h=1<<e;n:{if(!(h&126991)){e=0;if(h&396800){break n}break g}e=!q[a|0]}if(e|s[b>>2]<262145){break g}e=p[d+2884>>2];h=q[a+3|0];p[114610]=0;p[d+720>>2]=((h|0)==11)<<4;h=J(33,d+720|0,d+2884|0)|0;i=p[114610];p[114610]=0;o:{if((i|0)!=1){p[d+736>>2]=e-p[h>>2];e=q[a+3|0];if(e>>>0>16){break i}p:{if(!(1<<e&126991)){if((e|0)==11){break p}break i}if(!(q[a|0]&7)){break i}}e=p[d+736>>2];if(2147483647<e>>>0){break o}e=e<<1;break h}a=I()|0;H()|0;break a}e=-1;break h}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}e=0;p[114610]=0;h=M(1261,a|0)|0;i=p[114610];p[114610]=0;q:{r:{if((i|0)!=1){s:{t:{switch(q[a+3|0]){case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:e=q[a|0];break s;case 9:e=16;break s;case 11:e=4;break s;case 10:case 17:case 18:break t;default:break s}}e=8}i=p[d+736>>2];h=v(e,h)>>>3|0;e=h+ -1|0;if(-1-i>>>0<e>>>0){break r}e=e+i|0;break q}a=I()|0;H()|0;break a}e=-1}e=(e>>>0)/(h>>>0)|0}p[f+736>>2]=e;vc(b,e);break f}if(!(q[a+3|0]==4|q[a+3|0]==5|q[a+3|0]==8)){if(q[a+3|0]!=7){break f}}p[114610]=0;p[d+736>>2]=p[d+2884>>2];e=M(1261,a|0)|0;h=p[114610];p[114610]=0;f=d;u:{v:{if((h|0)!=1){e=8/(e>>>0)|0;h=p[d+736>>2];if(4294967295/(e>>>0)>>>0<h>>>0){break v}e=v(e,h);break u}a=I()|0;H()|0;break a}e=-1}p[f+736>>2]=e;vc(b,e)}w:{if(!p[b>>2]){e=0;break w}o[b+34>>1]=r[b+34>>1]&65534|q[a|0]>15;o[b+34>>1]=r[b+34>>1]&65471|(q[a+1|0]!=1)<<6;p[114610]=0;f=M(465,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break e}if(!f){e=0;p[b>>2]=0;break w}f=Tc(d+736|0,8,1,0,11);p[114610]=0;f=J(1262,a|0,f|0)|0;e=p[114610];p[114610]=0;x:{y:{z:{A:{B:{C:{if((e|0)!=1){if(!f){break y}e=0;p[114610]=0;a=J(1263,c|0,d+736|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break C}if(!a){break x}a=p[b>>2];p[114610]=0;p[d+720>>2]=a+1>>>1;a=M(548,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break z}vc(d+720|0,a);p[114610]=0;a=M(859,g|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break B}e=p[d+720>>2];if(e){break A}e=16;break x}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=a+16|0;b=p[b+20>>2];g=0;while(1){f=q[d+736|q[a|0]&15]+g|0;n[b|0]=f;g=q[d+736|q[a|0]>>>4]+(f&255)|0;n[b+1|0]=g;a=a+1|0;b=b+2|0;e=e+ -1|0;if(e){continue}break}e=p[d+720>>2]+16|0;break x}a=I()|0;H()|0;break a}if(!(q[a+3|0]!=5?q[a+3|0]!=4:0)){a=q[a+3|0];p[114610]=0;a=U(1264,d+1800|0,c|0,b|0,(a|0)==5|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}sb(a);e=p[c+8>>2]-y|0;break x}if(!(q[a+3|0]!=6|q[a+1|0]!=1)){e=0;if(s[d+2884>>2]<10){break x}p[114610]=0;J(338,c|0,4)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}p[114610]=0;a=M(390,c|0)|0;f=p[114610];p[114610]=0;D:{E:{F:{if((f|0)!=1){p[114610]=0;p[d+720>>2]=a;f=M(387,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break F}p[114610]=0;N(1265,d+736|0,c|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break E}vc(d+720|0,p[d+736>>2]);p[114610]=0;a=p[d+720>>2];e=M(412,d+736|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break D}g=p[d+736>>2];h=p[b+20>>2];b=sk(b);p[114610]=0;_(1266,e|0,g|0,h|0,b|0,f<<24>>24);b=p[114610];p[114610]=0;if((b|0)==1){break D}e=a+9|0;uc(d+736|0);break x}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;uc(d+736|0);break a}if(!(q[a+3|0]!=9|q[a+1|0]!=1|q[a|0]!=16)){a=p[d+2884>>2];f=r[ml(d+1792|0)>>1];p[114610]=0;e=U(1267,b|0,g|0,a|0,f|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}G:{H:{I:{J:{if(!(q[a+3|0]!=8|q[a+1|0]!=1|q[a|0]>16)){e=0;p[114610]=0;f=J(258,c|0,8)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}if(!f){break x}p[114610]=0;f=M(390,c|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}p[d+2884>>2]=f;if(f>>>0<4){break x}p[114610]=0;N(341,d+720|0,c|0,f|0);f=p[114610];p[114610]=0;if((f|0)==1){break b}f=Tl(d+736|0,d+720|0);sb(d+720|0);p[114610]=0;h=M(1268,f|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break d}if(!p[b>>2]){break H}i=q[a|0];z=(i|0)!=16;a=0;g=0;while(1){K:{if(z){break K}p[114610]=0;A=J(260,f|0,8)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break K}a=O(77024)|0;break I}p[114610]=0;B=J(260,f|0,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break J}p[114610]=0;e=J(260,f|0,1)|0;k=p[114610];p[114610]=0;if((k|0)==1){break J}L:{M:{N:{if(!e){e=8;while(1){p[114610]=0;k=J(260,f|0,1)|0;x=p[114610];p[114610]=0;if((x|0)==1){break L}if(k){break N}e=e+16|0;continue}}p[114610]=0;e=J(260,f|0,3)|0;k=p[114610];p[114610]=0;if((k|0)!=1){break M}break J}p[114610]=0;k=J(260,f|0,4)|0;x=p[114610];p[114610]=0;if((x|0)==1){break J}e=e+k|0}g=(g&255)+(((B?-1:0)^e)&255)|0;O:{if((i|0)!=16){n[p[b+20>>2]+a|0]=g;break O}o[p[b+20>>2]+(a<<1)>>1]=A&255|g<<8}a=a+1|0;if(a>>>0<s[b>>2]){continue}break H}break}a=O(77024)|0;break I}P:{Q:{R:{S:{T:{if(!(q[a+3|0]!=7|q[a+1|0]!=1|q[a|0]>16)){e=0;if(s[d+2884>>2]<5){break x}a=p[b+20>>2];p[114610]=0;a=M(466,a|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break T}p[114610]=0;a=M(1269,a|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}b=sk(b);p[114610]=0;e=P(1270,c|0,a|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=8|q[a+1|0]!=1)){U:{V:{W:{X:{Y:{a=q[a+3|0];switch(a|0){case 2:break V;case 1:break W;case 0:break X;default:break Y}}e=0;switch(a+ -10|0){case 0:break U;case 2:break V;default:break x}}p[114610]=0;e=P(1271,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;e=P(1272,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}a=p[d+2884>>2];f=q[Ix(d+712|0)|0];p[114610]=0;e=U(1273,b|0,g|0,a|0,f|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;e=P(1274,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=8|q[a+1|0]!=3)){Z:{_:{$:{aa:{f=q[a+3|0];switch(f|0){case 2:break Z;case 1:break $;case 0:break aa;default:break _}}p[114610]=0;e=P(1275,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;e=P(1276,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}e=0;if((f|0)!=12){break x}}f=p[d+2884>>2];e=q[Ix(d+704|0)|0];p[114610]=0;e=U(1277,b|0,g|0,f|0,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}if(q[a+3|0]!=12){break x}f=p[b>>2]<<1;if((f|0)<1){break x}a=p[b+20>>2];b=f+a|0;while(1){n[a+1|0]=q[a+1|0]+q[a|0];a=a+2|0;if(a>>>0<b>>>0){continue}break}break x}if(!(q[a|0]!=8|q[a+1|0]!=2)){e=0;ba:{switch(q[a+3|0]){case 0:p[114610]=0;e=P(1278,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x;case 1:p[114610]=0;e=P(1279,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x;case 2:break ba;default:break x}}a=p[d+2884>>2];f=q[Ix(d+696|0)|0];p[114610]=0;e=U(1280,b|0,g|0,a|0,f|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a+2|0]|(q[a|0]!=16|q[a+1|0]!=1))){ca:{da:{ea:{fa:{a=q[a+3|0];switch(a|0){case 2:break ca;case 1:break ea;case 0:break fa;default:break da}}p[114610]=0;e=P(1281,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;e=P(1282,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}e=0;if((a|0)!=12){break x}}a=p[d+2884>>2];f=r[ml(d+688|0)>>1];p[114610]=0;e=U(1283,b|0,g|0,a|0,f|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=16|q[a+1|0]!=1|q[a+2|0]!=1)){e=0;ga:{switch(q[a+3|0]){case 0:p[114610]=0;e=P(1284,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x;case 1:p[114610]=0;e=P(1285,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x;case 2:break ga;default:break x}}a=p[d+2884>>2];f=r[ml(d+680|0)>>1];p[114610]=0;e=U(1286,b|0,g|0,a|0,f|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a+2|0]|(q[a|0]!=16|q[a+1|0]!=3))){ha:{ia:{ja:{ka:{f=q[a+3|0];switch(f|0){case 2:break ha;case 1:break ja;case 0:break ka;default:break ia}}p[114610]=0;e=P(1287,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;e=P(1288,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}e=0;if((f|0)!=12){break x}}f=p[d+2884>>2];e=r[ml(d+672|0)>>1];p[114610]=0;e=U(1289,b|0,g|0,f|0,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}if(q[a+3|0]!=12){break x}f=p[b>>2];if(f<<1<1){break x}a=p[b+20>>2];b=a+(f<<2)|0;while(1){o[a+2>>1]=r[a+2>>1]+r[a>>1];a=a+4|0;if(a>>>0<b>>>0){continue}break}break x}if(!(q[a|0]!=16|q[a+1|0]!=3|q[a+2|0]!=1)){e=0;la:{switch(q[a+3|0]){case 0:p[114610]=0;e=P(1290,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x;case 1:p[114610]=0;e=P(1291,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x;case 2:break la;default:break x}}a=p[d+2884>>2];f=r[ml(d+664|0)>>1];p[114610]=0;e=U(1292,b|0,g|0,a|0,f|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a+2|0]|(q[a|0]!=16|q[a+1|0]!=2))){e=0;ma:{switch(q[a+3|0]){case 0:p[114610]=0;e=P(1293,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x;case 1:p[114610]=0;e=P(1294,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x;case 2:break ma;default:break x}}a=p[d+2884>>2];f=r[ml(d+656|0)>>1];p[114610]=0;e=U(1295,b|0,g|0,a|0,f|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=16|q[a+1|0]!=2|q[a+2|0]!=1)){e=0;na:{switch(q[a+3|0]){case 0:p[114610]=0;e=P(1296,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x;case 1:p[114610]=0;e=P(1297,b|0,g|0,p[d+2884>>2])|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x;case 2:break na;default:break x}}a=p[d+2884>>2];f=r[ml(d+648|0)>>1];p[114610]=0;e=U(1298,b|0,g|0,a|0,f|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a+3|0]|(q[a|0]!=24|q[a+1|0]!=1))){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;o[d>>1]=r[d+640>>1];e=U(1299,b|0,g|0,f|0,d|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;o[d+2>>1]=r[d+632>>1];e=U(1300,b|0,g|0,f|0,d+2|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a+3|0]|(q[a|0]!=24|q[a+1|0]!=2))){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;o[d+4>>1]=r[d+624>>1];e=U(1301,b|0,g|0,f|0,d+4|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;o[d+6>>1]=r[d+616>>1];e=U(1302,b|0,g|0,f|0,d+6|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a+3|0]|(q[a|0]!=32|q[a+1|0]!=1))){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;o[d+8>>1]=r[d+608>>1];e=U(1303,b|0,g|0,f|0,d+8|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;o[d+10>>1]=r[d+600>>1];e=U(1304,b|0,g|0,f|0,d+10|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a+3|0]|(q[a|0]!=32|q[a+1|0]!=2))){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;o[d+12>>1]=r[d+592>>1];e=U(1305,b|0,g|0,f|0,d+12|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;o[d+14>>1]=r[d+584>>1];e=U(1306,b|0,g|0,f|0,d+14|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a+3|0]|(q[a|0]!=64|q[a+1|0]!=1))){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;o[d+16>>1]=r[d+576>>1];e=U(1307,b|0,g|0,f|0,d+16|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;o[d+18>>1]=r[d+568>>1];e=U(1308,b|0,g|0,f|0,d+18|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a+3|0]|(q[a|0]!=64|q[a+1|0]!=2))){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;o[d+20>>1]=r[d+560>>1];e=U(1309,b|0,g|0,f|0,d+20|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;o[d+22>>1]=r[d+552>>1];e=U(1310,b|0,g|0,f|0,d+22|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=32|q[a+1|0]!=1|q[a+3|0]!=3)){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;o[d+24>>1]=r[d+544>>1];e=U(1311,b|0,g|0,f|0,d+24|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;o[d+26>>1]=r[d+536>>1];e=U(1312,b|0,g|0,f|0,d+26|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=32|q[a+1|0]!=2|q[a+3|0]!=3)){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;o[d+28>>1]=r[d+528>>1];e=U(1313,b|0,g|0,f|0,d+28|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;o[d+30>>1]=r[d+520>>1];e=U(1314,b|0,g|0,f|0,d+30|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=64|q[a+1|0]!=1|q[a+3|0]!=3)){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;o[d+32>>1]=r[d+512>>1];e=U(1315,b|0,g|0,f|0,d+32|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;o[d+34>>1]=r[d+504>>1];e=U(1316,b|0,g|0,f|0,d+34|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=64|q[a+1|0]!=2|q[a+3|0]!=3)){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;o[d+36>>1]=r[d+496>>1];e=U(1317,b|0,g|0,f|0,d+36|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;o[d+38>>1]=r[d+488>>1];e=U(1318,b|0,g|0,f|0,d+38|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=24|(q[a+1|0]!=2?q[a+1|0]!=1:0)|q[a+3|0]!=16)){p[d+736>>2]=-2147483648;f=p[d+2884>>2];oa:{if(!q[a+2|0]){p[114610]=0;p[d+48>>2]=p[d+480>>2];p[d+476>>2]=0;a=p[d+476>>2];p[d+40>>2]=p[d+472>>2];p[d+44>>2]=a;e=Z(1319,b|0,g|0,f|0,d+736|0,d+40|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break oa}break P}p[114610]=0;p[d- -64>>2]=p[d+464>>2];p[d+460>>2]=0;a=p[d+460>>2];p[d+56>>2]=p[d+456>>2];p[d+60>>2]=a;e=Z(1320,b|0,g|0,f|0,d+736|0,d+56|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break P}}if(!e){break x}a=p[d+736>>2];if((a|0)==-2147483648){break x}f=r[b+32>>1];p[114610]=0;f=NNa(f,0,a,0)+1073741824|0;a=ib;a=f>>>0<1073741824?a+1|0:a;a=rg(793,(a&2147483647)<<1|f>>>31,a>>>31|0);f=p[114610];p[114610]=0;if((f|0)==1){break P}C=b,D=sd(a,1,64),o[C+32>>1]=D;o[b+34>>1]=r[b+34>>1]|8192;break x}if(!(q[a|0]!=32|(q[a+1|0]!=2?q[a+1|0]!=1:0)|q[a+3|0]!=16)){p[d+736>>2]=-2147483648;f=p[d+2884>>2];pa:{if(!q[a+2|0]){p[114610]=0;p[d+80>>2]=p[d+448>>2];p[d+444>>2]=0;a=p[d+444>>2];p[d+72>>2]=p[d+440>>2];p[d+76>>2]=a;e=Z(1321,b|0,g|0,f|0,d+736|0,d+72|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break pa}break Q}p[114610]=0;p[d+96>>2]=p[d+432>>2];p[d+428>>2]=0;a=p[d+428>>2];p[d+88>>2]=p[d+424>>2];p[d+92>>2]=a;e=Z(1322,b|0,g|0,f|0,d+736|0,d+88|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break Q}}if(!e){break x}a=p[d+736>>2];if((a|0)==-2147483648){break x}f=r[b+32>>1];p[114610]=0;a=NNa(f,0,a,0)+1073741824|0;f=ib;f=a>>>0<1073741824?f+1|0:f;a=rg(793,(f&2147483647)<<1|a>>>31,f>>>31|0);f=p[114610];p[114610]=0;if((f|0)==1){break Q}C=b,D=sd(a,1,64),o[C+32>>1]=D;o[b+34>>1]=r[b+34>>1]|8192;break x}if(!(q[a|0]!=32|(q[a+1|0]!=2?q[a+1|0]!=1:0)|q[a+3|0]!=15)){p[d+736>>2]=1065353216;f=p[d+2884>>2];qa:{if(!q[a+2|0]){p[114610]=0;p[d+412>>2]=0;p[d+416>>2]=1065353216;a=p[d+420>>2];p[d+112>>2]=p[d+416>>2];p[d+116>>2]=a;a=p[d+412>>2];p[d+104>>2]=p[d+408>>2];p[d+108>>2]=a;e=Z(1323,b|0,g|0,f|0,d+736|0,d+104|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break qa}break R}p[114610]=0;p[d+396>>2]=0;p[d+400>>2]=1065353216;a=p[d+404>>2];p[d+128>>2]=p[d+400>>2];p[d+132>>2]=a;a=p[d+396>>2];p[d+120>>2]=p[d+392>>2];p[d+124>>2]=a;e=Z(1324,b|0,g|0,f|0,d+736|0,d+120|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break R}}if(!e){break x}l=t[d+736>>2];if(l==w(1)){break x}l=Rm(w(l*w(r[b+32>>1])),w(1),w(64));p[114610]=0;a=cb(1325,w(l))|0;f=p[114610];p[114610]=0;if((f|0)==1){break R}o[b+32>>1]=a;o[b+34>>1]=r[b+34>>1]|8192;break x}if(!(q[a|0]!=64|(q[a+1|0]!=2?q[a+1|0]!=1:0)|q[a+3|0]!=15)){p[d+736>>2]=0;p[d+740>>2]=1072693248;f=p[d+2884>>2];ra:{if(!q[a+2|0]){p[114610]=0;p[d+376>>2]=0;p[d+380>>2]=1072693248;p[d+144>>2]=0;p[d+148>>2]=0;p[d+152>>2]=0;p[d+156>>2]=1072693248;a=p[d+388>>2];p[d+160>>2]=p[d+384>>2];p[d+164>>2]=a;a=p[d+364>>2];p[d+136>>2]=p[d+360>>2];p[d+140>>2]=a;p[d+368>>2]=0;p[d+372>>2]=0;e=Z(1326,b|0,g|0,f|0,d+736|0,d+136|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break ra}break S}p[114610]=0;p[d+344>>2]=0;p[d+348>>2]=1072693248;p[d+176>>2]=0;p[d+180>>2]=0;p[d+184>>2]=0;p[d+188>>2]=1072693248;a=p[d+356>>2];p[d+192>>2]=p[d+352>>2];p[d+196>>2]=a;a=p[d+332>>2];p[d+168>>2]=p[d+328>>2];p[d+172>>2]=a;p[d+336>>2]=0;p[d+340>>2]=0;e=Z(1327,b|0,g|0,f|0,d+736|0,d+168|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break S}}if(!e){break x}m=u[d+736>>3];if(m==1){break x}m=Hx(m*+r[b+32>>1],1,64);p[114610]=0;a=ta(1328,+m)|0;f=p[114610];p[114610]=0;if((f|0)==1){break S}o[b+32>>1]=a;o[b+34>>1]=r[b+34>>1]|8192;break x}if(!(q[a|0]!=32|q[a+1|0]!=1|q[a+3|0]!=13)){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;p[d+320>>2]=939524096;a=p[d+324>>2];p[d+200>>2]=p[d+320>>2];p[d+204>>2]=a;e=U(1329,b|0,g|0,f|0,d+200|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;p[d+312>>2]=939524096;a=p[d+316>>2];p[d+208>>2]=p[d+312>>2];p[d+212>>2]=a;e=U(1330,b|0,g|0,f|0,d+208|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=32|q[a+1|0]!=2|q[a+3|0]!=13)){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;p[d+304>>2]=939524096;a=p[d+308>>2];p[d+216>>2]=p[d+304>>2];p[d+220>>2]=a;e=U(1331,b|0,g|0,f|0,d+216|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;p[d+296>>2]=939524096;a=p[d+300>>2];p[d+224>>2]=p[d+296>>2];p[d+228>>2]=a;e=U(1332,b|0,g|0,f|0,d+224|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}if(!(q[a|0]!=32|q[a+1|0]!=1|q[a+3|0]!=14)){f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;p[d+288>>2]=872415232;a=p[d+292>>2];p[d+232>>2]=p[d+288>>2];p[d+236>>2]=a;e=U(1329,b|0,g|0,f|0,d+232|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}p[114610]=0;p[d+280>>2]=872415232;a=p[d+284>>2];p[d+240>>2]=p[d+280>>2];p[d+244>>2]=a;e=U(1330,b|0,g|0,f|0,d+240|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}e=0;if(q[a|0]!=32|q[a+1|0]!=2|q[a+3|0]!=14){break x}f=p[d+2884>>2];if(!q[a+2|0]){p[114610]=0;p[d+272>>2]=872415232;a=p[d+276>>2];p[d+248>>2]=p[d+272>>2];p[d+252>>2]=a;e=U(1331,b|0,g|0,f|0,d+248|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break x}break e}p[114610]=0;p[d+264>>2]=872415232;a=p[d+268>>2];p[d+256>>2]=p[d+264>>2];p[d+260>>2]=a;e=U(1332,b|0,g|0,f|0,d+256|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}break x}a=O(0)|0;H()|0;rb(a);E()}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=O(77024)|0}if((H()|0)!=($(77024)|0)){break c}T(a|0)|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break G}}e=h+4|0;sb(f);break x}a=I()|0;H()|0;break c}p[114610]=0;J(256,c|0,e+y|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}}uc(j)}fb=d+2912|0;return e|0}a=I()|0;H()|0;break a}a=I()|0;H()|0}sb(f);break a}a=I()|0;H()|0}uc(j);L(a|0);E()}function Npa(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=w(0),R=0,S=0,T=w(0),U=0,V=0;d=fb-32|0;fb=d;a:{if(!r[a+480188>>1]){F=-1;C=65535;D=-1;break a}R=a+1075821|0;I=a+1304392|0;i=a+1074308|0;P=a+1074376|0;M=a+480209|0;D=-1;F=-1;C=65535;while(1){f=v(l,896)+a|0;j=f+1075799|0;g=q[j|0];B=f+1075797|0;x=q[B|0];E=f+1075798|0;u=q[E|0];L=f+1075796|0;G=q[L|0];J=f+1075795|0;b=q[J|0];c=p[a+1074392>>2];h=p[a+1074400>>2];k=p[a+1074416>>2];H=f+1075794|0;y=es(H);z=f+1075856|0;n[z|0]=p[a+480208>>2]>>>12&1|q[z|0]&254;e=(c>>>0)%(h+k>>>0)|0;c=q[H|0];if((c|0)==252){c=q[J|0];h=Gx(H);k=cs(H);b:{if(!c|c+ -251>>>0<5){break b}c=p[(v(c,160)+a|0)+906140>>2];if(!c){break b}m[p[p[c>>2]+44>>2]](c,h,w(w(k>>>0)*w(.0010010009864345193)))}c=q[H|0]}c:{if(x&255|t[f+1075868>>2]==w(0)?(c&255)!=251:0){break c}A=p[a+480208>>2]&4096;d:{if(!A){k=q[f+1075878|0];break d}k=q[J|0];n[f+1075878|0]=k}c=k&255;if(c+ -251>>>0<5|!c){break c}h=(v(c,160)+a|0)+906140|0;if(!p[h>>2]){break c}e:{if(!A){c=r[f+1075876>>1];break e}c=$r(q[L|0],q[E|0]);o[f+1075876>>1]=c;Q=w(w($r(q[B|0],q[j|0])>>>0)*w(.0010010009864345193));t[f+1075872>>2]=Q;j=p[h>>2];S=f+1075868|0,T=w(w(Q-w(m[p[p[j>>2]+48>>2]](j,c)))/w(il(a)>>>0)),t[S>>2]=T}j=p[a+1074392>>2];k=il(a);h=p[h>>2];if((k|0)==(j+1|0)){m[p[p[h>>2]+44>>2]](h,c,t[f+1075872>>2]);break c}m[p[p[h>>2]+100>>2]](h,c,t[f+1075868>>2])}j=f+1074984|0;f:{g:{h:{i:{j:{if(!TK(q[H|0])){if(q[M|0]&16){break j}break i}Mpa(j);b=0;G=0;u=0;x=0;g=0;y=0;if(!(q[M|0]&16)){break i}k=0;break g}if(!b){b=0;break h}p[f+1075768>>2]=0;break h}KK(a,j)}B=x&255;if((B|0)==33){vb(d+24|0,i,30);k=g>>>4|0;Bx(a,l&65535,k+(g&15)|0,tb(d+24|0));x=33;break g}k=0;if((x+ -19&255)>>>0>1){break g}k:{if(!(!(p[a+480180>>2]&16777250)|g)){g=q[f+1075837|0];break k}n[f+1075837|0]=g}c=g&240;if((c|0)==208){c=g&15;if(!c){if(p[a+480180>>2]&16777248){k=1;break g}if(p[a+480180>>2]!=2){break g}break f}l:{if(c>>>0<p[a+1074400>>2]+p[a+1074416>>2]>>>0){break l}vb(d+24|0,i,14);if(!tb(d+24|0)){break l}if(!b){break f}n[f+1075809|0]=b;break f}k=c;break g}if(!(q[M|0]&16)){break g}h=19;m:{n:{o:{if(!((c|0)==96?(B|0)==19:0)){if((c|0)!=176){break n}h=20;if((B|0)!=20){break o}}vb(d+24|0,i,77);if(!(!tb(d+24|0)|!(p[((l<<5)+a|0)+480280>>2]&1024))){x=h;break g}c=Lpa(a,j,g&15);p:{if((c|0)==-1){c=F;break p}q:{if((D|0)!=-1){vb(d+24|0,i,68);D=tb(d+24|0)?c:D;break q}D=-1}vb(d+24|0,i,103);C=tb(d+24|0)?-1:C}if(!r[a+480188>>1]|p[a+480180>>2]!=2){break m}F=f+1075845|0;B=f+1075788|0;x=0;while(1){E=v(x,896)+a|0;p[E+1075788>>2]=p[B>>2];n[E+1075845|0]=q[F|0];x=x+1|0;if(x>>>0<r[a+480188>>1]){continue}break}break m}x=19;break g}if((c|0)!=224|(p[a+1074396>>2]?p[a+480180>>2]&16777250:0)){break g}c=g&15;if(p[a+480180>>2]&2?!c:0){break g}p[a+1074396>>2]=c+1;break g}x=h;F=c}N=x&255;h=(N|0)==19&p[a+480180>>2]==16&(g&240)==208;A=h?0:k;r:{if(!A|q[H|0]!=255|q[L|0]!=2){break r}vb(d+24|0,i,74);if(!tb(d+24|0)){break r}n[L|0]=0}c=p[a+1074392>>2];vb(d+24|0,i,72);s:{if(tb(d+24|0)){k=0;if(A>>>0>=s[a+1074416>>2]){break s}}vb(d+24|0,i,88);k=(e|0)==(A|0)|(c|0)==(A|0);if(!(!A|!tb(d+24|0))){break s}k=(c|0)==(A|0)}E=k;vb(d+24|0,i,44);if(tb(d+24|0)){n[z|0]=q[z|0]&254|(e|0)==(A|0)}O=g&15;e=h?O|144:g;vb(d+24|0,i,66);y=(!A|tb(d+24|0)^1)&y;t:{u:{if(!(p[a+1074392>>2]|(!b|!(p[a+480208>>2]&2097152)))){p[f+1075644>>2]=0;if(E){break u}if(!yh(j)){break t}n[f+1075809|0]=b;if(b>>>0>r[a+480190>>1]){break t}b=v(b,104)+a|0;p[f+1075672>>2]=r[b+484410>>1];p[f+1075752>>2]=n[b+484417|0];break t}if(!E){break t}}g=q[H|0];if(b){n[f+1075809|0]=b}v:{w:{if(!Ud(g)){break w}vb(d+24|0,i,67);if(!tb(d+24|0)){break w}h=p[f+1075756>>2];x:{if(!b|y){break x}y:{if(r[a+480192>>1]){c=65535;if(b>>>0>r[a+480192>>1]){break y}k=p[((b<<2)+a|0)+900380>>2];if(!k){break y}c=r[Yc(k+236|0,g+ -1|0)>>1];break y}c=b}c=c&65535;if(c>>>0>r[a+480190>>1]){break x}h=n[cp(a,c)+36|0]}g=(g+h|0)+ -12>>>0>119?0:g;break v}if(!(p[a+480180>>2]&25165856)|!r[a+480192>>1]){break v}c=g;h=1;z:{if(!c){break z}h=Ud(c)}if(!h){break v}h=b?b:q[f+1075810|0];if(!h|(p[((h<<2)+a|0)+900380>>2]?h>>>0<=r[a+480192>>1]:0)){break v}g=0;b=0}if(!((N|0)!=25|e)){vb(d+24|0,i,55);c=tb(d+24|0);b=c?0:b;g=c?0:g}vb(d+24|0,i,65);c=(b|0)!=0;h=!g;k=tb(d+24|0);K=1;A:{if(p[a+480180>>2]&16777248){break A}vb(d+24|0,i,107);if(tb(d+24|0)){break A}vb(d+16|0,i,85);K=0;if(!tb(d+16|0)){break A}if(yh(j)){break A}K=1;z=p[f+1075088>>2];if(!z){break A}K=ue(z)^1}h=c&h;B=c&k;B:{C:{D:{E:{F:{G:{H:{I:{if(!(p[a+480180>>2]&1048580)){break I}J:{if((g|0)!=255){break J}if(!(b?0:!((N|0)==13|(G&255)==1))){vb(d+24|0,i,55);if(tb(d+24|0)){break J}}c=p[f+1075640>>2];if(n[c+60|0]&1?c:0){break J}p[f+1075672>>2]=0;b=f+1075072|0;p[b>>2]=p[b>>2]|2097152;K:{if(!(p[a+480208>>2]&4096)){break K}vb(d+24|0,i,86);if(!tb(d+24|0)){break K}p[b>>2]=p[b>>2]|4096}b=0;g=0;c=0;h=0;k=0;z=1;if(B){break C}break B}vb(d+24|0,i,59);if(!tb(d+24|0)|p[a+480208>>2]&4096){break I}c=q[f+1075803|0]-q[f+1075756|0]|0;if(!g){break G}if(g>>>0>250){K=0;B=1;c=0;break G}if(!b){vb(d+24|0,i,98);B=0;if(tb(d+24|0)){break H}}K=1;B=1;break H}c=0;k=0;if(!h){break E}break F}c=g}y=0}vb(d+24|0,i,65);if(!tb(d+24|0)){break D}g=c;k=1}h=g;c=k;z=1;if(B){break C}break B}g=c;c=1;z=B}L:{M:{if(!r[a+480192>>1]){if(b>>>0>r[a+480190>>1]){break L}h=(v(b,104)+a|0)+484380|0;break M}h=p[f+1075088>>2];if(!h){break L}}N:{if(o[h+34>>1]<0){break N}if(p[a+480180>>2]==2){if(!ue(h)){break N}}p[f+1075672>>2]=r[h+30>>1]}if(!z){break L}ts(j,r[h+28>>1],a)}h=g;k=c}vb(d+24|0,i,71);if(!(!b|!tb(d+24|0))){n[f+1075843|0]=32}O:{if(!r[a+480192>>1]){break O}vb(d+24|0,i,100);if(!b|!tb(d+24|0)){break O}if(Ud(h&255)){break O}c=p[a+480208>>2];P:{if(y){if(c&8){break P}break O}if(!(c&4)){break O}}jl(j);p[f+1075680>>2]=65536;c=f+1075072|0;p[c>>2]=p[c>>2]|2097152}if(k){vb(d+24|0,i,11);Q:{if(S=!tb(d+24|0),U=0,V=p[a+480180>>2]!=268435456,V?S:U){break Q}vb(d+24|0,i,87);g=0;if(tb(d+24|0)){g=yh(j)^1}if(r[a+480192>>1]){if((g^-1)&p[f+1075640>>2]==p[((b<<2)+a|0)+900380>>2]|b>>>0>r[a+480192>>1]){break Q}h=q[f+1075803|0];break Q}if((g^-1)&p[f+1075088>>2]==((v(b,104)+a|0)+484380|0)|b>>>0>3999){break Q}h=q[f+1075803|0]}R:{if(!r[a+480192>>1]|!(p[a+480180>>2]&1048588)){break R}jl(j);n[f+1075822|0]=0;p[f+1075764>>2]=0;p[f+1075680>>2]=65536;c=f+1075072|0;p[c>>2]=p[c>>2]&-2101249|2097152;vb(d+24|0,i,86);if(!tb(d+24|0)){break R}p[c>>2]=p[c>>2]&-2049}b=K?b:0}k=h&255;S:{if(k>>>0<251){break S}vb(d+24|0,i,50);T:{if(!b|!tb(d+24|0)){break T}if(r[a+480192>>1]){if(b>>>0>r[a+480192>>1]){break T}c=((b<<2)+a|0)+900380|0;if(!p[c>>2]){break T}g=f+1075805|0;if(!Ud(q[g|0])){break T}c=r[Yc(p[c>>2]+236|0,q[g|0]+ -1|0)>>1]}else{c=b}c=c&65535;if(!c|c>>>0>r[a+480190>>1]){break T}c=v(c,104)+a|0;if(o[c+484414>>1]<0){break T}p[f+1075672>>2]=r[c+484410>>1]}vb(d+24|0,i,100);if(S=tb(d+24|0),U=0,V=p[a+480208>>2]&4,V?S:U){break S}b=0}U:{if(!Ud(k)){break U}n[f+1075808|0]=h;n[f+1075805|0]=h;if(y){break U}NK(a,l&65535,b,k,0)}V:{W:{X:{Y:{if(k){g=f+1075780|0;c=o[g>>1];if(c){p[f+1075676>>2]=(c&32767)+ -1;if((c|0)<=-1){c=f+1075072|0;p[c>>2]=p[c>>2]|256}o[g>>1]=0}c=f+1075801|0;g=q[c|0];if(g){n[f+1075842|0]=g+ -1;n[c|0]=0}c=f+1075802|0;g=q[c|0];if(g){n[f+1075841|0]=g+ -1;n[c|0]=0}if(!b){break Y}break X}if(b){break X}b=y;break V}c=0;h=1;z=f+1075809|0;Z:{if(!q[z|0]){break Z}if(!Ud(k)){break Z}Mo(a,j,q[z|0],y,p[f+1075088>>2]?0:!p[f+1075640>>2],!(p[a+480180>>2]&1048580));n[z|0]=0;c=1}b=y;break W}c=f+1075088|0;g=p[c>>2];Mo(a,j,b,y,1,1);b=p[c>>2];_:{if(!b|!(q[b+35|0]&2)){break _}if(!kd(I)){break _}Ux(p[I>>2],l&65535,p[c>>2]+68|0)}$:{if(p[a+480180>>2]==1){if(y){vb(d+24|0,i,85);if(tb(d+24|0)){break $}}n[f+1075809|0]=0;break $}vb(d+24|0,i,50);if(tb(d+24|0)){if(!Ud(k)){break $}}n[f+1075809|0]=0}vb(d+24|0,i,42);aa:{ba:{ca:{if(tb(d+24|0)){if(!Ud(k)|(g|0)==p[c>>2]){break ba}break ca}if(!(!(p[a+480180>>2]&16777248)|(g|0)==p[c>>2])){b=0;if(Ud(k)){break aa}}vb(d+24|0,i,107);da:{if(!tb(d+24|0)|(g|0)==p[c>>2]){break da}if(!y){if(Ud(k)){break da}}b=f+1075060|0;if(s[b>>2]>=s[j+4>>2]){break da}p[b>>2]=0;break ba}vb(d+24|0,i,85);if(!tb(d+24|0)){break ba}if(yh(j)){break ba}}p[j>>2]=0;p[j+4>>2]=0}b=y}h=0;c=0;if(!k){break V}}g=f+1075088|0;y=p[g>>2];ea:{if(!y|!(q[y+35|0]&2)){break ea}if(!kd(I)){break ea}if(!c){if(OK(p[I>>2],l&65535)){break ea}}Ux(p[I>>2],l&65535,p[g>>2]+68|0)}c=l&65535;bs(a,j,k,b,!(p[a+480180>>2]&1048580),0,c);if(!(!b|(!(p[a+480180>>2]&1048580)|h))){g=f+1075072|0;p[g>>2]=p[g>>2]|2097152;jl(j);n[f+1075822|0]=0;p[f+1075764>>2]=0}if(!(p[f+1075072>>2]&512)){break V}if(!kd(I)){break V}fa:{switch(k+ -253|0){case 0:vb(d+24|0,i,99);if(tb(d+24|0)){break V}break;case 1:case 2:break fa;default:break V}}_j(p[I>>2],c)}ga:{ha:{switch((G&255)+ -1|0){case 0:u=u>>>0<64?u:64;p[f+1075672>>2]=u<<2;c=f+1075072|0;p[c>>2]=p[c>>2]|2097152;break ga;case 1:break ha;default:break ga}}kl(a,j,u,6)}if(r[a+480192>>1]){qJ(a,l&65535)}y=b}vb(d+24|0,i,77);if(S=tb(d+24|0),U=0,V=p[((l<<5)+a|0)+480280>>2]&1024,V?S:U){break f}b=p[a+1074392>>2];vb(d+24|0,i,75);ia:{ja:{ka:{b=b>>>0>=A>>>0;la:{if(!A|!tb(d+24|0)){break la}c=p[a+1074392>>2];if(!c){break ka}b=1;if((c|0)!=(A|0)){break la}b=!q[J|0]&(G&255)!=11}c=G&255;if(!b|c>>>0<3){break ka}if((c|0)==11){Fx(d+24|0,a,H,A);b=q[_b(d+24|0)|0];Lm(a,j,p[d+24>>2]);if(b){break ia}b=11;break ja}vb(d+24|0,i,62);ma:{if(!(!tb(d+24|0)|u)){u=0;b=0;na:{switch(c+ -8|0){case 0:break ma;case 1:break na;default:break ja}}if(q[M|0]&16){break ja}p[f+1075676>>2]=0;break ja}vb(d+24|0,i,41);if(tb(d+24|0)){break ma}if(u){n[f+1075838|0]=u;break ma}u=q[f+1075838|0]}b=G;oa:{switch(c+ -3|0){case 0:case 1:pa:{qa:{if(u){break qa}vb(d+24|0,i,41);if(!tb(d+24|0)){break qa}u=q[f+1075838|0];if(u){break pa}u=0;break ka}n[f+1075838|0]=u}Om(a,j,((c|0)==3?u<<4:u)&255);break ka;case 2:if((A|0)!=p[a+1074392>>2]){vb(d+24|0,i,41);b=5;if(tb(d+24|0)){break ja}}vb(d+24|0,i,41);Ko(a,j,u,tb(d+24|0));b=5;break ja;case 3:if((A|0)!=p[a+1074392>>2]){vb(d+24|0,i,41);b=6;if(tb(d+24|0)){break ja}}vb(d+24|0,i,41);Jo(a,j,u,tb(d+24|0));b=6;break ja;case 4:vb(d+24|0,i,53);if(tb(d+24|0)){n[f+1075827|0]=u&15;b=7;break ja}Uj(j,u<<4);b=7;break ja;case 5:Uj(j,u);b=8;break ja;case 6:vb(d+24|0,i,62);Ax(a,j,u,tb(d+24|0)^1);b=9;break ja;case 7:vb(d+24|0,i,62);Ax(a,j,u<<4&240,tb(d+24|0)^1);b=10;break ja;case 9:b=12;vb(d+24|0,i,12);JK(a,l&65535,u<<2&252,tb(d+24|0));break ja;case 10:vb(d+24|0,i,12);IK(a,l&65535,u<<2&252,tb(d+24|0));b=13;break ja;case 12:break oa;default:break ja}}b=15;if(!E|u>>>0>9){break ja}c=p[f+1075088>>2];if(!c){break ja}ra:{if(!u){k=p[f+1075648>>2];break ra}k=p[(c+(u<<2)|0)- -64>>2];p[f+1075648>>2]=k}Lo(a,j,k);break ja}b=G}sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{switch(N+ -1|0){case 12:if(!(q[a+480209|0]&16)){break ia}b=v(l,896)+a|0;p[b+1075672>>2]=e>>>0<64?e<<2:256;b=b+1075072|0;p[b>>2]=p[b>>2]|2097152;break ia;case 1:if(p[a+480180>>2]&1?!e:0){break Qa}JK(a,l&65535,e,0);break ia;case 2:if(p[a+480180>>2]&1?!e:0){break Qa}IK(a,l&65535,e,0);break ia;case 10:if(p[a+480180>>2]==1?!e:0){break Qa}Om(a,j,e);break ia;case 3:Lm(a,j,e);break ia;case 5:if(!(p[a+480180>>2]==1?!e:0)){Om(a,j,e)}Lm(a,j,0);break ia;case 4:Uj(j,e);break ia;case 6:if(!(p[a+480180>>2]==1?!e:0)){Om(a,j,e)}Uj(j,0);break ia;case 15:if(!(q[a+480209|0]&16)){break ia}break sa;case 16:vb(d+24|0,i,5);if(tb(d+24|0)){if(!e){break ia}if(p[a+480208>>2]&4096){break sa}break ia}e=No(a,r[a+1074436>>1],p[a+1074424>>2],l&65535,0);Sa:{if(!(p[a+480180>>2]&16777250)){break Sa}if(e){n[(v(l,896)+a|0)+1075839|0]=e;break Sa}e=q[(v(l,896)+a|0)+1075839|0]}p[d+24>>2]=v(e,1e4);vc(d+24|0,v(p[p[a+8>>2]+24>>2],1e4));Kpa(a,p[d+24>>2]);break ia;case 9:if(!E|(p[a+480180>>2]==4?y:0)){break ia}n[d+24|0]=0;b=No(a,r[a+1074436>>1],p[a+1074424>>2],l&65535,d+24|0);c=a;g=j;if(!q[d+24|0]){h=(v(l,896)+a|0)+1075648|0;b=b<<8;Ta:{if(b){p[h>>2]=b;break Ta}b=p[h>>2]}b=(q[(v(l,896)+a|0)+1075840|0]<<16)+b|0}Lo(c,g,b);break ia;case 40:if(!E){break ia}Lo(a,j,dd(QNa(NNa(p[(v(l,896)+a|0)+1075060>>2],0,e,0),ib,255,0),ib));break ia;case 0:if(p[a+1074392>>2]){break ia}b=v(l,896)+a|0;Ua:{if(q[b+1075803|0]?p[b+1075684>>2]:0){break Ua}b=p[b+1075640>>2];if(b){if(gi(b)){break Ua}}vb(d+24|0,i,13);if(tb(d+24|0)){break Ua}if(p[a+480180>>2]&16777248){break ia}}if(!e){e=0;if(p[a+480180>>2]&5){break ia}n[(v(l,896)+a|0)+1075811|0]=1;break ia}b=v(l,896)+a|0;n[b+1075812|0]=e;n[b+1075811|0]=1;break ia;case 14:if(p[a+480180>>2]&1048580){e=e&240?e:r[(v(l,896)+a|0)+1075784>>1]&240|e;if(!(e&15)){e=r[(v(l,896)+a|0)+1075784>>1]&15|e}e=e|256}vb(d+24|0,i,23);if(tb(d+24|0)){Va:{if(!e){k=r[(v(l,896)+a|0)+1075784>>1];break Va}k=e&255;o[(v(l,896)+a|0)+1075784>>1]=k}zx(a,l&65535,k<<16>>16,(b&255)==15?u+1|0:0);break ia}Wa:{if(e){o[(v(l,896)+a|0)+1075784>>1]=e&255;break Wa}e=o[(v(l,896)+a|0)+1075784>>1]}zx(a,l&65535,e,(b&255)==15?u+1|0:0);break ia;case 39:break wa;case 38:break xa;case 34:case 35:case 36:case 37:break ya;case 13:break za;case 11:break Aa;case 29:break Ba;case 26:break Ca;case 21:break Da;case 20:break Ea;case 27:break Fa;case 24:break Ga;case 19:break Ha;case 18:break Ia;case 25:break Ja;case 7:break Ka;case 28:break La;case 8:break Ma;case 23:break Na;case 22:break Oa;case 17:break Ra;default:break ia}}if(!(q[a+480209|0]&16)){break ia}vb(d+24|0,i,22);Xa:{Ya:{if(tb(d+24|0)){if(!e){e=0;break Ya}if(q[a+480208|0]&4){break Ya}b=e&240?e+ -16|0:e;e=b-((b&15)!=0)|0;break Ya}vb(d+24|0,i,71);if(!tb(d+24|0)){break Xa}}b=(v(l,896)+a|0)+1075843|0;n[b|0]=q[b|0]|128}b=v(l,896)+a|0;n[b+1075811|0]=18;if(e){break Pa}}e=0;break ia}n[b+1075844|0]=e;break ia}if(!(q[a+480209|0]&16)){break ia}e=e<<!(p[a+480180>>2]&59593760);if(e>>>0<=128){p[a+1074444>>2]=e<<1;break ia}if(p[a+480180>>2]&16777250){break ia}p[a+1074444>>2]=256;break ia}vb(d+24|0,i,9);if(tb(d+24|0)){HK(a,e,(v(l,896)+a|0)+1075821|0);break ia}HK(a,e,R);break ia}if(!(q[a+480209|0]&16)){break ia}kl(a,j,e,8);break ia}Ax(a,j,e,1);break ia}$K(j,e);break ia}aL(a,j,e);break ia}Ipa(a,l&65535,e);break ia}vb(d+24|0,i,78);c=a;b=l&65535;if(!(!tb(d+24|0)|e)){e=q[(v(l,896)+a|0)+1075812|0]}GK(c,b,e);break ia}vb(d+24|0,i,55);if(tb(d+24|0)){if(p[a+1074392>>2]!=(e|0)){break ia}b=p[(v(l,896)+a|0)+1075640>>2];if(n[b+60|0]&1?b:0){break ta}if(!((q[L|0]?0:!q[J|0])|e)){b=(v(l,896)+a|0)+1075072|0;p[b>>2]=p[b>>2]|4096;break ta}b=v(l,896)+a|0;p[b+1075672>>2]=0;b=b+1075072|0;p[b>>2]=p[b>>2]|2097152;break ta}if(q[a+480209|0]&16){break ta}break ia}b=(e&240)+ -16>>>4|0;if(b>>>0>9){break ia}if(!(1<<b&880)){if(!b){break va}if((b|0)!=1){break ia}FK(a,j,e&15);break ia}vb(d+24|0,i,58);if(tb(d+24|0)){break ia}GK(a,l&65535,e);break ia}if(!(p[a+480208>>2]&4096)|e>>>0>64){break ia}b=v(l,896)+a|0;p[b+1075744>>2]=e;b=b+1075072|0;p[b>>2]=p[b>>2]|2097152;break ia}Hpa(a,j,e);break ia}_K(j,e);break ia}if(!(q[a+480209|0]&16)){break ia}b=v(l,896)+a|0;p[b+1075712>>2]=e;vb(d+24|0,i,60);if(S=0,U=tb(d+24|0),V=q[b+1075708|0]&4,V?S:U){break ia}b=v(l,896)+a|0;p[b+1075736>>2]=e;p[b+1075724>>2]=e;break ia}p[a+1074432>>2]=0;C=No(a,r[a+1074436>>1],p[a+1074424>>2],l&65535,0);D=(D|0)!=-1?p[a+480180>>2]&5?0:D:D;break ia}b=bL(a,P,l&65535,e);if((b|0)==-1){break ia}if(!(q[a+480208|0]&32)){break ua}C=r[a+1074438>>1];break ua}b=x&255;Gpa(a,j,e,(b|0)==35|(b|0)==37,(x+ -37&255)>>>0<2);break ia}XK(d,j,e);break ia}if(p[a+1074392>>2]|O>>>0>2|e>>>0>31){break ia}b=l;G=b;if((e&240)==16){G=r[a+480188>>1]+ -1|0;b=0}while(1){g=b&65535;c=((g<<5)+a|0)+480280|0;h=p[c>>2];Za:{if((O|0)==1){x=p[(v(g,896)+a|0)+1075072>>2]|67108864;h=h|67108864;break Za}x=p[(v(g,896)+a|0)+1075072>>2]&-67108865;h=h&-67108865}p[c>>2]=h;p[(v(g,896)+a|0)+1075072>>2]=x;b=b+1|0;if((b&65535)>>>0<=(G&65535)>>>0){continue}break}break ia}EK(a,j,e&15);break ia}D=b;break ia}Nm(a,j);break ia}cL(a,P,e)}vb(d+24|0,i,78);if(!(!e|!tb(d+24|0))){Fpa(j,e&255)}b=q[J|0];if(!b){break f}n[f+1075810|0]=b}l=l+1|0;if(l>>>0<r[a+480188>>1]){continue}break}}_a:{if(!(q[a+480209|0]&16)){break _a}$a:{if(!((C&65535)!=65535|(D|0)!=-1)){if((F|0)==-1){break _a}break $a}ab:{if((F|0)==-1){break ab}b=a+1074308|0;vb(d+24|0,b,68);if(tb(d+24|0)){break ab}vb(d+16|0,b,103);c=(C&65535)==65535;if(tb(d+16|0)?!c:0){break ab}vb(d+8|0,b,49);if(c|!tb(d+8|0)){break $a}}C=(C&65535)==65535?r[a+1074438>>1]+1|0:C;p[a+480208>>2]=p[a+480208>>2]|524288;b=a+484360|0;if(fc(Ob(b))>>>0<=(C&65535)>>>0){C=r[Ob(b)+28>>1]}c=(D|0)==-1?0:D;bb:{if(r[a+1074438>>1]==(C&65535)){break bb}b=a+1074308|0;vb(d+24|0,b,26);if(tb(d+24|0)){break bb}vb(d+16|0,b,68);if(tb(d+16|0)|p[a+480180>>2]==1|!r[a+480188>>1]){break bb}b=0;while(1){n[(v(b,896)+a|0)+1075845|0]=0;b=b+1|0;if(b>>>0<r[a+480188>>1]){continue}break}}p[a+1074428>>2]=c;if(q[a+480208|0]&32){break _a}o[a+1074440>>1]=C;break _a}p[a+1074428>>2]=F;o[a+1074440>>1]=r[a+1074438>>1];cb:{if(!p[a+1074396>>2]){break cb}if(p[a+480180>>2]==32){vb(d+24|0,a+1074308|0,103);if(tb(d+24|0)){break cb}}if(p[a+480180>>2]==2){break cb}p[a+1074428>>2]=p[a+1074428>>2]+1}if(F>>>0>=s[Rb(a+484344|0,r[a+1074436>>1])+12>>2]){p[a+1074428>>2]=0;o[a+1074440>>1]=r[a+1074440>>1]+1}isa(a+1304360|0,r[a+1074438>>1],F)}fb=d+32|0;return 1}function nLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,O=0,R=0;d=fb-304|0;fb=d;Ac(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{if(!bf(b,d+296|0)){break S}if(!iS(d+296|0)){break S}if(!c){x=1;break S}y=rk(d+280|0,b);p[114610]=0;N(473,d+264|0,y|0,1);b=p[114610];p[114610]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{if((b|0)!=1){p[114610]=0;N(474,d+128|0,d+264|0,1229866575);b=p[114610];p[114610]=0;if((b|0)==1){break Y}p[114610]=0;x=J(475,d+128|0,d+248|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break _}sb(d+128|0);if(!x){break T}p[114610]=0;K(447,a|0,524288);b=p[114610];p[114610]=0;if((b|0)==1){break c}p[114610]=0;S(476,a|0);b=p[114610];p[114610]=0;if((b|0)!=1){break Z}break c}b=I()|0;H()|0;break a}b=I()|0;H()|0;sb(d+128|0);break b}p[a+480208>>2]=12;b=q[d+256|0]|q[d+257|0]<<8;O=a,R=sd((b<<24|b<<8&16711680)>>>16|0,1,127),o[O+480188>>1]=R;b=q[d+248|0]|q[d+249|0]<<8;p[114610]=0;o[d+128>>1]=(b<<8&16711680|b<<24)>>>16;o[d+216>>1]=255;b=J(477,d+128|0,d+216|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break d}o[a+480192>>1]=r[b>>1];b=d+248|2;b=q[b|0]|q[b+1|0]<<8;p[114610]=0;o[d+128>>1]=(b<<8&16711680|b<<24)>>>16;o[d+216>>1]=3999;b=J(477,d+128|0,d+216|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break e}o[a+480190>>1]=r[b>>1];p[114610]=0;b=a+1074308|0;P(478,b|0,6,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;J(479,b|0,21)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;J(479,b|0,13)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}p[114610]=0;b=J(2,d+128|0,12385)|0;e=p[114610];p[114610]=0;if((e|0)==1){break f}xb(a+1304436|0,b);pb(b);p[114610]=0;b=J(2,d+128|0,12401)|0;e=p[114610];p[114610]=0;if((e|0)==1){break g}xb(a+1304448|0,b);pb(b);p[114610]=0;e=J(2,d+232|0,12405)|0;b=p[114610];p[114610]=0;if((b|0)==1){break h}p[114610]=0;K(219,d+216|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break j}p[114610]=0;K(480,d+200|0,d+296|4);b=p[114610];p[114610]=0;if((b|0)==1){break l}p[114610]=0;K(480,d+184|0,d+296|5);b=p[114610];p[114610]=0;if((b|0)==1){break n}p[114610]=0;Q(222,d+128|0,d+216|0,d+200|0,d+184|0);b=p[114610];p[114610]=0;if((b|0)==1){break o}xb(a+1304460|0,d+128|0);pb(d+128|0);pb(d+184|0);pb(d+200|0);yb(d+216|0);pb(e);p[a+1304496>>2]=2;p[114610]=0;N(474,d+216|0,d+264|0,1312902469);b=p[114610];p[114610]=0;if((b|0)==1){break p}p[114610]=0;b=M(255,d+216|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break r}p[114610]=0;f=a+1304400|0;P(481,d+216|0,f|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break r}p[114610]=0;N(474,d+200|0,d+264|0,1397706311);b=p[114610];p[114610]=0;if((b|0)==1){break s}b=a+484360|0;Bp(Ob(b));$:{e=d+248|4;e=q[e|0]|q[e+1|0]<<8;aa:{if(!e){break aa}h=(e<<24|e<<8)>>>16|0;e=0;while(1){p[114610]=0;g=J(258,d+200|0,46)|0;i=p[114610];p[114610]=0;ba:{if((i|0)!=1){if(!g){break aa}p[114610]=0;P(482,d+200|0,d+128|0,44)|0;g=p[114610];p[114610]=0;if((g|0)!=1){if(!Pc(f)){break ba}p[114610]=0;J(483,f|0,d+128|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break ba}}b=I()|0;H()|0;break t}b=I()|0;H()|0;break t}p[114610]=0;g=M(484,d+200|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break $}if(!cd(Ob(b))){p[114610]=0;i=M(485,b|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break $}if((i|0)==255){break aa}}i=Ob(b);p[114610]=0;K(486,d+184|0,d+128|0);j=p[114610];p[114610]=0;if((j|0)==1){break u}p[114610]=0;K(487,i|0,d+184|0);i=p[114610];p[114610]=0;if((i|0)==1){break v}pb(d+184|0);i=Ob(b);p[114610]=0;Z(488,i|0,d+200|0,g|0,65535,65535)|0;g=p[114610];p[114610]=0;if((g|0)==1){break $}e=e+1|0;if((e&65535)>>>0<h>>>0){continue}break}}p[114610]=0;K(489,b|0,0);b=p[114610];p[114610]=0;if((b|0)==1){break w}p[114610]=0;N(474,d+184|0,d+264|0,1229869908);b=p[114610];p[114610]=0;if((b|0)==1){break x}p[114610]=0;b=M(490,d+184|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break G}ca:{if(!b){break ca}if(r[a+480192>>1]){h=1;while(1){p[114610]=0;J(491,d+184|0,d+128|0)|0;b=p[114610];p[114610]=0;da:{ea:{fa:{if((b|0)!=1){b=q[d+158|0]|q[d+159|0]<<8;p[114610]=0;b=P(454,a|0,h&65535,(b<<8&16711680|b<<24)>>>16|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break fa}if(!b){break da}e=q[d+158|0]|q[d+159|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>3999){break da}p[114610]=0;N(492,d+16|0,2,d+128|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;K(415,d- -64|0,d+16|0);e=p[114610];p[114610]=0;if((e|0)!=1){break ea}}b=I()|0;H()|0;break y}b=I()|0;H()|0;break y}b=I()|0;H()|0;break y}p[114610]=0;J(369,b+492|0,d- -64|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break z}pb(d- -64|0);p[114610]=0;N(492,d+16|0,2,d+128|0);e=p[114610];p[114610]=0;if((e|0)==1){break A}p[114610]=0;K(415,d- -64|0,d+16|0);e=p[114610];p[114610]=0;if((e|0)==1){break A}e=q[d+158|0]|q[d+159|0]<<8;p[114610]=0;J(369,(((e<<8&16711680|e<<24)>>>11|0)+a|0)+946300|0,d- -64|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break B}pb(d- -64|0);p[b>>2]=0;e=q[d+174|0]|q[d+175|0]<<8;p[b+8>>2]=((e<<24|e<<8&16711680)>>>16|0)+128&65535;vc(b+8|0,256);n[b+15|0]=q[b+15|0]|1;b=q[d+158|0]|q[d+159|0]<<8;p[114610]=0;b=v((b<<8&16711680|b<<24)>>>16|0,104)+a|0;K(386,b+484380|0,0);e=p[114610];p[114610]=0;if((e|0)==1){break C}e=q[d+160|0]|q[d+161|0]<<8;p[114610]=0;o[d+64>>1]=(e<<8&16711680|e<<24)>>>16;o[d+16>>1]=64;e=J(477,d- -64|0,d+16|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break D}o[b+484410>>1]=r[e>>1]<<2;e=q[d+162|0]|q[d+163|0]<<8|(q[d+164|0]<<16|q[d+165|0]<<24);p[b+484404>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if(!(q[d+170|0]|q[d+171|0]<<8|(q[d+172|0]<<16|q[d+173|0]<<24))|!(q[d+177|0]&3)){break da}e=q[d+166|0]|q[d+167|0]<<8|(q[d+168|0]<<16|q[d+169|0]<<24);g=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);p[b+484384>>2]=g;e=q[d+170|0]|q[d+171|0]<<8|(q[d+172|0]<<16|q[d+173|0]<<24);f=b+484414|0;o[f>>1]=r[f>>1]|2;p[b+484388>>2]=g+(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));if(!(q[d+177|0]&2)){break da}o[f>>1]=r[f>>1]|4}h=h+1|0;if((h&65535)>>>0<=r[a+480192>>1]){continue}break}}p[114610]=0;N(474,d+112|0,d+264|0,1447382614);b=p[114610];p[114610]=0;if((b|0)==1){break G}p[114610]=0;Q(493,d+112|0,0,a|0,0);b=p[114610];p[114610]=0;if((b|0)==1){break E}sb(d+112|0);p[114610]=0;N(474,d+96|0,d+264|0,1346719318);b=p[114610];p[114610]=0;if((b|0)==1){break G}p[114610]=0;Q(493,d+96|0,1,a|0,q[d+300|0]>2|0);b=p[114610];p[114610]=0;if((b|0)==1){break F}sb(d+96|0);if(!r[a+480192>>1]){break ca}b=1;while(1){e=p[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|n[e+60|0]&1)){p[e>>2]=32767}b=b+1|0;if((b&65535)>>>0<=r[a+480192>>1]){continue}break}}sb(d+184|0);p[114610]=0;N(474,d+128|0,d+264|0,1346458708);b=p[114610];p[114610]=0;if((b|0)==1){break H}p[114610]=0;b=M(337,d+128|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break J}if(!(c&1)|b^1){break X}p[114610]=0;N(474,d+184|0,d+264|0,1347305805);b=p[114610];p[114610]=0;if((b|0)==1){break K}p[114610]=0;J(338,d+184|0,1)|0;b=p[114610];p[114610]=0;if((b|0)==1){break M}m=d+248|6;e=q[m|0]|q[m+1|0]<<8;b=0;p[114610]=0;s=a+484344|0;K(401,s|0,(e<<8&16711680|e<<24)>>>16|0);e=p[114610];p[114610]=0;if((e|0)==1){break M}e=d+80|0;TKa(e);if(q[m|0]|q[m+1|0]<<8){A=d+16|5;B=d+16|3;C=d+16|4;D=d+16|2;F=d+16|1;f=0;while(1){p[114610]=0;z=M(484,d+128|0)|0;h=p[114610];p[114610]=0;ga:{ha:{ia:{ja:{ka:{if((h|0)!=1){p[114610]=0;h=M(494,d+128|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break ka}p[114610]=0;N(341,d- -64|0,d+128|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break ja}p[114610]=0;h=P(402,s|0,f&65535,z|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break ia}if(!h){break ga}u=Lb(d+48|0);p[114610]=0;P(495,d+184|0,u|0,-1)|0;h=p[114610];p[114610]=0;if((h|0)!=1){h=Rb(s,f);p[114610]=0;J(496,h|0,u|0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){break ha}}break P}b=I()|0;H()|0;break N}b=I()|0;H()|0;break N}b=I()|0;H()|0;break N}b=I()|0;H()|0;break O}h=Rb(s,f);p[114610]=0;h=J(497,h|0,0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break P}bS(e);t=0;la:{while(1){p[114610]=0;g=J(258,d- -64|0,1)|0;i=p[114610];p[114610]=0;ma:{na:{oa:{if((i|0)!=1){if(!g){break la}p[114610]=0;j=M(387,d- -64|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break P}if(j){break na}O=d,R=Ub(e),p[O+40>>2]=R;O=d,R=Vb(e),p[O+32>>2]=R;if(Ab(d+40|0,d+32|0)){break oa}break ma}break P}while(1){pa:{h=p[d+40>>2];g=Rb(s,f);i=q[h+1|0];h=q[h|0];p[114610]=0;h=P(498,d+16|0,h|0,i|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break pa}h=Oe(h,t);p[114610]=0;J(499,g|0,h|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break pa}te(d+40|0);if(Ab(d+40|0,d+32|0)){continue}break ma}break}break P}ch(d+16|0);w=r[a+480188>>1];p[114610]=0;g=M(387,d- -64|0)|0;i=p[114610];p[114610]=0;qa:{if((i|0)==1){break qa}i=v(j+ -1|0,6)+h|0;ra:{if(!(g&1)){break ra}p[114610]=0;k=M(387,d- -64|0)|0;l=p[114610];p[114610]=0;sa:{if((l|0)!=1){if(!k){break ra}if((k|0)!=31){break sa}n[(w>>>0<j>>>0?d+16|0:i)|0]=255;break ra}break P}if(k>>>0>253){break ra}n[(w>>>0<j>>>0?d+16|0:i)|0]=(v(k>>>4|0,12)+(k&15)|0)+13}if(g&2){p[114610]=0;k=M(387,d- -64|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break qa}n[(w>>>0<j>>>0?F:i+1|0)|0]=k}if(!(g&60)){continue}n[d+15|0]=0;n[d+14|0]=0;n[d+13|0]=0;n[d+12|0]=0;if(g&4){p[114610]=0;k=M(387,d- -64|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break P}n[d+14|0]=k}if(g&8){p[114610]=0;k=M(387,d- -64|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break P}n[d+12|0]=k}if(g&16){p[114610]=0;k=M(387,d- -64|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break P}n[d+15|0]=k}if(g&32){p[114610]=0;g=M(387,d- -64|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break P}n[d+13|0]=g}aS(d+15|0,d+13|0);aS(d+14|0,d+12|0);g=q[d+14|0];if(!(q[d+15|0]==13|g?(g|0)!=13:0)){bh(d+15|0,d+14|0);bh(d+13|0,d+12|0)}p[114610]=0;_(500,d+32|0,d+15|0,d+13|0,d+14|0,d+12|0);g=p[114610];p[114610]=0;ta:{if((g|0)==1){break ta}p[114610]=0;g=J(501,q[d+32|0],q[d+33|0])|0;k=p[114610];p[114610]=0;if((k|0)==1){break ta}ua:{if(!g){break ua}O=d,R=Ub(e),p[O+40>>2]=R;Ld(d+8|0,d+40|0);p[114610]=0;P(502,e|0,p[d+8>>2],d+32|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break ua}break P}g=w>>>0<j>>>0;n[(g?D:i+2|0)|0]=q[d+15|0];n[(g?C:i+4|0)|0]=q[d+13|0];j=q[d+14|0];n[(g?B:i+3|0)|0]=j;n[(g?A:i+5|0)|0]=q[d+12|0];if((j|0)==40){G=1;continue}if((j|0)!=31){continue}b=1;continue}break P}break P}bS(e);t=t+1|0;if(t>>>0>=z>>>0){break la}h=Rb(s,f);p[114610]=0;h=J(497,h|0,t|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){continue}break}break P}pb(u)}sb(d- -64|0);f=f+1|0;h=q[m|0]|q[m+1|0]<<8;if(f>>>0<(h<<24|h<<8&16711680)>>>16>>>0){continue}break}}$R(e);h=b;sb(d+184|0);if(!(c&4)){break V}e=0;if(!G){break W}f=r[a+480188>>1];if(!f){e=1;break W}b=0;while(1){e=1;g=(b<<5)+a|0;n[g+480288|0]=1;g=g+480280|0;p[g>>2]=p[g>>2]|67108864;b=b+1|0;if((f|0)!=(b|0)){continue}break}break W}b=I()|0;H()|0;break t}b=I()|0;H()|0;break b}h=0;e=0;if(!(c&4)){break U}}p[114610]=0;p[d+64>>2]=-1778364416;p[d+68>>2]=-16756736;N(474,d+184|0,d+264|0,1146310725);b=p[114610];p[114610]=0;va:{wa:{xa:{ya:{za:{Aa:{if((b|0)!=1){p[114610]=0;b=M(490,d+184|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break xa}if(!b){break za}p[114610]=0;g=M(484,d+184|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break xa}if(g){break Aa}f=e;break ya}b=I()|0;H()|0;break I}b=0;f=e;while(1){p[114610]=0;i=M(387,d+184|0)|0;j=p[114610];p[114610]=0;Ba:{Ca:{if((j|0)!=1){if(b>>>0>=r[a+480188>>1]){break Ba}if(!e){break Ca}j=((b<<5)+a|0)+480280|0;p[j>>2]=p[j>>2]&-67108865|((i|0)!=0)<<26;break Ba}break xa}if(i){break Ba}f=1;n[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((g|0)!=(b|0)){continue}break}break ya}sb(d+184|0);if(!e){break V}break va}p[114610]=0;J(503,d+184|0,d- -64|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break wa}}b=I()|0;H()|0;sb(d+184|0);break I}sb(d+184|0);if(!(f&1)){break V}}p[114610]=0;S(504,a+906300|0);b=p[114610];p[114610]=0;Da:{Ea:{Fa:{Ga:{Ha:{Ia:{if((b|0)==1){break Ia}b=a+906316|0;p[b>>2]=810369604;p[b+4>>2]=1869112133;n[a+906324|0]=16;n[a+906325|0]=0;n[a+906326|0]=10;n[a+906327|0]=0;b=a+906328|0;n[b|0]=0;n[b+1|0]=0;n[b+2|0]=0;n[b+3|0]=0;p[114610]=0;p[d+184>>2]=0;b=a+906332|0;N(505,b|0,b+16|0,d+184|0);b=p[114610];p[114610]=0;if((b|0)==1){break Ha}p[114610]=0;e=J(85,d+184|0,12427)|0;b=p[114610];p[114610]=0;if((b|0)==1){break Ga}p[114610]=0;J(506,a+906348|0,e|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break Fa}pb(e);p[114610]=0;e=J(85,d+184|0,12432)|0;b=p[114610];p[114610]=0;if((b|0)==1){break Ea}p[114610]=0;J(507,a+906380|0,e|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break Da}pb(e);p[114610]=0;b=a+906304|0;K(508,b|0,8);e=p[114610];p[114610]=0;if((e|0)==1){break Ia}ZR(d+184|0,q[d+65|0],q[d+67|0],q[d+69|0],q[d+71|0]);e=p[d+188>>2];b=p[b>>2];f=p[d+184>>2];n[b|0]=f;n[b+1|0]=f>>>8;n[b+2|0]=f>>>16;n[b+3|0]=f>>>24;n[b+4|0]=e;n[b+5|0]=e>>>8;n[b+6|0]=e>>>16;n[b+7|0]=e>>>24;break V}b=I()|0;H()|0;break I}b=I()|0;H()|0;break I}b=I()|0;H()|0;break I}b=I()|0;H()|0;pb(e);break I}b=I()|0;H()|0;break I}b=I()|0;H()|0;pb(e);break I}if(!h){break U}b=0;Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{while(1){eb:{p[114610]=0;p[d+48>>2]=v(b,127)>>>5;K(509,d- -64|0,12453);e=p[114610];p[114610]=0;if((e|0)==1){break eb}p[114610]=0;K(510,d+16|0,d+48|0);e=p[114610];p[114610]=0;if((e|0)==1){break db}p[114610]=0;N(511,d+184|0,d- -64|0,d+16|0);e=p[114610];p[114610]=0;if((e|0)==1){break cb}p[114610]=0;e=(b<<5)+a|0;K(512,d+80|0,e+902204|0);f=p[114610];p[114610]=0;if((f|0)==1){break bb}p[114610]=0;J(470,d+80|0,d+184|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break bb}pb(d+184|0);pb(d+16|0);yb(d- -64|0);p[114610]=0;K(509,d- -64|0,12462);f=p[114610];p[114610]=0;if((f|0)==1){break _a}p[114610]=0;K(510,d+16|0,d+48|0);f=p[114610];p[114610]=0;if((f|0)==1){break Za}p[114610]=0;N(511,d+184|0,d- -64|0,d+16|0);f=p[114610];p[114610]=0;if((f|0)==1){break Ya}p[114610]=0;K(512,d+80|0,e+903228|0);f=p[114610];p[114610]=0;if((f|0)==1){break Xa}p[114610]=0;J(470,d+80|0,d+184|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Xa}pb(d+184|0);pb(d+16|0);yb(d- -64|0);p[114610]=0;K(509,d- -64|0,12471);f=p[114610];p[114610]=0;if((f|0)==1){break Ua}p[114610]=0;K(510,d+16|0,d+48|0);f=p[114610];p[114610]=0;if((f|0)==1){break Ta}p[114610]=0;N(511,d+184|0,d- -64|0,d+16|0);f=p[114610];p[114610]=0;if((f|0)==1){break Sa}p[114610]=0;K(512,d+80|0,e+904252|0);f=p[114610];p[114610]=0;if((f|0)==1){break Ra}p[114610]=0;J(470,d+80|0,d+184|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Ra}pb(d+184|0);pb(d+16|0);yb(d- -64|0);p[114610]=0;K(509,d- -64|0,12480);f=p[114610];p[114610]=0;if((f|0)==1){break Oa}p[114610]=0;K(510,d+16|0,d+48|0);f=p[114610];p[114610]=0;if((f|0)==1){break Na}p[114610]=0;N(511,d+184|0,d- -64|0,d+16|0);f=p[114610];p[114610]=0;if((f|0)==1){break Ma}p[114610]=0;K(512,d+80|0,e+905276|0);e=p[114610];p[114610]=0;if((e|0)==1){break La}p[114610]=0;J(470,d+80|0,d+184|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break La}pb(d+184|0);pb(d+16|0);yb(d- -64|0);b=b+1|0;if((b|0)!=32){continue}break U}break}b=I()|0;H()|0;break I}b=I()|0;H()|0;break $a}b=I()|0;H()|0;break ab}b=I()|0;H()|0;pb(d+184|0)}pb(d+16|0)}yb(d- -64|0);break I}b=I()|0;H()|0;break I}b=I()|0;H()|0;break Va}b=I()|0;H()|0;break Wa}b=I()|0;H()|0;pb(d+184|0)}pb(d+16|0)}yb(d- -64|0);break I}b=I()|0;H()|0;break I}b=I()|0;H()|0;break Pa}b=I()|0;H()|0;break Qa}b=I()|0;H()|0;pb(d+184|0)}pb(d+16|0)}yb(d- -64|0);break I}b=I()|0;H()|0;break I}b=I()|0;H()|0;break Ja}b=I()|0;H()|0;break Ka}b=I()|0;H()|0;pb(d+184|0)}pb(d+16|0)}yb(d- -64|0);break I}p[114610]=0;N(474,d+184|0,d+264|0,1397575756);b=p[114610];p[114610]=0;if((b|0)==1){break Q}p[114610]=0;b=M(337,d+184|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break R}if(!(!r[a+480190>>1]|(!(c&2)|b^1))){e=1;c=1;while(1){p[114610]=0;b=M(494,d+184|0)|0;f=p[114610];p[114610]=0;fb:{if((f|0)!=1){p[114610]=0;f=M(494,d+184|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break R}if(!(b&7)){break fb}e=(v(e,104)+a|0)+484380|0;p[e>>2]=f;b=Tc(d- -64|0,b&4?32:b&2?16:8,1,1,0);p[114610]=0;P(400,b|0,e|0,d+184|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break fb}break R}break R}c=c+1|0;e=c&65535;if(e>>>0<=r[a+480190>>1]){continue}break}}sb(d+184|0);sb(d+128|0);sb(d+200|0);sb(d+216|0)}Qz(d+264|0);sb(y)}fb=d+304|0;return x|0}b=I()|0;H()|0;sb(d+184|0);break I}b=I()|0;H()|0;break I}b=I()|0;H()|0;pb(u)}sb(d- -64|0)}$R(e);break L}b=I()|0;H()|0}sb(d+184|0);break I}b=I()|0;H()|0;break I}b=I()|0;H()|0}sb(d+128|0);break t}b=I()|0;H()|0;break t}b=I()|0;H()|0;break y}b=I()|0;H()|0;sb(d+96|0);break y}b=I()|0;H()|0;sb(d+112|0);break y}b=I()|0;H()|0;break y}b=I()|0;H()|0;break y}b=I()|0;H()|0;pb(d- -64|0);break y}b=I()|0;H()|0;break y}b=I()|0;H()|0;pb(d- -64|0)}sb(d+184|0);break t}b=I()|0;H()|0;break t}b=I()|0;H()|0;break t}b=I()|0;H()|0;pb(d+184|0);break t}b=I()|0;H()|0}sb(d+200|0);break q}b=I()|0;H()|0;break q}b=I()|0;H()|0}sb(d+216|0);break b}b=I()|0;H()|0;break b}b=I()|0;H()|0;pb(d+184|0);break m}b=I()|0;H()|0}pb(d+200|0);break k}b=I()|0;H()|0}yb(d+216|0);break i}b=I()|0;H()|0}pb(e);break b}b=I()|0;H()|0;break b}b=I()|0;H()|0;break b}b=I()|0;H()|0;break b}b=I()|0;H()|0;break b}b=I()|0;H()|0;break b}b=I()|0;H()|0}Qz(d+264|0)}sb(y);L(b|0);E()}function rAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0;d=fb-320|0;fb=d;Ac(b);a:{if(!gt(b,d+304|0)){break a}if(!VN(d+304|0)){break a}w=rk(d+288|0,b);u=wy(d+272|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!c){p[114610]=0;Q(953,d|0,w|0,1,1413891155);b=p[114610];p[114610]=0;if((b|0)==1){break s}break u}p[114610]=0;N(954,d|0,w|0,1);b=p[114610];p[114610]=0;if((b|0)==1){break t}}Tza(u,d);sl(d);p[114610]=0;N(955,d|0,u|0,1413891155);b=p[114610];p[114610]=0;v:{w:{if((b|0)!=1){p[114610]=0;e=J(956,d|0,16715)|0;b=p[114610];p[114610]=0;if((b|0)==1){break w}sb(d);if(!c){break b}if(!(e^1)){break v}break b}e=I()|0;H()|0;break c}e=I()|0;H()|0;sb(d);break c}p[114610]=0;K(447,a|0,4194304);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[a+480208>>2]=12;p[114610]=0;N(955,d+256|0,u|0,1280592212);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=M(255,d+256|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break g}p[114610]=0;P(463,d+256|0,a+1304400|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}m=a+484360|0;Bp(Ob(m));k=d+240|0;bAa(k);p[114610]=0;n[d+239|0]=0;N(957,d+224|0,u|0,1196314451);b=p[114610];p[114610]=0;if((b|0)==1){break i}A=d,B=Ub(d+224|0),p[A+216>>2]=B;A=d,B=Vb(d+224|0),p[A+208>>2]=B;x:{y:{z:{A:{B:{C:{if(!Ab(d+216|0,d+208|0)){break C}j=d+12|0;f=d+24|0;t=d+44|0;while(1){e=rk(d+192|0,p[d+216>>2]);p[114610]=0;g=J(958,d+192|0,d+176|0)|0;b=p[114610];p[114610]=0;D:{E:{F:{G:{H:{I:{if((b|0)!=1){b=1;if(!(g&q[d+185|0]==1)){break D}A=a,B=sd(q[d+186|0],r[a+480188>>1],127),o[A+480188>>1]=B;p[114610]=0;l=M(959,d|0)|0;b=p[114610];p[114610]=0;J:{K:{L:{M:{if((b|0)!=1){p[114610]=0;N(960,d+160|0,1,d+176|0);b=p[114610];p[114610]=0;if((b|0)==1){break M}p[114610]=0;K(415,d+120|0,d+160|0);b=p[114610];p[114610]=0;if((b|0)==1){break M}p[114610]=0;K(961,d+152|0,t|0);b=p[114610];p[114610]=0;if((b|0)==1){break L}p[114610]=0;J(470,d+152|0,d+120|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break L}pb(d+120|0);if(cd(Ob(m))){break J}p[114610]=0;b=M(485,m|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break K}if((b|0)!=255){break J}b=2;break E}e=I()|0;H()|0;break k}e=I()|0;H()|0;break l}e=I()|0;H()|0;pb(d+120|0);break l}e=I()|0;H()|0;break l}b=Ob(m);p[114610]=0;K(962,d+120|0,t|0);g=p[114610];p[114610]=0;N:{O:{P:{if((g|0)!=1){p[114610]=0;K(487,b|0,d+120|0);b=p[114610];p[114610]=0;if((b|0)==1){break P}pb(d+120|0);p[114610]=0;N(954,d+160|0,e|0,1);b=p[114610];p[114610]=0;if((b|0)==1){break O}A=d,B=Ub(d+160|0),p[A+144>>2]=B;A=d,B=Vb(d+160|0),p[A+136>>2]=B;if(Ab(d+144|0,d+136|0)){break N}break H}e=I()|0;H()|0;break l}e=I()|0;H()|0;pb(d+120|0);break l}e=I()|0;H()|0;break l}Q:{R:{while(1){S:{e=p[d+144>>2];b=Re(d+120|0,qb(e));g=q[e+4|0]|q[e+5|0]<<8|(q[e+6|0]<<16|q[e+7|0]<<24);p[d+152>>2]=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);p[d+156>>2]=g;s=1;T:{e=q[d+152|0]|q[d+153|0]<<8|(q[d+154|0]<<16|q[d+155|0]<<24);if((e|0)!=1212960847){if((e|0)!=1312903248){break T}e=0;if(!r[a+480188>>1]){break T}U:{while(1){p[114610]=0;g=J(258,b|0,2)|0;h=p[114610];p[114610]=0;if((h|0)==1){break U}if(!g){break T}p[114610]=0;K(472,d+96|0,b|0);g=p[114610];p[114610]=0;V:{W:{X:{Y:{if((g|0)!=1){g=Zc(d+96|0);switch(q[d+96|0]){case 4:break W;case 2:break X;case 0:break Y;default:break V}}break I}g=q[g|0];A=oc(d,e),B=g^128,n[A|0]=B;Wd(d+104|0,f,e);Zd(d+104|0,0);break V}A=oc(d,e),B=128,n[A|0]=B;Wd(d+104|0,f,e);Zd(d+104|0,1);break V}A=oc(d,e),B=128,n[A|0]=B;Wd(d+104|0,f,e);Zd(d+104|0,0)}e=e+1|0;if(e>>>0<r[a+480188>>1]){continue}break}break T}break I}if(Dz(d+152|0)>>>0<9){break T}h=0;p[114610]=0;J(338,b|0,2)|0;e=p[114610];p[114610]=0;g=65535;if((e|0)==1){break S}while(1){p[114610]=0;e=J(258,b|0,1)|0;i=p[114610];p[114610]=0;Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((i|0)!=1){if(!e){break T}p[114610]=0;e=M(387,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break I}switch(e|0){case 0:break T;case 14:break _;case 13:break $;case 12:break ba;case 8:break ca;case 7:break da;case 4:break ea;case 1:break fa;default:break aa}}break I}if(r[d+36>>1]==65535){e=Ob(m);p[114610]=0;e=M(544,e|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break I}o[d+36>>1]=e}e=Ob(m);p[114610]=0;e=M(544,e|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break I}p[114610]=0;o[d+38>>1]=e;e=J(963,b|0,d+239|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break I}ga:{ha:{switch(e+ -254|0){case 1:p[114610]=0;e=Y(964)|0;i=p[114610];p[114610]=0;if((i|0)!=1){break ga}break I;case 0:break ha;default:break ga}}p[114610]=0;e=Y(965)|0;i=p[114610];p[114610]=0;if((i|0)==1){break I}}i=Ob(m);p[114610]=0;K(797,i|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break I}g=(g&65535)==65535?h:g;break Z}p[114610]=0;e=M(357,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break I}if(e>>>0>=(g&65535)>>>0){o[d+40>>1]=e-g}Pe(Ob(m),r[d+40>>1]);break Z}p[114610]=0;e=M(387,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break I}n[d+43|0]=e;break Z}p[114610]=0;e=M(387,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break I}n[d+42|0]=e;break Z}p[114610]=0;e=J(920,b|0,d+104|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break I}if(!(e&!q[d+104|0])|(q[d+106|0]|q[d+107|0])|(q[d+105|0]!=255|q[d+108|0]!=1)){break aa}if(!q[d+109|0]){break Z}}s=0;break T}p[114610]=0;K(810,d+112|0,b|0);e=p[114610];p[114610]=0;ia:{ja:{ka:{la:{if((e|0)!=1){i=Zc(d+112|0);x=Tf(d+112|0);e=d+112|0;z=q[e|0];if(Cc(d)>>>0<=z>>>0){break Z}switch(q[x|0]){case 4:break ja;case 2:break ka;case 0:break la;default:break ia}}break I}i=q[i|0];A=oc(d,q[e|0]),B=i^128,n[A|0]=B;Wd(d+104|0,f,q[e|0]);Zd(d+104|0,0);break ia}A=oc(d,q[e|0]),B=128,n[A|0]=B;Wd(d+104|0,f,q[e|0]);Zd(d+104|0,1);break ia}A=oc(d,q[e|0]),B=128,n[A|0]=B;Wd(d+104|0,f,q[e|0]);Zd(d+104|0,0)}ma:{if(y){break ma}y=0;if(!ak(k)){break Z}if(q[oc(TN(k),q[e|0])|0]!=q[oc(d,q[e|0])|0]){break ma}Wd(d+104|0,TN(k)+24|0,q[e|0]);i=tb(d+104|0);Wd(d+96|0,f,q[e|0]);if((tb(d+96|0)|0)==(i|0)){break Z}}y=1;break Z}p[114610]=0;K(472,d+104|0,b|0);e=p[114610];p[114610]=0;if((e|0)==1){break Q}e=Zc(d+104|0);i=d+104|0;x=q[i|0];if(Cc(j)>>>0<=x>>>0){break Z}e=q[e|0];A=oc(j,q[i|0]),B=(e>>>2|0)+1|0,n[A|0]=B}h=h+1|0;continue}}sb(b);if(!s){break R}ok(d+144|0);if(Ab(d+144|0,d+136|0)){continue}break H}break}break I}b=1;break F}break I}e=I()|0;H()|0;break k}e=I()|0;H()|0;sb(b);break G}b=0;if(r[d+36>>1]==65535|r[d+38>>1]==65535){break F}b=Ob(m);p[114610]=0;S(966,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){b=0;p[114610]=0;K(967,k|0,l|0);e=p[114610];p[114610]=0;if((e|0)!=1){break F}}e=I()|0;H()|0}sl(d+160|0);break l}sl(d+160|0)}vy(l)}sb(d+192|0);if(!b){Ff(d+216|0);if(Ab(d+216|0,d+208|0)){continue}break C}break}e=0;if((b|0)!=2){break B}}e=0;p[114610]=0;K(489,m|0,0);b=p[114610];p[114610]=0;if((b|0)==1){break r}if(cd(k)){break B}if(c&2){p[114610]=0;N(957,d+192|0,u|0,1347244868);b=p[114610];p[114610]=0;if((b|0)==1){break x}A=d,B=Ub(d+192|0),p[A+176>>2]=B;A=d,B=Vb(d+192|0),p[A+152>>2]=B;if(Ab(d+176|0,d+152|0)){e=a+480190|0;f=d+13|0;g=d+17|0;l=q[d+239|0];while(1){b=p[d+176>>2];na:{oa:{pa:{qa:{ra:{if(!l){p[114610]=0;h=J(968,b|0,d|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break ra}if(!h){break na}h=q[d+52|0]|q[d+53|0]<<8;o[d+104>>1]=h+1;if(h>>>0>3998){break pa}p[114610]=0;h=J(452,e|0,d+104|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break ra}o[a+480190>>1]=r[h>>1];p[114610]=0;K(969,d|0,(v(r[d+104>>1],104)+a|0)+484380|0);h=p[114610];p[114610]=0;if((h|0)==1){break ra}p[114610]=0;N(970,d+160|0,1,f|0);h=p[114610];p[114610]=0;sa:{ta:{if((h|0)==1){break ta}p[114610]=0;K(415,d+120|0,d+160|0);h=p[114610];p[114610]=0;if((h|0)==1){break ta}p[114610]=0;J(369,((r[d+104>>1]<<5)+a|0)+946300|0,d+120|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break sa}pb(d+120|0);break pa}e=I()|0;H()|0;break oa}e=I()|0;H()|0;pb(d+120|0);break oa}p[114610]=0;h=J(971,b|0,d|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break qa}if(!h){break na}h=q[d+56|0]|q[d+57|0]<<8;o[d+104>>1]=h+1;if(h>>>0>3998){break pa}p[114610]=0;h=J(452,e|0,d+104|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break qa}o[a+480190>>1]=r[h>>1];p[114610]=0;K(972,d|0,(v(r[d+104>>1],104)+a|0)+484380|0);h=p[114610];p[114610]=0;if((h|0)==1){break qa}p[114610]=0;N(970,d+160|0,1,g|0);h=p[114610];p[114610]=0;ua:{va:{if((h|0)==1){break va}p[114610]=0;K(415,d+120|0,d+160|0);h=p[114610];p[114610]=0;if((h|0)==1){break va}p[114610]=0;J(369,((r[d+104>>1]<<5)+a|0)+946300|0,d+120|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break ua}pb(d+120|0);break pa}e=I()|0;H()|0;break oa}e=I()|0;H()|0;pb(d+120|0);break oa}e=I()|0;H()|0;break oa}e=I()|0;H()|0;break oa}if((r[d+104>>1]+ -1&65535)>>>0>3998){break na}h=Tc(d,8,1,0,2);p[114610]=0;P(400,h|0,(v(r[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break na}e=I()|0;H()|0}$c(d+192|0);break j}Ff(d+176|0);if(Ab(d+176|0,d+152|0)){continue}break}}$c(d+192|0)}A=a,B=q[rl(k,0)+43|0],p[A+480196>>2]=B;A=a,B=v(q[rl(k,0)+42|0],1e4),p[A+480204>>2]=B;Pe(Ob(m),r[rl(k,0)+40>>1]);if(r[a+480188>>1]){b=0;while(1){p[114610]=0;e=(b<<5)+a|0;f=e+480280|0;S(432,f|0);g=p[114610];p[114610]=0;if((g|0)==1){break y}A=e+480286|0,B=q[oc(rl(k,0)+12|0,b)|0],o[A>>1]=B;A=e+480284|0,B=q[oc(rl(k,0),b)|0],o[A>>1]=B;Wd(d,rl(k,0)+24|0,b);e=tb(d);p[f>>2]=p[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<r[a+480188>>1]){continue}break}}wa:{if(q[d+239|0]){p[114610]=0;J(2,d|0,16724)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break wa}break m}p[114610]=0;J(2,d|0,16768)|0;b=p[114610];p[114610]=0;if((b|0)==1){break m}}xb(a+1304436|0,d);pb(d);p[114610]=0;b=J(2,d|0,16802)|0;f=p[114610];p[114610]=0;e=1;if((f|0)==1){break z}xb(a+1304448|0,b);pb(b);p[a+1304496>>2]=4;if(!(c&1)|!r[a+480188>>1]){break B}p[114610]=0;N(957,d+192|0,u|0,1146045008);b=p[114610];p[114610]=0;if((b|0)==1){break n}b=gd(d+192|0);p[114610]=0;h=a+484344|0;K(401,h|0,b&65535);b=p[114610];p[114610]=0;if((b|0)==1){break q}A=d,B=Ub(d+192|0),p[A+120>>2]=B;A=d,B=Vb(d+192|0),p[A+160>>2]=B;if(Ab(d+120|0,d+160|0)){while(1){l=p[d+120>>2];p[114610]=0;b=M(255,l|0)|0;c=p[114610];p[114610]=0;xa:{ya:{za:{if((c|0)==1){break za}p[114610]=0;c=M(390,l|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break za}if((b|0)!=(c|0)){break xa}p[114610]=0;b=J(973,l|0,8)|0;c=p[114610];p[114610]=0;if((c|0)==1){break za}if(b){break ya}break xa}e=I()|0;H()|0;break o}p[114610]=0;t=J(963,l|0,d+239|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){p[114610]=0;j=M(357,l|0)|0;b=p[114610];p[114610]=0;Aa:{if((b|0)==1){break Aa}p[114610]=0;b=P(402,h|0,t|0,j|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Aa}if(!j|b^1){break xa}g=0;while(1){Ba:{b=Rb(h,t);p[114610]=0;c=J(497,b|0,g|0)|0;b=p[114610];p[114610]=0;Ca:{Da:{Ea:{if((b|0)!=1){p[114610]=0;b=M(357,l|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Ea}if(b>>>0<3){break Ca}p[114610]=0;N(341,d|0,l|0,b+ -2|0);b=p[114610];p[114610]=0;if((b|0)!=1){break Da}e=I()|0;H()|0;break o}e=I()|0;H()|0;break o}e=I()|0;H()|0;break o}Fa:{while(1){p[114610]=0;b=J(258,d|0,3)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Ba}if(!b){break Fa}p[114610]=0;K(472,d+176|0,d|0);b=p[114610];p[114610]=0;Ga:{Ha:{Ia:{Ja:{if((b|0)!=1){f=d+176|0;b=Zc(d+176|0);o[d+152>>1]=r[a+480188>>1]+ -1;b=q[b|0];p[114610]=0;o[d+104>>1]=b;b=J(477,d+152|0,d+104|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Ba}e=r[b>>1];b=n[f|0];if((b|0)>-1){break Ga}p[114610]=0;b=M(387,d|0)|0;s=p[114610];p[114610]=0;if((s|0)==1){break Ba}if(q[d+239|0]){break Ia}if((b|0)!=255){break Ja}b=254;break Ha}break Ba}if(b>>>0>128){break Ha}b=(v(b>>>4|0,12)+(b&15)|0)+13|0;break Ha}b=b>>>0<85?b+36|0:b}n[c+v(e,6)|0]=b;b=q[f|0]}if(b&64){p[114610]=0;b=M(387,d|0)|0;s=p[114610];p[114610]=0;if((s|0)==1){break Ba}n[(c+v(e,6)|0)+1|0]=b+1;b=q[f|0]}if(b&32){p[114610]=0;b=M(387,d|0)|0;s=p[114610];p[114610]=0;if((s|0)==1){break Ba}n[d+152|0]=b;b=c+v(e,6)|0;n[b+2|0]=1;p[114610]=0;n[d+104|0]=127;s=J(391,d+152|0,d+104|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break Ba}n[b+4|0]=q[s|0]+1>>>1;b=q[f|0]}if(!(b&16)){continue}p[114610]=0;K(472,d+152|0,d|0);b=p[114610];p[114610]=0;if((b|0)!=1){b=c+v(e,6)|0;f=q[Zc(d+152|0)|0];n[b+5|0]=f;Ka:{switch(q[d+152|0]+ -1|0){case 0:n[(c+v(e,6)|0)+3|0]=11;if(!q[d+239|0]){n[b+5|0]=f<<3|15;continue}n[b+5|0]=f<<4|15;continue;case 1:n[(c+v(e,6)|0)+3|0]=11;if(q[d+239|0]){n[b+5|0]=f<<4;continue}n[b+5|0]=f<<3&240;continue;case 2:n[(c+v(e,6)|0)+3|0]=11;if(q[d+239|0]){n[b+5|0]=f|240;continue}n[b+5|0]=f>>>1|240;continue;case 3:n[(c+v(e,6)|0)+3|0]=11;if(q[d+239|0]){n[b+5|0]=f&15;continue}if(f>>>0<=1){n[b+5|0]=f|240;continue}n[b+5|0]=f>>>1&15;continue;case 10:n[(c+v(e,6)|0)+3|0]=2;A=b,B=Cs(f,q[d+239|0])|240,n[A+5|0]=B;continue;case 11:n[(c+v(e,6)|0)+3|0]=2;A=b,B=Cs(f,q[d+239|0]),n[A+5|0]=B;continue;case 12:n[(c+v(e,6)|0)+3|0]=3;A=b,B=Cs(f,q[d+239|0])|240,n[A+5|0]=B;continue;case 13:n[(c+v(e,6)|0)+3|0]=3;A=b,B=Cs(f,q[d+239|0]),n[A+5|0]=B;continue;case 14:n[(c+v(e,6)|0)+3|0]=4;if(q[d+239|0]){continue}n[b+5|0]=(f&252)>>>2;continue;case 16:n[(c+v(e,6)|0)+3|0]=20;n[b+5|0]=f&1|16;continue;case 15:n[(c+v(e,6)|0)+3|0]=6;n[b+5|0]=f&240;continue;case 17:n[(c+v(e,6)|0)+3|0]=6;n[b+5|0]=(f&240)>>>4;continue;case 18:n[(c+v(e,6)|0)+3|0]=20;continue;case 20:n[(c+v(e,6)|0)+3|0]=5;continue;case 21:n[(c+v(e,6)|0)+3|0]=20;n[b+5|0]=f&15|48;continue;case 22:n[(c+v(e,6)|0)+3|0]=7;n[b+5|0]=f|240;continue;case 23:n[(c+v(e,6)|0)+3|0]=7;continue;case 30:n[(c+v(e,6)|0)+3|0]=8;continue;case 31:n[(c+v(e,6)|0)+3|0]=20;n[b+5|0]=f&15|64;continue;case 40:n[(c+v(e,6)|0)+3|0]=10;p[114610]=0;e=M(387,d|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Ba}n[b+5|0]=e;p[114610]=0;J(338,d|0,1)|0;b=p[114610];p[114610]=0;if((b|0)!=1){continue}break Ba;case 41:n[(c+v(e,6)|0)+3|0]=15;continue;case 42:n[(c+v(e,6)|0)+3|0]=20;n[b+5|0]=f&15|192;continue;case 43:n[(c+v(e,6)|0)+3|0]=20;n[b+5|0]=f&15|208;continue;case 50:n[(c+v(e,6)|0)+3|0]=12;n[b+5|0]=(f&254)>>>1;p[114610]=0;J(338,d|0,1)|0;b=p[114610];p[114610]=0;if((b|0)!=1){continue}break Ba;case 51:n[(c+v(e,6)|0)+3|0]=14;n[b+5|0]=0;continue;case 52:n[(c+v(e,6)|0)+3|0]=20;n[b+5|0]=f&15|176;continue;case 53:n[(c+v(e,6)|0)+3|0]=20;n[b+5|0]=f&15|224;continue;case 60:n[(c+v(e,6)|0)+3|0]=16;continue;case 61:n[(c+v(e,6)|0)+3|0]=17;continue;case 70:n[(c+v(e,6)|0)+3|0]=1;continue;case 71:n[(c+v(e,6)|0)+3|0]=20;n[b+5|0]=f&15|32;continue;case 72:n[(c+v(e,6)|0)+3|0]=20;n[b+5|0]=f&15|128;continue;default:break Ka}}n[(c+v(e,6)|0)+3|0]=0;continue}break}break Ba}sb(d)}g=g+1|0;if((j|0)!=(g|0)){continue}break xa}break}e=I()|0;H()|0;sb(d);break o}e=I()|0;H()|0;break o}e=I()|0;H()|0;break o}Ff(d+120|0);if(Ab(d+120|0,d+160|0)){continue}break}}La:{if(ak(k)>>>0<2){break La}if(!ak(k)){break La}e=0;while(1){b=li(m,e&255);c=rl(k,e);f=r[kc(b,r[c+36>>1])>>1];p[114610]=0;f=J(442,h|0,f|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break p}Ma:{if(!f){break Ma}f=r[c+36>>1];p[114610]=0;f=J(814,b|0,f|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break p}if(!(!y|!r[a+480188>>1])){l=c+24|0;b=0;while(1){Wd(d,l,b);j=tb(d);g=Rb(h,f);Na:{if(j){p[114610]=0;j=P(498,d|0,20,145)|0;t=p[114610];p[114610]=0;if((t|0)!=1){j=wi(nn(Oe(j,0),b&65535));p[114610]=0;J(499,g|0,j|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break Na}}e=I()|0;H()|0;break o}j=q[oc(c,b)|0];p[114610]=0;j=P(498,d|0,9,j|0)|0;t=p[114610];p[114610]=0;if((t|0)!=1){j=wi(nn(Oe(j,0),b&65535));p[114610]=0;J(499,g|0,j|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break Na}}e=I()|0;H()|0;break o}b=b+1|0;if(b>>>0<r[a+480188>>1]){continue}break}}b=Rb(h,f);g=q[c+43|0];p[114610]=0;g=P(498,d|0,16,g|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break A}g=wi(Oe(g,0));p[114610]=0;J(499,b|0,g|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break A}b=Rb(h,f);c=q[c+42|0];p[114610]=0;c=P(498,d|0,17,c|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){c=wi(Oe(c,0));p[114610]=0;J(499,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break Ma}}e=I()|0;H()|0;break o}e=e+1|0;if(e>>>0<ak(k)>>>0){continue}break}}$c(d+192|0);e=1}$c(d+224|0);SN(k);sb(d+256|0);break b}e=I()|0;H()|0;break o}e=I()|0;H()|0;break j}e=I()|0;H()|0;break j}e=I()|0;H()|0;break j}e=I()|0;H()|0;break c}e=I()|0;H()|0;break c}e=I()|0;H()|0;break j}e=I()|0;H()|0;break o}e=I()|0;H()|0}$c(d+192|0);break j}e=I()|0;H()|0;break j}e=I()|0;H()|0;break j}vy(l)}sb(d+192|0)}$c(d+224|0);break h}e=I()|0;H()|0}SN(k);break f}e=I()|0;H()|0}sb(d+256|0);break c}e=I()|0;H()|0;break c}e=I()|0;H()|0}sl(u);sb(w);L(e|0);E()}sl(u);sb(w)}fb=d+320|0;return e|0}function cJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0;d=fb-288|0;fb=d;Ac(b);f=d+264|0;g=MIa(b,f);if(!g){gR(f)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!g){break u}if(!jR(d+264|0)){break u}if(!c){e=1;break u}xd(a,1024);ei(a);p[a+480208>>2]=p[a+480208>>2]|12;Ag(a+1074308|0,21);if(q[d+280|0]|q[d+281|0]<<8){e=q[d+280|0]|q[d+281|0]<<8;p[a+480204>>2]=v((e<<24|e<<8&16711680)>>>16|0,1e4)}if(q[d+278|0]|q[d+279|0]<<8){e=q[d+278|0]|q[d+279|0]<<8;p[a+480196>>2]=(e<<24|e<<8&16711680)>>>16}if(!q[d+274|0]){Xi(a,1)}e=d+264|4;e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);Sz(b,a+1304400|0,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+ -14|0);b=rk(d+160|0,b);p[114610]=0;N(582,d+248|0,b|0,1);e=p[114610];p[114610]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){sb(b);p[114610]=0;N(583,d+160|0,d+248|0,1395544366);b=p[114610];p[114610]=0;if((b|0)==1){break E}p[114610]=0;b=M(490,d+160|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break L}if(!b){break F}p[114610]=0;b=M(484,d+160|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break L}p[114610]=0;e=M(484,d+160|0)|0;f=p[114610];p[114610]=0;N:{if((f|0)==1){break N}p[114610]=0;J(338,d+160|0,4)|0;f=p[114610];p[114610]=0;if((f|0)==1){break N}f=a+484360|0;g=Ob(f);p[114610]=0;Z(584,g|0,d+160|0,b|0,65535,65535)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break M}}break L}e=I()|0;H()|0;sb(b);break a}Pe(Ob(f),e);sb(d+160|0);p[114610]=0;N(583,d+160|0,d+248|0,1346458708);b=p[114610];p[114610]=0;if((b|0)==1){break K}p[114610]=0;b=M(490,d+160|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break J}if(!b){break H}p[114610]=0;b=M(484,d+160|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break J}o[a+480188>>1]=b;if((b+ -1&65535)>>>0>31){break H}p[114610]=0;b=M(484,d+160|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break J}p[114610]=0;u=a+484344|0;K(401,u|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break J}p[114610]=0;w=M(494,d+160|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break J}switch(w+ -841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}e=I()|0;H()|0;sb(d+160|0);break b}e=I()|0;H()|0;break b}e=I()|0;H()|0;sb(d+160|0);break b}if(!w){break G}}sb(d+160|0);break A}sb(d+160|0);p[114610]=0;N(583,d+232|0,d+248|0,1398157625);b=p[114610];p[114610]=0;if((b|0)==1){break D}p[114610]=0;b=M(490,d+232|0)|0;e=p[114610];p[114610]=0;O:{if((e|0)==1){break O}if(!b){break B}p[114610]=0;J(338,d+232|0,2)|0;b=p[114610];p[114610]=0;if((b|0)==1){break O}p[114610]=0;e=M(494,d+232|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}b=a;g=b;y=(+(e>>>0)*2.3283064365386963e-10+ +(s[b+480204>>2]/1e4>>>0))*1e4;P:{if(y<4294967296&y>=0){b=~~y>>>0;break P}b=0}p[g+480204>>2]=b;p[114610]=0;J(585,d+232|0,d+160|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}b=0;while(1){if(b>>>0>=r[a+480188>>1]){break C}e=(d+160|0)+(b<<1)|0;e=q[e|0]|q[e+1|0]<<8;p[114610]=0;p[d+96>>2]=(e<<8&16711680|e<<24)>>>16;p[d+80>>2]=180;e=J(462,d+96|0,d+80|0)|0;f=p[114610];p[114610]=0;Q:{if((f|0)==1){break Q}e=p[e>>2];p[114610]=0;e=e+ -90|0;f=e>>31;e=rg(458,ONa(e<<7|45,f<<7|e>>>25,90,0),ib);f=p[114610];p[114610]=0;if((f|0)==1){break Q}o[((b<<5)+a|0)+480284>>1]=e+128;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}sb(d+160|0);break A}e=I()|0;H()|0;break b}e=I()|0;H()|0;break b}p[114610]=0;J(338,d+232|0,16)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}p[114610]=0;b=J(258,d+232|0,2)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}if(b){p[114610]=0;b=M(484,d+232|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;o[d+96>>1]=b;o[d+80>>1]=256;b=J(477,d+96|0,d+80|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}p[a+480200>>2]=r[b>>1]}p[114610]=0;J(338,d+232|0,128)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}p[114610]=0;b=J(585,d+232|0,d+96|0)|0;e=p[114610];p[114610]=0;R:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(b>>>0>=r[a+480188>>1]){break R}e=(d+96|0)+(b<<1)|0;e=q[e|0]|q[e+1|0]<<8;p[114610]=0;p[d+80>>2]=(e<<8&16711680|e<<24)>>>16;p[d+56>>2]=128;e=J(462,d+80|0,d+56|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){o[((b<<5)+a|0)+480286>>1]=p[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break R}break}break c}break c}p[a+480228>>2]=p[a+480228>>2]<<1}sb(d+232|0);p[114610]=0;N(583,d+160|0,d+248|0,1413830740);b=p[114610];p[114610]=0;S:{T:{if((b|0)!=1){p[114610]=0;b=M(490,d+160|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break d}if(!b){break S}p[114610]=0;J(586,d+160|0,d+96|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}if((q[d+106|0]|q[d+107|0]<<8)!=65535){break T}p[114610]=0;J(338,d+160|0,1)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break T}break d}e=I()|0;H()|0;break b}p[114610]=0;b=M(548,d+160|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break d}p[114610]=0;U(587,a+1304424|0,d+160|0,b|0,2)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}}sb(d+160|0);p[114610]=0;N(583,d+96|0,d+248|0,1229869908);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=M(490,d+96|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){if(b){p[114610]=0;b=M(484,d+96|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break g}U:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break U}p[114610]=0;e=J(258,d+96|0,v(f,(b>>>14&2)+50|0)|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break y}if(!e){break U}o[a+480190>>1]=f;g=a+480190|0;if(!f){break z}i=d+178|0;j=(b|0)>-1;b=1;V:{W:{while(1){X:{e=b;Y:{Z:{_:{if(!j){p[114610]=0;e=M(484,d+96|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break _}e=e+1|0}p[114610]=0;o[d+56>>1]=e;J(588,d+96|0,d+160|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){if((r[d+56>>1]+ -1&65535)>>>0>3998){break Y}p[114610]=0;e=J(452,g|0,d+56|0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){break Z}}e=I()|0;H()|0;break f}e=I()|0;H()|0;break f}o[a+480190>>1]=r[e>>1];h=r[d+56>>1];e=q[d+282|0]|q[d+283|0]<<8|(q[d+284|0]<<16|q[d+285|0]<<24);p[114610]=0;Q(589,d+160|0,(v(h,104)+a|0)+484380|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24),w|0);e=p[114610];p[114610]=0;if((e|0)==1){break X}p[114610]=0;N(590,d+80|0,2,i|0);e=p[114610];p[114610]=0;if((e|0)==1){break W}p[114610]=0;K(415,d+232|0,d+80|0);e=p[114610];p[114610]=0;if((e|0)==1){break W}p[114610]=0;J(369,((r[d+56>>1]<<5)+a|0)+946300|0,d+232|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break V}pb(d+232|0)}e=b&65535;b=b+1|0;if(e>>>0<f>>>0){continue}break z}break}e=I()|0;H()|0;break f}e=I()|0;H()|0;break f}e=I()|0;H()|0;pb(d+232|0);break f}sb(d+96|0);break A}break w}e=I()|0;H()|0;break f}e=0;break v}p[114610]=0;b=M(484,d+96|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break x}}e=I()|0;H()|0;break f}if((b|0)==4){b=r[g>>1];p[114610]=0;o[d+160>>1]=b;o[d+232>>1]=255;b=J(477,d+160|0,d+232|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break h}o[a+480192>>1]=r[b>>1];p[114610]=0;N(583,d+232|0,d+248|0,1229278806);b=p[114610];p[114610]=0;if((b|0)==1){break i}g=d+80|4;i=d+80|3;j=d+80|5;h=d+80|7;while(1){p[114610]=0;b=J(258,d+96|0,15)|0;e=p[114610];p[114610]=0;$:{if((e|0)!=1){aa:{if(b){p[114610]=0;J(591,d+96|0,d+80|0)|0;b=p[114610];p[114610]=0;ba:{if((b|0)!=1){b=q[d+80|0]|q[d+81|0]<<8;if((b<<24|b<<8&16711680)>>>16>>>0>=r[a+480192>>1]){continue}b=q[d+80|0]|q[d+81|0]<<8;b=v((b<<24|b<<8&16711680)>>>16|0,104)+a|0;n[b+484524|0]=q[d+88|0];e=q[h|0];n[b+484523|0]=255;n[b+484525|0]=e;b=q[d+80|0]|q[d+81|0]<<8;e=q[d+80|0]|q[d+81|0]<<8;p[114610]=0;e=P(454,a|0,((b<<8&16711680|b<<24)>>>16|0)+1&65535,((e<<8&16711680|e<<24)>>>16|0)+1&65535)|0;b=p[114610];p[114610]=0;if((b|0)==1){break aa}if(!e){continue}b=q[j|0]|q[j+1|0]<<8;p[114610]=0;o[d+160>>1]=(b<<8&16711680|b<<24)>>>16;o[d+56>>1]=4095;b=J(477,d+160|0,d+56|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break aa}p[e>>2]=r[b>>1];if(q[i|0]==255){continue}b=q[i|0];p[114610]=0;b=J(256,d+232|0,v(b,34)+2|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break aa}if(!b){continue}p[114610]=0;J(592,d+232|0,d+160|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break aa}n[e+60|0]=q[e+60|0]|1;b=q[d+160|0]|q[d+161|0]<<8;p[d+56>>2]=(b<<24|b<<8&16711680)>>>16;p[114610]=0;p[d+76>>2]=3;p[d+64>>2]=240;p[d+60>>2]=16;p[d+72>>2]=d+56;b=p[d+76>>2];p[d+8>>2]=p[d+72>>2];p[d+12>>2]=b;b=M(593,d+8|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break aa}p[114610]=0;f=e+48|0;K(594,f|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break aa}b=0;if(Bb(f)){break ba}break $}break aa}while(1){ca:{n[d+56|0]=64;t=(d+160|0)+(b<<1)|0;m=q[t+2|0];p[114610]=0;n[d+48|0]=m;m=J(391,d+56|0,d+48|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break ca}m=q[m|0];F=Fb(f,b),G=m,n[F+2|0]=G;t=q[t+3|0];F=Fb(f,b),G=t,o[F>>1]=G;b=b+1|0;if(b>>>0<Bb(f)>>>0){continue}break $}break}break aa}sb(d+232|0);break w}}e=I()|0;H()|0;sb(d+232|0);break f}if(q[g|0]!=255){n[e+60|0]=q[e+60|0]|4;b=q[g|0];n[e+63|0]=b;n[e- -64|0]=b}if(cd(f)){continue}n[e+60|0]=q[e+60|0]|2;b=Bb(f)+ -1|0;n[e+61|0]=b;n[e+62|0]=b;continue}}}sb(d+96|0);p[114610]=0;N(595,d+96|0,d+248|0,1145131092);b=p[114610];p[114610]=0;if((b|0)==1){break j}F=d,G=Ub(d+96|0),p[F+48>>2]=G;F=d,G=Vb(d+96|0),p[F+40>>2]=G;if(Ab(d+48|0,d+40|0)){B=c&1;t=d+232|4;m=(w|0)!=841887798;C=(w|0)!=841887796;while(1){i=p[d+48>>2];p[114610]=0;J(338,i|0,4)|0;b=p[114610];p[114610]=0;da:{ea:{fa:{if((b|0)!=1){p[114610]=0;e=M(484,i|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break l}p[114610]=0;j=M(484,i|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break m}j=m?j:(j>>>0)/s[a+480196>>2]|0;if(!B|e>>>0>255){break da}p[114610]=0;b=P(402,u|0,e|0,j|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break m}if(!b){break da}if(m){break ea}p[114610]=0;J(338,i|0,4)|0;b=p[114610];p[114610]=0;if((b|0)==1){break m}h=0;if(!r[a+480188>>1]){break da}while(1){p[114610]=0;b=M(484,i|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break fa}p[114610]=0;N(341,d+160|0,i|0,b+(b&1)&65535);b=p[114610];p[114610]=0;if((b|0)==1){break n}p[d+232>>2]=0;p[d+236>>2]=0;f=0;ga:{while(1){p[114610]=0;b=J(258,d+160|0,6)|0;g=p[114610];p[114610]=0;if((g|0)==1){break o}if(b^1|s[d+232>>2]>=j>>>0){break ga}b=Rb(u,e);p[114610]=0;b=P(471,b|0,p[d+232>>2],h&65535)|0;g=p[114610];p[114610]=0;ha:{ia:{if((g|0)!=1){p[114610]=0;K(596,d+56|0,d+160|0);g=p[114610];p[114610]=0;if((g|0)==1){break o}g=Zc(d+56|0);z=Tf(d+56|0);x=vi(d+56|0);l=_b(d+56|0);D=d+61|0;k=n[d+56|0];if((k+ -1&255)>>>0>95){break ia}n[b|0]=k+13;if(!p[d+236>>2]){break ha}n[b+3|0]=19;p[114610]=0;p[d+80>>2]=15;k=J(462,t|0,d+80|0)|0;A=p[114610];p[114610]=0;if((A|0)==1){break o}n[b+5|0]=q[k|0]|208;break ha}break o}if((k|0)>-1){break ha}if(p[d+236>>2]){n[b+3|0]=19;p[114610]=0;p[d+80>>2]=15;k=J(462,t|0,d+80|0)|0;A=p[114610];p[114610]=0;if((A|0)!=1){n[b+5|0]=q[k|0]|192;break ha}break o}n[b|0]=254}if(q[g|0]){n[b+2|0]=1;p[114610]=0;n[d+80|0]=64;g=J(391,g|0,d+80|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break o}n[b+4|0]=q[g|0]}g=q[z|0];if(g){n[b+1|0]=g}g=q[x|0];if(g|q[l|0]){n[b+3|0]=g;n[b+5|0]=q[l|0];p[114610]=0;S(577,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break o}}b=q[D|0];if(b&128){p[114610]=0;g=M(387,d+160|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break o}b=g|b<<8&32512}g=p[a+480196>>2];p[114610]=0;f=b+f|0;N(597,d+80|0,f|0,g|0);b=p[114610];p[114610]=0;if((b|0)!=1){b=p[d+84>>2];p[d+232>>2]=p[d+80>>2];p[d+236>>2]=b;continue}break}break o}sb(d+160|0);h=h+1|0;if((h&65535)>>>0<r[a+480188>>1]){continue}break}break da}e=I()|0;H()|0;break k}e=I()|0;H()|0;break k}b=Rb(u,e);p[114610]=0;b=P(471,b|0,0,0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break s}h=0;if(!j){break da}while(1){e=0;ja:{if(!r[a+480188>>1]){break ja}while(1){ka:{p[114610]=0;K(598,d+160|0,i|0);f=p[114610];p[114610]=0;if((f|0)==1){break ka}la:{if(!C){p[d+232>>2]=p[d+160>>2];l=Zc(d+232|0);k=Tf(d+232|0);z=vi(d+232|0);f=n[d+232|0];if((f|0)>=1){n[b|0]=(v((f&240)>>>4|0,12)+(f&15)|0)+12}g=b;f=q[l|0];x=f>>>2|0;if(x){n[b+2|0]=1;n[b+4|0]=x+ -1;f=q[l|0]}n[g+1|0]=f<<4&48|q[k|0]>>>4;n[b+3|0]=q[k|0]&15;n[b+5|0]=q[z|0];break la}p[114610]=0;f=p[d+160>>2];p[d+36>>2]=f;p[d+20>>2]=f;K(599,d+20|0,b|0);f=p[114610];p[114610]=0;if((f|0)==1){break ka}f=Yb(d+160|0,0);n[b+1|0]=q[b+1|0]|q[f|0]&48}p[114610]=0;S(577,b|0);f=p[114610];p[114610]=0;if((f|0)==1){break ka}f=q[b+3|0];ma:{if(f>>>0>11){break ma}f=1<<f;na:{if(!(f&2240)){if(!(f&12)){break ma}if(!q[b+5|0]){break na}break ma}f=q[b+5|0];g=f&240;if(g){n[b+5|0]=g;break ma}if(f){break ma}}n[b+3|0]=0}b=b+6|0;e=e+1|0;if((e&65535)>>>0<r[a+480188>>1]){continue}break ja}break}e=I()|0;H()|0;break k}h=h+1|0;if((h|0)!=(j|0)){continue}break}}Ff(d+48|0);if(Ab(d+48|0,d+40|0)){continue}break}}$c(d+96|0);p[114610]=0;N(583,d+160|0,d+248|0,1346458702);b=p[114610];p[114610]=0;if((b|0)==1){e=I()|0;H()|0;break b}p[114610]=0;b=M(490,d+160|0)|0;e=p[114610];p[114610]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((e|0)!=1){if(b){f=Lb(d+96|0);b=0;Ca:{while(1){Da:{p[114610]=0;e=J(258,d+160|0,1)|0;g=p[114610];p[114610]=0;if((g|0)==1){break Da}if(!e){break Ca}if(b>>>0>=ke(u)>>>0){break Ca}p[114610]=0;P(600,d+160|0,f|0,32)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Da}e=Rb(u,b);p[114610]=0;J(496,e|0,f|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Da}b=b+1|0;continue}break}e=I()|0;H()|0;pb(f);break Ba}pb(f)}sb(d+160|0);p[114610]=0;N(583,d+160|0,d+248|0,1414679374);b=p[114610];p[114610]=0;if((b|0)==1){break Aa}p[114610]=0;b=M(490,d+160|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break wa}if(!b){break xa}f=Lb(d+96|0);b=0;while(1){p[114610]=0;e=J(258,d+160|0,1)|0;g=p[114610];p[114610]=0;if((g|0)==1){break za}if(!e|b>>>0>=r[a+480188>>1]){break ya}p[114610]=0;P(600,d+160|0,f|0,32)|0;e=p[114610];p[114610]=0;if((e|0)==1){break za}p[114610]=0;J(378,((b<<5)+a|0)+480289|0,f|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break za}b=b+1|0;continue}}e=I()|0;H()|0}sb(d+160|0);break b}e=I()|0;H()|0;break b}e=I()|0;H()|0;pb(f);break va}pb(f)}sb(d+160|0);p[114610]=0;N(595,d+160|0,d+248|0,1145129300);b=p[114610];p[114610]=0;if((b|0)==1){break ua}F=d,G=Ub(d+160|0),p[F+96>>2]=G;F=d,G=Vb(d+160|0),p[F+232>>2]=G;if(Ab(d+96|0,d+232|0)){e=c&2;while(1){b=p[d+96>>2];p[114610]=0;c=M(484,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=r[a+480190>>1])){c=v(c,104)+a|0;f=r[c+484518>>1];f=Tc(d+80|0,f&1?16:8,f&64?2:1,1,0);p[114610]=0;P(400,f|0,c+484484|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break p}}Ff(d+96|0);if(Ab(d+96|0,d+232|0)){continue}break}}$c(d+160|0);b=Xc(d+96|0);if((w|0)!=841887798){break sa}p[114610]=0;c=J(2,d+160|0,12790)|0;e=p[114610];p[114610]=0;if((e|0)==1){break ta}xb(b,c);pb(c);break ra}e=I()|0;H()|0}sb(d+160|0);break b}e=I()|0;H()|0;break b}e=I()|0;H()|0;break q}p[114610]=0;N(583,d+160|0,d+248|0,1447383635);c=p[114610];p[114610]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((c|0)!=1){p[114610]=0;c=M(490,d+160|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break qa}if(!c){break Fa}p[114610]=0;e=M(494,d+160|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break Ka}p[114610]=0;c=J(2,d+24|0,12810)|0;f=p[114610];p[114610]=0;if((f|0)==1){break Ja}p[114610]=0;K(219,d+80|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break Ia}p[114610]=0;p[d+56>>2]=e>>>4;p[d+48>>2]=e&15;Q(601,d+232|0,d+80|0,d+56|0,d+48|0);e=p[114610];p[114610]=0;if((e|0)==1){break Ha}xb(b,d+232|0);pb(d+232|0);yb(d+80|0);break Ea}e=I()|0;H()|0;break q}e=I()|0;H()|0;break r}e=I()|0;H()|0;break r}e=I()|0;H()|0;break Ga}e=I()|0;H()|0;yb(d+80|0)}pb(c);break r}p[114610]=0;c=J(2,d+232|0,12832)|0;e=p[114610];p[114610]=0;if((e|0)==1){break t}xb(b,c)}pb(c);sb(d+160|0)}p[114610]=0;c=J(2,d+160|0,12832)|0;e=p[114610];p[114610]=0;if((e|0)==1){break pa}xb(a+1304436|0,c);pb(c);p[114610]=0;c=J(2,d+160|0,12848)|0;e=p[114610];p[114610]=0;if((e|0)==1){break oa}xb(a+1304448|0,c);pb(c);xb(a+1304460|0,b);p[a+1304496>>2]=2;pb(b);e=1;break v}e=I()|0;H()|0;break r}e=I()|0;H()|0;break q}e=I()|0;H()|0;break q}yz(d+248|0)}fb=d+288|0;return e|0}e=I()|0;H()|0;break r}e=I()|0;H()|0;break k}sb(d+160|0)}pb(b);break b}e=I()|0;H()|0;$c(d+160|0);break b}e=I()|0;H()|0;sb(d+160|0);break k}e=I()|0;H()|0;break k}e=I()|0;H()|0;break k}e=I()|0;H()|0}$c(d+96|0);break b}e=I()|0;H()|0;break b}e=I()|0;H()|0;break f}e=I()|0;H()|0;break f}e=I()|0;H()|0}sb(d+96|0);break b}e=I()|0;H()|0;break b}e=I()|0;H()|0;sb(d+160|0);break b}e=I()|0;H()|0;sb(d+232|0)}yz(d+248|0)}L(e|0);E()}function Sxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,O=0;d=fb-528|0;fb=d;Ac(b);a:{if(!mn(b,d+448|0)){break a}if(!$M(d+448|0)){break a}if(!Hb(b,dd(_M(d+448|0),ib))){break a}b:{if(!c){break b}xd(a,4);ei(a);p[a+1074368>>2]=4;l=Xc(d+432|0);c:{d:{k=d+486|0;e:{if(!(hd(k,17472,20)|(q[d+508|0]|q[d+509|0]<<8|(q[d+510|0]<<16|q[d+511|0]<<24))!=276)){e=48;if((q[d+506|0]|q[d+507|0]<<8)>>>0<260){break e}p[114610]=0;g=P(628,d+465|0,0,20)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}e=g?1154:34;break e}if(!hd(k,17493,20)){e=1;break e}p[114610]=0;N(749,d+416|0,3,k|0);g=p[114610];p[114610]=0;f:{g:{h:{if((g|0)==1){break h}p[114610]=0;K(415,d+72|0,d+416|0);g=p[114610];p[114610]=0;if((g|0)==1){break h}p[114610]=0;N(13,d+144|0,4,d+72|0);g=p[114610];p[114610]=0;if((g|0)==1){break g}xb(l,d+144|0);pb(d+144|0);pb(d+72|0);if((q[k|0]|q[k+1|0]<<8|(q[k+2|0]<<16|q[k+3|0]<<24))!=1852141647|(q[k+4|0]|q[k+5|0]<<8|(q[k+6|0]<<16|q[k+7|0]<<24))!=542396493){break f}e=1048;break e}e=I()|0;H()|0;break c}e=I()|0;H()|0;pb(d+72|0);break c}if(!hd(k,17523,12)){e=16;if((r[d+498>>1]|r[d+500>>1]<<16)==538976288&(r[d+502>>1]|r[d+504>>1]<<16)==538976288){break e}p[a+1074368>>2]=5;break e}if(!hd(k,17537,20)){e=48;break e}if(!hd(k,17558,15)){p[114610]=0;g=a+1074308|0;J(479,g|0,54)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}p[114610]=0;J(479,g|0,51)|0;g=p[114610];p[114610]=0;e=16;if((g|0)==1){break d}break e}if(!hd(k,17574,14)){p[114610]=0;J(479,a+1074308|0,57)|0;g=p[114610];p[114610]=0;e=16;if((g|0)!=1){break e}break d}e=hd(k,17589,11)?16:256}p[114610]=0;A=d+465|0;N(749,d+72|0,3,A|0);g=p[114610];p[114610]=0;i:{j:{k:{l:{m:{if((g|0)==1){break m}p[114610]=0;K(415,d+144|0,d+72|0);g=p[114610];p[114610]=0;if((g|0)==1){break m}xb(a+1304400|0,d+144|0);pb(d+144|0);p[a+480260>>2]=1;p[a+480264>>2]=31999;x=a+484360|0;Pe(Ob(x),q[d+514|0]|q[d+515|0]<<8);o[a+480188>>1]=q[d+516|0]|q[d+517|0]<<8;g=q[d+520|0]|q[d+521|0]<<8;p[114610]=0;o[d+144>>1]=g;o[d+72>>1]=255;g=J(477,d+144|0,d+72|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break l}o[a+480192>>1]=r[g>>1];if(q[d+524|0]|q[d+525|0]<<8){p[a+480196>>2]=q[d+524|0]|q[d+525|0]<<8}if(q[d+526|0]|q[d+527|0]<<8){g=p[19850];G=a,O=sd(v(q[d+526|0]|q[d+527|0]<<8,1e4),v(p[g+20>>2],1e4),v(p[g+24>>2],1e4)),p[G+480204>>2]=O}p[a+480208>>2]=0;p[a+480208>>2]=p[a+480208>>2]&-17|(q[d+522|0]|q[d+523|0]<<8)<<4&16;g=(q[d+522|0]|q[d+523|0]<<8)<<3&32768;p[a+480208>>2]=g|p[a+480208>>2]&-32769;f=Ob(x);i=q[d+512|0]|q[d+513|0]<<8;p[114610]=0;Z(584,f|0,b|0,i|0,65535,65535)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}h=(e|0)==34?g>>>15|0?146:e:e;if(!(h&1024|(q[d+512|0]|q[d+513|0]<<8))){g=Ob(x);p[114610]=0;N(1033,g|0,1,0);g=p[114610];p[114610]=0;if((g|0)==1){break d}}g=q[d+508|0]|q[d+509|0]<<8|(q[d+510|0]<<16|q[d+511|0]<<24);p[114610]=0;J(256,b|0,g+60|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break d}if((q[d+506|0]|q[d+507|0]<<8)>>>0>=260){p[114610]=0;N(1034,b|0,d+448|0,a|0);g=p[114610];p[114610]=0;if((g|0)==1){break d}}n[d+415|0]=0;m=d+416|0;Ixa(m);if(r[a+480192>>1]){break k}g=-1;break j}e=I()|0;H()|0;break c}e=I()|0;H()|0;break c}C=c&2;D=d+90|0;F=d+177|0;i=d+173|0;e=1;g=-1;t=1;while(1){n:{p[114610]=0;f=M(390,b|0)|0;j=p[114610];p[114610]=0;o:{p:{q:{r:{s:{t:{if((j|0)!=1){jg(b,4);p[114610]=0;P(1035,b|0,d+144|0,(f?f:263)|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break n}u:{if((h|0)==1){if((q[d+144|0]|q[d+145|0]<<8|(q[d+146|0]<<16|q[d+147|0]<<24))==245){p[a+1074304>>2]=16777381;p[114610]=0;f=J(2,d+72|0,17601)|0;h=p[114610];p[114610]=0;if((h|0)!=1){xb(l,f);pb(f);h=17;break u}e=I()|0;H()|0;break i}h=16;if((q[d+144|0]|q[d+145|0]<<8|(q[d+146|0]<<16|q[d+147|0]<<24))!=263){break u}p[a+1074304>>2]=16777395;p[114610]=0;f=J(2,d+72|0,17627)|0;h=p[114610];p[114610]=0;if((h|0)!=1){xb(l,f);pb(f);h=17;break u}e=I()|0;H()|0;break i}if(q[d+171|0]|q[d+172|0]<<8){break u}v:{if(!(h&2)|(q[d+144|0]|q[d+145|0]<<8|(q[d+146|0]<<16|q[d+147|0]<<24))!=263){break v}f=i;if(q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24)){break v}h=h|16;break u}if(!(!(h&256)|(q[d+144|0]|q[d+145|0]<<8|(q[d+146|0]<<16|q[d+147|0]<<24))==29)){h=h&-257;break u}if(!(h&160)){break u}h=(q[d+144|0]|q[d+145|0]<<8|(q[d+146|0]<<16|q[d+147|0]<<24))==33?h:0}p[114610]=0;f=P(454,a|0,t&65535,0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break n}if(!f){break o}j=((e<<2)+a|0)+900380|0;f=p[j>>2];p[114610]=0;K(1036,d+144|0,f|0);f=p[114610];p[114610]=0;if((f|0)==1){break n}f=q[d+170|0];w:{if((g|0)==-1){g=f;break w}if(!(h&32)|(f|0)==(g|0)){break w}h=h&-161|128}if(!(q[d+171|0]|q[d+172|0]<<8)){break o}f=q[d+385|0];e=q[d+386|0];w=q[d+387|0]|q[d+388|0]<<8;u=q[d+391|0];y=q[d+171|0]|q[d+172|0]<<8;p[114610]=0;N(1037,d+128|0,a|0,y|0);y=p[114610];p[114610]=0;if((y|0)==1){break t}h=u|(w|(e|f))?h&-4:h;e=12;while(1){f=r[Yc(p[j>>2]+236|0,e)>>1];if(fc(d+128|0)>>>0>f>>>0){f=r[kc(d+128|0,r[Yc(p[j>>2]+236|0,e)>>1])>>1];G=Yc(p[j>>2]+236|0,e),O=f,o[G>>1]=O}e=e+1|0;if((e|0)!=108){continue}break}if((q[d+506|0]|q[d+507|0]<<8)>>>0>259){Bb(m);YM(m);Hg(m)}f=q[d+171|0]|q[d+172|0]<<8;p[114610]=0;f=J(1038,d+112|0,f|0)|0;e=p[114610];p[114610]=0;x:{if((e|0)!=1){e=0;if(q[d+171|0]|q[d+172|0]<<8){break x}break s}e=I()|0;H()|0;break q}y:{z:{A:{B:{while(1){p[114610]=0;J(1039,b|0,d+72|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break y}p[114610]=0;K(1040,d+56|0,d+72|0);j=p[114610];p[114610]=0;C:{if((j|0)==1){break C}p[114610]=0;K(1041,m|0,d+56|0);j=p[114610];p[114610]=0;if((j|0)==1){break C}j=q[d+72|0]|q[d+73|0]<<8|(q[d+74|0]<<16|q[d+75|0]<<24);G=Fb(f,e),O=j,p[G>>2]=O;w=q[d+89|0];if(fc(d+128|0)>>>0>e>>>0){j=r[kc(d+128|0,e)>>1];p[114610]=0;u=(v(j,104)+a|0)+484380|0;K(1042,d+72|0,u|0);y=p[114610];p[114610]=0;if((y|0)==1){break B}p[114610]=0;K(1043,F|0,u|0);u=p[114610];p[114610]=0;if((u|0)==1){break B}p[114610]=0;N(590,d+40|0,3,D|0);u=p[114610];p[114610]=0;if((u|0)==1){break A}p[114610]=0;K(415,d+56|0,d+40|0);u=p[114610];p[114610]=0;if((u|0)==1){break A}p[114610]=0;J(369,((j<<5)+a|0)+946300|0,d+56|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break z}pb(d+56|0);h=(h&2)>>>1|0?(q[d+86|0]&3)==3?h|4:h:h}z=w|z;e=e+1|0;if(e>>>0>=(q[d+171|0]|q[d+172|0]<<8)>>>0){break s}continue}break}e=I()|0;H()|0;break r}e=I()|0;H()|0;break r}e=I()|0;H()|0;break r}e=I()|0;H()|0;pb(d+56|0);break r}e=I()|0;H()|0;break r}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}if((q[d+506|0]|q[d+507|0]<<8)>>>0<260){break p}e=0;if(!(q[d+171|0]|q[d+172|0]<<8)){break p}D:{while(1){E:{w=q[Fb(m,e)+3|0];j=p[Fb(f,e)>>2];p[114610]=0;N(341,d+72|0,b|0,((w|0)==11?(j+1>>>1|0)+16|0:j)|0);j=p[114610];p[114610]=0;if((j|0)==1){break E}if(!(!C|fc(d+128|0)>>>0<=e>>>0)){w=r[kc(d+128|0,e)>>1];j=Fb(m,e);j=q[j|0]|q[j+1|0]<<8|(q[j+2|0]<<16|q[j+3|0]<<24);p[114610]=0;p[d+36>>2]=j;p[d+4>>2]=j;j=U(1044,(v(w,104)+a|0)+484380|0,d+4|0,d+72|0,d+415|0)|0;w=p[114610];p[114610]=0;if((w|0)==1){break D}B=j^1|B}sb(d+72|0);e=e+1|0;if(e>>>0<(q[d+171|0]|q[d+172|0]<<8)>>>0){continue}break p}break}e=I()|0;H()|0;break r}e=I()|0;H()|0;sb(d+72|0)}be(f)}qf(d+128|0);break i}be(f);qf(d+128|0)}t=t+1|0;e=t&65535;if(e>>>0<=r[a+480192>>1]){continue}break j}break}e=I()|0;H()|0;break i}F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if(!(!(h&2)|z&255)){p[114610]=0;f=P(628,A|0,0,20)|0;i=p[114610];p[114610]=0;if((i|0)==1){break W}h=f?h|16:h}X:{if((q[d+506|0]|q[d+507|0]<<8)>>>0>259){break X}if(c&3){p[114610]=0;N(1034,b|0,d+448|0,a|0);f=p[114610];p[114610]=0;if((f|0)==1){break W}}if(!(c&2)|!r[a+480190>>1]){break X}c=1;e=1;while(1){f=Fb(m,c+ -1|0);p[114610]=0;P(400,f|0,(v(c,104)+a|0)+484380|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break V}e=e+1|0;c=e&65535;if(c>>>0<=r[a+480190>>1]){continue}break}}if(B&1){p[114610]=0;c=J(2,d+144|0,17652)|0;f=p[114610];p[114610]=0;if((f|0)==1){break U}p[114610]=0;N(650,a|0,2,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break T}pb(c)}p[114610]=0;c=J(621,b|0,17735)|0;f=p[114610];p[114610]=0;if((f|0)==1){break W}if(c){p[114610]=0;c=M(390,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break W}p[114610]=0;U(587,a+1304424|0,b|0,c|0,0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break W}h=h|16}p[114610]=0;f=J(621,b|0,17740)|0;c=p[114610];p[114610]=0;if((c|0)==1){break F}if(f){p[114610]=0;c=M(390,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break F}p[114610]=0;i=a+901404|0;P(1045,b|0,i|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break F}p[114610]=0;S(637,i|0);c=p[114610];p[114610]=0;if((c|0)==1){break F}h=h|16}p[114610]=0;c=J(621,b|0,17745)|0;i=p[114610];p[114610]=0;if((i|0)==1){break F}if(c){p[114610]=0;c=M(390,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break S}o[d+144>>1]=c>>>5;i=a+484344|0;c=ke(i);p[114610]=0;o[d+72>>1]=c;c=J(477,d+144|0,d+72|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break R}e=r[c>>1];if(e){c=0;while(1){p[114610]=0;P(871,b|0,d+144|0,32)|0;t=p[114610];p[114610]=0;if((t|0)==1){break Q}t=Rb(i,c);p[114610]=0;J(872,t|0,d+144|0)|0;t=p[114610];p[114610]=0;if((t|0)==1){break Q}c=c+1|0;if((e|0)!=(c|0)){continue}break}}h=h|16}p[114610]=0;c=J(621,b|0,17750)|0;i=p[114610];p[114610]=0;if((i|0)==1){break F}if(c){p[114610]=0;c=M(390,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break P}o[d+144>>1]=(c>>>0)/20;c=r[a+480188>>1];p[114610]=0;o[d+72>>1]=c;c=J(477,d+144|0,d+72|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break O}c=r[c>>1];if(c){e=0;while(1){p[114610]=0;P(639,b|0,((e<<5)+a|0)+480289|0,20)|0;i=p[114610];p[114610]=0;if((i|0)==1){break K}e=e+1|0;if((c|0)!=(e|0)){continue}break}}h=h|16}p[114610]=0;c=J(258,b|0,8)|0;i=p[114610];p[114610]=0;if((i|0)==1){break F}if(c){c=p[b+8>>2];p[114610]=0;J(640,a|0,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break J}h=(c|0)==p[b+8>>2]?h:h|16}if(!(h&16)){break L}if(!(h&4)){break M}p[a+1074304>>2]=17367040;p[114610]=0;c=J(2,d+144|0,17755)|0;i=p[114610];p[114610]=0;if((i|0)==1){break N}xb(l,c);pb(c);break L}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;pb(c);break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}if(!(h&2)){break L}p[a+1074304>>2]=18219008;p[114610]=0;c=J(2,d+144|0,17776)|0;i=p[114610];p[114610]=0;if((i|0)==1){break I}xb(l,c);pb(c)}Y:{Z:{_:{$:{aa:{ba:{ca:{if((q[k|0]|q[k+1|0]<<8|(q[k+2|0]<<16|q[k+3|0]<<24))==1852141647&(q[k+4|0]|q[k+5|0]<<8|(q[k+6|0]<<16|q[k+7|0]<<24))==542396493){p[114610]=0;c=P(1046,d+144|0,d+494|0,12)|0;i=p[114610];p[114610]=0;if((i|0)==1){break ca}p[114610]=0;N(13,d+72|0,1,c|0);i=p[114610];p[114610]=0;if((i|0)==1){break ba}p[114610]=0;i=M(1047,d+72|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break aa}p[a+1074304>>2]=i;pb(d+72|0);p[a+1074368>>2]=s[a+1074304>>2]<19007257?4:5;pb(c);h=24}if(!(!p[a+1074304>>2]|h&8)){p[a+1074368>>2]=0;bt(a+1074308|0)}c=h&32;da:{if(!c){break da}p[a+1074368>>2]=5;if(!f){p[114610]=0;S(638,a+901404|0);f=p[114610];p[114610]=0;if((f|0)==1){break F}}if((q[d+506|0]|q[d+507|0]<<8)>>>0<260){break da}p[114610]=0;P(478,a+1074308|0,4,1)|0;f=p[114610];p[114610]=0;if((f|0)==1){break F}}if(!Pc(l)){break Y}if(!(h&256)|(z&255|g+1>>>0>1)){break Z}p[114610]=0;c=J(2,d+144|0,17804)|0;g=p[114610];p[114610]=0;if((g|0)==1){break _}xb(l,c);pb(c);break Y}e=I()|0;H()|0;break i}e=I()|0;H()|0;break $}e=I()|0;H()|0;pb(d+72|0)}pb(c);break i}e=I()|0;H()|0;break i}if(c){p[114610]=0;c=J(2,d+144|0,17816)|0;g=p[114610];p[114610]=0;if((g|0)!=1){xb(l,c);pb(c);break Y}e=I()|0;H()|0;break i}p[114610]=0;c=J(2,d+144|0,17844)|0;g=p[114610];p[114610]=0;if((g|0)==1){break H}xb(l,c);pb(c)}n[d+40|0]=0;ea:{if(r[a+480192>>1]){p[114610]=0;c=J(656,a|0,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break ea}n[d+40|0]=c}p[114610]=0;Q(657,a|0,b|0,1,d+40|0);b=p[114610];p[114610]=0;if((b|0)==1){break ea}c=a+1074304|0;if(!(!q[d+40|0]|s[c>>2]>=18284544)){p[c>>2]=18284544}fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{b=p[c>>2];if(b>>>0>=18284544){p[114610]=0;b=J(2,d+72|0,17514)|0;g=p[114610];p[114610]=0;if((g|0)==1){break sa}p[114610]=0;K(1048,d+128|0,c|0);g=p[114610];p[114610]=0;if((g|0)==1){break ra}p[114610]=0;N(3,d+144|0,b|0,d+128|0);g=p[114610];p[114610]=0;if((g|0)==1){break qa}xb(l,d+144|0);pb(d+144|0);pb(d+128|0);pb(b);b=p[c>>2]}ta:{if(!b|s[c>>2]>=19005954){break ta}p[114610]=0;b=a+484344|0;c=J(442,b|0,254)|0;g=p[114610];p[114610]=0;if((g|0)==1){break ea}if(!c){c=Ob(x);p[114610]=0;K(1049,c|0,254);c=p[114610];p[114610]=0;if((c|0)==1){break ea}}p[114610]=0;b=J(442,b|0,255)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ea}if(b){break ta}b=Ob(x);p[114610]=0;c=Y(964)|0;g=p[114610];p[114610]=0;if((g|0)==1){break ea}p[114610]=0;N(1050,b|0,255,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break ea}}if(!q[d+415|0]){break fa}p[114610]=0;b=J(2,d+144|0,17852)|0;c=p[114610];p[114610]=0;if((c|0)==1){break oa}xb(a+1304436|0,b);pb(b);p[114610]=0;b=J(2,d+144|0,17873)|0;c=p[114610];p[114610]=0;if((c|0)==1){break na}xb(a+1304448|0,b);pb(b);p[114610]=0;b=J(2,d+24|0,17877)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ma}p[114610]=0;K(219,d+72|0,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break la}p[d+112>>2]=q[d+507|0];c=q[d+506|0];p[114610]=0;p[d+56>>2]=c;K(664,d+128|0,d+56|0);c=p[114610];p[114610]=0;if((c|0)==1){break ka}p[114610]=0;Q(649,d+144|0,d+72|0,d+112|0,d+128|0);c=p[114610];p[114610]=0;if((c|0)==1){break ja}xb(a+1304472|0,d+144|0);pb(d+144|0);pb(d+128|0);yb(d+72|0);pb(b);p[114610]=0;c=J(2,d+144|0,17898)|0;b=p[114610];p[114610]=0;if((b|0)==1){break ga}xb(a+1304484|0,c);break G}e=I()|0;H()|0;break i}e=I()|0;H()|0;break pa}e=I()|0;H()|0;pb(d+128|0)}pb(b);break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break ha}e=I()|0;H()|0;break ia}e=I()|0;H()|0;pb(d+128|0)}yb(d+72|0)}pb(b);break i}e=I()|0;H()|0;break i}p[114610]=0;b=J(2,d+8|0,17877)|0;c=p[114610];p[114610]=0;ua:{va:{wa:{xa:{ya:{za:{if((c|0)!=1){p[114610]=0;K(219,d+72|0,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break za}p[d+112>>2]=q[d+507|0];c=q[d+506|0];p[114610]=0;p[d+56>>2]=c;K(664,d+128|0,d+56|0);c=p[114610];p[114610]=0;if((c|0)==1){break ya}p[114610]=0;Q(649,d+144|0,d+72|0,d+112|0,d+128|0);c=p[114610];p[114610]=0;if((c|0)==1){break xa}xb(a+1304436|0,d+144|0);pb(d+144|0);pb(d+128|0);yb(d+72|0);pb(b);p[114610]=0;c=J(2,d+144|0,17898)|0;b=p[114610];p[114610]=0;if((b|0)==1){break ua}xb(a+1304448|0,c);break G}e=I()|0;H()|0;break i}e=I()|0;H()|0;break va}e=I()|0;H()|0;break wa}e=I()|0;H()|0;pb(d+128|0)}yb(d+72|0)}pb(b);break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}e=I()|0;H()|0;break i}pb(c);xb(a+1304460|0,l);p[a+1304496>>2]=p[a+1074304>>2]?7:4;ZM(m);pb(l);break b}e=I()|0;H()|0}ZM(m);break c}e=I()|0;H()|0}pb(l);L(e|0);E()}e=1}fb=d+528|0;return e|0}function EFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,O=0,Q=0;d=fb-288|0;fb=d;Ac(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!$z(b,d+280|0)){break x}if(!WP(d+280|0)){break x}if(!c){z=1;break x}C=rk(d+264|0,b);p[114610]=0;N(745,d+248|0,C|0,0);b=p[114610];p[114610]=0;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{if((b|0)!=1){p[114610]=0;N(746,d+232|0,d+248|0,20041);b=p[114610];p[114610]=0;if((b|0)==1){break N}p[114610]=0;b=M(337,d+232|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break E}if(!b){break y}p[114610]=0;b=J(747,d+232|0,d+136|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break E}if(!b){break y}p[114610]=0;K(447,a|0,16384);b=p[114610];p[114610]=0;if((b|0)==1){break E}p[a+480208>>2]=8;p[114610]=0;b=a+1074308|0;P(478,b|0,9,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break E}p[114610]=0;J(479,b|0,21)|0;e=p[114610];p[114610]=0;if((e|0)==1){break E}p[114610]=0;J(479,b|0,30)|0;b=p[114610];p[114610]=0;if((b|0)==1){break E}p[114610]=0;b=J(2,d+16|0,14652)|0;e=p[114610];p[114610]=0;if((e|0)==1){break K}xb(a+1304436|0,b);pb(b);p[114610]=0;b=J(2,d+16|0,14664)|0;e=p[114610];p[114610]=0;if((e|0)==1){break J}xb(a+1304448|0,b);pb(b);p[114610]=0;e=J(2,d+120|0,14668)|0;b=p[114610];p[114610]=0;if((b|0)==1){break I}b=q[d+284|0];switch(b+ -16|0){case 1:break H;case 0:break M;default:break L}}b=I()|0;H()|0;break a}b=I()|0;H()|0;break b}p[114610]=0;J(2,d+104|0,14683)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break F}break e}if(!b){break G}p[114610]=0;J(2,d+104|0,14698)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}break F}b=I()|0;H()|0;break c}b=I()|0;H()|0;break c}b=I()|0;H()|0;break c}p[114610]=0;J(2,d+104|0,14681)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break F}break e}p[114610]=0;J(2,d+104|0,14687)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}}p[114610]=0;N(3,d+16|0,e|0,d+104|0);b=p[114610];p[114610]=0;if((b|0)==1){break f}xb(a+1304460|0,d+16|0);pb(d+16|0);pb(d+104|0);pb(e);p[a+1304496>>2]=4;p[114610]=0;N(748,d+120|0,3,d+136|0);b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;K(415,d+16|0,d+120|0);b=p[114610];p[114610]=0;if((b|0)==1){break g}xb(a+1304400|0,d+16|0);pb(d+16|0);p[114610]=0;N(749,d+104|0,3,d+168|0);b=p[114610];p[114610]=0;if((b|0)==1){break h}p[114610]=0;K(415,d+120|0,d+104|0);b=p[114610];p[114610]=0;if((b|0)==1){break h}p[114610]=0;N(13,d+16|0,4,d+120|0);b=p[114610];p[114610]=0;if((b|0)==1){break i}xb(a+1304412|0,d+16|0);pb(d+16|0);pb(d+120|0);p[a+480200>>2]=q[d+192|0]+1;O=a,Q=sd(q[d+193|0],1,255),p[O+480196>>2]=Q;O=a,Q=v(sd(q[d+194|0],4,255),1e4),p[O+480204>>2]=Q;b=a+484360|0;e=Ob(b);f=q[d+188|0]|q[d+189|0]<<8;p[114610]=0;Z(584,e|0,d+232|0,f|0,65535,65535)|0;e=p[114610];p[114610]=0;if((e|0)==1){break E}Pe(Ob(b),q[d+190|0]|q[d+191|0]<<8);o[a+480188>>1]=0;b=0;while(1){p[114610]=0;e=(b<<5)+a|0;f=e+480280|0;S(432,f|0);g=p[114610];p[114610]=0;if((g|0)==1){break j}g=b+d|0;i=q[g+195|0]<<1&254;o[e+480284>>1]=(i|0)==254?256:i;O:{if(n[g+195|0]<=-1){p[f>>2]=p[f>>2]|1024;break O}o[a+480188>>1]=b+1}p[114610]=0;P(750,d+232|0,e+480289|0,8)|0;e=p[114610];p[114610]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}p[114610]=0;N(746,d+16|0,d+248|0,17741);b=p[114610];p[114610]=0;if((b|0)==1){break k}Nd(d+232|0,d+16|0);sb(d+16|0);p[114610]=0;b=M(255,d+232|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break E}p[114610]=0;U(587,a+1304424|0,d+232|0,b|0,0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break E}p[114610]=0;N(746,d+16|0,d+248|0,21321);b=p[114610];p[114610]=0;if((b|0)==1){break l}Nd(d+232|0,d+16|0);sb(d+16|0);p[114610]=0;b=M(337,d+232|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break E}P:{if(b){p[114610]=0;N(746,d+16|0,d+248|0,16723);b=p[114610];p[114610]=0;if((b|0)==1){break m}p[114610]=0;k=M(387,d+232|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break n}Q:{if(!k){break Q}l=c&2;while(1){p[114610]=0;e=M(387,d+232|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break n}if(!e){break Q}p[114610]=0;b=J(258,d+232|0,56)|0;f=p[114610];p[114610]=0;if((f|0)==1){break n}if(!b){break Q}if(r[a+480190>>1]<e>>>0){o[a+480190>>1]=e}p[114610]=0;b=v(e,104)+a|0;f=b+484380|0;K(386,f|0,0);g=p[114610];p[114610]=0;if((g|0)==1){break n}p[114610]=0;P(751,d+232|0,((e<<5)+a|0)+946300|0,32)|0;e=p[114610];p[114610]=0;if((e|0)==1){break n}p[114610]=0;P(552,d+232|0,b+484423|0,8)|0;e=p[114610];p[114610]=0;if((e|0)==1){break n}R:{if(q[d+284|0]<=15){p[114610]=0;e=M(357,d+232|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break R}break n}p[114610]=0;e=M(390,d+232|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break n}}p[b+484404>>2]=e<<1;p[114610]=0;e=M(390,d+232|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break n}p[f>>2]=e;p[114610]=0;g=M(390,d+232|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break n}e=b+484384|0;p[e>>2]=g;p[114610]=0;g=M(390,d+232|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break n}i=b+484388|0;p[i>>2]=g;if(g){j=b+484414|0;o[j>>1]=r[j>>1]|2;p[i>>2]=g+p[e>>2]}p[114610]=0;g=M(387,d+232|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break P}if(q[d+284|0]<=15){o[b+484410>>1]=g}p[114610]=0;g=M(387,d+232|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break n}j=8;if(g&1){j=b+484414|0;o[j>>1]=r[j>>1]|1;p[f>>2]=p[f>>2]>>>1;p[e>>2]=p[e>>2]>>>1;p[i>>2]=p[i>>2]>>>1;j=16}b=b+484414|0;o[b>>1]=r[b>>1]&65531|g<<1&4;b=Tc(d+120|0,j,1,0,((g&12)!=0)<<3);S:{if(!l){break S}p[114610]=0;P(400,b|0,f|0,d+16|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break S}break n}h=h+1|0;if((h&255)>>>0<k>>>0){continue}break}}sb(d+16|0)}p[114610]=0;N(746,d+16|0,d+248|0,18761);b=p[114610];p[114610]=0;if((b|0)==1){break q}Nd(d+232|0,d+16|0);sb(d+16|0);p[114610]=0;b=M(337,d+232|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break E}T:{U:{V:{W:{if(b){k=Zy(d+120|0);l=Zy(d+104|0);j=Zy(d+88|0);p[114610]=0;N(746,d+72|0,d+248|0,17750);b=p[114610];p[114610]=0;if((b|0)==1){break r}p[114610]=0;K(752,d+72|0,k|0);b=p[114610];p[114610]=0;if((b|0)==1){break s}sb(d+72|0);p[114610]=0;N(746,d+56|0,d+248|0,17744);b=p[114610];p[114610]=0;if((b|0)==1){break r}p[114610]=0;K(752,d+56|0,l|0);b=p[114610];p[114610]=0;if((b|0)==1){break t}sb(d+56|0);p[114610]=0;N(746,d+40|0,d+248|0,17734);b=p[114610];p[114610]=0;if((b|0)==1){break r}p[114610]=0;K(752,d+40|0,j|0);b=p[114610];p[114610]=0;if((b|0)==1){break u}sb(d+40|0);p[114610]=0;s=M(387,d+232|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break v}if(s){y=d+16|4;z=d+16|2;u=d+16|6;w=d+16|5;x=d+16|3;e=d+16|1;h=0;while(1){p[114610]=0;K(472,d|0,d+232|0);b=p[114610];p[114610]=0;if((b|0)==1){break A}m=Zc(d);X:{Y:{Z:{if(!q[d|0]){break Z}b=q[m|0];p[114610]=0;b=J(258,d+232|0,v(b,14)+32|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break p}if(!b){break Z}b=q[d|0];p[114610]=0;i=P(454,a|0,b|0,0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break p}if(i){break Y}}b=q[m|0];p[114610]=0;J(338,d+232|0,v(b,14)+32|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break X}break p}p[114610]=0;P(751,d+232|0,i+492|0,32)|0;b=p[114610];p[114610]=0;if((b|0)==1){break p}if(!q[m|0]){break X}A=i+88|0;B=i+68|0;D=i+48|0;F=i+236|0;g=0;b=0;while(1){p[114610]=0;J(753,d+232|0,d+16|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break w}_:{if(!q[d+16|0]|r[a+480190>>1]<q[d+16|0]){break _}f=e;if(q[e|0]>128){n[f|0]=128}if((b&255)>>>0<=q[e|0]){while(1){f=q[d+16|0];O=Yc(F,b&255),Q=f,o[O>>1]=Q;b=b+1|0;if((b&255)>>>0<=q[e|0]){continue}break}}b=q[e|0];f=q[x|0];p[114610]=0;N(754,D|0,f|0,k|0);f=p[114610];p[114610]=0;if((f|0)==1){break w}f=q[w|0];p[114610]=0;N(754,B|0,f|0,l|0);f=p[114610];p[114610]=0;if((f|0)==1){break w}f=q[d+29|0];p[114610]=0;N(754,A|0,f|0,j|0);f=p[114610];p[114610]=0;if((f|0)==1){break w}p[i>>2]=(q[u|0]|q[u+1|0]<<8)+1>>>1;f=q[d+16|0];$:{if(q[x|0]&64){o[(v(f,104)+a|0)+484410>>1]=q[z|0];break $}t=(v(f,104)+a|0)+484414|0;o[t>>1]=r[t>>1]|32768}t=q[y|0];p[114610]=0;o[d+38>>1]=t<<1;o[d+36>>1]=254;t=J(477,d+38|0,d+36|0)|0;G=p[114610];p[114610]=0;if((G|0)==1){break W}b=b+1|0;f=v(f,104)+a|0;o[f+484408>>1]=r[t>>1];n[f+484418|0]=q[(q[d+27|0]&3)+14699|0];n[f+484419|0]=q[d+26|0];n[f+484420|0]=q[d+25|0];n[f+484421|0]=q[d+24|0];if(!(q[w|0]&64)){break _}f=f+484414|0;o[f>>1]=r[f>>1]|32}g=g+1|0;if((g&255)>>>0<q[m|0]){continue}break}}h=h+1|0;if((h&255)>>>0<s>>>0){continue}break}}gn(j);gn(l);gn(k)}z=1;l=qp(d+120|0);if(!(c&1)){break z}p[114610]=0;N(746,d+16|0,d+248|0,21076);b=p[114610];p[114610]=0;if((b|0)!=1){b=Nd(d+232|0,d+16|0);p[114610]=0;b=M(337,b|0)|0;c=p[114610];p[114610]=0;aa:{ba:{ca:{da:{ea:{fa:{if((c|0)!=1){sb(d+16|0);ga:{if(!b){break ga}p[114610]=0;c=M(357,d+232|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break fa}p[114610]=0;K(755,l|0,c+1|0);b=p[114610];p[114610]=0;if((b|0)==1){break fa}if(!c){break ga}b=1;while(1){p[114610]=0;e=M(357,d+232|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break ea}p[114610]=0;N(341,d+16|0,d+232|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break ea}Nd(jc(l,b),d+16|0);e=(b|0)==(c|0);sb(d+16|0);b=b+1|0;if(!e){continue}break}}p[114610]=0;N(746,d+16|0,d+248|0,16720);b=p[114610];p[114610]=0;if((b|0)==1){break da}b=Nd(d+232|0,d+16|0);p[114610]=0;b=M(337,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ca}sb(d+16|0);if(!b){break aa}p[114610]=0;m=M(387,d+232|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break C}if(m){k=0;while(1){g=32;ha:{if(q[d+284|0]>=16){p[114610]=0;J(756,d+232|0,d+16|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break V}if(!(q[d+16|0]>32|r[a+480188>>1]>=q[d+16|0])){o[a+480188>>1]=q[d+16|0]}g=q[d+16|0];if(!g){break ha}}e=0;while(1){p[114610]=0;b=M(357,d+232|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break U}if(!(!b|(e&65535)>>>0<r[a+480188>>1])){o[a+480188>>1]=e+1}e=e+1|0;if(g>>>0>(e&65535)>>>0){continue}break}}k=k+1|0;if((k&65535)>>>0<m>>>0){continue}break}}p[114610]=0;J(256,d+232|0,1)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break ba}break C}b=I()|0;H()|0;sb(d+16|0);break B}b=I()|0;H()|0;break B}b=I()|0;H()|0;break B}b=I()|0;H()|0;break B}b=I()|0;H()|0;sb(d+16|0);break B}p[114610]=0;s=a+484344|0;K(401,s|0,m|0);b=p[114610];p[114610]=0;if((b|0)==1){break C}if(!m){break aa}D=d+16|2;F=d+16|1;c=0;while(1){u=Lb(d+104|0);k=64;w=32;if(q[d+284|0]>=16){p[114610]=0;J(756,d+232|0,d+16|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break D}w=q[d+16|0];b=q[F|0];p[114610]=0;N(757,d|0,3,D|0);e=p[114610];p[114610]=0;if((e|0)==1){break D}p[114610]=0;K(415,d+88|0,d|0);e=p[114610];p[114610]=0;if((e|0)==1){break D}xb(u,d+88|0);pb(d+88|0);k=b+1|0}p[114610]=0;b=P(402,s|0,c&65535,k|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break D}ia:{if(!b){p[114610]=0;J(338,d+232|0,w<<1)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break ia}break D}b=Rb(s,c);p[114610]=0;J(496,b|0,u|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break D}x=0;if(!w){break ia}while(1){p[114610]=0;b=M(357,d+232|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break D}ja:{if(!b){break ja}if(gd(l)>>>0<=b>>>0){break ja}y=x&65535;if(y>>>0>=r[a+480188>>1]){break ja}i=jc(l,b);Ac(i);f=0;while(1){p[114610]=0;b=J(258,i|0,1)|0;e=p[114610];p[114610]=0;ka:{la:{ma:{na:{oa:{pa:{if((e|0)!=1){if(!b){break ja}b=Rb(s,c);p[114610]=0;b=P(471,b|0,f|0,y|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break D}p[114610]=0;g=M(387,i|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break D}e=g>>>2|0;switch((g&3)-1|0){case 2:break ma;case 1:break na;case 0:break oa;default:break pa}}break D}f=(e+f|0)+1|0;break ka}if(!f){f=0;break ka}g=Rb(s,c);p[114610]=0;g=P(471,g|0,f+ -1|0,y|0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){while(1){h=q[g|0]|q[g+1|0]<<8|(q[g+2|0]<<16|q[g+3|0]<<24);n[b|0]=h;n[b+1|0]=h>>>8;n[b+2|0]=h>>>16;n[b+3|0]=h>>>24;h=q[g+4|0]|q[g+5|0]<<8;n[b+4|0]=h;n[b+5|0]=h>>>8;f=f+1|0;if(f>>>0>=k>>>0){break ka}b=v(r[a+480188>>1],6)+b|0;h=e&255;e=e+ -1|0;if(h){continue}break ka}}break D}if(f>>>0<=e>>>0){break la}g=Rb(s,c);p[114610]=0;e=P(471,g|0,e|0,y|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break T}g=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);n[b|0]=g;n[b+1|0]=g>>>8;n[b+2|0]=g>>>16;n[b+3|0]=g>>>24;e=q[e+4|0]|q[e+5|0]<<8;n[b+4|0]=e;n[b+5|0]=e>>>8;break la}if(e&1){p[114610]=0;g=M(387,i|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break T}n[b|0]=g>>>0>120?-1:g}if(e&2){p[114610]=0;g=M(387,i|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break T}n[b+1|0]=g}j=0;g=0;if(e&4){p[114610]=0;g=M(387,i|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break D}}A=0;if(e&8){p[114610]=0;h=M(387,i|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break D}A=h>>>4|0;j=h&15}B=0;h=0;if(e&16){p[114610]=0;h=M(387,i|0)|0;t=p[114610];p[114610]=0;if((t|0)==1){break D}}if(e&32){p[114610]=0;B=M(387,i|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break D}}p[114610]=0;fa(758,b|0,g|0,j|0,A|0,h|0,B|0);b=p[114610];p[114610]=0;if((b|0)==1){break D}}f=f+1|0}if(f>>>0<k>>>0){continue}break}}x=x+1|0;if((x&65535)>>>0<w>>>0){continue}break}}pb(u);c=c+1|0;if((m|0)!=(c|0)){continue}break}}p[114610]=0;N(746,d+16|0,d+248|0,20048);b=p[114610];p[114610]=0;qa:{ra:{sa:{if((b|0)!=1){b=Nd(d+232|0,d+16|0);p[114610]=0;b=M(337,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break sa}sb(d+16|0);if(!b){break z}a=a+484344|0;if(!ke(a)){break z}while(1){p[114610]=0;b=J(258,d+232|0,16)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ra}if(!b){break z}p[114610]=0;P(759,d+232|0,d+16|0,16)|0;b=p[114610];p[114610]=0;if((b|0)==1){break qa}b=Rb(a,0);p[114610]=0;J(760,b|0,d+16|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break qa}if(ke(a)){continue}break}break z}b=I()|0;H()|0;break B}b=I()|0;H()|0;sb(d+16|0);break B}b=I()|0;H()|0;break B}b=I()|0;H()|0;break B}b=I()|0;H()|0;break B}b=I()|0;H()|0;break o}b=I()|0;H()|0;break B}b=I()|0;H()|0;break B}break D}break n}b=I()|0;H()|0;break c}b=I()|0;H()|0;pb(u);break B}b=I()|0;H()|0}$c(l);break c}b=I()|0;H()|0;break o}$c(l)}sb(d+232|0);Yy(d+248|0);sb(C)}fb=d+288|0;return z|0}b=I()|0;H()|0;break o}b=I()|0;H()|0;break o}b=I()|0;H()|0;sb(d+40|0);break o}b=I()|0;H()|0;sb(d+56|0);break o}b=I()|0;H()|0;sb(d+72|0);break o}b=I()|0;H()|0;break o}b=I()|0;H()|0;break c}b=I()|0;H()|0}gn(j);gn(l);gn(k);break c}b=I()|0;H()|0;sb(d+16|0);break c}b=I()|0;H()|0;break c}b=I()|0;H()|0;break c}b=I()|0;H()|0;break c}b=I()|0;H()|0;break c}b=I()|0;H()|0;pb(d+120|0);break c}b=I()|0;H()|0;break c}b=I()|0;H()|0;break c}b=I()|0;H()|0;pb(d+104|0);break d}b=I()|0;H()|0}pb(e)}sb(d+232|0)}Yy(d+248|0)}sb(C);L(b|0);E()}function tF(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;L=fb-144|0;fb=L;a:{b:{c:{if(e>>>0>=d>>>0){j=p[f>>2];N=g&4;M=N?-1:j+((d^-1)+e|0)|0;F=M+1|0;if(!(F&M)){break c}}p[f>>2]=0;p[c>>2]=0;k=-3;break b}G=e+j|0;D=p[c>>2];A=D+b|0;H=p[a+60>>2];y=p[a+40>>2];j=p[a+36>>2];B=p[a+32>>2];m=p[a+56>>2];i=p[a+4>>2];l=b;w=e;z=-1;k=-1;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{x=p[a>>2];switch(x|0){case 35:break i;case 17:break j;case 21:break k;case 37:break l;case 34:break m;case 42:break q;case 41:break r;case 53:break s;case 52:break t;case 51:break u;case 38:break v;case 27:break w;case 26:break x;case 25:break y;case 24:break z;case 23:break A;case 18:break B;case 16:break C;case 14:break D;case 11:break E;case 9:break F;case 7:break G;case 6:break H;case 3:break I;case 32:break J;case 5:break K;case 2:break M;case 1:break N;case 0:break O;case 36:break f;case 39:break g;case 10:break h;default:break d}}p[a+28>>2]=1;m=0;p[a+8>>2]=0;p[a+12>>2]=0;p[a+16>>2]=1;y=0;j=0;B=0;i=0;if(g&1){break N}break L}if((D|0)<=0){p[a>>2]=1;break e}p[a+8>>2]=q[b|0];l=b+1|0}if(l>>>0>=A>>>0){p[a>>2]=2;k=g&2?1:-4;break d}j=q[l|0];p[a+12>>2]=j;h=p[a+8>>2];k=(((j|h<<8)>>>0)%31|j&32)!=0|(h&15)!=8;j=1;l=l+1|0;if(!N){x=36;h=256<<(h>>>4);if(!(k|(h>>>0>32768|F>>>0<h>>>0))){break L}break f}x=36;if(k){break f}}h=0;break p}if((D|0)<=0){p[a>>2]=5;break e}l=b+1|0;m=q[b|0]<<i|m;i=i+8|0;h=2;break p}if((D|0)<=0){p[a>>2]=32;break e}l=b+1|0;m=q[b|0]<<i|m;C=j;i=i+8|0;break o}h=1;break p}h=3;break p}h=4;break p}h=5;break p}h=9;break p}h=10;break p}h=11;break p}h=12;break p}h=13;break p}h=14;break p}h=15;break p}h=16;break p}h=17;break p}h=8;break p}h=6;break p}h=7;break p}h=18;break p}t=2;break n}t=1;break n}P:while(1){Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{switch(h|0){case 0:j=C;if(i>>>0>2){break Ca}h=1;continue;case 17:break la;case 16:break ma;case 15:break na;case 14:break oa;case 13:break pa;case 12:break qa;case 11:break ra;case 10:break sa;case 9:break ta;case 8:break va;case 7:break wa;case 6:break xa;case 5:break ya;case 4:break za;case 3:break Aa;case 2:break Ba;case 1:break Da;default:break ka}}while(1){if(l>>>0>=A>>>0){p[a>>2]=3;k=g&2?1:-4;break d}m=q[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<3){continue}break}l=h;C=j}j=m&7;p[a+20>>2]=j;h=j>>>1|0;p[a+24>>2]=h;i=i+ -3|0;m=m>>>3|0;k=0;j=C;switch(h|0){case 0:break ja;case 1:break ua;case 3:break h;default:break ga}}h=i&-8;m=m>>>(i&7)|0;j=0;i=0;break ha}while(1){if(l>>>0>=A>>>0){p[a>>2]=6;k=g&2?1:-4;break d}m=q[l|0]<<i|m;u=i>>>0>4294967287;k=l+1|0;l=k;h=i+8|0;i=h;if(u){continue}break}l=k;i=1;break ha}if(l>>>0>=A>>>0){p[a>>2]=7;k=g&2?1:-4;break d}n[(a+j|0)+10528|0]=q[l|0];l=l+1|0;h=i;i=2;break ha}if(w>>>0<G>>>0){break ia}z=2;x=9;break f}while(1){if(l>>>0>=A>>>0){p[a>>2]=51;k=g&2?1:-4;break d}m=q[l|0]<<i|m;u=i>>>0>4294967287;k=l+1|0;l=k;h=i+8|0;i=h;if(u){continue}break}l=k;break R}if(w>>>0<G>>>0){n[w|0]=B;j=j+ -1|0;w=w+1|0;h=i;break U}z=2;x=52;break f}if(l>>>0>=A>>>0){p[a>>2]=38;k=g&2?1:-4;break d}h=G-w|0;k=A-l|0;h=h>>>0<k>>>0?h:k;h=h>>>0<j>>>0?h:j;j=j-h|0;w=ac(w,l,h)+h|0;l=h+l|0;break T}p[a+44>>2]=288;p[a+48>>2]=32;h=a+3552|0;p[h>>2]=84215045;p[h+4>>2]=84215045;h=a+3560|0;p[h>>2]=84215045;p[h+4>>2]=84215045;h=a+3568|0;p[h>>2]=84215045;p[h+4>>2]=84215045;h=a+3576|0;p[h>>2]=84215045;p[h+4>>2]=84215045;h=a- -64|0;Jb(h,8,144);while(1){h=h+1|0;k=k+1|0;if((k|0)!=144){continue}break}Jb(h,9,112);k=144;while(1){h=h+1|0;k=k+1|0;if((k|0)!=256){continue}break}n[h|0]=117901063;n[h+1|0]=460551;n[h+2|0]=1799;n[h+3|0]=7;n[h+4|0]=117901063;n[h+5|0]=460551;n[h+6|0]=1799;n[h+7|0]=7;n[h+16|0]=117901063;n[h+17|0]=460551;n[h+18|0]=1799;n[h+19|0]=7;n[h+20|0]=117901063;n[h+21|0]=460551;n[h+22|0]=1799;n[h+23|0]=7;n[h+8|0]=117901063;n[h+9|0]=460551;n[h+10|0]=1799;n[h+11|0]=7;n[h+12|0]=117901063;n[h+13|0]=460551;n[h+14|0]=1799;n[h+15|0]=7;k=256;while(1){h=h+1|0;k=k+1|0;if((k|0)!=280){continue}break}n[h|0]=134744072;n[h+1|0]=526344;n[h+2|0]=2056;n[h+3|0]=8;n[h+4|0]=134744072;n[h+5|0]=526344;n[h+6|0]=2056;n[h+7|0]=8;break Y}while(1){if(l>>>0>=A>>>0){p[a>>2]=11;k=g&2?1:-4;break d}m=q[l|0]<<i|m;k=l+1|0;l=k;h=i+8|0;i=h;I=n[j+42316|0];if(h>>>0<I>>>0){continue}break}l=k;k=j;i=h;j=1;break _}while(1){if(l>>>0>=A>>>0){p[a>>2]=14;k=g&2?1:-4;break d}m=q[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<3){continue}break}l=h;h=1;break Z}if(l>>>0>=A>>>0){p[a>>2]=16;k=g&2?1:-4;break d}m=q[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break fa}break ea}while(1){if(l>>>0>=A>>>0){p[a>>2]=18;k=g&2?1:-4;break d}m=q[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<y>>>0){continue}break}O=B+ -16|0;l=h;h=3;break X}if(l>>>0>=A>>>0){p[a>>2]=23;k=g&2?1:-4;break d}m=q[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break da}break ca}if(w>>>0>=G>>>0){z=2;x=24;break f}n[w|0]=j;w=w+1|0;t=m;break W}while(1){if(l>>>0>=A>>>0){p[a>>2]=25;k=g&2?1:-4;break d}m=q[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<y>>>0){continue}break}l=h;h=3;break V}if(l>>>0>=A>>>0){p[a>>2]=26;k=g&2?1:-4;break d}m=q[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ba}break aa}while(1){if(l>>>0>=A>>>0){p[a>>2]=27;k=g&2?1:-4;break d}m=q[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<y>>>0){continue}break}l=h;h=6;break V}if(w>>>0>=G>>>0){z=2;x=53;break f}n[w|0]=q[(H-B&M)+d|0];w=w+1|0;H=H+1|0;break $}h=2;continue}h=8;continue}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{switch(i|0){case 0:if(j>>>0>3){break Ia}i=0;if(!h){break Ha}i=h;if(h>>>0>7){break Fa}h=3;continue P;case 1:n[(a+j|0)+10528|0]=m;h=h+ -8|0;m=m>>>8|0;break Ea;default:break Ja}}j=j+1|0;break Ga}i=h;j=r[a+10528>>1];if((j|0)==(r[a+10530>>1]^65535)){break U}break g}h=4;continue P}i=0;continue}i=1;continue}i=2;continue}}j=0;break _}h=1;break X}h=2;break X}h=0;break V}h=1;break V}h=4;break V}h=5;break V}h=7;break V}while(1){Ka:{La:{Ma:{if(!j){if(k>>>0>2){break Ma}j=k;I=n[j+42316|0];if(i>>>0>=I>>>0){break Ka}h=9;continue P}j=k<<2;p[(j+a|0)+44>>2]=p[j+42304>>2]+((-1<<(I&255)^-1)&m);k=k+1|0;i=i-I|0;m=m>>>I|0;break La}j=0;Jb(a+7040|0,0,288);h=0;break Z}j=0;continue}j=1;continue}}while(1){Na:{Oa:{Pa:{if(!h){if(j>>>0>=s[a+52>>2]){break Pa}if(i>>>0>2){break Na}h=10;continue P}n[(q[j+42368|0]+a|0)+7040|0]=m&7;j=j+1|0;i=i+ -3|0;m=m>>>3|0;break Oa}p[a+52>>2]=19;C=j;break Y}h=0;continue}h=1;continue}}J=p[a+24>>2];h=0}while(1){Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(h|0){case 0:j=0;if((J|0)<0){t=m;j=C;break W}D=Jb(L,0,64);k=v(J,3488)+a|0;Jb(k+352|0,0,3200);x=p[a+24>>2];h=p[((x<<2)+a|0)+44>>2];if(h){while(1){u=D+(q[(j+k|0)- -64|0]<<2)|0;p[u>>2]=p[u>>2]+1;j=j+1|0;if((h|0)!=(j|0)){continue}break}}p[D+64>>2]=0;p[D+68>>2]=0;u=0;k=0;j=1;while(1){z=j<<2;j=j+1|0;z=p[z+D>>2];u=z+u<<1;p[(D- -64|0)+(j<<2)>>2]=u;k=k+z|0;if((j|0)!=16){continue}break}if(!((u|0)==65536|k>>>0<2)){j=C;break i}if(h){h=-1;F=0;K=v(J,3488)+a|0;while(1){x=q[(F+K|0)- -64|0];Za:{if(!x){break Za}k=(D- -64|0)+(x<<2)|0;j=p[k>>2];p[k>>2]=j+1;k=0;u=x;while(1){z=k;k=j&1|k<<1;j=j>>>1|0;u=u+ -1|0;if(u){continue}break}if(x>>>0<=10){if(k>>>0>1023){break Za}j=x<<9|F;u=1<<x;while(1){o[((k<<1)+K|0)+352>>1]=j;k=k+u|0;if(k>>>0<1024){continue}break}break Za}k=((k&1023)<<1)+K|0;j=o[k+352>>1];_a:{if(j){k=h;h=j;break _a}o[k+352>>1]=h;k=h+ -2|0}j=z>>>8&8388607;if(x>>>0>=12){while(1){j=j>>>1|0;u=(((j&1)+(h^-1)<<1)+K|0)+2400|0;h=o[u>>1];if(!h){o[u>>1]=k;h=k;k=h+ -2|0}x=x+ -1|0;if(x>>>0>11){continue}break}}o[(((j>>>1&1)+(h^-1)<<1)+K|0)+2400>>1]=F;h=k}F=F+1|0;x=p[a+24>>2];if(F>>>0<s[((x<<2)+a|0)+44>>2]){continue}break}}j=0;if((x|0)!=2){break Ra}break Va;case 1:h=o[(((m&1023)<<1)+a|0)+7328>>1];$a:{if((h|0)>=0){if((h>>9)+ -1>>>0>=i>>>0){break $a}break Ua}if(i>>>0<11){break $a}k=10;while(1){h=o[(((m>>>k&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<=-1){u=k+2|0;k=k+1|0;if(i>>>0>=u>>>0){continue}}break}if((h|0)>-1){break Ua}}h=11;continue P;case 2:k=o[(((m&1023)<<1)+a|0)+7328>>1];if((k|0)>=0){break Xa}h=10;while(1){u=m>>>h|0;h=h+1|0;k=o[(((u&1)+(k^-1)<<1)+a|0)+9376>>1];if((k|0)<0){continue}break}break Wa;default:break Ya}}h=n[O+42324|0]+((-1<<y^-1)&m)|0;i=i-y|0;m=m>>>y|0;k=a+j|0;Jb(k+10532|0,(B|0)==16?q[k+10531|0]:0,h);j=h+j|0;break Va}h=k>>9;k=k&511}i=i-h|0;m=m>>>h|0;B=k;if(k>>>0>15){break Ta}n[(a+j|0)+10532|0]=B;j=j+1|0}k=p[a+48>>2];h=p[a+44>>2];u=k+h|0;if(j>>>0>=u>>>0){break Sa}if(i>>>0>14){break Ua}if((A-l|0)<=1){h=1;continue}m=q[l|0]<<i|m|q[l+1|0]<<i+8;i=i+16|0;l=l+2|0}h=2;continue}if(!((B|0)!=16|j)){B=16;j=0;break j}O=B+ -16|0;y=n[O+42320|0];if(i>>>0>=y>>>0){break Qa}h=12;continue P}if((j|0)!=(u|0)){break k}C=a+10532|0;ac(a- -64|0,C,h);ac(a+3552|0,h+C|0,k);x=p[a+24>>2];C=j}J=x+ -1|0;p[a+24>>2]=J;h=0;continue}h=3;continue}}h=2}ab:while(1){bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{switch(h|0){case 0:h=o[(((m&1023)<<1)+a|0)+352>>1];qb:{if((h|0)>=0){if((h>>9)+ -1>>>0>=i>>>0){break qb}break bb}if(i>>>0<11){break qb}k=10;while(1){h=o[(((m>>>k&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<=-1){u=k+2|0;k=k+1|0;if(i>>>0>=u>>>0){continue}}break}if((h|0)>-1){break bb}}h=13;continue P;case 1:k=o[(((m&1023)<<1)+a|0)+352>>1];if((k|0)>=0){break ob}h=10;while(1){j=m>>>h|0;h=h+1|0;k=o[(((j&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break}j=k;break nb;case 3:break eb;case 4:break fb;case 5:break jb;case 6:break kb;case 2:break pb;default:break lb}}while(1){h=A-l|0;if(!((G-w|0)>1?(h|0)>=4:0)){if(i>>>0>14){m=t;break bb}if((h|0)<=1){m=t;h=0;continue ab}m=q[l|0]<<i|t|q[l+1|0]<<i+8;i=i+16|0;l=l+2|0;break bb}rb:{if(i>>>0>14){m=i;h=l;break rb}m=i+16|0;t=(q[l|0]|q[l+1|0]<<8)<<i|t;h=l+2|0}j=o[(((t&1023)<<1)+a|0)+352>>1];sb:{if((j|0)<0){l=10;while(1){i=t>>>l|0;l=l+1|0;j=o[(((i&1)+(j^-1)<<1)+a|0)+2400>>1];if((j|0)<0){continue}break}break sb}l=j>>9}i=m-l|0;m=t>>>l|0;if(j&256){l=h;break mb}if(i>>>0>14){k=i}else{m=(q[h|0]|q[h+1|0]<<8)<<i|m;h=h+2|0;k=i+16|0}l=h;h=o[(((m&1023)<<1)+a|0)+352>>1];tb:{if((h|0)<0){t=10;while(1){i=m>>>t|0;t=t+1|0;h=o[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break tb}t=h>>9}n[w|0]=j;i=k-t|0;t=m>>>t|0;if(!(h&256)){n[w+1|0]=h;w=w+2|0;continue}break}w=w+1|0;m=t;j=h;break mb}h=k>>9;j=k&511}i=i-h|0;m=m>>>h|0;if(j>>>0>255){break mb}h=14;continue P}C=256;k=j&511;if((k|0)==256){break Q}y=0;h=m;u=(k<<2)+ -1028|0;j=p[u+41792>>2];z=j;if(k+ -265>>>0>19){break db}y=p[u+41920>>2];if(i>>>0<y>>>0){h=15;continue P}h=3;continue}if(!j){t=m;j=-1;break hb}j=j+ -1|0;h=18;continue P}i=i-y|0;t=m>>>y|0;B=((-1<<y^-1)&m)+B|0;break ib}y=o[(((m&1023)<<1)+a|0)+3840>>1];ub:{if((y|0)<0){h=10;while(1){k=m>>>h|0;h=h+1|0;y=o[(((k&1)+(y^-1)<<1)+a|0)+5888>>1];if((y|0)<0){continue}break}k=y;break ub}h=y>>9;k=y&511}u=k<<2;B=p[u+42048>>2];i=i-h|0;m=m>>>h|0;y=0;if(k+ -4>>>0>25){t=m;break ib}y=p[u+42176>>2];if(i>>>0>=y>>>0){break gb}h=17;continue P}H=w-d|0;if(!(!N|H>>>0>=B>>>0)){m=t;break l}h=(H-B&M)+d|0;if((w>>>0>h>>>0?w:h)+j>>>0>G>>>0){m=t;h=7;continue}if(j>>>0>2){while(1){n[w|0]=q[h|0];n[w+1|0]=q[h+1|0];n[w+2|0]=q[h+2|0];h=h+3|0;w=w+3|0;j=j+ -3|0;if(j>>>0>2){continue}break}}if(!j){break hb}n[w|0]=q[h|0];if((j|0)!=1){n[w+1|0]=q[h+1|0]}w=j+w|0}h=2;continue}h=6;continue}h=o[(((m&1023)<<1)+a|0)+3840>>1];vb:{if((h|0)>=0){if((h>>9)+ -1>>>0>=i>>>0){break vb}break cb}if(i>>>0<11){break vb}k=10;while(1){h=o[(((m>>>k&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<=-1){u=k+2|0;k=k+1|0;if(i>>>0>=u>>>0){continue}}break}if((h|0)>-1){break cb}}h=16;continue P}i=i-y|0;h=m>>>y|0;z=((-1<<y^-1)&m)+j|0}j=z;m=h;if(i>>>0>14){break cb}if((A-l|0)<=1){h=4;continue}m=m|q[l|0]<<i|q[l+1|0]<<i+8;i=i+16|0;l=l+2|0}h=5;continue}h=1;continue}}if(h?j:0){break S}i=h}C=0;if(!j){break Q}h=5;continue}i=h;if(h>>>0>7){break R}h=6;continue}i=h+ -8|0;B=m&255;m=m>>>8|0;h=7;continue}if(n[a+20|0]&1){break o}h=0;continue}}t=i&-8;if(!(!t|l>>>0<=b>>>0)){j=t+ -8|0;d=j>>>3|0;h=(b^-1)+l|0;d=d>>>0<h>>>0?d:h;t=j-(d<<3)|0;l=(d^-1)+l|0}if(!t){m=((32<=(t&63)>>>0?0:-1<<(t&31))^-1)&m>>>(i&7);u=0;h=0;j=C;i=0;if(!(g&1)){break m}t=0;break n}aa(42328,41760,2787,42338);E()}while(1){wb:{xb:{yb:{zb:{Ab:{Bb:{switch(t|0){case 0:if(u>>>0>3){j=u;i=h;break m}i=0;if(h){break Ab}j=u;t=1;continue;case 1:break Bb;default:break zb}}if(l>>>0<A>>>0){break xb}p[a>>2]=42;k=g&2?1:-4;break d}j=u;i=h;if(h>>>0>7){break yb}t=2;continue}while(1){if(l>>>0>=A>>>0){p[a>>2]=41;k=g&2?1:-4;break d}m=q[l|0]<<i|m;t=i>>>0>4294967287;d=l+1|0;l=d;h=i+8|0;i=h;if(t){continue}break}l=d;u=j}t=m&255;m=m>>>8|0;h=h+ -8|0;break wb}t=q[l|0];l=l+1|0;u=j;h=i}p[a+16>>2]=p[a+16>>2]<<8|t;u=u+1|0;t=0;continue}}z=0;x=34;break f}x=37;z=-1;break f}x=21;z=-1;break f}x=17;z=-1;break f}x=35;z=-1;break f}x=10;z=-1;break f}x=39;z=-1}p[a>>2]=x;if(!(i>>>0<8|l>>>0<=b>>>0)){h=i+ -8|0;d=h>>>3|0;i=(b^-1)+l|0;d=d>>>0<i>>>0?d:i;l=(d^-1)+l|0;i=h-(d<<3)|0}k=z;break d}k=g&2?1:-4}p[a+4>>2]=i;p[a+60>>2]=H;p[a+40>>2]=y;p[a+36>>2]=j;p[a+32>>2]=B;p[a+56>>2]=((32<=(i&63)>>>0?0:-1<<(i&31))^-1)&m;p[c>>2]=l-b;h=w-e|0;p[f>>2]=h;if(!(g&9)|(k|0)<0){break b}b=p[a+28>>2];i=b>>>16|0;m=b&65535;if(h){j=(h>>>0)%5552|0;while(1){l=0;if(j>>>0>7){while(1){b=q[e|0]+m|0;c=b+q[e+1|0]|0;d=c+q[e+2|0]|0;f=d+q[e+3|0]|0;t=f+q[e+4|0]|0;C=t+q[e+5|0]|0;u=C+q[e+6|0]|0;m=u+q[e+7|0]|0;i=m+(u+(C+(t+(f+(d+(c+(b+i|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;l=l+8|0;if((l|7)>>>0<j>>>0){continue}break}l=j&8184}if(j>>>0>l>>>0){b=j-l|0;t=e;while(1){m=q[t|0]+m|0;i=m+i|0;t=t+1|0;l=l+1|0;if((l|0)!=(j|0)){continue}break}e=b+e|0}h=h-j|0;i=(i>>>0)%65521|0;m=(m>>>0)%65521|0;j=5552;if(h){continue}break}}b=i<<16|m;p[a+28>>2]=b;if(k){break b}k=0;if(g&1){break a}}fb=L+144|0;return k}fb=L+144|0;return p[a+16>>2]==(b|0)?0:-2}function Tya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,O=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=fb-416|0;fb=f;Ac(b);m=f+208|0;e=uya(b,m);if(!e){kN(m)}a:{if(!e){break a}if(!pN(f+208|0)){break a}if(!c){d=1;break a}xd(a,134217728);d=Mb(f+192|0,17296);p[114610]=0;K(219,f+144|0,d|0);m=p[114610];p[114610]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((m|0)!=1){p[114610]=0;u=f+208|4;N(1005,f+16|0,f+144|0,u|0);m=p[114610];p[114610]=0;if((m|0)==1){break q}xb(a+1304436|0,f+16|0);pb(f+16|0);yb(f+144|0);pb(d);d=Mb(f+16|0,17320);xb(a+1304448|0,d);pb(d);p[a+480188>>2]=4;p[a+1304496>>2]=2;d=q[f+344|0]|q[f+345|0]<<8;p[a+480196>>2]=(d<<24|d<<8&16711680)>>>16;d=q[f+348|0]|q[f+349|0]<<8;p[a+480260>>2]=56;p[a+480264>>2]=13696;X=a,Y=oN((d<<8&16711680|d<<24)>>>16|0),p[X+480204>>2]=Y;qn(Ob(a+484360|0),f+216|0,q[f+208|6],65535,65535);y=a+480190|0;w=f+176|0;Gya(w);x=wn(f+160|0);if(q[f+408|0]|q[f+409|0]<<8){break o}break n}a=I()|0;H()|0;break p}a=I()|0;H()|0;yb(f+144|0)}pb(d);break c}m=0;while(1){p[114610]=0;d=M(484,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break g}o[f+120>>1]=d;if((d+ -1&65535)>>>0>3998){break l}d=q[f+410|0]|q[f+411|0]<<8;d=(d<<8&16711680|d<<24)>>>16|0;r:{if((q[u|0]|q[u+1|0]<<8)!=512){break r}p[114610]=0;d=M(494,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break h}d=d+ -2|0}p[114610]=0;N(341,f+144|0,b|0,d|0);d=p[114610];p[114610]=0;s:{t:{u:{if((d|0)!=1){p[114610]=0;d=J(452,y|0,f+120|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break u}B=r[d>>1];o[a+480190>>1]=B;p[114610]=0;d=v(r[f+120>>1],104)+a|0;t=d+484380|0;K(386,t|0,1);e=p[114610];p[114610]=0;v:{if((e|0)==1){break v}e=q[u|0]|q[u+1|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>1){break t}p[114610]=0;P(1006,f+144|0,d+484423|0,31)|0;e=p[114610];p[114610]=0;if((e|0)==1){break v}p[114610]=0;J(338,f+144|0,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break v}p[114610]=0;P(388,f+144|0,((r[f+120>>1]<<5)+a|0)+946300|0,30)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break s}}a=I()|0;H()|0;break e}a=I()|0;H()|0;break d}a=I()|0;H()|0;break e}e=Lb(f+16|0);p[114610]=0;P(600,f+144|0,e|0,257)|0;j=p[114610];p[114610]=0;w:{x:{if((j|0)==1){break x}p[114610]=0;J(370,d+484423|0,e|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break x}p[114610]=0;J(338,f+144|0,1)|0;j=p[114610];p[114610]=0;if((j|0)==1){break x}p[114610]=0;P(600,f+144|0,e|0,31)|0;j=p[114610];p[114610]=0;if((j|0)==1){break x}p[114610]=0;J(369,((r[f+120>>1]<<5)+a|0)+946300|0,e|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break x}if(!(p[f+152>>2]&1)){break w}p[114610]=0;J(338,f+144|0,1)|0;j=p[114610];p[114610]=0;if((j|0)!=1){break w}}a=I()|0;H()|0;pb(e);break e}pb(e)}p[114610]=0;J(1007,f+144|0,f+16|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}p[114610]=0;K(1008,f+16|0,t|0);e=p[114610];p[114610]=0;if((e|0)==1){break k}if((q[u|0]|q[u+1|0]<<8)==512){n[d+484417|0]=q[f+34|0]<<3}y:{if(!(q[u|0]|q[u+1|0]<<8)){break y}p[114610]=0;K(384,x|0,B|0);e=p[114610];p[114610]=0;if((e|0)==1){break k}p[114610]=0;K(1009,w|0,B|0);e=p[114610];p[114610]=0;if((e|0)==1){break k}e=id(w,r[f+120>>1]+ -1|0);nc(e);mN(e);zs(e);p[114610]=0;t=M(484,b|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break i}p[114610]=0;K(1010,e|0,t|0);j=p[114610];p[114610]=0;if((j|0)==1){break i}g=0;p[f+136>>2]=0;if(!t){if(!(q[d+484414|0]&2)){break y}t=p[d+484384>>2];p[f+128>>2]=t;d=p[d+484388>>2];p[114610]=0;p[f+132>>2]=d-t;K(1011,e|0,f+128|0);d=p[114610];p[114610]=0;if((d|0)!=1){break y}a=I()|0;H()|0;break e}while(1){p[114610]=0;d=M(494,b|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break m}p[114610]=0;p[f+128>>2]=d;d=M(494,b|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break m}p[114610]=0;p[f+132>>2]=d;K(1011,e|0,f+128|0);d=p[114610];p[114610]=0;if((d|0)==1){break m}g=g+1|0;if((g&65535)>>>0<t>>>0){continue}break}}sb(f+144|0);m=m+1|0;d=q[f+408|0]|q[f+409|0]<<8;if((m&65535)>>>0<(d<<24|d<<8&16711680)>>>16>>>0){continue}break}}C=128;if(q[u|0]|q[u+1|0]<<8){break j}p[114610]=0;C=M(484,b|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break j}a=I()|0;H()|0;break d}a=I()|0;H()|0;break e}d=0;break b}a=I()|0;H()|0;break e}m=a+480188|0;D=q[f+208|7];o[f+126>>1]=4;z:{A:{B:{if(!(q[u|0]|q[u+1|0]<<8)){g=r[m>>1];break B}e=p[b+8>>2];C:{if(!C){break C}d=0;while(1){p[114610]=0;t=M(484,b|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break A}if((t|0)==65535){break C}p[114610]=0;D=M(484,b|0)|0;t=p[114610];p[114610]=0;if((t|0)==1){break A}p[114610]=0;t=M(484,b|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break A}p[114610]=0;o[f+126>>1]=t;t=J(452,m|0,f+126|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break A}o[m>>1]=r[t>>1];p[114610]=0;J(338,b|0,v(r[f+126>>1],D)<<2)|0;t=p[114610];p[114610]=0;if((t|0)==1){break A}d=d+1|0;if((d&65535)>>>0<C>>>0){continue}break}}d=0;p[114610]=0;J(256,b|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break z}g=r[m>>1];if(g>>>0>127){break b}}p[114610]=0;O=J(1012,f+144|0,g&65535)|0;d=p[114610];p[114610]=0;if((d|0)!=1){D:{if(!C){break D}T=a+484344|0;W=c&1;Q=q[f+347|0];m=0;t=0;while(1){d=t;if(q[u|0]|q[u+1|0]<<8){p[114610]=0;d=M(484,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break f}if((d|0)==65535){break D}p[114610]=0;D=M(484,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break f}p[114610]=0;e=M(484,b|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break f}o[f+126>>1]=e}F=D&65535;E:{F:{if(!W){break F}p[114610]=0;U=d&65535;d=P(402,T|0,U|0,F|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break f}if(!d){break F}if(!F){break E}z=0;while(1){d=Rb(T,U);p[114610]=0;k=J(497,d|0,z|0)|0;d=p[114610];p[114610]=0;G:{if((d|0)!=1){g=0;A=0;H:{I:{switch((Q&3)+ -1|0){case 0:A=!(z&3);break H;case 1:A=!(z&1);break H;case 2:break I;default:break H}}A=(z&3)!=3}R=0;if(!r[f+126>>1]){break G}while(1){d=p[O>>2];p[114610]=0;K(598,f+128|0,b|0);e=p[114610];p[114610]=0;if((e|0)==1){break f}i=v(g,9)+d|0;d=Zc(f+128|0);j=Tf(f+128|0);h=vi(f+128|0);l=v(g,6)+k|0;n[l+1|0]=q[f+128|0];e=q[d|0];n[l|0]=e;d=q[h|0];n[l+5|0]=d;h=l+5|0;if(e){n[l|0]=e+25;n[i+8|0]=0;n[i|0]=0;n[i+1|0]=0;n[i+2|0]=0;n[i+3|0]=0;n[i+4|0]=0;n[i+5|0]=0;n[i+6|0]=0;n[i+7|0]=0;d=q[h|0]}e=d;S=q[j|0];J:{if(S>>>0>=240){d=e|(S&15)<<8;if(d){d=oN(d);p[114610]=0;d=ta(1013,+(+(d>>>0)*1e-4))|0;e=p[114610];p[114610]=0;if((e|0)!=1){n[h|0]=d;n[l+3|0]=17;break J}break f}n[l+3|0]=0;break J}G=e>>>4|0;V=e<<4;j=G|V;K:{switch(S|0){case 0:e=v(g,6)+k|0;if(d){n[e+3|0]=1;break J}n[e+3|0]=0;break J;case 1:n[(v(g,6)+k|0)+3|0]=2;break J;case 2:n[(v(g,6)+k|0)+3|0]=3;break J;case 3:p[114610]=0;n[f+16|0]=15;d=J(391,h|0,f+16|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){n[i|0]=q[d|0]|16;n[i+7|0]=0;n[i+1|0]=0;n[i+2|0]=0;n[(v(g,6)+k|0)+3|0]=0;break J}break f;case 4:p[114610]=0;n[f+16|0]=15;d=J(391,h|0,f+16|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){n[i|0]=q[d|0]|32;n[i+7|0]=0;n[i+1|0]=0;n[i+2|0]=0;n[(v(g,6)+k|0)+3|0]=0;break J}break f;case 5:n[i+7|0]=0;n[i+2|0]=0;n[i+1|0]=d;n[i|0]=0;n[(v(g,6)+k|0)+3|0]=0;break J;case 6:n[i+7|0]=0;n[i+2|0]=d;n[i|0]=0;n[i+1|0]=0;n[(v(g,6)+k|0)+3|0]=0;break J;case 7:n[(v(g,6)+k|0)+3|0]=23;m=0;break J;case 8:n[(v(g,6)+k|0)+3|0]=0;m=j;break J;case 9:n[(v(g,6)+k|0)+3|0]=19;p[114610]=0;n[f+16|0]=15;d=J(391,h|0,f+16|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){n[h|0]=q[d|0]|16;break J}break f;case 10:n[(v(g,6)+k|0)+3|0]=19;p[114610]=0;n[f+16|0]=15;d=J(391,h|0,f+16|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){n[h|0]=q[d|0]|32;break J}break f;case 11:n[i+3|0]=j;n[(v(g,6)+k|0)+3|0]=0;break J;case 12:e=v(g,6)+k|0;n[e+4|0]=d;n[e+2|0]=1;n[i+3|0]=0;n[e+3|0]=0;break J;case 13:j=v(g,6)+k|0;L:{M:{if(e&240){n[(v(g,6)+k|0)+2|0]=4;d=(d&240)>>>4|0;break M}if(!(e&15)){break L}n[(v(g,6)+k|0)+2|0]=3;d=d&15}n[j+4|0]=d}n[i+3|0]=0;n[(v(g,6)+k|0)+3|0]=0;break J;case 14:n[(v(g,6)+k|0)+3|0]=19;n[h|0]=!d;break J;case 15:n[(v(g,6)+k|0)+3|0]=16;n[h|0]=(d&240)>>>4;Q=d&15;break J;case 16:n[i+5|0]=0;n[i+4|0]=d;n[(v(g,6)+k|0)+3|0]=0;break J;case 17:n[i+6|0]=e&15?d:0;n[(v(g,6)+k|0)+3|0]=0;break J;case 18:n[(v(g,6)+k|0)+3|0]=14;break J;case 19:n[i+8|0]=0;n[i+7|0]=d;n[i+2|0]=0;n[i|0]=0;n[i+1|0]=0;n[(v(g,6)+k|0)+3|0]=0;break J;case 20:n[(v(g,6)+k|0)+3|0]=12;break J;case 22:N:{d=q[l+1|0];O:{if(!d){break O}if(nc(w)>>>0<d>>>0){break O}d=id(w,q[l+1|0]+ -1|0);e=q[h|0]+ -1|0;n[h|0]=e;p[114610]=0;J(1014,f+16|0,0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break f}p[f+120>>2]=9;d=nc(d);p[114610]=0;p[f+12>>2]=d;d=J(33,f+120|0,f+12|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break N}if(s[d>>2]<=(e&255)>>>0){break O}d=v(g,6)+k|0;n[d+2|0]=15;n[d+4|0]=q[h|0]}n[(v(g,6)+k|0)+3|0]=0;break J}break f;case 23:d=q[l+1|0];P:{if(!d){break P}if(nc(w)>>>0<d>>>0){break P}d=id(w,q[l+1|0]+ -1|0);e=q[h|0]+ -1|0;n[h|0]=e;if(nc(d)>>>0<=(e&255)>>>0){break P}Q:{if(r[id(d,q[h|0])+8>>1]){break Q}e=r[y>>1];if(e>>>0>3998){break Q}e=e+1|0;o[y>>1]=e;X=id(d,q[h|0]),Y=e,o[X+8>>1]=Y}X=l,Y=q[id(d,q[h|0])+8|0],n[X+1|0]=Y}n[(v(g,6)+k|0)+3|0]=0;break J;case 24:R:{d=q[l+1|0];S:{if(!d){break S}if(nc(w)>>>0<d>>>0){break S}d=id(w,q[l+1|0]+ -1|0);e=q[h|0]+ -1|0;n[h|0]=e;p[114610]=0;J(1014,f+16|0,0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break f}p[f+120>>2]=9;d=nc(d);p[114610]=0;p[f+12>>2]=d;d=J(33,f+120|0,f+12|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break R}if(s[d>>2]>(e&255)>>>0){d=v(g,6)+k|0;n[d+2|0]=15;n[d+4|0]=q[h|0]}T:{if(r[kc(x,q[l+1|0]+ -1|0)>>1]){break T}d=r[y>>1];if(d>>>0>3998){break T}d=d+1|0;o[y>>1]=d;X=kc(x,q[l+1|0]+ -1|0),Y=d,o[X>>1]=Y}X=l,Y=q[kc(x,q[l+1|0]+ -1|0)|0],n[X+1|0]=Y}n[(v(g,6)+k|0)+3|0]=0;break J}break f;case 25:d=q[l+1|0];U:{if(!d){break U}if(nc(w)>>>0<d>>>0){break U}d=id(w,q[l+1|0]+ -1|0);e=q[h|0]+ -1|0;n[h|0]=e;if(nc(d)>>>0<=(e&255)>>>0){break U}V:{if(r[id(d,q[h|0])+10>>1]){break V}e=r[y>>1];if(e>>>0>3998){break V}e=e+1|0;o[y>>1]=e;X=id(d,q[h|0]),Y=e,o[X+10>>1]=Y}X=l,Y=q[id(d,q[h|0])+10|0],n[X+1|0]=Y}n[(v(g,6)+k|0)+3|0]=0;break J;case 29:n[(v(g,6)+k|0)+3|0]=11;n[h|0]=j;if(e&15){n[h|0]=V|15;break J}if(!G){break J}n[h|0]=G|240;break J;case 32:if(e&240){n[i+3|0]=G;n[(v(g,6)+k|0)+3|0]=0;break J}n[(v(g,6)+k|0)+3|0]=19;n[h|0]=d&15|192;break J;case 33:n[(v(g,6)+k|0)+3|0]=19;p[114610]=0;n[f+16|0]=15;d=J(391,h|0,f+16|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){n[h|0]=q[d|0]|208;break J}break f;case 34:n[(v(g,6)+k|0)+3|0]=19;p[114610]=0;n[f+16|0]=15;d=J(391,h|0,f+16|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){n[h|0]=q[d|0]|144;break J}break f;case 73:n[(v(g,6)+k|0)+3|0]=10;break J;case 78:if((d&112|128)==224){n[(v(g,6)+k|0)+3|0]=19;break J}n[(v(g,6)+k|0)+3|0]=0;break J;case 79:e=v(g,6)+k|0;if(d>>>0<=31){n[e+3|0]=16;Q=0;break J}n[e+3|0]=17;break J;default:break K}}n[(v(g,6)+k|0)+3|0]=0}d=0;e=q[i+3|0];if(!(q[l+2|0]|!e)){W:{if(e>>>0>=16){n[l+2|0]=5;n[l+4|0]=e>>>4;break W}n[l+2|0]=6;n[l+4|0]=e}d=1}X:{if(q[l+3|0]){break X}e=q[i+1|0];if(e){n[l+3|0]=2;n[h|0]=e;break X}e=q[i+2|0];if(e){n[l+3|0]=3;n[h|0]=e;break X}e=q[i|0];if(e){n[l+3|0]=19;n[h|0]=e;break X}e=q[i+7|0];if(e){n[l+3|0]=4;n[i+8|0]=e;n[h|0]=e;break X}e=q[i+4|0];if(e){n[l+3|0]=5;n[i+5|0]=e;n[h|0]=e;break X}e=d;d=q[i+3|0];if(!(e|!d)){n[l+3|0]=11;n[h|0]=d;if(d&15){n[h|0]=d|240;break X}if(!(d&240)){break X}n[h|0]=d|15;break X}d=q[i+6|0];if(d){n[l+3|0]=8;n[h|0]=d;break X}if(A){n[l+3|0]=20;n[h|0]=97;A=0;break X}A=0;d=m&255;if(!d|!(R^1)){break X}n[l+3|0]=24;n[h|0]=m;if(m&15){n[h|0]=m|240;R=1;break X}R=1;if(!(d&240)){break X}n[h|0]=m|15}g=g+1|0;if(g>>>0<r[f+126>>1]){continue}break}break G}break f}z=z+1|0;if((F|0)!=(z|0)){continue}break}break E}p[114610]=0;J(338,b|0,v(r[f+126>>1],F)<<2)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break E}break f}t=t+1|0;if((t&65535)>>>0<C>>>0){continue}break}}p[a+480228>>2]=256/r[a+480188>>1];p[114610]=0;K(449,a|0,1);d=p[114610];p[114610]=0;if((d|0)==1){break f}if(q[u|0]|q[u+1|0]<<8){Y:{while(1){p[114610]=0;d=J(258,b|0,2)|0;m=p[114610];p[114610]=0;if((m|0)==1){break f}if(!d){break Y}p[114610]=0;d=M(484,b|0)|0;m=p[114610];p[114610]=0;if((m|0)==1){break f}if((d|0)==65535){break Y}p[114610]=0;J(338,b|0,2)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}p[114610]=0;d=M(494,b|0)|0;m=p[114610];p[114610]=0;if((m|0)!=1){p[114610]=0;J(338,b|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){continue}}break}break f}p[114610]=0;J(338,b|0,34)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}}Z:{if(!(!(c&2)|!B)){d=1;m=1;while(1){c=(v(d,104)+a|0)+484380|0;_:{if(!p[c>>2]){break _}e=Tc(f+16|0,8,1,0,0);p[114610]=0;P(400,e|0,c|0,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Z}if(nc(w)>>>0<d>>>0){break _}d=d+ -1|0;e=id(w,d);p[114610]=0;K(1015,c|0,e|0);e=p[114610];p[114610]=0;$:{if((e|0)!=1){if(!r[kc(x,d)>>1]){break $}e=r[kc(x,d)>>1];t=p[c>>2];p[114610]=0;_(1016,c|0,(v(e,104)+a|0)+484380|0,0,t|0,0);e=p[114610];p[114610]=0;if((e|0)!=1){break $}}break f}d=id(w,d);X=f,Y=Ub(d),p[X+16>>2]=Y;X=f,Y=Vb(d),p[X+128>>2]=Y;if(!Ab(f+16|0,f+128|0)){break _}while(1){d=p[f+16>>2];e=r[d+8>>1];if(e){t=p[d+4>>2];j=p[d>>2];p[114610]=0;_(1016,c|0,(v(e,104)+a|0)+484380|0,j|0,t|0,1);e=p[114610];p[114610]=0;if((e|0)==1){break f}}e=r[d+10>>1];if(e){t=p[d+4>>2];d=p[d>>2];p[114610]=0;_(1016,c|0,(v(e,104)+a|0)+484380|0,d|0,t|0,0);d=p[114610];p[114610]=0;if((d|0)==1){break f}}kn(f+16|0);if(Ab(f+16|0,f+128|0)){continue}break}}m=m+1|0;d=m&65535;if(d>>>0<=B>>>0){continue}break}}ly(O);d=1;break b}break f}a=I()|0;H()|0;break d}a=I()|0;H()|0;break d}a=I()|0;H()|0;break d}a=I()|0;H()|0;break e}a=I()|0;H()|0;break d}a=I()|0;H()|0;break d}a=I()|0;H()|0;ly(O);break d}sb(f+144|0)}qf(x);nN(w)}L(a|0);E()}qf(x);nN(w)}fb=f+416|0;return d|0}function p6(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,u=w(0),x=0,y=w(0),z=0,A=0,B=0,C=w(0);k=fb-1024|0;fb=k;n[a+1377|0]=1;a:{if(!ar(a)){break a}c=q[a+1375|0];if(!(c&2)){Wb(a,34);break a}if(c&4){Wb(a,34);break a}if(c&1){Wb(a,34);break a}if(p[a+1116>>2]!=1){Wb(a,34);break a}c=q[a+1120|0];if((c|0)!=30){b:{if((c|0)!=64){break b}if(!Mv(a,k+1018|0,6)|q[k+1018|0]!=102|(q[k+1019|0]!=105|q[k+1020|0]!=115)){break b}if(q[k+1021|0]!=104|q[k+1022|0]!=101|q[k+1023|0]!=97){break b}if((re(a)|0)!=100){break b}if(re(a)){break b}Wb(a,38);break a}Wb(a,34);break a}if((re(a)|0)!=1){Wb(a,34);break a}if(!Mv(a,k+1018|0,6)){Wb(a,10);break a}if(!Lv(k+1018|0)){Wb(a,34);break a}if(Vh(a)){Wb(a,34);break a}c=re(a);p[a+4>>2]=c;if(!c){Wb(a,34);break a}if(c>>>0>=17){Wb(a,5);break a}c=Vh(a);p[a>>2]=c;if(!c){Wb(a,34);break a}Vh(a);Vh(a);Vh(a);c=re(a);f=c>>>4|0;p[a+116>>2]=1<<f;d=c&15;p[a+112>>2]=1<<d;if(d+ -6>>>0>=8){Wb(a,20);break a}if((c<<24)+ -1610612736>>24<=-1){Wb(a,20);break a}if(d>>>0>f>>>0){Wb(a,20);break a}if(!(re(a)&1)){Wb(a,34);break a}if(!ar(a)){break a}if(!Kv(a)){break a}if(!Jv(a)){break a}c:{d:{if((yg(a)|0)==3){while(1){A=(k+1018|0)+b|0,B=yg(a),n[A|0]=B;b=b+1|0;if((b|0)!=6){continue}break}if(!Lv(k+1018|0)){Wb(a,20);break c}d=Iv(a);c=Jd(a,d+1|0);p[a+20>>2]=c;if(c){b=0;if((d|0)>0){while(1){c=yg(a);n[p[a+20>>2]+b|0]=c;b=b+1|0;if((d|0)!=(b|0)){continue}break}c=p[a+20>>2]}n[c+d|0]=0;b=Iv(a);p[a+24>>2]=b;b=Jd(a,b<<2);p[a+28>>2]=b;if(b){e:{if(p[a+24>>2]>0){while(1){d=Iv(a);b=Jd(a,d+1|0);f=e<<2;p[f+p[a+28>>2]>>2]=b;c=p[f+p[a+28>>2]>>2];if(!c){break e}b=0;if((d|0)>0){while(1){c=yg(a);n[p[f+p[a+28>>2]>>2]+b|0]=c;b=b+1|0;if((d|0)!=(b|0)){continue}break}c=p[f+p[a+28>>2]>>2]}n[c+d|0]=0;e=e+1|0;if((e|0)<p[a+24>>2]){continue}break}}if(!(yg(a)&1)){Wb(a,20);break c}gF(a,q[a+1376|0]);n[a+1376|0]=0;while(1){b=Jv(a);gF(a,b);n[a+1376|0]=0;if(b){continue}break}b=0;if(!Kv(a)){break a}if(!iF(a)){if(p[a+100>>2]!=21){break a}p[a+100>>2]=20;break a}n6();if((yg(a)|0)==5){while(1){A=(k+1018|0)+b|0,B=yg(a),n[A|0]=B;b=b+1|0;if((b|0)!=6){continue}break}if(!Lv(k+1018|0)){Wb(a,20);break c}b=bc(a,8)+1|0;p[a+120>>2]=b;b=Jd(a,v(b,2096));p[a+124>>2]=b;if(!b){Wb(a,3);break c}Jb(b,0,v(p[a+120>>2],2096));f:{g:{if(p[a+120>>2]>=1){while(1){b=p[a+124>>2];if((bc(a,8)&255)!=66){Wb(a,20);break c}if((bc(a,8)&255)!=67){Wb(a,20);break c}if((bc(a,8)&255)!=86){Wb(a,20);break c}d=b+v(m,2096)|0;A=d,B=bc(a,8)&255|bc(a,8)<<8,p[A>>2]=B;b=bc(a,8);A=d,B=bc(a,8)<<8&65280|b&255|bc(a,8)<<16,p[A+4>>2]=B;b=0;i=d+4|0;e=bc(a,1);if(!e){b=bc(a,1)}n[d+23|0]=b;if(!(p[d>>2]|!p[i>>2])){Wb(a,20);break c}c=p[i>>2];h:{if(b&255){c=rm(a,c);break h}c=Jd(a,c);p[d+8>>2]=c}if(!c){Wb(a,3);break c}i:{if(!e){b=0;l=0;e=p[i>>2];if((e|0)<=0){break i}while(1){j:{k:{if(q[d+23|0]){if(!bc(a,1)){break k}}e=bc(a,5)+1|0;n[b+c|0]=e;if((e&255)!=32){l=l+1|0;break j}Wb(a,20);break c}n[b+c|0]=255}b=b+1|0;e=p[i>>2];if((b|0)<(e|0)){continue}break}break i}g=bc(a,5);l=0;b=0;e=p[i>>2];if((e|0)<1){break i}while(1){e=bc(a,_k(e-b|0));g=g+1|0;if((g|0)>=32){Wb(a,20);break c}f=b+e|0;if((f|0)>p[i>>2]){Wb(a,20);break c}Jb(b+c|0,g,e);e=p[i>>2];b=f;if((e|0)>(b|0)){continue}break}}l:{m:{if(q[d+23|0]){if((l|0)<e>>2){break m}b=d;f=a;if((e|0)>p[a+16>>2]){p[a+16>>2]=e;e=p[i>>2]}x=b;b=Jd(f,e);p[x+8>>2]=b;if(!b){Wb(a,3);break c}ac(b,c,p[i>>2]);Uh(a,c,p[i>>2]);c=p[d+8>>2];n[d+23|0]=0}g=0;b=0;e=0;f=p[i>>2];if((f|0)>=1){while(1){e=((q[b+c|0]+ -11&255)>>>0<244)+e|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}}p[d+2092>>2]=e;b=Jd(a,f<<2);p[d+32>>2]=b;if(b){h=d+2092|0;break l}Wb(a,3);break c}p[d+2092>>2]=l;h=d+2092|0;n:{if(!l){g=0;break n}b=Jd(a,l);p[d+8>>2]=b;if(!b){Wb(a,3);break c}b=rm(a,p[h>>2]<<2);p[d+32>>2]=b;if(!b){Wb(a,3);break c}g=rm(a,p[h>>2]<<2);if(g){break n}Wb(a,3);break c}b=p[i>>2]+(p[h>>2]<<3)|0;if(b>>>0<=s[a+16>>2]){break l}p[a+16>>2]=b}if(!m6(d,c,p[i>>2],g)){if(q[d+23|0]){Uh(a,g,0)}Wb(a,20);break c}b=p[h>>2];if(b){b=Jd(a,(b<<2)+4|0);p[d+2084>>2]=b;if(!b){Wb(a,3);break c}b=Jd(a,(p[h>>2]<<2)+4|0);p[d+2088>>2]=b;if(!b){Wb(a,3);break c}p[d+2088>>2]=b+4;p[b>>2]=-1;l6(d,c,g)}if(q[d+23|0]){Uh(a,g,p[h>>2]<<2);Uh(a,p[d+32>>2],p[h>>2]<<2);Uh(a,c,p[i>>2]);p[d+32>>2]=0}j6(d);b=bc(a,4);n[d+21|0]=b;b=b&255;if(b>>>0>=3){Wb(a,20);break c}if(b){A=d,C=fF(bc(a,32)),t[A+12>>2]=C;A=d,C=fF(bc(a,32)),t[A+16>>2]=C;A=d,B=bc(a,4)+1|0,n[A+20|0]=B;A=d,B=bc(a,1),n[A+22|0]=B;b=p[d>>2];c=p[i>>2];o:{if(q[d+21|0]==1){b=i6(c,b);if((b|0)>-1){break o}Wb(a,20);break c}b=v(b,c)}p[d+24>>2]=b;if(!b){Wb(a,20);break c}c=rm(a,b<<1);if(!c){break g}b=0;g=p[d+24>>2];if((g|0)>0){while(1){e=bc(a,q[d+20|0]);if((e|0)==-1){Uh(a,c,p[d+24>>2]<<1);Wb(a,20);break c}o[c+(b<<1)>>1]=e;b=b+1|0;g=p[d+24>>2];if((b|0)<(g|0)){continue}break}}p:{if(q[d+21|0]==1){l=q[d+23|0];q:{if(l){b=p[h>>2];if(b){break q}break p}b=p[i>>2]}b=Jd(a,v(p[d>>2],b)<<2);p[d+28>>2]=b;if(!b){Uh(a,c,p[d+24>>2]<<1);Wb(a,3);break c}z=p[(l?h:i)>>2];if((z|0)>=1){x=d+2088|0;u=w(0);f=0;while(1){h=l?p[p[x>>2]+(f<<2)>>2]:f;b=1;e=0;r:{g=p[d>>2];if((g|0)<1){break r}while(1){y=w(w(t[d+12>>2]+u)+w(t[d+16>>2]*w(r[c+(((h>>>0)/(b>>>0)>>>0)%s[d+24>>2]<<1)>>1])));t[p[d+28>>2]+(v(f,g)+e<<2)>>2]=y;u=q[d+22|0]?y:u;e=e+1|0;g=p[d>>2];if((e|0)>=(g|0)){break r}i=p[d+24>>2];NNa(i,0,b,0);if(ib){Uh(a,c,i<<1);Wb(a,20);break c}else{b=v(b,i);continue}}}f=f+1|0;if((z|0)!=(f|0)){continue}break}}n[d+21|0]=2;g=p[d+24>>2];break p}b=Jd(a,g<<2);p[d+28>>2]=b;g=p[d+24>>2];if(!b){break f}if((g|0)<1){break p}u=w(t[d+12>>2]+w(t[d+16>>2]*w(r[c>>1])));t[b>>2]=u;b=1;g=p[d+24>>2];if((g|0)<=1){break p}y=w(0);while(1){y=q[d+22|0]?u:y;u=w(w(t[d+12>>2]+y)+w(t[d+16>>2]*w(r[c+(b<<1)>>1])));t[p[d+28>>2]+(b<<2)>>2]=u;b=b+1|0;g=p[d+24>>2];if((b|0)<(g|0)){continue}break}}Uh(a,c,g<<1)}m=m+1|0;if((m|0)<p[a+120>>2]){continue}break}}s:{b=bc(a,6)+1&255;if(!b){break s}while(1){if(!bc(a,16)){j=j+1|0;if((b|0)!=(j|0)){continue}break s}break}Wb(a,20);break c}b=bc(a,6)+1|0;p[a+128>>2]=b;b=Jd(a,v(b,1596));p[a+260>>2]=b;t:{if(b){if(p[a+128>>2]>=1){break t}h=0;break d}Wb(a,3);break c}l=0;f=0;u:while(1){b=bc(a,16);o[((l<<1)+a|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){Wb(a,20);break c}if(!b){c=p[a+260>>2]+v(l,1596)|0;A=c,B=bc(a,8),n[A|0]=B;A=c,B=bc(a,16),o[A+2>>1]=B;A=c,B=bc(a,16),o[A+4>>1]=B;A=c,B=bc(a,6),n[A+6|0]=B;A=c,B=bc(a,8),n[A+7|0]=B;b=(bc(a,4)&255)+1|0;n[c+8|0]=b;if((b|0)==(b&255)){d=c+9|0;b=0;while(1){A=b+d|0,B=bc(a,8),n[A|0]=B;b=b+1|0;if(b>>>0<q[c+8|0]){continue}break}}Wb(a,4);break c}d=p[a+260>>2]+v(l,1596)|0;h=bc(a,5);n[d|0]=h;b=-1;e=0;c=0;if(h&255){while(1){h=bc(a,4);n[(c+d|0)+1|0]=h;h=h&255;b=(h|0)>(b|0)?h:b;c=c+1|0;if(c>>>0<q[d|0]){continue}break}while(1){h=d+e|0;A=h,B=bc(a,3)+1|0,n[A+33|0]=B;c=bc(a,2);n[h+49|0]=c;v:{if(c&255){c=bc(a,8);n[h+65|0]=c;if((c&255)>=p[a+120>>2]){Wb(a,20);break c}if(q[h+49|0]==31){break v}}c=0;while(1){w:{j=bc(a,8)+ -1|0;o[((d+(e<<4)|0)+(c<<1)|0)+82>>1]=j;if(p[a+120>>2]<=j<<16>>16){break w}c=c+1|0;if((c|0)<1<<q[h+49|0]){continue}break v}break}Wb(a,20);break c}c=(b|0)!=(e|0);e=e+1|0;if(c){continue}break}}e=2;A=d,B=bc(a,2)+1|0,n[A+1588|0]=B;b=bc(a,4);p[d+1592>>2]=2;g=0;o[d+338>>1]=0;n[d+1589|0]=b;o[d+340>>1]=1<<(b&255);b=d+1592|0;j=q[d|0];x:{if(j){h=d+1589|0;while(1){c=0;i=d+q[(d+g|0)+1|0]|0;if(q[i+33|0]){while(1){e=bc(a,q[h|0]);o[(d+(p[b>>2]<<1)|0)+338>>1]=e;e=p[b>>2]+1|0;p[b>>2]=e;c=c+1|0;if(c>>>0<q[i+33|0]){continue}break}j=q[d|0]}g=g+1|0;if(g>>>0<(j&255)>>>0){continue}break}if((e|0)<1){break x}}c=0;while(1){e=r[(d+(c<<1)|0)+338>>1];h=(k+16|0)+(c<<2)|0;o[h+2>>1]=c;o[h>>1]=e;c=c+1|0;e=p[b>>2];if((c|0)<(e|0)){continue}break}}h=d+338|0;KE(k+16|0,e,2301);c=0;e=p[b>>2];j=e+ -1|0;j=(j|0)>0?j:0;while(1){if((c|0)==(j|0)){c=0;y:{if((e|0)<=0){break y}while(1){n[(c+d|0)+838|0]=q[((k+16|0)+(c<<2)|0)+2|0];c=c+1|0;e=p[b>>2];if((c|0)<(e|0)){continue}break}c=2;if((e|0)<=2){break y}while(1){p[k+12>>2]=0;p[k+8>>2]=0;g6(h,c,k+12|0,k+8|0);e=d+(c<<1)|0;n[e+1088|0]=p[k+12>>2];n[e+1089|0]=p[k+8>>2];c=c+1|0;e=p[b>>2];if((c|0)<(e|0)){continue}break}}f=(e|0)>(f|0)?e:f;l=l+1|0;if((l|0)<p[a+128>>2]){continue u}h=f<<1;break d}x=r[(k+16|0)+(c<<2)>>1];c=c+1|0;if((x|0)!=r[(k+16|0)+(c<<2)>>1]){continue}break}break}Wb(a,20);break c}Wb(a,3);break c}Uh(a,c,g<<1);Wb(a,3);break c}Wb(a,20);break c}Wb(a,3);break c}Wb(a,3);break c}Wb(a,3);break c}Wb(a,20);break c}b=bc(a,6)+1|0;p[a+264>>2]=b;b=Jd(a,v(b,24));p[a+396>>2]=b;if(!b){Wb(a,3);break c}e=0;Jb(b,0,v(p[a+264>>2],24));z:{if(p[a+264>>2]>=1){while(1){b=p[a+396>>2];c=bc(a,16);o[((e<<1)+a|0)+268>>1]=c;if((c&65535)>>>0>=3){Wb(a,20);break c}f=b+v(e,24)|0;A=f,B=bc(a,24),p[A>>2]=B;b=bc(a,24);p[f+4>>2]=b;if(b>>>0<s[f>>2]){Wb(a,20);break c}A=f,B=bc(a,24)+1|0,p[A+8>>2]=B;A=f,B=bc(a,6)+1|0,n[A+12|0]=B;b=bc(a,8);n[f+13|0]=b;A:{B:{if((b&255)<p[a+120>>2]){b=0;if(q[f+12|0]){break B}c=0;break A}Wb(a,20);break c}while(1){c=(k+16|0)+b|0;d=bc(a,3);if(bc(a,1)){j=bc(a,5)}else{j=0}n[c|0]=d+(j<<3);b=b+1|0;c=q[f+12|0];if(b>>>0<c>>>0){continue}break}}b=Jd(a,c<<4);p[f+20>>2]=b;if(!b){break z}if(q[f+12|0]){g=0;while(1){c=q[(k+16|0)+g|0];b=0;while(1){C:{if(c>>>b&1){d=bc(a,8);i=b<<1;j=g<<4;o[i+(j+p[f+20>>2]|0)>>1]=d;if(p[a+120>>2]>o[i+(j+p[f+20>>2]|0)>>1]){break C}Wb(a,20);break c}o[(p[f+20>>2]+(g<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}g=g+1|0;if(g>>>0<q[f+12|0]){continue}break}}b=Jd(a,p[(p[a+124>>2]+v(q[f+13|0],2096)|0)+4>>2]<<2);p[f+16>>2]=b;if(!b){Wb(a,3);break c}j=0;Jb(b,0,p[(p[a+124>>2]+v(q[f+13|0],2096)|0)+4>>2]<<2);b=p[a+124>>2];c=q[f+13|0];if(p[(b+v(c,2096)|0)+4>>2]>0){while(1){d=p[v(c,2096)+b>>2];b=Jd(a,d);g=j<<2;p[g+p[f+16>>2]>>2]=b;D:{c=p[g+p[f+16>>2]>>2];if(c){if((d|0)<1){break D}b=d+ -1|0;n[c+b|0]=(j>>>0)%q[f+12|0];c=j;if((d|0)==1){break D}while(1){d=b+ -1|0;i=q[f+12|0];c=(c|0)/(i|0)|0;n[d+p[g+p[f+16>>2]>>2]|0]=(c|0)%(i|0);i=(b|0)>1;b=d;if(i){continue}break}break D}Wb(a,3);break c}j=j+1|0;b=p[a+124>>2];c=q[f+13|0];if((j|0)<p[(b+v(c,2096)|0)+4>>2]){continue}break}}e=e+1|0;if((e|0)<p[a+264>>2]){continue}break}}b=bc(a,6)+1|0;p[a+400>>2]=b;b=Jd(a,v(b,40));p[a+404>>2]=b;if(!b){Wb(a,3);break c}g=0;Jb(b,0,v(p[a+400>>2],40));if(p[a+400>>2]>=1){while(1){b=p[a+404>>2];if(bc(a,16)){Wb(a,20);break c}d=b+v(g,40)|0;b=Jd(a,v(p[a+4>>2],3));p[d+4>>2]=b;if(!b){Wb(a,3);break c}b=d;if(bc(a,1)){f=bc(a,4)+1|0}else{f=1}n[b+8|0]=f;E:{if(bc(a,1)){b=bc(a,8)+1|0;o[d>>1]=b;F:{c=p[a+4>>2];b=b&65535;if((c|0)>=(b|0)){f=0;if(b){break F}break E}Wb(a,20);break c}while(1){c=bc(a,_k(c+ -1|0));b=v(f,3);n[b+p[d+4>>2]|0]=c;c=bc(a,_k(p[a+4>>2]+ -1|0));n[(b+p[d+4>>2]|0)+1|0]=c;c=p[a+4>>2];b=b+p[d+4>>2]|0;e=q[b|0];if((c|0)<=(e|0)){Wb(a,20);break c}b=q[b+1|0];if((c|0)<=(b|0)){Wb(a,20);break c}if((b|0)!=(e|0)){f=f+1|0;if(f>>>0>=r[d>>1]){break E}continue}break}Wb(a,20);break c}o[d>>1]=0}if(bc(a,2)){Wb(a,20);break c}e=p[a+4>>2];G:{H:{b=q[d+8|0];if(b>>>0<=1){c=0;if((e|0)>0){while(1){n[(p[d+4>>2]+v(c,3)|0)+2|0]=0;c=c+1|0;if((c|0)<p[a+4>>2]){continue}break}b=q[d+8|0]}if(!(b&255)){break G}break H}c=0;if((e|0)<=0){break H}while(1){I:{b=bc(a,4);e=v(c,3);n[(e+p[d+4>>2]|0)+2|0]=b;if(q[(e+p[d+4>>2]|0)+2|0]>=q[d+8|0]){break I}c=c+1|0;if((c|0)<p[a+4>>2]){continue}break H}break}Wb(a,20);break c}b=0;while(1){bc(a,8);e=b+d|0;c=e;A=c,B=bc(a,8),n[A+9|0]=B;e=bc(a,8);n[c+24|0]=e;if(p[a+128>>2]<=q[c+9|0]){Wb(a,20);break c}if((e&255)<p[a+264>>2]){b=b+1|0;if(b>>>0>=q[d+8|0]){break G}continue}break}Wb(a,20);break c}g=g+1|0;if((g|0)<p[a+400>>2]){continue}break}}b=bc(a,6)+1|0;p[a+408>>2]=b;c=0;J:{if((b|0)<=0){break J}while(1){b=v(c,6)+a|0;A=b,B=bc(a,1),n[A+412|0]=B;A=b,B=bc(a,16),o[A+414>>1]=B;A=b,B=bc(a,16),o[A+416>>1]=B;d=bc(a,8);n[b+413|0]=d;if(r[b+414>>1]){Wb(a,20);break c}if(r[b+416>>1]){Wb(a,20);break c}if((d&255)<p[a+400>>2]){c=c+1|0;if((c|0)>=p[a+408>>2]){break J}continue}break}Wb(a,20);break c}eF(a);b=0;p[a+992>>2]=0;if(p[a+4>>2]>=1){while(1){c=(b<<2)+a|0;A=c,B=Jd(a,p[a+116>>2]<<2),p[A+800>>2]=B;A=c,B=Jd(a,p[a+116>>2]<<1&2147483646),p[A+928>>2]=B;d=Jd(a,h);p[c+996>>2]=d;e=p[c+800>>2];if(!(p[c+928>>2]?!(!e|!d):0)){Wb(a,3);break c}Jb(e,0,p[a+116>>2]<<2);b=b+1|0;if((b|0)<p[a+4>>2]){continue}break}}b=0;if(!dF(a,0,p[a+112>>2])){break a}if(!dF(a,1,p[a+116>>2])){break a}p[a+104>>2]=p[a+112>>2];d=p[a+116>>2];p[a+108>>2]=d;z=a;j=d<<1&2147483646;x=j;i=p[a+264>>2];f=4;K:{if((i|0)<1){break K}d=(d|0)/2|0;l=p[a+396>>2];e=0;f=0;while(1){h=l+v(f,24)|0;m=p[h+4>>2];c=m>>>0<d>>>0?m:d;m=p[h>>2];h=(c-(m>>>0<d>>>0?m:d)>>>0)/s[h+8>>2]|0;e=(h|0)>(e|0)?h:e;f=f+1|0;if((i|0)!=(f|0)){continue}break}f=(e<<2)+4|0}c=v(f,p[a+4>>2]);c=j>>>0>c>>>0?x:c;p[z+12>>2]=c;L:{M:{if(!p[a+80>>2]){break M}d=p[a+92>>2];if((d|0)!=p[a+84>>2]){break L}if((c+p[a+88>>2]|0)+1512>>>0<=d>>>0){break M}Wb(a,3);break a}if(p[a+1380>>2]==-1){p[a+52>>2]=q[a+48|0]?0:p[a+32>>2]-p[a+36>>2]|0;b=1;break a}p[a+52>>2]=0;b=1;break a}aa(51860,50416,4177,51916);E()}Wb(a,3)}b=0}fb=k+1024|0;return b}function kza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,O=0;d=fb-304|0;fb=d;Ac(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!Ds(b,d+208|0)){break h}if(!yN(d+208|0)){break h}if(!Hb(b,dd(xN(d+208|0),ib))){break h}if(!c){z=1;break h}xd(a,2);p[a+480260>>2]=64;p[a+480264>>2]=32767;l=Xc(d+192|0);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{i=d+248|0;switch(((q[i|0]|q[i+1|0]<<8)&61440)+ -4096>>>12|0){case 6:break q;case 5:break r;case 4:break s;case 3:break t;case 2:break u;case 1:break v;case 0:break w;default:break p}}x:{if(q[d+270|0]|q[d+271|0]<<8|(q[i|0]|q[i+1|0]<<8)!=4896|(q[d+260|0]|q[d+240|0]&15)){break x}if((q[d+246|0]|q[d+247|0]<<8)&65455){break x}p[a+1074304>>2]=18219008;p[114610]=0;e=J(2,d+32|0,16970)|0;g=p[114610];p[114610]=0;h=1;if((g|0)==1){break o}xb(l,e);pb(e);p[114610]=0;P(478,a+1074308|0,81,1)|0;g=p[114610];p[114610]=0;e=1;if((g|0)!=1){break i}break b}y:{if(q[d+270|0]|q[d+271|0]<<8|(q[i|0]|q[i+1|0]<<8)!=4896|(q[d+260|0]|(q[d+246|0]|q[d+247|0]<<8))){break y}if(q[d+261|0]){break y}p[114610]=0;g=J(2,d+32|0,16996)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break j}f=I()|0;H()|0;break a}p[114610]=0;g=J(2,d+32|0,17010)|0;j=p[114610];p[114610]=0;f=1;if((j|0)!=1){xb(l,g);pb(g);break k}f=I()|0;H()|0;break a}p[114610]=0;g=J(2,d+32|0,17025)|0;j=p[114610];p[114610]=0;e=1;if((j|0)!=1){xb(l,g);pb(g);break k}f=I()|0;H()|0;break a}z:{A:{B:{C:{D:{m=q[i|0]|q[i+1|0]<<8;E:{if(m>>>0<=12820){p[114610]=0;g=J(2,d+32|0,17039)|0;e=p[114610];p[114610]=0;if((e|0)!=1){xb(l,g);break E}f=I()|0;H()|0;break a}p[114610]=0;g=J(2,d+160|0,17055)|0;e=p[114610];p[114610]=0;if((e|0)==1){break D}p[114610]=0;K(219,d+176|0,g|0);e=p[114610];p[114610]=0;if((e|0)==1){break C}e=q[i|0]|q[i+1|0]<<8;p[114610]=0;p[d+128>>2]=e+ -12820;N(245,d+32|0,d+176|0,d+128|0);e=p[114610];p[114610]=0;if((e|0)==1){break B}xb(l,d+32|0);pb(d+32|0);yb(d+176|0)}pb(g);if((q[i|0]|q[i+1|0]<<8)>>>0<12807){break l}if(q[d+264|0]|q[d+265|0]<<8|(q[d+266|0]<<16|q[d+267|0]<<24)){break z}break l}f=I()|0;H()|0;break a}f=I()|0;H()|0;break A}f=I()|0;H()|0;yb(d+176|0)}pb(g);break a}e=q[i|0]|q[i+1|0]<<8;g=q[d+264|0]|q[d+265|0]<<8|(q[d+266|0]<<16|q[d+267|0]<<24);p[114610]=0;e=J(665,e|0,g|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break n}g=wp(d+32|0);p[g+44>>2]=e;p[114610]=0;K(666,a+1304500|0,g|0);e=p[114610];p[114610]=0;if((e|0)!=1){break l}f=I()|0;H()|0;break a}f=q[i|0]|q[i+1|0]<<8;F:{if((f|0)==16640){p[114610]=0;e=J(2,d+32|0,17079)|0;g=p[114610];p[114610]=0;if((g|0)!=1){xb(l,e);pb(e);p[114610]=0;P(478,a+1074308|0,81,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}break F}f=I()|0;H()|0;break a}e=q[i|0]|q[i+1|0]<<8;g=q[d+262|0]|q[d+263|0]<<8;p[114610]=0;N(667,d+32|0,e|0,g|0);e=p[114610];p[114610]=0;if((e|0)==1){break m}xb(l,d+32|0);pb(d+32|0);p[a+480260>>2]=1}j=(f|0)!=16640;e=1;f=0;break i}p[114610]=0;f=J(2,d+32|0,17091)|0;g=p[114610];p[114610]=0;if((g|0)!=1){xb(l,f);pb(f);p[a+1074304>>2]=((q[i|0]|q[i+1|0]<<8)&4095)<<16;f=0;break k}f=I()|0;H()|0;break a}p[114610]=0;e=J(2,d+32|0,17079)|0;g=p[114610];p[114610]=0;if((g|0)!=1){xb(l,e);pb(e);p[114610]=0;P(478,a+1074308|0,81,1)|0;g=p[114610];p[114610]=0;e=0;if((g|0)==1){break b}break i}f=I()|0;H()|0;break a}p[114610]=0;g=J(2,d+32|0,17099)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break j}f=I()|0;H()|0;break a}if((q[i|0]|q[i+1|0]<<8)!=51712){break i}p[114610]=0;g=J(2,d+32|0,17112)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break j}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}p[114610]=0;e=1;P(478,a+1074308|0,107,1)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}p[a+480260>>2]=1;if(m>>>0>12820){break i}}p[114610]=0;g=J(2,d+144|0,17119)|0;j=p[114610];p[114610]=0;G:{H:{I:{J:{K:{if((j|0)!=1){p[114610]=0;K(219,d+176|0,g|0);j=p[114610];p[114610]=0;if((j|0)==1){break K}p[d+16>>2]=q[i+1|0]&15;j=q[i|0];p[114610]=0;p[d>>2]=j;K(664,d+128|0,d|0);j=p[114610];p[114610]=0;if((j|0)==1){break J}p[114610]=0;_(998,d+32|0,d+176|0,l|0,d+16|0,d+128|0);j=p[114610];p[114610]=0;if((j|0)==1){break I}xb(l,d+32|0);pb(d+32|0);pb(d+128|0);yb(d+176|0);pb(g);j=0;break i}f=I()|0;H()|0;break a}f=I()|0;H()|0;break G}f=I()|0;H()|0;break H}f=I()|0;H()|0;pb(d+128|0)}yb(d+176|0)}pb(g);break a}xb(l,g);pb(g);e=0}p[114610]=0;g=J(2,d+32|0,17128)|0;m=p[114610];p[114610]=0;L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((m|0)!=1){xb(a+1304436|0,g);pb(g);p[114610]=0;g=J(2,d+32|0,17144)|0;m=p[114610];p[114610]=0;if((m|0)==1){break Z}xb(a+1304448|0,g);pb(g);xb(a+1304460|0,l);p[a+1304496>>2]=p[a+1074304>>2]?7:4;if(e){p[114610]=0;e=a+1074308|0;J(479,e|0,77)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}p[114610]=0;J(479,e|0,78)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}p[114610]=0;J(479,e|0,79)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}p[114610]=0;J(479,e|0,80)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}p[114610]=0;J(479,e|0,82)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}p[114610]=0;J(479,e|0,96)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}}h=((q[i|0]|q[i+1|0]<<8)&61440)>>>0<4097|((q[i|0]|q[i+1|0]<<8)>>>0<12820?((q[i|0]|q[i+1|0]<<8)&61440)==12288:0)?h:1;p[114610]=0;e=a+901404|0;S(999,e|0);g=p[114610];p[114610]=0;if((g|0)==1){break b}if(!h){p[114610]=0;S(638,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break b}}p[114610]=0;N(580,d+176|0,1,d+208|0);e=p[114610];p[114610]=0;if((e|0)==1){break Y}p[114610]=0;K(415,d+32|0,d+176|0);e=p[114610];p[114610]=0;if((e|0)==1){break Y}xb(a+1304400|0,d+32|0);pb(d+32|0);if(q[d+246|0]&16){p[a+480208>>2]=p[a+480208>>2]|65536}if(n[d+246|0]&1){p[a+480208>>2]=p[a+480208>>2]|131072}if(!(q[d+246|0]&64?0:(q[i|0]|q[i+1|0]<<8)!=4864)){p[a+480208>>2]=p[a+480208>>2]|2}e=q[d+257|0];p[a+480196>>2]=e;_:{$:{if(e){if((e|0)!=255){break $}e=0;if(!f){break _}}p[a+480196>>2]=6}e=f}p[a+480204>>2]=v(q[d+258|0],1e4);if(q[d+258|0]<=32){p[a+480204>>2]=e?125e4:32e4}f=q[d+256|0];p[114610]=0;n[d+32|0]=f;n[d+176|0]=64;f=J(391,d+32|0,d+176|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break U}f=q[f|0];p[a+480200>>2]=f<<2;if(!((q[i|0]|q[i+1|0]<<8)>>>0>4895|f)){p[a+480200>>2]=256}if((q[d+250|0]|q[d+251|0]<<8)!=1|q[d+259|0]>7){break W}f=q[d+259|0];p[114610]=0;p[d+32>>2]=(f<<4)+16;p[d+176>>2]=127;f=J(462,d+32|0,d+176|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break X}p[a+480228>>2]=p[f>>2];break V}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}if(!(q[d+259|0]!=18?q[d+259|0]!=2:0)){p[a+480228>>2]=32;break V}f=q[d+259|0];p[114610]=0;p[d+32>>2]=f&127;p[d+176>>2]=16;f=J(555,d+32|0,d+176|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break T}p[a+480228>>2]=p[f>>2]}p[a+480232>>2]=36;if(!(!j|19763<=(q[i|0]|q[i+1|0]<<8))){p[a+480232>>2]=64}o[a+480188>>1]=4;j=ct(d+120|0);f=0;while(1){p[114610]=0;g=(f<<5)+a|0;k=g+480280|0;S(432,k|0);h=p[114610];p[114610]=0;if((h|0)==1){break S}h=d+f|0;m=q[h+272|0];if(q[h+272|0]!=255){o[a+480188>>1]=f+1;o[g+480284>>1]=m&8?204:51}if(n[h+272|0]<=-1){p[k>>2]=1024}if(((m&127)+ -16&255)>>>0<=13){o[g+480284>>1]=128;uj(d+32|0,j,f);Zd(d+32|0,1)}f=f+1|0;if((f|0)!=32){continue}break}if(!r[a+480188>>1]){o[a+480188>>1]=1}f=Ob(a+484360|0);g=q[d+240|0]|q[d+241|0]<<8;p[114610]=0;Z(584,f|0,b|0,g|0,255,254)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}x=Ct(d+176|0);f=q[d+242|0]|q[d+243|0]<<8;p[114610]=0;P(393,b|0,x|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}m=Ct(d+128|0);f=q[d+244|0]|q[d+245|0]<<8;p[114610]=0;P(393,b|0,m|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){if(q[d+261|0]==252){f=0;p[114610]=0;J(1e3,b|0,d+32|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break g}while(1){h=(d+32|0)+f|0;g=q[h|0];aa:{if(!(g&32)){break aa}k=((f<<5)+a|0)+480284|0;if(e){uj(d+16|0,j,f);if(tb(d+16|0)){break aa}g=q[h|0]}o[k>>1]=(((g&15)<<8|8)>>>0)/15}f=f+1|0;if((f|0)!=32){continue}break}}e=q[d+242|0]|q[d+243|0]<<8;p[114610]=0;o[d+32>>1]=e;o[d+16>>1]=3999;e=J(477,d+32|0,d+16|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break R}e=r[e>>1];o[a+480190>>1]=e;if(e){e=c&2;g=d+45|0;j=d+80|0;f=0;while(1){h=kc(x,f);h=q[h|0]|q[h+1|0]<<8;p[114610]=0;h=J(256,b|0,h<<4)|0;k=p[114610];p[114610]=0;if((k|0)==1){break Q}ba:{if(!h){break ba}p[114610]=0;h=J(1001,b|0,d+32|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break Q}if(!h){break ba}p[114610]=0;h=f+1|0;k=(v(h,104)+a|0)+484380|0;K(1002,d+32|0,k|0);s=p[114610];p[114610]=0;if((s|0)==1){break Q}p[114610]=0;N(580,d|0,1,j|0);s=p[114610];p[114610]=0;ca:{da:{ea:{if((s|0)==1){break ea}p[114610]=0;K(415,d+16|0,d|0);s=p[114610];p[114610]=0;if((s|0)==1){break ea}p[114610]=0;J(369,((h<<5)+a|0)+946300|0,d+16|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break da}pb(d+16|0);if(!(q[d+48|0]|q[d+49|0]<<8|(q[d+50|0]<<16|q[d+51|0]<<24))|(!e|q[d+32|0]>1)){break ba}h=q[d+46|0];s=q[d+47|0];w=q[g|0];p[114610]=0;h=J(256,b|0,s<<12|h<<4|w<<20)|0;s=p[114610];p[114610]=0;if((s|0)==1){break ca}if(!h){break ba}h=q[d+250|0]|q[d+251|0]<<8;p[114610]=0;N(1003,d+16|0,d+32|0,(h|0)==1|0);h=p[114610];p[114610]=0;if((h|0)!=1){p[114610]=0;P(400,d+16|0,k|0,b|0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){break ba}}f=I()|0;H()|0;break f}f=I()|0;H()|0;break f}f=I()|0;H()|0;pb(d+16|0);break f}f=I()|0;H()|0;break f}f=f+1|0;if(f>>>0<r[a+480190>>1]){continue}break}}z=1;if(!(c&1)){break L}c=q[i|0]|q[i+1|0]<<8;e=q[d+244|0]|q[d+245|0]<<8;p[114610]=0;o[d+32>>1]=e;o[d+16>>1]=255;e=J(477,d+32|0,d+16|0)|0;f=p[114610];p[114610]=0;fa:{ga:{if((f|0)!=1){y=r[e>>1];p[114610]=0;k=a+484344|0;K(401,k|0,y|0);e=p[114610];p[114610]=0;if((e|0)==1){break ga}A=c>>>0<4896;if(y){break fa}s=0;w=0;break M}f=I()|0;H()|0;break f}f=I()|0;H()|0;break f}D=d+32|5;F=d+32|3;B=d+32|4;G=d+32|2;O=d+32|1;j=0;w=0;s=0;while(1){p[114610]=0;c=P(402,k|0,j&65535,64)|0;e=p[114610];p[114610]=0;if((e|0)==1){break P}ha:{if(!c){break ha}c=kc(m,j);if(!(q[c|0]|q[c+1|0]<<8)){break ha}c=kc(m,j);c=q[c|0]|q[c+1|0]<<8;p[114610]=0;c=J(256,b|0,c<<4)|0;e=p[114610];p[114610]=0;if((e|0)==1){break P}if(!c){break ha}p[114610]=0;J(338,b|0,2)|0;c=p[114610];p[114610]=0;if((c|0)==1){break P}f=0;c=Rb(k,j);p[114610]=0;g=J(497,c|0,0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break O}while(1){p[114610]=0;u=M(387,b|0)|0;c=p[114610];p[114610]=0;ia:{ja:{if((c|0)!=1){if(u){break ja}if(f>>>0>62){break ha}c=Rb(k,j);p[114610]=0;f=f+1|0;g=J(497,c|0,f|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break ia}}f=I()|0;H()|0;break f}ch(d+32|0);e=u&31;c=v(e,6)+g|0;h=r[a+480188>>1]>e>>>0;C=h?c:d+32|0;if(u&32){p[114610]=0;K(472,d+16|0,b|0);e=p[114610];p[114610]=0;ka:{la:{ma:{if((e|0)!=1){t=Zc(d+16|0);e=q[d+16|0];if(e>>>0>239){break ma}e=(v(e>>>4|0,12)+(e&15)|0)+13|0;break la}f=I()|0;H()|0;break f}na:{switch(e+ -254|0){case 0:break la;case 1:break na;default:break ka}}e=0}n[C|0]=e}n[(h?c+1|0:O)|0]=q[t|0]}oa:{if(!(u&64)){break oa}p[114610]=0;e=M(387,b|0)|0;t=p[114610];p[114610]=0;pa:{if((t|0)!=1){t=h?c+2|0:G;n[d+16|0]=e;if(e<<24>>24>-1|e>>>0>192){break pa}n[t|0]=2;n[(h?c+4|0:B)|0]=q[d+16|0]^128;break oa}f=I()|0;H()|0;break f}n[t|0]=1;p[114610]=0;n[d|0]=64;e=J(391,d+16|0,d|0)|0;t=p[114610];p[114610]=0;if((t|0)==1){break N}n[(h?c+4|0:B)|0]=q[e|0]}if(!(u&128)){break ia}p[114610]=0;K(472,d+16|0,b|0);e=p[114610];p[114610]=0;qa:{if((e|0)!=1){t=Zc(d+16|0);u=h?c+3|0:F;n[u|0]=q[d+16|0];e=h?c+5|0:D;n[e|0]=q[t|0];py(C,0);ra:{c=q[u|0];if((c|0)==20){if((q[e|0]&240)!=160){break ia}if((q[i|0]|q[i+1|0]<<8)>>>0<4896){break ra}c=q[u|0]}if((c|0)!=31){break ia}c=q[e|0];if(c>>>0<=15){break qa}A=0;break ia}n[e|0]=q[e|0]&15^136;break ia}f=I()|0;H()|0;break f}if(c>>>0<=7){w=w+1|0;break ia}s=((c|0)!=8)+s|0}if(f>>>0<64){continue}break}}j=j+1|0;if((y|0)!=(j|0)){continue}break}break M}f=I()|0;H()|0;break f}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}f=I()|0;H()|0;break a}f=I()|0;H()|0;break f}f=I()|0;H()|0;break f}f=I()|0;H()|0;break f}f=I()|0;H()|0;break f}f=I()|0;H()|0;break f}if(!A){break L}a=r[a+480188>>1];if((s+w|0)<(a|0)|(s-w|0)>=(a|0)){break L}hza(k,ke(k)+ -1&65535)}tk(m);tk(x);pb(l)}fb=d+304|0;return z|0}f=I()|0;H()|0}tk(m);break d}f=I()|0;H()|0}tk(x);break a}f=I()|0;H()|0;break a}f=I()|0;H()|0}pb(l);L(f|0);E()}function TLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0;e=fb-288|0;fb=e;Ac(b);a:{if(ES(b,12222)){t=Lb(e+272|0);p[114610]=0;f=P(430,b|0,t|0,-1)|0;i=p[114610];p[114610]=0;b:{c:{d:{e:{f:{g:{h:{if((i|0)!=1){if(!f){break b}p[114610]=0;f=J(445,b|0,e+264|0)|0;i=p[114610];p[114610]=0;i:{if((i|0)==1){break i}if(!f){break b}if(!CS(e+264|0)){break b}d=BS(e+264|0);p[114610]=0;d=rg(446,d,ib);f=p[114610];p[114610]=0;if((f|0)==1){break i}p[114610]=0;f=J(258,b|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break i}d=0;if(!f){break b}if(!c){break c}p[114610]=0;K(447,a|0,4096);d=p[114610];p[114610]=0;if((d|0)==1){break i}p[114610]=0;J(448,a+1304400|0,t|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break i}d=q[e+264|2];o[a+480188>>1]=32;o[a+480192>>1]=d;p[114610]=0;K(449,a|0,1);d=p[114610];p[114610]=0;if((d|0)==1){break i}p[114610]=0;d=J(2,e+96|0,12230)|0;f=p[114610];p[114610]=0;j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((f|0)!=1){xb(a+1304436|0,d);pb(d);p[114610]=0;d=J(2,e+96|0,12194)|0;f=p[114610];p[114610]=0;if((f|0)==1){break t}xb(a+1304448|0,d);pb(d);p[114610]=0;d=J(2,e+248|0,12244)|0;f=p[114610];p[114610]=0;if((f|0)==1){break s}p[114610]=0;K(219,e+48|0,d|0);f=p[114610];p[114610]=0;if((f|0)==1){break r}n[e+216|0]=q[e+264|1];f=q[e+264|0];p[114610]=0;n[e+8|0]=f;K(450,e+232|0,e+8|0);f=p[114610];p[114610]=0;if((f|0)==1){break q}p[114610]=0;Q(451,e+96|0,e+48|0,e+216|0,e+232|0);f=p[114610];p[114610]=0;if((f|0)==1){break p}xb(a+1304460|0,e+96|0);pb(e+96|0);pb(e+232|0);yb(e+48|0);pb(d);p[a+1304496>>2]=4;if(q[e+264|0]<2){break k}p[114610]=0;o[e+96>>1]=8192;d=M(357,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break m}p[114610]=0;o[e+48>>1]=d;d=J(452,e+96|0,e+48|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break m}p[a+480204>>2]=v(r[d>>1],1e4)>>>8;p[114610]=0;n[e+96|0]=1;d=M(387,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break l}p[114610]=0;n[e+48|0]=d;d=J(453,e+96|0,e+48|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break l}p[a+480196>>2]=q[d|0];p[114610]=0;J(338,b|0,3)|0;d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;d=M(357,b|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){break j}}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break n}b=I()|0;H()|0;break o}b=I()|0;H()|0;pb(e+232|0)}yb(e+48|0)}pb(d);break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}p[114610]=0;n[e+96|0]=32;d=M(387,b|0)|0;f=p[114610];p[114610]=0;u:{v:{if((f|0)==1){break v}p[114610]=0;n[e+48|0]=d;d=J(453,e+96|0,e+48|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break v}p[a+480204>>2]=v(q[d|0],1e4);p[114610]=0;n[e+96|0]=1;d=M(387,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break u}p[114610]=0;n[e+48|0]=d;d=J(453,e+96|0,e+48|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break u}p[a+480196>>2]=q[d|0];p[114610]=0;d=M(387,b|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){break j}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}p[a+480208>>2]=d>>>2&16|12;s=wn(e+232|0);m=wn(e+216|0);w:{x:{if(!r[a+480192>>1]){break x}i=e+80|1;u=e+96|12;j=1;while(1){p[114610]=0;f=P(454,a|0,j&65535,0)|0;d=p[114610];p[114610]=0;y:{z:{A:{if((d|0)==1){break A}if(!f){break x}p[114610]=0;d=P(431,b|0,f+492|0,-1)|0;h=p[114610];p[114610]=0;if((h|0)==1){break A}if(!d){break x}p[114610]=0;h=M(387,b|0)|0;d=p[114610];p[114610]=0;B:{C:{D:{E:{if((d|0)!=1){Jb(e+96|0,0,120);if(!h){break y}if(q[e+264|0]){p[114610]=0;d=J(455,b|0,e+96|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break E}if(!d){break y}}if(!q[e+264|0]){p[114610]=0;d=P(261,b|0,u|0,96)|0;g=p[114610];p[114610]=0;if((g|0)==1){break E}if(!d){break y}}g=f+236|0;d=0;while(1){l=q[(e+96|0)+d|0];k=r[a+480190>>1];x=Yc(g,d),y=(k+l|0)+1|0,o[x>>1]=y;d=d+1|0;if((d|0)!=120){continue}break}p[114610]=0;d=f+48|0;N(456,e+8|0,d|0,b|0);g=p[114610];p[114610]=0;if((g|0)==1){break D}p[114610]=0;g=f+68|0;N(456,e+32|0,g|0,b|0);l=p[114610];p[114610]=0;if((l|0)==1){break D}p[114610]=0;l=f+88|0;N(456,e+88|0,l|0,b|0);k=p[114610];p[114610]=0;if((k|0)==1){break D}p[114610]=0;J(457,b|0,e+80|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break C}p[f>>2]=(q[i|0]|q[i+1|0]<<8)&4095;f=q[i|0]|q[i+1|0]<<8;_z(e+80|0,d,0);_z(e+80|0,g,1);_z(e+80|0,l,2);x=e,y=Ub(d),p[x+48>>2]=y;x=e,y=Vb(d),p[x+72>>2]=y;if(Ab(e+48|0,e+72|0)){break B}break z}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}while(1){F:{d=p[e+48>>2];n[e+68|0]=64;k=q[d+2|0];p[114610]=0;n[e+71|0]=((k<<6)- -64>>>0)/127;k=J(391,e+68|0,e+71|0)|0;w=p[114610];p[114610]=0;if((w|0)==1){break F}n[d+2|0]=q[k|0];Rd(e+48|0);if(Ab(e+48|0,e+72|0)){continue}break z}break}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}x=e,y=Ub(g),p[x+48>>2]=y;x=e,y=Vb(g),p[x+72>>2]=y;G:{if(!Ab(e+48|0,e+72|0)){break G}while(1){H:{d=p[e+48>>2];n[e+68|0]=64;g=q[d+2|0];p[114610]=0;n[e+71|0]=((g<<6)+128>>>0)/255;g=J(391,e+68|0,e+71|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break H}n[d+2|0]=q[g|0];Rd(e+48|0);if(Ab(e+48|0,e+72|0)){continue}break G}break}b=I()|0;H()|0;break e}x=e,y=Ub(l),p[x+48>>2]=y;x=e,y=Vb(l),p[x+72>>2]=y;if(Ab(e+48|0,e+72|0)){l=1<<(f>>>12&3)&65535;while(1){k=p[e+48>>2];d=n[k+2|0];f=NNa(d^-128,d>>31^-1,l,0);g=ib;d=g;I:{if((d|0)>-1?1:(d|0)>=-1?f>>>0>=4294967292:0){p[114610]=0;f=f+4|0;if(f>>>0<4){d=d+1|0}f=rg(458,((d&7)<<29|f>>>3)&536870911,0);d=p[114610];p[114610]=0;if((d|0)!=1){break I}break f}p[114610]=0;d=d+ -1|0;f=f+ -3|0;if(f>>>0<4294967293){d=d+1|0}f=rg(458,ONa(f,d,8,0),ib);d=p[114610];p[114610]=0;if((d|0)==1){break f}}n[k+2|0]=f^128;Rd(e+48|0);if(Ab(e+48|0,e+72|0)){continue}break}}d=r[a+480190>>1]+1|0;o[e+68>>1]=d;J:{K:{L:{M:{g=d&65535;if(g>>>0<=3999){f=0;d=0;while(1){p[114610]=0;P(431,b|0,((g<<5)+a|0)+946300|0,-1)|0;g=p[114610];p[114610]=0;if((g|0)==1){break M}p[114610]=0;J(459,b|0,e+48|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break L}p[114610]=0;K(460,e+48|0,(v(r[e+68>>1]+d|0,104)+a|0)+484380|0);d=p[114610];p[114610]=0;if((d|0)==1){break L}d=q[e+80|0];g=q[e+67|0];p[114610]=0;o[e+72>>1]=d|f<<8&32512|((g&3)!=0)<<15;K(461,m|0,e+72|0);d=p[114610];p[114610]=0;if((d|0)==1){break K}f=f+1|0;d=f&65535;if(d>>>0>=h>>>0){break J}g=r[e+68>>1]+d|0;if(g>>>0<=3999){continue}break}}p[114610]=0;J(338,b|0,20)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break J}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}p[114610]=0;K(461,s|0,e+68|0);d=p[114610];p[114610]=0;if((d|0)==1){break g}p[e+48>>2]=3999;d=r[a+480190>>1];p[114610]=0;p[e+72>>2]=d+h;d=J(462,e+48|0,e+72|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break w}o[a+480190>>1]=p[d>>2]}j=j+1|0;if((j&65535)>>>0<=r[a+480192>>1]){continue}break}}p[114610]=0;f=M(387,b|0)|0;d=p[114610];p[114610]=0;N:{if((d|0)!=1){if(!f){break h}d=Lb(e+96|0);p[114610]=0;P(463,b|0,d|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break N}p[114610]=0;N(13,e+48|0,6,d|0);f=p[114610];p[114610]=0;if((f|0)==1){break N}xb(a+1304412|0,e+48|0);pb(e+48|0);pb(d);break h}b=I()|0;H()|0;break e}b=I()|0;H()|0;pb(d);break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}f=0;O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{while(1){p[114610]=0;d=(f<<5)+a|0;S(432,d+480280|0);i=p[114610];p[114610]=0;if((i|0)==1){break Y}p[114610]=0;P(433,b|0,d+480289|0,-1)|0;d=p[114610];p[114610]=0;if((d|0)==1){break Y}f=f+1|0;if((f|0)!=32){continue}break}p[114610]=0;d=J(464,b|0,e+32|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break V}if(!d){break S}if((q[e+32|0]|q[e+33|0]<<8|(q[e+34|0]<<16|q[e+35|0]<<24))>>>0<12){break W}d=q[e+32|0]|q[e+33|0]<<8|(q[e+34|0]<<16|q[e+35|0]<<24);p[114610]=0;d=J(258,b|0,d+ -11|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break V}if(d){break X}break W}b=I()|0;H()|0;break e}d=q[e+32|0]|q[e+33|0]<<8|(q[e+34|0]<<16|q[e+35|0]<<24);j=Yt(e+96|0);p[114610]=0;h=d+ -11|0;P(436,b|0,j|0,h|0)|0;d=p[114610];p[114610]=0;Z:{if((d|0)!=1){i=Lb(e+48|0);d=e+32|4;d=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);p[114610]=0;K(111,i|0,d|0);d=p[114610];p[114610]=0;if((d|0)!=1){_:{if(h){d=0;while(1){$:{g=q[oc(j,d)|0];f=d+1|0;if(!((g|0)!=255|h-f>>>0<2)){f=n[oc(j,f)|0];g=q[oc(j,d+2|0)|0];x=e,y=jf(i),p[x+8>>2]=y;Ld(e+24|0,e+8|0);p[114610]=0;U(437,i|0,p[e+24>>2],g|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){f=d+3|0;break $}break _}p[114610]=0;K(110,i|0,g<<24>>24);d=p[114610];p[114610]=0;if((d|0)!=1){break $}break _}d=f;if(d>>>0<h>>>0){continue}break}}p[114610]=0;Q(438,e+8|0,4,6,i|0);d=p[114610];p[114610]=0;if((d|0)!=1){aa:{xb(i,e+8|0);pb(e+8|0);d=Ib(i);p[114610]=0;d=M(439,d|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break aa}f=wb(i);p[114610]=0;Z(440,a+1304424|0,d|0,f|0,74,0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break aa}pb(i);Xd(j);break W}}}}b=I()|0;H()|0;pb(i);break Z}b=I()|0;H()|0}Xd(j);break e}d=Ob(a+484360|0);f=e+264|5;f=q[f|0]|q[f+1|0]<<8;p[114610]=0;Z(441,d|0,b|0,f|0,65535,65535)|0;d=p[114610];p[114610]=0;if((d|0)==1){break V}j=c&1;if(j){d=e+264|3;d=q[d|0]|q[d+1|0]<<8;p[114610]=0;K(401,a+484344|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break V}}d=e+264|3;ba:{if(!(q[d|0]|q[d+1|0]<<8)){break ba}i=a+484344|0;f=0;while(1){p[114610]=0;h=J(258,b|0,4)|0;g=p[114610];p[114610]=0;ca:{if((g|0)!=1){if(h){break ca}break ba}b=I()|0;H()|0;break e}p[114610]=0;h=M(390,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break P}p[114610]=0;N(341,e+96|0,b|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break Q}da:{if(!j){break da}p[114610]=0;h=M(387,e+96|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break O}p[114610]=0;J(338,e+96|0,1)|0;g=p[114610];p[114610]=0;if((g|0)==1){break O}p[114610]=0;h=P(402,i|0,f&65535,h+1|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break O}if(!h){break da}p[114610]=0;P(434,e+96|0,e+48|0,-1)|0;h=p[114610];p[114610]=0;if((h|0)==1){break O}h=Rb(i,f);p[114610]=0;J(435,h|0,e+48|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break O}h=Rb(i,f);p[114610]=0;N(443,h|0,1,e+96|0);h=p[114610];p[114610]=0;if((h|0)==1){break O}}sb(e+96|0);f=f+1|0;if(f>>>0<(q[d|0]|q[d+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break S}if(!r[a+480190>>1]){break T}d=0;while(1){c=d+1|0;if(!q[kc(m,d)|0]){c=d+1|0;f=v(c,104)+a|0;d=Tc(e+96|0,o[f+484414>>1]&1?16:8,1,0,o[kc(m,d)>>1]>-1?0:6);p[114610]=0;P(400,d|0,f+484380|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break U}}d=c;if(d>>>0<r[a+480190>>1]){continue}break}break T}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}if(!r[a+480190>>1]){break S}b=0;while(1){c=q[kc(m,b)|0];ea:{if(!c){break ea}c=c+ -1&65535;if(fc(s)>>>0<=c>>>0){break ea}c=(q[kc(m,b)+1|0]&127)+r[kc(s,c)>>1]&65535;if(c>>>0>r[a+480190>>1]){break ea}f=v(c,104);i=f+a|0;d=i+484380|0;if(!ue(d)){break ea}j=a+484380|0;h=v(b+1|0,104);c=j+h|0;o[c+34>>1]=r[c+34>>1]&65534|o[(f+j|0)+34>>1]&1;p[c>>2]=p[d>>2];p[114610]=0;c=M(465,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break R}if(!c){break ea}c=p[(a+h|0)+484400>>2];p[114610]=0;c=M(466,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}f=p[i+484400>>2];p[114610]=0;f=M(466,f|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break a}ac(c,f,sk(d))}b=b+1|0;if(b>>>0<r[a+480190>>1]){continue}break}}qf(m);qf(s);break c}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;sb(e+96|0);break e}b=I()|0;H()|0;break e}b=I()|0;H()|0}qf(m);qf(s)}pb(t);L(b|0);E()}d=1}pb(t)}fb=e+288|0;return d|0}a=O(0)|0;H()|0;rb(a);E()}function fd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;m=fb-16|0;fb=m;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(a>>>0<=244){e=p[115920];f=a>>>0<11?16:a+11&-8;a=f>>>3|0;b=e>>>a|0;if(b&3){c=a+((b^-1)&1)|0;f=c<<3;b=p[f+463728>>2];a=b+8|0;d=p[b+8>>2];f=f+463720|0;m:{if((d|0)==(f|0)){n=463680,o=SNa(-2,c)&e,p[n>>2]=o;break m}p[d+12>>2]=f;p[f+8>>2]=d}c=c<<3;p[b+4>>2]=c|3;b=b+c|0;p[b+4>>2]=p[b+4>>2]|1;break a}i=p[115922];if(f>>>0<=i>>>0){break l}if(b){c=2<<a;a=(0-c|c)&b<<a;a=(0-a&a)+ -1|0;b=a>>>12&16;c=b;a=a>>>b|0;b=a>>>5&8;c=c|b;a=a>>>b|0;b=a>>>2&4;c=c|b;a=a>>>b|0;b=a>>>1&2;c=c|b;a=a>>>b|0;b=a>>>1&1;c=(c|b)+(a>>>b|0)|0;d=c<<3;b=p[d+463728>>2];a=p[b+8>>2];d=d+463720|0;n:{if((a|0)==(d|0)){e=SNa(-2,c)&e;p[115920]=e;break n}p[a+12>>2]=d;p[d+8>>2]=a}a=b+8|0;p[b+4>>2]=f|3;g=b+f|0;c=c<<3;f=c-f|0;p[g+4>>2]=f|1;p[b+c>>2]=f;if(i){c=i>>>3|0;b=(c<<3)+463720|0;d=p[115925];c=1<<c;o:{if(!(c&e)){p[115920]=c|e;c=b;break o}c=p[b+8>>2]}p[b+8>>2]=d;p[c+12>>2]=d;p[d+12>>2]=b;p[d+8>>2]=c}p[115925]=g;p[115922]=f;break a}k=p[115921];if(!k){break l}a=(k&0-k)+ -1|0;b=a>>>12&16;c=b;a=a>>>b|0;b=a>>>5&8;c=c|b;a=a>>>b|0;b=a>>>2&4;c=c|b;a=a>>>b|0;b=a>>>1&2;c=c|b;a=a>>>b|0;b=a>>>1&1;b=p[((c|b)+(a>>>b|0)<<2)+463984>>2];g=(p[b+4>>2]&-8)-f|0;c=b;while(1){p:{a=p[c+16>>2];if(!a){a=p[c+20>>2];if(!a){break p}}d=(p[a+4>>2]&-8)-f|0;c=d>>>0<g>>>0;g=c?d:g;b=c?a:b;c=a;continue}break}l=b+f|0;if(l>>>0<=b>>>0){break k}j=p[b+24>>2];d=p[b+12>>2];if((d|0)!=(b|0)){a=p[b+8>>2];p[a+12>>2]=d;p[d+8>>2]=a;break b}c=b+20|0;a=p[c>>2];if(!a){a=p[b+16>>2];if(!a){break j}c=b+16|0}while(1){h=c;d=a;c=a+20|0;a=p[c>>2];if(a){continue}c=d+16|0;a=p[d+16>>2];if(a){continue}break}p[h>>2]=0;break b}f=-1;if(a>>>0>4294967231){break l}b=a+11|0;f=b&-8;i=p[115921];if(!i){break l}g=0-f|0;b=b>>>8|0;e=0;q:{if(!b){break q}e=31;if(f>>>0>16777215){break q}c=b+1048320>>>16&8;b=b<<c;a=b+520192>>>16&4;e=b<<a;b=e+245760>>>16&2;a=(e<<b>>>15|0)-(b|(a|c))|0;e=(a<<1|f>>>a+21&1)+28|0}c=p[(e<<2)+463984>>2];r:{s:{t:{if(!c){a=0;break t}a=0;b=f<<((e|0)==31?0:25-(e>>>1|0)|0);while(1){u:{h=(p[c+4>>2]&-8)-f|0;if(h>>>0>=g>>>0){break u}d=c;g=h;if(g){break u}g=0;a=c;break s}h=p[c+20>>2];c=p[((b>>>29&4)+c|0)+16>>2];a=h?(h|0)==(c|0)?a:h:a;b=b<<1;if(c){continue}break}}if(!(a|d)){a=2<<e;a=(0-a|a)&i;if(!a){break l}a=(a&0-a)+ -1|0;b=a>>>12&16;c=b;a=a>>>b|0;b=a>>>5&8;c=c|b;a=a>>>b|0;b=a>>>2&4;c=c|b;a=a>>>b|0;b=a>>>1&2;c=c|b;a=a>>>b|0;b=a>>>1&1;a=p[((c|b)+(a>>>b|0)<<2)+463984>>2]}if(!a){break r}}while(1){c=(p[a+4>>2]&-8)-f|0;b=c>>>0<g>>>0;g=b?c:g;d=b?a:d;b=p[a+16>>2];if(b){a=b}else{a=p[a+20>>2]}if(a){continue}break}}if(!d|g>>>0>=p[115922]-f>>>0){break l}e=d+f|0;if(e>>>0<=d>>>0){break k}j=p[d+24>>2];b=p[d+12>>2];if((d|0)!=(b|0)){a=p[d+8>>2];p[a+12>>2]=b;p[b+8>>2]=a;break c}c=d+20|0;a=p[c>>2];if(!a){a=p[d+16>>2];if(!a){break i}c=d+16|0}while(1){h=c;b=a;c=a+20|0;a=p[c>>2];if(a){continue}c=b+16|0;a=p[b+16>>2];if(a){continue}break}p[h>>2]=0;break c}b=p[115922];if(b>>>0>=f>>>0){a=p[115925];c=b-f|0;v:{if(c>>>0>=16){p[115922]=c;d=a+f|0;p[115925]=d;p[d+4>>2]=c|1;p[a+b>>2]=c;p[a+4>>2]=f|3;break v}p[115925]=0;p[115922]=0;p[a+4>>2]=b|3;b=a+b|0;p[b+4>>2]=p[b+4>>2]|1}a=a+8|0;break a}d=p[115923];if(d>>>0>f>>>0){b=d-f|0;p[115923]=b;a=p[115926];c=a+f|0;p[115926]=c;p[c+4>>2]=b|1;p[a+4>>2]=f|3;a=a+8|0;break a}a=0;g=f+47|0;c=g;if(p[116038]){b=p[116040]}else{p[116041]=-1;p[116042]=-1;p[116039]=4096;p[116040]=4096;p[116038]=m+12&-16^1431655768;p[116043]=0;p[116031]=0;b=4096}e=c+b|0;h=0-b|0;c=e&h;if(c>>>0<=f>>>0){break a}b=p[116030];if(b){i=p[116028];j=i+c|0;if(j>>>0<=i>>>0|j>>>0>b>>>0){break a}}if(q[464124]&4){break f}w:{x:{b=p[115926];if(b){a=464128;while(1){i=p[a>>2];if(i+p[a+4>>2]>>>0>b>>>0?i>>>0<=b>>>0:0){break x}a=p[a+8>>2];if(a){continue}break}}b=Jk(0);if((b|0)==-1){break g}e=c;a=p[116039];d=a+ -1|0;if(d&b){e=(c-b|0)+(b+d&0-a)|0}if(e>>>0<=f>>>0|e>>>0>2147483646){break g}a=p[116030];if(a){d=p[116028];h=d+e|0;if(h>>>0<=d>>>0|h>>>0>a>>>0){break g}}a=Jk(e);if((b|0)!=(a|0)){break w}break e}e=h&e-d;if(e>>>0>2147483646){break g}b=Jk(e);if((b|0)==(p[a>>2]+p[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|f+48>>>0<=e>>>0)){b=p[116040];b=b+(g-e|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Jk(b)|0)!=-1){e=b+e|0;b=a;break e}Jk(0-e|0);break g}b=a;if((a|0)!=-1){break e}break g}E()}d=0;break b}b=0;break c}if((b|0)!=-1){break e}}p[116031]=p[116031]|4}if(c>>>0>2147483646){break d}b=Jk(c);a=Jk(0);if(b>>>0>=a>>>0|(b|0)==-1|(a|0)==-1){break d}e=a-b|0;if(e>>>0<=f+40>>>0){break d}}a=p[116028]+e|0;p[116028]=a;if(a>>>0>s[116029]){p[116029]=a}y:{z:{A:{c=p[115926];if(c){a=464128;while(1){d=p[a>>2];g=p[a+4>>2];if((d+g|0)==(b|0)){break A}a=p[a+8>>2];if(a){continue}break}break z}a=p[115924];if(!(b>>>0>=a>>>0?a:0)){p[115924]=b}a=0;p[116033]=e;p[116032]=b;p[115928]=-1;p[115929]=p[116038];p[116035]=0;while(1){c=a<<3;d=c+463720|0;p[c+463728>>2]=d;p[c+463732>>2]=d;a=a+1|0;if((a|0)!=32){continue}break}a=e+ -40|0;c=b+8&7?-8-b&7:0;d=a-c|0;p[115923]=d;c=b+c|0;p[115926]=c;p[c+4>>2]=d|1;p[(a+b|0)+4>>2]=40;p[115927]=p[116042];break y}if(q[a+12|0]&8|b>>>0<=c>>>0|d>>>0>c>>>0){break z}p[a+4>>2]=e+g;a=c+8&7?-8-c&7:0;b=a+c|0;p[115926]=b;d=p[115923]+e|0;a=d-a|0;p[115923]=a;p[b+4>>2]=a|1;p[(c+d|0)+4>>2]=40;p[115927]=p[116042];break y}d=p[115924];if(b>>>0<d>>>0){p[115924]=b;d=0}g=b+e|0;a=464128;B:{C:{D:{E:{F:{G:{while(1){if((g|0)!=p[a>>2]){a=p[a+8>>2];if(a){continue}break G}break}if(!(q[a+12|0]&8)){break F}}a=464128;while(1){d=p[a>>2];if(d>>>0<=c>>>0){g=d+p[a+4>>2]|0;if(g>>>0>c>>>0){break E}}a=p[a+8>>2];continue}}p[a>>2]=b;p[a+4>>2]=p[a+4>>2]+e;j=(b+8&7?-8-b&7:0)+b|0;p[j+4>>2]=f|3;b=g+(g+8&7?-8-g&7:0)|0;a=(b-j|0)-f|0;h=f+j|0;if((b|0)==(c|0)){p[115926]=h;a=p[115923]+a|0;p[115923]=a;p[h+4>>2]=a|1;break C}if(p[115925]==(b|0)){p[115925]=h;a=p[115922]+a|0;p[115922]=a;p[h+4>>2]=a|1;p[a+h>>2]=a;break C}c=p[b+4>>2];if((c&3)==1){k=c&-8;H:{if(c>>>0<=255){f=c>>>3|0;c=p[b+8>>2];d=p[b+12>>2];if((d|0)==(c|0)){n=463680,o=p[115920]&SNa(-2,f),p[n>>2]=o;break H}p[c+12>>2]=d;p[d+8>>2]=c;break H}i=p[b+24>>2];e=p[b+12>>2];I:{if((e|0)!=(b|0)){c=p[b+8>>2];p[c+12>>2]=e;p[e+8>>2]=c;break I}J:{g=b+20|0;f=p[g>>2];if(f){break J}g=b+16|0;f=p[g>>2];if(f){break J}e=0;break I}while(1){c=g;e=f;g=e+20|0;f=p[g>>2];if(f){continue}g=e+16|0;f=p[e+16>>2];if(f){continue}break}p[c>>2]=0}if(!i){break H}c=p[b+28>>2];d=(c<<2)+463984|0;K:{if(p[d>>2]==(b|0)){p[d>>2]=e;if(e){break K}n=463684,o=p[115921]&SNa(-2,c),p[n>>2]=o;break H}p[i+(p[i+16>>2]==(b|0)?16:20)>>2]=e;if(!e){break H}}p[e+24>>2]=i;c=p[b+16>>2];if(c){p[e+16>>2]=c;p[c+24>>2]=e}c=p[b+20>>2];if(!c){break H}p[e+20>>2]=c;p[c+24>>2]=e}b=b+k|0;a=a+k|0}p[b+4>>2]=p[b+4>>2]&-2;p[h+4>>2]=a|1;p[a+h>>2]=a;if(a>>>0<=255){b=a>>>3|0;a=(b<<3)+463720|0;c=p[115920];b=1<<b;L:{if(!(c&b)){p[115920]=b|c;b=a;break L}b=p[a+8>>2]}p[a+8>>2]=h;p[b+12>>2]=h;p[h+12>>2]=a;p[h+8>>2]=b;break C}c=h;d=a>>>8|0;b=0;M:{if(!d){break M}b=31;if(a>>>0>16777215){break M}f=d+1048320>>>16&8;d=d<<f;b=d+520192>>>16&4;e=d<<b;d=e+245760>>>16&2;b=(e<<d>>>15|0)-(d|(b|f))|0;b=(b<<1|a>>>b+21&1)+28|0}p[c+28>>2]=b;p[h+16>>2]=0;p[h+20>>2]=0;c=(b<<2)+463984|0;d=p[115921];f=1<<b;N:{if(!(d&f)){p[115921]=d|f;p[c>>2]=h;break N}g=a<<((b|0)==31?0:25-(b>>>1|0)|0);b=p[c>>2];while(1){c=b;if((p[b+4>>2]&-8)==(a|0)){break D}b=g>>>29|0;g=g<<1;d=(b&4)+c|0;b=p[d+16>>2];if(b){continue}break}p[d+16>>2]=h}p[h+24>>2]=c;p[h+12>>2]=h;p[h+8>>2]=h;break C}a=e+ -40|0;d=b+8&7?-8-b&7:0;h=a-d|0;p[115923]=h;d=b+d|0;p[115926]=d;p[d+4>>2]=h|1;p[(a+b|0)+4>>2]=40;p[115927]=p[116042];a=(g+(g+ -39&7?39-g&7:0)|0)+ -47|0;d=a>>>0<c+16>>>0?c:a;p[d+4>>2]=27;a=p[116035];p[d+16>>2]=p[116034];p[d+20>>2]=a;a=p[116033];p[d+8>>2]=p[116032];p[d+12>>2]=a;p[116034]=d+8;p[116033]=e;p[116032]=b;p[116035]=0;a=d+24|0;while(1){p[a+4>>2]=7;b=a+8|0;a=a+4|0;if(g>>>0>b>>>0){continue}break}if((c|0)==(d|0)){break y}p[d+4>>2]=p[d+4>>2]&-2;e=d-c|0;p[c+4>>2]=e|1;p[d>>2]=e;if(e>>>0<=255){b=e>>>3|0;a=(b<<3)+463720|0;d=p[115920];b=1<<b;O:{if(!(d&b)){p[115920]=b|d;b=a;break O}b=p[a+8>>2]}p[a+8>>2]=c;p[b+12>>2]=c;p[c+12>>2]=a;p[c+8>>2]=b;break y}p[c+16>>2]=0;p[c+20>>2]=0;b=c;d=e>>>8|0;a=0;P:{if(!d){break P}a=31;if(e>>>0>16777215){break P}g=d+1048320>>>16&8;d=d<<g;a=d+520192>>>16&4;h=d<<a;d=h+245760>>>16&2;a=(h<<d>>>15|0)-(d|(a|g))|0;a=(a<<1|e>>>a+21&1)+28|0}p[b+28>>2]=a;b=(a<<2)+463984|0;d=p[115921];g=1<<a;Q:{if(!(d&g)){p[115921]=d|g;p[b>>2]=c;p[c+24>>2]=b;break Q}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);b=p[b>>2];while(1){d=b;if((e|0)==(p[b+4>>2]&-8)){break B}b=a>>>29|0;a=a<<1;g=d+(b&4)|0;b=p[g+16>>2];if(b){continue}break}p[g+16>>2]=c;p[c+24>>2]=d}p[c+12>>2]=c;p[c+8>>2]=c;break y}a=p[c+8>>2];p[a+12>>2]=h;p[c+8>>2]=h;p[h+24>>2]=0;p[h+12>>2]=c;p[h+8>>2]=a}a=j+8|0;break a}a=p[d+8>>2];p[a+12>>2]=c;p[d+8>>2]=c;p[c+24>>2]=0;p[c+12>>2]=d;p[c+8>>2]=a}a=p[115923];if(a>>>0<=f>>>0){break d}b=a-f|0;p[115923]=b;a=p[115926];c=a+f|0;p[115926]=c;p[c+4>>2]=b|1;p[a+4>>2]=f|3;a=a+8|0;break a}p[114584]=48;a=0;break a}R:{if(!j){break R}a=p[d+28>>2];c=(a<<2)+463984|0;S:{if(p[c>>2]==(d|0)){p[c>>2]=b;if(b){break S}i=SNa(-2,a)&i;p[115921]=i;break R}p[j+(p[j+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break R}}p[b+24>>2]=j;a=p[d+16>>2];if(a){p[b+16>>2]=a;p[a+24>>2]=b}a=p[d+20>>2];if(!a){break R}p[b+20>>2]=a;p[a+24>>2]=b}T:{if(g>>>0<=15){a=f+g|0;p[d+4>>2]=a|3;a=a+d|0;p[a+4>>2]=p[a+4>>2]|1;break T}p[d+4>>2]=f|3;p[e+4>>2]=g|1;p[e+g>>2]=g;if(g>>>0<=255){b=g>>>3|0;a=(b<<3)+463720|0;c=p[115920];b=1<<b;U:{if(!(c&b)){p[115920]=b|c;b=a;break U}b=p[a+8>>2]}p[a+8>>2]=e;p[b+12>>2]=e;p[e+12>>2]=a;p[e+8>>2]=b;break T}b=e;c=g>>>8|0;a=0;V:{if(!c){break V}a=31;if(g>>>0>16777215){break V}f=c+1048320>>>16&8;c=c<<f;a=c+520192>>>16&4;h=c<<a;c=h+245760>>>16&2;a=(h<<c>>>15|0)-(c|(a|f))|0;a=(a<<1|g>>>a+21&1)+28|0}p[b+28>>2]=a;p[e+16>>2]=0;p[e+20>>2]=0;b=(a<<2)+463984|0;W:{c=1<<a;X:{if(!(c&i)){p[115921]=c|i;p[b>>2]=e;break X}a=g<<((a|0)==31?0:25-(a>>>1|0)|0);f=p[b>>2];while(1){b=f;if((p[b+4>>2]&-8)==(g|0)){break W}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;f=p[c+16>>2];if(f){continue}break}p[c+16>>2]=e}p[e+24>>2]=b;p[e+12>>2]=e;p[e+8>>2]=e;break T}a=p[b+8>>2];p[a+12>>2]=e;p[b+8>>2]=e;p[e+24>>2]=0;p[e+12>>2]=b;p[e+8>>2]=a}a=d+8|0;break a}Y:{if(!j){break Y}a=p[b+28>>2];c=(a<<2)+463984|0;Z:{if(p[c>>2]==(b|0)){p[c>>2]=d;if(d){break Z}n=463684,o=SNa(-2,a)&k,p[n>>2]=o;break Y}p[j+(p[j+16>>2]==(b|0)?16:20)>>2]=d;if(!d){break Y}}p[d+24>>2]=j;a=p[b+16>>2];if(a){p[d+16>>2]=a;p[a+24>>2]=d}a=p[b+20>>2];if(!a){break Y}p[d+20>>2]=a;p[a+24>>2]=d}_:{if(g>>>0<=15){a=f+g|0;p[b+4>>2]=a|3;a=a+b|0;p[a+4>>2]=p[a+4>>2]|1;break _}p[b+4>>2]=f|3;p[l+4>>2]=g|1;p[g+l>>2]=g;if(i){c=i>>>3|0;a=(c<<3)+463720|0;d=p[115925];c=1<<c;$:{if(!(c&e)){p[115920]=c|e;c=a;break $}c=p[a+8>>2]}p[a+8>>2]=d;p[c+12>>2]=d;p[d+12>>2]=a;p[d+8>>2]=c}p[115925]=l;p[115922]=g}a=b+8|0}fb=m+16|0;return a|0}function Zla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0;d=fb-720|0;fb=d;Ac(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(!bf(b,d+712|0)){break D}if(!_I(d+712|0)){break D}if(!vp(b,d+704|0)){break D}if(!ZI(d+704|0)){break D}i=1313423693;f=q[d+704|0]|q[d+705|0]<<8|(q[d+706|0]<<16|q[d+707|0]<<24);if((f|0)!=1179012417){i=1414090313;if((f|0)!=538987841){break D}}l=rk(d+688|0,b);j=Vw(d+672|0);E:{F:{G:{H:{I:{J:{K:{L:{M:{if(!c){p[114610]=0;Q(1535,d+112|0,l|0,((f|0)==1179012417?1:2)|0,i|0);b=p[114610];p[114610]=0;if((b|0)!=1){break M}a=I()|0;H()|0;break a}p[114610]=0;N(1536,d+112|0,l|0,((f|0)==1179012417?1:2)|0);b=p[114610];p[114610]=0;if((b|0)==1){break L}}Ela(j,d+112|0);fl(d+112|0);p[114610]=0;N(1537,d+656|0,j|0,i|0);b=p[114610];p[114610]=0;if((b|0)!=1){p[114610]=0;b=M(337,d+656|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break G}g=0;if(!b){break E}p[114610]=0;b=J(1538,d+656|0,d+576|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break G}if(!b|!q[d+641|0]){break E}b=q[d+641|0];p[114610]=0;g=J(258,d+656|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break G}if(!c|g^1){break E}p[114610]=0;K(447,a|0,8388608);b=p[114610];p[114610]=0;if((b|0)==1){break G}p[a+480208>>2]=12;p[a+480208>>2]=p[a+480208>>2]&-17|(q[d+640|0]<<4^-1)&16;b=q[d+641|0];p[114610]=0;o[d+112>>1]=b;o[d+480>>1]=127;b=J(477,d+112|0,d+480|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break K}o[a+480188>>1]=r[b>>1];p[a+480196>>2]=q[d+642|0];p[a+480204>>2]=v(q[d+643|0],1e4);p[a+480200>>2]=q[d+648|0]<<1;p[114610]=0;J(238,a+1304436|0,((f|0)==1179012417?31651:31617)|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break G}p[114610]=0;b=J(2,d+112|0,31685)|0;g=p[114610];p[114610]=0;if((g|0)==1){break I}xb(a+1304448|0,b);pb(b);p[a+1304496>>2]=4;p[114610]=0;N(1539,d+480|0,2,d+576|0);b=p[114610];p[114610]=0;if((b|0)==1){break J}p[114610]=0;K(415,d+112|0,d+480|0);b=p[114610];p[114610]=0;if((b|0)==1){break J}xb(a+1304400|0,d+112|0);pb(d+112|0);if(!r[a+480188>>1]){break H}h=(f|0)==1179012417;b=0;while(1){p[114610]=0;i=(b<<5)+a|0;e=i+480280|0;S(432,e|0);g=p[114610];p[114610]=0;N:{O:{P:{Q:{R:{if((g|0)!=1){p[114610]=0;g=M(387,d+656|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break R}if(h){break Q}if(g>>>0<129){break P}break O}a=I()|0;H()|0;break b}a=I()|0;H()|0;break b}if(g<<24>>24<=-1){break O}p[114610]=0;p[d+112>>2]=g<<2;p[d+480>>2]=256;g=J(462,d+112|0,d+480|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){o[i+480284>>1]=p[g>>2];break N}a=I()|0;H()|0;break b}o[i+480284>>1]=g<<1;break N}p[e>>2]=1024}b=b+1|0;if(b>>>0<r[a+480188>>1]){continue}break}break H}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;break b}a=I()|0;H()|0;break b}p[114610]=0;b=J(1540,j|0,1380209231)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break F}}a=I()|0;H()|0;break b}if(b){p[114610]=0;N(1537,d+112|0,j|0,1380209231);b=p[114610];p[114610]=0;if((b|0)==1){break c}p[114610]=0;b=M(387,d+112|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break d}g=Ob(a+484360|0);p[114610]=0;Z(584,g|0,d+112|0,b+1&255,255,254)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}sb(d+112|0)}if(c&1){p[114610]=0;o[d+40>>1]=0;N(1541,d+480|0,j|0,1414807888);b=p[114610];p[114610]=0;if((b|0)==1){break e}b=gd(d+480|0);p[114610]=0;g=a+484344|0;K(401,g|0,b&65535);b=p[114610];p[114610]=0;if((b|0)==1){break k}m=d,s=Ub(d+480|0),p[m+544>>2]=s;m=d,s=Vb(d+480|0),p[m+64>>2]=s;if(Ab(d+544|0,d- -64|0)){i=(f|0)!=1179012417;while(1){b=Re(d+112|0,p[d+544>>2]);p[114610]=0;h=M(387,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break h}p[114610]=0;o[d+464>>1]=h;h=M(390,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}p[114610]=0;N(341,d+560|0,b|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break i}p[114610]=0;Q(1542,d+560|0,r[d+464>>1],i|0,a|0);h=p[114610];p[114610]=0;if((h|0)==1){break j}sb(d+560|0);p[114610]=0;h=J(452,d+40|0,d+464|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}o[d+40>>1]=r[h>>1];sb(b);Ff(d+544|0);if(Ab(d+544|0,d- -64|0)){continue}break}}if(r[d+40>>1]){b=0;while(1){p[114610]=0;i=b&65535;h=J(442,g|0,i|0)|0;e=p[114610];p[114610]=0;S:{if((e|0)!=1){if(h){break S}p[114610]=0;P(402,g|0,i|0,64)|0;i=p[114610];p[114610]=0;if((i|0)!=1){break S}}a=I()|0;H()|0;break f}b=b+1|0;if((b&65535)>>>0<r[d+40>>1]){continue}break}}$c(d+480|0)}T:{if((f|0)==1179012417){p[114610]=0;N(1541,d- -64|0,j|0,1414745673);b=p[114610];p[114610]=0;if((b|0)==1){break B}m=d,s=Ub(d- -64|0),p[m+96>>2]=s;m=d,s=Vb(d- -64|0),p[m+24>>2]=s;U:{if(Ab(d+96|0,d+24|0)){g=c&2;i=d+488|0;h=d+112|1;while(1){c=Re(d+544|0,p[d+96>>2]);p[114610]=0;b=J(1543,c|0,d+112|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break U}V:{if(!b){break V}b=q[h|0];if((b|0)==255){break V}p[114610]=0;b=P(454,a|0,b+1|0,0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break A}if(!b){break V}f=r[a+480190>>1];p[114610]=0;N(1544,d+112|0,b|0,f|0);b=p[114610];p[114610]=0;if((b|0)==1){break A}b=0;if(!q[d+142|0]){break V}while(1){W:{if(r[a+480190>>1]>3998){break W}p[114610]=0;f=J(1545,c|0,d+480|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break z}if(!f){break W}f=r[a+480190>>1]+1|0;o[a+480190>>1]=f;if((q[d+480|0]|q[d+481|0]<<8|(q[d+482|0]<<16|q[d+483|0]<<24))!=1347240275){break W}p[114610]=0;N(580,d+464|0,2,i|0);e=p[114610];p[114610]=0;X:{Y:{Z:{if((e|0)==1){break Z}p[114610]=0;K(415,d+40|0,d+464|0);e=p[114610];p[114610]=0;if((e|0)==1){break Z}p[114610]=0;f=f&65535;J(369,((f<<5)+a|0)+946300|0,d+40|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break Y}pb(d+40|0);p[114610]=0;f=(v(f,104)+a|0)+484380|0;N(1546,d+480|0,d+112|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break m}if(!g){break X}p[114610]=0;K(1547,d+40|0,d+480|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;P(400,d+40|0,f|0,c|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){break W}}a=I()|0;H()|0;break l}a=I()|0;H()|0;break l}a=I()|0;H()|0;pb(d+40|0);break l}f=sk(f);p[114610]=0;J(338,c|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break m}}b=b+1|0;if(b>>>0<q[d+142|0]){continue}break}}sb(c);Ff(d+96|0);if(Ab(d+96|0,d+24|0)){continue}break}}$c(d- -64|0);break T}a=I()|0;H()|0;break l}p[114610]=0;N(1541,d+464|0,j|0,1179011410);b=p[114610];p[114610]=0;if((b|0)==1){break y}m=d,s=Ub(d+464|0),p[m+456>>2]=s;m=d,s=Vb(d+464|0),p[m+448>>2]=s;if(Ab(d+456|0,d+448|0)){f=c&2;g=d+480|4;c=d+56|4;i=d+112|5;while(1){h=rk(d+544|0,p[d+456>>2]);p[114610]=0;b=M(390,d+544|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break x}_:{if((b|0)!=538986817){break _}p[114610]=0;b=J(1548,d+544|0,d+440|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break w}if(!b|(q[d+440|0]|q[d+441|0]<<8|(q[d+442|0]<<16|q[d+443|0]<<24))!=1414745673){break _}p[114610]=0;b=J(1549,d+544|0,d+112|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break v}if(!b){break _}b=q[i|0];if((b|0)==255){break _}p[114610]=0;b=P(454,a|0,b+1|0,0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break u}if(!b){break _}e=r[a+480190>>1];p[114610]=0;N(1550,d+112|0,b|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break u}p[114610]=0;N(1536,d+480|0,h|0,2);b=p[114610];p[114610]=0;if((b|0)==1){break C}p[114610]=0;N(1541,d+96|0,d+480|0,1179011410);b=p[114610];p[114610]=0;if((b|0)==1){break t}fl(d+480|0);m=d,s=Ub(d+96|0),p[m+88>>2]=s;m=d,s=Vb(d+96|0),p[m+80>>2]=s;$:{if(!Ab(d+88|0,d+80|0)){break $}aa:{while(1){b=Re(d- -64|0,p[d+88>>2]);p[114610]=0;h=M(390,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break s}ba:{if(!((h|0)!=538989377|r[a+480190>>1]>3998)){h=q[d+436|0]|q[d+437|0]<<8;e=h+ -1|0;n[d+436|0]=e;n[d+437|0]=e>>>8;if(!h){sb(b);break $}h=r[a+480190>>1]+1|0;o[a+480190>>1]=h;p[114610]=0;e=J(1548,b|0,d+56|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break r}ca:{if(!(!e|(q[d+56|0]|q[d+57|0]<<8|(q[d+58|0]<<16|q[d+59|0]<<24))!=1347240275)){e=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[114610]=0;N(341,d+40|0,b|0,e|0);e=p[114610];p[114610]=0;da:{if((e|0)!=1){p[114610]=0;e=J(1551,d+40|0,d+480|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break ba}if(!e){break aa}p[114610]=0;N(748,d+8|0,2,g|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)!=1){break da}}a=I()|0;H()|0;break p}a=I()|0;H()|0;break o}p[114610]=0;h=h&65535;J(369,((h<<5)+a|0)+946300|0,d+24|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break q}pb(d+24|0);p[114610]=0;h=(v(h,104)+a|0)+484380|0;N(1552,d+480|0,d+112|0,h|0);e=p[114610];p[114610]=0;if((e|0)==1){break ba}if(!f){break ca}e=q[d+480|0]|q[d+481|0]<<8|(q[d+482|0]<<16|q[d+483|0]<<24);p[114610]=0;J(256,d+40|0,e+4|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break ba}p[114610]=0;K(1553,d+24|0,d+480|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;P(400,d+24|0,h|0,d+40|0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){break ca}}a=I()|0;H()|0;break p}sb(b);break $}sb(d+40|0)}sb(b);Ff(d+88|0);if(Ab(d+88|0,d+80|0)){continue}break $}break}a=I()|0;H()|0;break p}sb(d+40|0);sb(b)}$c(d+96|0)}sb(d+544|0);Ff(d+456|0);if(Ab(d+456|0,d+448|0)){continue}break}}$c(d+464|0)}g=1}sb(d+656|0);fl(j);sb(l)}fb=d+720|0;return g|0}a=I()|0;H()|0;break n}a=I()|0;H()|0;break b}a=I()|0;H()|0;break l}a=I()|0;H()|0;break l}a=I()|0;H()|0;break b}a=I()|0;H()|0;break n}a=I()|0;H()|0;break n}a=I()|0;H()|0;break n}a=I()|0;H()|0;break n}a=I()|0;H()|0;fl(d+480|0);break n}a=I()|0;H()|0;break o}a=I()|0;H()|0;break o}a=I()|0;H()|0;pb(d+24|0)}sb(d+40|0)}sb(b);$c(d+96|0)}sb(d+544|0);$c(d+464|0);break b}a=I()|0;H()|0}sb(c);$c(d- -64|0);break b}a=I()|0;H()|0;break f}a=I()|0;H()|0;sb(d+560|0);break g}a=I()|0;H()|0;break g}a=I()|0;H()|0}sb(b)}$c(d+480|0);break b}a=I()|0;H()|0;break b}a=I()|0;H()|0;sb(d+112|0);break b}a=I()|0;H()|0}sb(d+656|0)}fl(j);sb(l);L(a|0);E()}function JT(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-32|0;fb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!a){break i}j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{if((b|0)<=1347628589){if((b|0)<=1297100333){if((b|0)<=1179931727){if((b|0)<=1145263149){if((b|0)==1095062094){break t}if((b|0)==1095126087){break q}if((b|0)!=1129524782|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+23|0]=i;e=1;break i}if((b|0)<=1179463213){if((b|0)==1145263150){break I}if((b|0)!=1145979182|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+18|0]=i;e=1;break i}if((b|0)==1179463214){break w}if((b|0)!=1179594286|c>>>0>4){break i}if(!Hb(d,c)){break i}h=a,i=yk(d,c),p[h>>2]=i;e=1;break i}if((b|0)<=1229345325){if((b|0)==1179931728){break j}if((b|0)==1196830254){break S}if((b|0)!=1229341486|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+21|0]=i;e=1;break i}if((b|0)<=1296182829){if((b|0)==1229345326){break F}if((b|0)!=1264266798|256<c>>>0){break i}a=a+236|0;ld(f+16|0,d,c);b=0;while(1){p[114610]=0;c=M(373,f+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break A}h=Yc(a,b),i=c,o[h>>1]=i;b=b+1|0;if(b>>>0<128){continue}break}sb(f+16|0);e=1;break i}if((b|0)==1296182830){break E}if((b|0)!=1296248366|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+31|0]=i;e=1;break i}if((b|0)<=1346720333){if((b|0)<=1313692461){if((b|0)==1297100334){break D}if((b|0)==1297110852){break o}if((b|0)!=1298747438|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+34|0]=i;e=1;break i}if((b|0)<=1345203757){if((b|0)==1313692462){break B}if((b|0)!=1313751342|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+16|0]=i;e=1;break i}if((b|0)==1345203758){break R}if((b|0)!=1346711086){break i}p[f+16>>2]=240;h=f,i=yk(d,c),p[h>>2]=i;Vf(a+68|0,p[Cb(f+16|0,f)>>2]);e=1;break i}if((b|0)<=1347179309){if((b|0)<=1346784326){if((b|0)==1346720334){break u}if((b|0)!=1346722606){break i}ld(f+16|0,d,c);p[114610]=0;a=J(374,a|0,1)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}if(Bb(a)){b=0;while(1){p[114610]=0;c=M(375,f+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}h=Fb(a,b),i=c,n[h+2|0]=i;b=b+1|0;if(b>>>0<Bb(a)>>>0){continue}break}}sb(f+16|0);e=1;break i}if((b|0)==1346784327){break r}if((b|0)!=1347175726|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+82|0]=i;e=1;break i}if((b|0)<=1347441453){if((b|0)==1347179310){break O}if((b|0)!=1347437358|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+27|0]=i;e=1;break i}if((b|0)==1347441454){break C}if((b|0)!=1347443502){break i}ld(f+16|0,d,c);p[114610]=0;a=J(374,a|0,1)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}if(Bb(a)){b=0;while(1){p[114610]=0;c=M(373,f+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}h=Fb(a,b),i=c,o[h>>1]=i;b=b+1|0;if(b>>>0<Bb(a)>>>0){continue}break}}sb(f+16|0);e=1;break i}if((b|0)<=1447374381){if((b|0)<=1349078084){if((b|0)<=1347831111){if((b|0)<=1347634477){if((b|0)==1347628590){break H}if((b|0)!=1347633710|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+83|0]=i;e=1;break i}if((b|0)==1347634478){break N}if((b|0)!=1347703884){break i}h=a,i=v(Lp(d,c),1e4)+(s[a+40>>2]%1e4|0)|0,p[h+40>>2]=i;e=1;break i}if((b|0)<=1349076269){if((b|0)==1347831112){break v}if((b|0)!=1347833672|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+36|0]=i;e=1;break i}if((b|0)==1349076270){break l}if((b|0)!=1349076315){break i}ld(f+16|0,d,c);p[114610]=0;a=J(374,a|0,2)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}if(Bb(a)){b=0;while(1){p[114610]=0;c=M(375,f+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}h=Fb(a,b),i=c,n[h+2|0]=i;b=b+1|0;if(b>>>0<Bb(a)>>>0){continue}break}}sb(f+16|0);e=1;break i}if((b|0)<=1349079873){if((b|0)==1349078085){break L}if((b|0)==1349078099){break M}if((b|0)!=1349079131){break i}ld(f+16|0,d,c);p[114610]=0;a=J(374,a|0,2)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}if(Bb(a)){b=0;while(1){p[114610]=0;c=M(373,f+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break d}h=Fb(a,b),i=c,o[h>>1]=i;b=b+1|0;if(b>>>0<Bb(a)>>>0){continue}break}}sb(f+16|0);e=1;break i}T:{switch(b+ -1349079874|0){case 3:break J;case 0:break K;case 1:case 2:break i;default:break T}}if((b|0)==1378758190){break n}if((b|0)!=1381183022|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+24|0]=i;e=1;break i}if((b|0)<=1448226349){if((b|0)<=1447447622){if((b|0)==1447374382){break m}if((b|0)==1447383630){break s}if((b|0)!=1447385902){break i}ld(f+16|0,d,c);p[114610]=0;a=J(374,a|0,0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}if(Bb(a)){b=0;while(1){p[114610]=0;c=M(375,f+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}h=Fb(a,b),i=c,n[h+2|0]=i;b=b+1|0;if(b>>>0<Bb(a)>>>0){continue}break}}sb(f+16|0);e=1;break i}if((b|0)<=1447842605){if((b|0)==1447447623){break p}if((b|0)!=1447839022|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+62|0]=i;e=1;break i}if((b|0)==1447842606){break Q}if((b|0)!=1448106798){break i}ld(f+16|0,d,c);p[114610]=0;a=J(374,a|0,0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}if(Bb(a)){b=0;while(1){p[114610]=0;c=M(373,f+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}h=Fb(a,b),i=c,o[h>>1]=i;b=b+1|0;if(b>>>0<Bb(a)>>>0){continue}break}}sb(f+16|0);e=1;break i}if((b|0)<=1448297773){if((b|0)==1448226350){break x}if((b|0)==1448291886){break G}if((b|0)!=1448297006|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+63|0]=i;e=1;break i}if((b|0)<=1718508333){if((b|0)==1448297774){break P}if((b|0)!=1682320942|c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+15|0]=i;e=1;break i}if((b|0)==1718508334){break y}if((b|0)!=1851469358|32<c>>>0){break i}b=a+492|0;ld(f+16|0,d,c);d=Lb(f);if(c){a=0;while(1){p[114610]=0;e=M(376,f+16|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break z}p[114610]=0;J(377,d|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break z}a=a+1|0;if((c|0)!=(a|0)){continue}break}}p[114610]=0;J(369,b|0,d|0)|0;a=p[114610];p[114610]=0;e=1;if((a|0)==1){break z}pb(d);sb(f+16|0);break i}if(c>>>0>4){break i}if(!Hb(d,c)){break i}h=a,i=yk(d,c),p[h+4>>2]=i;e=1;break i}if(c>>>0>4){break i}if(!Hb(d,c)){break i}h=a,i=yk(d,c),p[h+8>>2]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+61|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a- -64|0,i=ad(d,c),n[h|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+81|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+84|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+101|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+102|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+103|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+104|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+17|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+19|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+20|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+22|0]=i;e=1;break i}if(c>>>0>2){break i}if(!Hb(d,c)){break i}h=a,i=Lp(d,c),o[h+28>>1]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+30|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=GT(d,c),n[h+26|0]=i;e=1;break i}if(128<c>>>0){break i}a=a+108|0;ld(f+16|0,d,c);b=0;while(1){p[114610]=0;c=M(375,f+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break k}h=Yb(a,b),i=c,n[h|0]=i;b=b+1|0;if(b>>>0<128){continue}break}sb(f+16|0);e=1;break i}b=I()|0;H()|0;break a}b=I()|0;H()|0;pb(d);break a}if(32<c>>>0){break i}b=a+524|0;ld(f+16|0,d,c);d=Lb(f);if(c){a=0;while(1){p[114610]=0;e=M(376,f+16|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break h}p[114610]=0;J(377,d|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break h}a=a+1|0;if((c|0)!=(a|0)){continue}break}}p[114610]=0;J(369,b|0,d|0)|0;a=p[114610];p[114610]=0;e=1;if((a|0)!=1){pb(d);sb(f+16|0);break i}break h}if(c>>>0>2){break i}if(!Hb(d,c)){break i}h=a,i=Lp(d,c),o[h+12>>1]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+25|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+35|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+105|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+85|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+65|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+100|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+80|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=ad(d,c),n[h+60|0]=i;e=1;break i}if(c>>>0>1){break i}if(!Hb(d,c)){break i}h=a,i=GT(d,c),n[h+33|0]=i;e=1;break i}e=1;b=yk(d,c);if(!Kp(b)){break i}n[a+14|0]=b;break i}p[f+16>>2]=240;h=f,i=yk(d,c),p[h>>2]=i;Vf(a+48|0,p[Cb(f+16|0,f)>>2]);e=1;break i}p[f+16>>2]=240;h=f,i=yk(d,c),p[h>>2]=i;Vf(a+88|0,p[Cb(f+16|0,f)>>2]);e=1;break i}b=I()|0;H()|0;break a}b=Lp(d,c);c=a;a=p[a+40>>2];p[c+40>>2]=a-((a>>>0)%1e4|0)+(b>>>0)%1e4;e=1}fb=f+32|0;return e}b=I()|0;H()|0;pb(d);break a}b=I()|0;H()|0;break a}b=I()|0;H()|0;break a}b=I()|0;H()|0;break a}b=I()|0;H()|0;break a}b=I()|0;H()|0;break a}b=I()|0;H()|0}sb(f+16|0);L(b|0);E()}function $Ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,K=0;e=fb+ -64|0;fb=e;Ac(a);bf(a,e+56|0);a:{t=c+484344|0;d=e+56|2;A=sd(q[d|0]|q[d+1|0]<<8,1,1024);s=Kw(t,A,0);if((s|0)!=65535){d=Jp(Rb(t,s),0);o[e+8>>1]=r[c+480188>>1]+ -1;o[e+40>>1]=q[e+56|0];B=r[rf(e+8|0,e+40|0)>>1];f=B+1|0;if(r[c+480188>>1]>(f&65535)>>>0){g=f&65535;while(1){n[d+v(g,6)|0]=254;g=g+1|0;if(g>>>0<r[c+480188>>1]){continue}break}}n[b+13|0]=q[e+56|1]>>>4;d=q[b+12|0];n[e+8|0]=0;u=pt(e+40|0,f,e+8|0);if(A){g=(d|0)!=0;while(1){b:{c:{if(!q[oc(u,0)|0]){p[114610]=0;f=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}k=f<<24>>24;if((k|0)<=-1){p[114610]=0;f=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}G=oc(u,0),K=f,n[G|0]=K}C=0;n[e+8|0]=0;h=k&63;d:{e:{if(!h){break e}p[114610]=0;d=M(387,a|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}n[e+8|0]=d;k=0;f:{switch(h+ -1|0){case 0:n[b+12|0]=0;p[114610]=0;n[e+36|0]=1;f=J(453,e+36|0,e+8|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){n[b+14|0]=q[f|0];n[b+15|0]=0;g=1;break d}break a;case 1:if(!d){break d}n[b+15|0]=d;g=1;n[b+12|0]=1;f=q[b+13|0];if(!f){break e}n[b+14|0]=v(v(d,f),15);break e;case 2:d=d>>>4|0;n[b+13|0]=d;if(d){g=q[b+12|0]!=0;break d}n[b+12|0]=0;break d;case 3:k=d;break d;case 5:if(!d){break d}f=(q[b+12|0]?15:14)+b|0;k=q[f|0];n[f|0]=256-d>>>0>k>>>0?d+k|0:-1;g=1;break e;case 6:break f;default:break d}}if(!d){break d}g=1;f=(q[b+12|0]?15:14)+b|0;k=q[f|0];n[f|0]=d+1>>>0<k>>>0?k-d|0:1}k=0}p[e+36>>2]=0;p[e+32>>2]=0;if(g&1){break c}break b}k=0;d=oc(u,0);n[d|0]=q[d|0]+ -1;p[e+36>>2]=0;p[e+32>>2]=0;C=0;if(!(g&1)){break b}}d=q[b+12|0];f=q[b+13|0];if(f?0:d){break b}g:{if(d){p[e+8>>2]=1;d=q[b+15|0];p[114610]=0;p[e+28>>2]=v(d,f)<<1;f=J(555,e+8|0,e+28|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}f=p[f>>2];break g}f=v(q[b+14|0],30)+30|0}g=255;p[e+36>>2]=255;while(1){m=v(f,g);if(m+ -1536>>>0>=10752){d=g+ -1|0;p[e+36>>2]=d;h=g>>>0<2;g=d;if(!h){continue}}break}p[e+32>>2]=(m|0)/48;Vd(e+32|0,32,255);p[114610]=0;p[e+8>>2]=1;f=J(555,e+8|0,e+36|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[b+16|0]=p[f>>2];C=1}d=Rb(t,s);p[114610]=0;g=P(471,d|0,l|0,1)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(B){D=l+ -1|0;i=1;y=1;while(1){h:{if(!q[oc(u,i)|0]){p[114610]=0;x=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(x&128){p[114610]=0;f=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}G=oc(u,i),K=f,n[G|0]=K}F=1;if(x&64){p[114610]=0;f=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[g+1|0]=f;F=!f}i:{if(!(x&32)){break i}p[114610]=0;f=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[g|0]=f;if((f+ -1&255)>>>0<=107){d=up(f+24|0);n[g|0]=d;G=Fc(b,i),K=d,n[G+1|0]=K;break i}if((f+127&255)>>>0<=107){d=up((f&127)+24|0);n[g|0]=d;G=Fc(b,i),K=d,n[G|0]=K;n[g|0]=0;break i}if((f|0)!=255){break i}n[g|0]=254}if(!(q[g|0]|!q[g+1|0])){d=q[Fc(b,i)+1|0];n[g+1|0]=0;n[g|0]=d}p[114610]=0;f=M(556,g|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(f){G=Fc(b,i),K=0,n[G+5|0]=K}n[e+28|0]=0;n[e+27|0]=0;n[e+26|0]=0;n[e+25|0]=0;if(x&16){n[g+2|0]=1;p[114610]=0;f=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[g+4|0]=f+2>>>2}f=0;z=0;w=0;j:{if(!(x&8)){break j}p[114610]=0;j=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;w=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}k:{switch(j+ -1|0){case 0:n[g|0]=254;break j;case 1:n[g|0]=255;break j;case 2:G=g,K=q[Fc(b,i)+1|0],n[G|0]=K;G=Fc(b,i),K=0,n[G+5|0]=K;break j;case 3:d=ot(w,q[b+16|0]);w=d?d|-48:0;z=d?20:0;if(q[g|0]){break j}G=g,K=q[Fc(b,i)+1|0],n[G|0]=K;G=Fc(b,i),K=0,n[G+5|0]=K;break j;case 4:n[e+8|0]=1;d=ot(w,q[b+16|0]);p[114610]=0;n[e+24|0]=d;h=J(453,e+8|0,e+24|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){w=q[h|0];G=Fc(b,i),K=0,n[G+5|0]=K;z=15;break j}break a;case 5:case 6:case 7:case 8:l:{if(!l){break l}if((j|0)==q[Fc(b,i)+4|0]){break l}m=Rb(t,s);p[114610]=0;h=P(498,e+8|0,20,(j+122|160)&255)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}d=on(nn(Oe(h,D),y&65535));p[114610]=0;h=J(499,m|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(!h){break l}G=Fc(b,i),K=j,n[G+4|0]=K}if(!q[g|0]){G=g,K=q[Fc(b,i)+1|0],n[G|0]=K}G=Fc(b,i),K=0,n[G+5|0]=K;z=10;break j;case 9:break k;default:break j}}h=q[Fc(b,i)+5|0];d=q[Fc(b,i)+5|0];G=Fc(b,i),K=d^1,n[G+5|0]=K;w=h?-98:-97;z=20}m:{if(!(x&4)){break m}p[114610]=0;h=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;n[e+28|0]=h;j=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[e+26|0]=j;d=e;n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{h=q[e+28|0];switch(h+ -1|0){case 11:break p;case 10:break q;case 7:case 8:case 9:break r;case 6:break s;case 5:break t;case 3:case 4:break u;case 2:break v;case 1:break w;case 0:break x;default:break o}}n[e+28|0]=j<<24>>24>-1?2:3;if(j>>>0>=129){n[e+26|0]=0-j}p[114610]=0;n[e+8|0]=15;h=J(391,e+8|0,e+26|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){n[e+26|0]=q[h|0]|240;break m}break a}d=ot(j,q[b+16|0]);n[e+26|0]=d;if(d){n[e+28|0]=20;n[e+26|0]=d|208;f=1;break m}n[e+28|0]=0;f=1;break m}f=1;break n}d=q[b+16|0];p[114610]=0;f=P(557,j|0,d|0,1)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[e+26|0]=f;n[e+28|0]=q[e+28|0]==4?2:3;f=1;break m}if(!q[g|0]){G=g,K=q[Fc(b,i)|0],n[G|0]=K;j=q[e+26|0]}d=q[b+16|0];p[114610]=0;f=P(557,j&255,d|0,0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[e+28|0]=4;n[e+26|0]=f;f=1;break m}G=g,K=up(j+25|0),n[G|0]=K;n[e+26|0]=255;n[e+28|0]=4;f=1;break m}y:{if(!l){break y}if((h|0)==q[Fc(b,i)+2|0]){break y}h=Rb(t,s);p[114610]=0;f=P(498,e+8|0,20,(q[e+28|0]+ -8|48)&255)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}d=on(nn(Oe(f,D),y&65535));p[114610]=0;f=J(499,h|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(!f){break y}d=q[e+28|0];G=Fc(b,i),K=d,n[G+2|0]=K}n[e+28|0]=5;d=q[b+16|0];p[114610]=0;f=J(558,q[e+26|0],d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[e+26|0]=f;f=1;break m}d=BR(j,q[b+16|0]);n[e+28|0]=18;n[e+26|0]=d;f=1;break m}d=ot(j,q[b+16|0]);n[e+26|0]=d;if(d){n[e+28|0]=20;n[e+26|0]=d|192;f=1;break m}n[e+28|0]=0;n[g|0]=254;f=1;break m}f=0}n[d+28|0]=f}j=0;z:{if(!(x&2)){break z}p[114610]=0;h=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;n[e+27|0]=h;m=M(387,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[e+25|0]=m;A:{B:{C:{D:{E:{F:{G:{h=q[e+27|0];switch(h+ -1|0){case 9:break B;case 7:case 8:break C;case 6:break D;case 3:case 4:case 5:break E;case 2:break F;case 0:case 1:break G;default:break A}}d=q[b+16|0];p[114610]=0;h=P(559,m|0,d|0,(h|0)==1|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[e+27|0]=11;n[e+25|0]=h;j=1;break z}d=BR(m,q[b+16|0]);n[e+27|0]=18;n[e+25|0]=d;j=1;break z}H:{if(!l){break H}if((h|0)==q[Fc(b,i)+3|0]){break H}m=Rb(t,s);p[114610]=0;h=P(498,e+8|0,20,(q[e+27|0]+ -4|64)&255)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}d=on(nn(Oe(h,D),y&65535));p[114610]=0;h=J(499,m|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(!h){break H}d=q[e+27|0];G=Fc(b,i),K=d,n[G+3|0]=K}n[e+27|0]=8;d=q[b+16|0];p[114610]=0;h=J(558,q[e+25|0],d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[e+25|0]=h;j=1;break z}n[e+27|0]=9;break z}d=q[b+16|0];p[114610]=0;h=P(559,m|0,d|0,(h|0)==8|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[e+27|0]=29;n[e+25|0]=h;j=1;break z}n[e+27|0]=27;d=q[b+16|0];p[114610]=0;h=J(558,m|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[e+25|0]=h;j=1;break z}n[e+27|0]=0}if(f){AR(g,l,r[c+480188>>1],q[e+28|0],e+26|0)}if(j){AR(g,l,r[c+480188>>1],q[e+27|0],e+25|0)}I:{if(!F){break I}p[114610]=0;f=M(556,g|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(!f){break I}d=q[e+28|0];if(!d){n[e+26|0]=255;n[e+28|0]=4;break I}if(q[e+27|0]|(d|0)==4){break I}n[e+25|0]=255;n[e+27|0]=4}J:{if(q[g+2|0]!=1){break J}K:{if(!q[e+28|0]){n[e+28|0]=13;n[e+26|0]=q[g+4|0];break K}if(q[e+27|0]){break J}n[e+27|0]=13;n[e+25|0]=q[g+4|0]}n[g+2|0]=0}p[114610]=0;_(500,e+8|0,e+28|0,e+26|0,e+27|0,e+25|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}L:{if(q[g+2|0]){break L}d=q[e+28|0];if(!d){break L}n[g+2|0]=d;n[g+4|0]=q[e+26|0]}M:{if(z){n[g+3|0]=z;break M}d=q[e+27|0];if(!d){break h}n[g+3|0]=d;w=q[e+25|0]}n[g+5|0]=w;break h}d=oc(u,i);n[d|0]=q[d|0]+ -1}g=g+6|0;y=y+1|0;i=y&65535;if(i>>>0<=B>>>0){continue}break}}N:{if(!C){break N}g=Rb(t,s);p[114610]=0;f=P(498,e+8|0,17,q[e+32|0])|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}d=wi(nn(Oe(f,l),0));p[114610]=0;J(499,g|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}g=Rb(t,s);p[114610]=0;f=P(498,e+8|0,16,q[e+36|0])|0;d=p[114610];p[114610]=0;if((d|0)!=1){d=wi(Oe(f,l));p[114610]=0;J(499,g|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break N}}break a}O:{if(!(k&240)){break O}g=Rb(t,s);p[114610]=0;f=P(498,e+8|0,20,k>>>4|224)|0;d=p[114610];p[114610]=0;if((d|0)!=1){d=zR(Oe(f,l));p[114610]=0;J(499,g|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break O}}break a}P:{f=k&15;if(!f){break P}d=q[b+16|0];k=Rb(t,s);d=sd((v(d,f)>>>0)/15&255,1,15);p[114610]=0;f=P(498,e+8|0,20,d|96)|0;d=p[114610];p[114610]=0;if((d|0)!=1){d=zR(Oe(f,l));p[114610]=0;J(499,k|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break P}}break a}g=0;l=l+1|0;if((A|0)!=(l|0)){continue}break}}Xd(u)}fb=e- -64|0;return s|0}a=I()|0;H()|0;Xd(u);L(a|0);E()}function SD(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;n=fb-192|0;fb=n;A=h;H=i&65535;o=d;r=e&65535;D=(e^i)&-2147483648;k=i>>>16&32767;a:{u=e>>>16&32767;b:{c:{if(k+ -1>>>0<32766?u+ -1>>>0<=32765:0){break c}m=e&2147483647;j=m;l=d;if(!(!d&(j|0)==2147418112?!(b|c):(j|0)==2147418112&d>>>0<0|j>>>0<2147418112)){K=d;D=e|32768;break b}m=i&2147483647;e=m;d=h;if(!(!d&(e|0)==2147418112?!(f|g):(e|0)==2147418112&d>>>0<0|e>>>0<2147418112)){K=h;D=i|32768;b=f;c=g;break b}if(!(b|l|(j^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;D=2147450880;break b}D=D|2147418112;b=0;c=0;break b}if(!(d|f|(e^2147418112|g))){b=0;c=0;break b}if(!(b|l|(c|j))){break a}if(!(d|f|(e|g))){D=D|2147418112;b=0;c=0;break b}if((j|0)==65535|j>>>0<65535){i=b;d=!(o|r);h=d<<6;j=y(d?b:o)+32|0;b=y(d?c:r);b=h+((b|0)==32?j:b)|0;ef(n+176|0,i,c,o,r,b+ -15|0);I=16-b|0;o=p[n+184>>2];r=p[n+188>>2];c=p[n+180>>2];b=p[n+176>>2]}if(e>>>0>65535){break c}d=!(A|H);e=d<<6;h=y(d?f:A)+32|0;d=y(d?g:H);d=e+((d|0)==32?h:d)|0;ef(n+160|0,f,g,A,H,d+ -15|0);I=(d+I|0)+ -16|0;A=p[n+168>>2];H=p[n+172>>2];f=p[n+160>>2];g=p[n+164>>2]}e=H|65536;J=e;N=A;d=A;m=e<<15|d>>>17;d=d<<15|g>>>17;h=-102865788-d|0;e=m;j=e;i=1963258675-(j+(4192101508<d>>>0)|0)|0;oh(n+144|0,d,j,h,i);l=p[n+152>>2];oh(n+128|0,0-l|0,0-(p[n+156>>2]+(0<l>>>0)|0)|0,h,i);h=p[n+136>>2];i=h<<1|p[n+132>>2]>>>31;h=p[n+140>>2]<<1|h>>>31;oh(n+112|0,i,h,d,j);l=h;h=p[n+120>>2];oh(n+96|0,i,l,0-h|0,0-(p[n+124>>2]+(0<h>>>0)|0)|0);h=p[n+104>>2];i=h<<1|p[n+100>>2]>>>31;h=p[n+108>>2]<<1|h>>>31;oh(n+80|0,i,h,d,j);l=h;h=p[n+88>>2];oh(n- -64|0,i,l,0-h|0,0-(p[n+92>>2]+(0<h>>>0)|0)|0);h=p[n+72>>2];i=h<<1|p[n+68>>2]>>>31;h=p[n+76>>2]<<1|h>>>31;oh(n+48|0,i,h,d,j);l=h;h=p[n+56>>2];oh(n+32|0,i,l,0-h|0,0-(p[n+60>>2]+(0<h>>>0)|0)|0);h=p[n+40>>2];i=h<<1|p[n+36>>2]>>>31;h=p[n+44>>2]<<1|h>>>31;oh(n+16|0,i,h,d,j);j=h;h=p[n+24>>2];oh(n,i,j,0-h|0,0-(p[n+28>>2]+(0<h>>>0)|0)|0);I=(u-k|0)+I|0;h=p[n+8>>2];l=p[n+12>>2]<<1|h>>>31;i=h<<1;m=l+ -1|0;i=(p[n+4>>2]>>>31|i)+ -1|0;if((i|0)!=-1){m=m+1|0}h=i;l=0;B=l;q=e;k=0;w=NNa(h,l,e,k);e=ib;s=e;x=m;u=0;h=d;l=NNa(m,u,d,0);d=l+w|0;j=ib+e|0;e=d;j=d>>>0<l>>>0?j+1|0:j;l=0;m=(j|0)==(s|0)&e>>>0<w>>>0|j>>>0<s>>>0;w=NNa(q,k,x,u);k=w+j|0;j=ib+(l|m)|0;j=k>>>0<w>>>0?j+1|0:j;l=k;m=e;e=0;h=NNa(i,B,h,t);d=e+h|0;k=ib+m|0;k=d>>>0<h>>>0?k+1|0:k;w=d;h=d;d=k;e=(m|0)==(d|0)&h>>>0<e>>>0|d>>>0<m>>>0;h=l+e|0;if(h>>>0<e>>>0){j=j+1|0}C=h;h=j;e=g;z=(e&131071)<<15|f>>>17;q=NNa(i,B,z,0);e=ib;t=e;j=f;v=j<<15&-32768;j=NNa(x,u,v,0);l=j+q|0;k=ib+e|0;k=l>>>0<j>>>0?k+1|0:k;e=k;F=NNa(i,B,v,F);v=0+F|0;j=l;k=j+ib|0;k=v>>>0<F>>>0?k+1|0:k;k=(j|0)==(k|0)&v>>>0<G>>>0|k>>>0<j>>>0;j=(e|0)==(t|0)&j>>>0<q>>>0|e>>>0<t>>>0;l=e;e=NNa(x,u,z,E)+e|0;m=j+ib|0;m=e>>>0<l>>>0?m+1|0:m;j=e;e=k+j|0;l=m;l=e>>>0<j>>>0?l+1|0:l;m=e;e=w+e|0;j=l+d|0;j=e>>>0<m>>>0?j+1|0:j;k=h;s=j;d=(d|0)==(j|0)&e>>>0<w>>>0|j>>>0<d>>>0;h=d+C|0;if(h>>>0<d>>>0){k=k+1|0}j=k;d=(e|0)!=0|(s|0)!=0;h=h+d|0;if(h>>>0<d>>>0){j=j+1|0}m=h;h=0-h|0;q=0;w=NNa(h,q,i,B);d=ib;t=d;v=NNa(x,u,h,q);h=ib;C=h;z=0-((0<m>>>0)+j|0)|0;j=0;q=NNa(i,B,z,j);m=q+v|0;k=ib+h|0;k=m>>>0<q>>>0?k+1|0:k;h=m;l=h;q=0+w|0;m=d+l|0;m=q>>>0<E>>>0?m+1|0:m;l=q;d=m;m=(t|0)==(d|0)&l>>>0<w>>>0|d>>>0<t>>>0;l=(k|0)==(C|0)&h>>>0<v>>>0|k>>>0<C>>>0;h=NNa(x,u,z,j)+k|0;j=l+ib|0;j=h>>>0<k>>>0?j+1|0:j;l=h;h=m+l|0;if(h>>>0<l>>>0){j=j+1|0}z=h;h=j;m=q;l=0-((0<e>>>0)+s|0)|0;e=0-e|0;E=l;s=0;C=NNa(l,s,i,B);v=ib;t=e;F=0;l=NNa(e,F,x,u);e=l+C|0;k=ib+v|0;k=e>>>0<l>>>0?k+1|0:k;l=e;e=k;t=NNa(i,B,t,F);i=0+t|0;j=l;k=j+ib|0;k=i>>>0<t>>>0?k+1|0:k;k=(j|0)==(k|0)&i>>>0<G>>>0|k>>>0<j>>>0;j=(e|0)==(v|0)&j>>>0<C>>>0|e>>>0<v>>>0;i=e;e=NNa(E,s,x,u)+e|0;l=j+ib|0;l=e>>>0<i>>>0?l+1|0:l;i=e;e=k+e|0;j=l;j=e>>>0<i>>>0?j+1|0:j;i=e;e=e+m|0;j=j+d|0;j=e>>>0<i>>>0?j+1|0:j;i=e;k=h;e=j;d=(d|0)==(j|0)&i>>>0<m>>>0|j>>>0<d>>>0;h=d+z|0;if(h>>>0<d>>>0){k=k+1|0}d=h;j=k;k=d;m=e+ -1|0;d=i+ -2|0;if(d>>>0<4294967294){m=m+1|0}h=d;l=d;d=m;e=(e|0)==(d|0)&l>>>0<i>>>0|d>>>0<e>>>0;i=k+e|0;if(i>>>0<e>>>0){j=j+1|0}e=i+ -1|0;k=j+ -1|0;k=(e|0)!=-1?k+1|0:k;i=0;x=i;u=e;l=o;v=l<<2|c>>>30;z=0;s=NNa(e,i,v,z);i=ib;l=i;i=c;E=(i&1073741823)<<2|b>>>30;w=0;F=k;i=0;j=NNa(E,w,k,i);e=j+s|0;m=ib+l|0;m=e>>>0<j>>>0?m+1|0:m;j=e;q=m;t=(l|0)==(m|0)&j>>>0<s>>>0|m>>>0<l>>>0;l=m;m=0;s=m;k=0;C=d;G=((r&1073741823)<<2|o>>>30)&-262145|262144;e=NNa(d,m,G,0);d=e+j|0;l=ib+l|0;l=d>>>0<e>>>0?l+1|0:l;o=d;e=l;d=(q|0)==(e|0)&d>>>0<j>>>0|e>>>0<q>>>0;l=d+t|0;if(l>>>0<d>>>0){k=1}c=l;l=NNa(F,i,G,L);d=c+l|0;j=ib+k|0;q=d;m=d>>>0<l>>>0?j+1|0:j;k=NNa(u,x,G,L);j=ib;r=NNa(v,z,F,i);d=r+k|0;l=ib+j|0;l=d>>>0<r>>>0?l+1|0:l;r=d;d=l;l=(j|0)==(d|0)&r>>>0<k>>>0|d>>>0<j>>>0;q=d+q|0;k=l+m|0;j=q;l=j>>>0<d>>>0?k+1|0:k;c=j;m=e+r|0;k=0;d=k+o|0;if(d>>>0<k>>>0){m=m+1|0}r=d;j=d;d=m;e=(e|0)==(d|0)&j>>>0<o>>>0|d>>>0<e>>>0;j=c+e|0;if(j>>>0<e>>>0){l=l+1|0}O=j;e=r;k=d;o=NNa(E,w,C,s);m=ib;q=h;t=NNa(h,0,v,z);h=t+o|0;j=ib+m|0;j=h>>>0<t>>>0?j+1|0:j;B=h;t=h;h=j;o=(m|0)==(j|0)&t>>>0<o>>>0|j>>>0<m>>>0;Q=e;j=0;c=o;M=b<<2&-4;o=NNa(u,x,M,0);e=o+t|0;m=ib+h|0;m=e>>>0<o>>>0?m+1|0:m;t=e;o=e;e=m;h=(h|0)==(e|0)&o>>>0<B>>>0|e>>>0<h>>>0;m=c+h|0;if(m>>>0<h>>>0){j=1}h=Q+m|0;k=j+k|0;k=h>>>0<m>>>0?k+1|0:k;o=h;m=l;h=k;d=(d|0)==(k|0)&o>>>0<r>>>0|k>>>0<d>>>0;l=d+O|0;if(l>>>0<d>>>0){m=m+1|0}c=l;r=o;B=h;O=NNa(F,i,M,P);F=ib;i=NNa(G,L,q,R);d=i+O|0;l=ib+F|0;l=d>>>0<i>>>0?l+1|0:l;G=d;j=NNa(v,z,C,s);d=d+j|0;i=l;k=l+ib|0;k=d>>>0<j>>>0?k+1|0:k;v=d;l=NNa(u,x,E,w);d=d+l|0;j=ib+k|0;u=d;j=d>>>0<l>>>0?j+1|0:j;x=0;l=m;d=j;z=(j|0)==(k|0)&u>>>0<v>>>0|j>>>0<k>>>0;j=(i|0)==(F|0)&G>>>0<O>>>0|i>>>0<F>>>0;i=(i|0)==(k|0)&v>>>0<G>>>0|k>>>0<i>>>0;m=j+i|0;m>>>0<i>>>0;k=m;i=z+k|0;k=i;j=d|0;i=j+r|0;k=(k|x)+B|0;k=i>>>0<j>>>0?k+1|0:k;B=i;r=k;h=(h|0)==(k|0)&i>>>0<o>>>0|k>>>0<h>>>0;i=h+c|0;if(i>>>0<h>>>0){l=l+1|0}z=i;i=l;o=B;x=r;k=t;C=NNa(C,s,M,P);s=ib;l=NNa(E,w,q,R);h=l+C|0;m=ib+s|0;m=h>>>0<l>>>0?m+1|0:m;l=m;m=0;j=(l|0)==(s|0)&h>>>0<C>>>0|l>>>0<s>>>0;h=l+k|0;k=(j|m)+e|0;k=h>>>0<l>>>0?k+1|0:k;l=h;j=l;j=(e|0)==(k|0)&j>>>0<t>>>0|k>>>0<e>>>0;e=k;c=j;k=u;u=0;d=u+l|0;j=e+k|0;j=d>>>0<u>>>0?j+1|0:j;d=(e|0)==(j|0)&d>>>0<l>>>0|j>>>0<e>>>0;e=c+d|0;if(e>>>0<d>>>0){m=1}d=e+o|0;l=m+x|0;h=d;j=i;l=d>>>0<e>>>0?l+1|0:l;i=l;d=(r|0)==(l|0)&d>>>0<B>>>0|l>>>0<r>>>0;e=d+z|0;if(e>>>0<d>>>0){j=j+1|0}d=e;e=j;d:{if((j|0)==131071|j>>>0<131071){l=h;x=0;v=0;m=NNa(l,x,f,v);k=ib;j=b<<17;b=0;c=(m|0)!=0|(k|0)!=0;o=b-c|0;G=j-(b>>>0<c>>>0)|0;w=0-m|0;s=0-((0<m>>>0)+k|0)|0;c=0;z=NNa(i,c,f,v);b=ib;E=b;u=0;k=NNa(l,x,g,u);j=k+z|0;m=ib+b|0;m=j>>>0<k>>>0?m+1|0:m;b=j;k=j;q=0;j=q;t=k;j=(k|0)==(s|0)&w>>>0<j>>>0|s>>>0<k>>>0;B=o-j|0;o=G-(o>>>0<j>>>0)|0;j=NNa(d,0,f,v);k=ib;r=NNa(l,x,A,0);j=r+j|0;l=ib+k|0;l=j>>>0<r>>>0?l+1|0:l;r=NNa(g,u,i,c);j=r+j|0;k=ib+l|0;k=j>>>0<r>>>0?k+1|0:k;l=k;k=(m|0)==(E|0)&b>>>0<z>>>0|m>>>0<E>>>0;b=m+j|0;k=k+l|0;k=b>>>0<m>>>0?k+1|0:k;m=b;b=k;l=NNa(h,i,J,0);k=ib;r=m;m=NNa(f,g,e,0);l=m+l|0;j=ib+k|0;j=l>>>0<m>>>0?j+1|0:j;m=NNa(d,e,g,u);l=m+l|0;k=ib+j|0;j=l;l=NNa(i,c,A,H);c=j+l|0;j=c;l=0;c=r+l|0;j=b+j|0;b=c;A=B-b|0;H=o-((B>>>0<b>>>0)+(b>>>0<l>>>0?j+1|0:j)|0)|0;I=I+ -1|0;c=w-q|0;b=s-((w>>>0<q>>>0)+t|0)|0;break d}B=i>>>1|0;m=0;l=b<<16;c=0;k=d<<31;h=(i&1)<<31|h>>>1;i=i>>>1|k;z=0;E=0;b=NNa(h,z,f,E);j=ib;k=j;j=(b|0)!=0|(j|0)!=0;s=c-j|0;L=l-(c>>>0<j>>>0)|0;q=0-b|0;t=0-((0<b>>>0)+k|0)|0;o=0;w=NNa(h,z,g,o);b=ib;G=b;l=m;k=e<<31|d>>>1;m=d<<31|B;M=k|l;l=NNa(m,0,f,E);c=l+w|0;j=ib+b|0;j=c>>>0<l>>>0?j+1|0:j;b=j;j=c;v=j;x=0;l=(j|0)==(t|0)&q>>>0<x>>>0|t>>>0<j>>>0;C=s-l|0;s=L-(s>>>0<l>>>0)|0;l=NNa(h,i,J,0);k=ib;j=NNa(f,g,e>>>1|0,0);l=j+l|0;k=ib+k|0;k=l>>>0<j>>>0?k+1|0:k;d=(e&1)<<31|d>>>1;e=e>>>1|0;L=NNa(d,e,g,o);l=L+l|0;j=ib+k|0;k=NNa(m,M,A,H);l=k+l|0;H=0;j=NNa(g,o,m,P);k=ib;u=NNa(d,0,f,E);m=u+j|0;j=ib+k|0;j=m>>>0<u>>>0?j+1|0:j;A=NNa(h,z,A,0);m=A+m|0;k=ib+j|0;k=m>>>0<A>>>0?k+1|0:k;A=m;m=((b|0)==(G|0)&c>>>0<w>>>0|b>>>0<G>>>0)+k|0;c=b;b=b+A|0;if(b>>>0<c>>>0){m=m+1|0}c=b;b=b+H|0;j=l+m|0;j=b>>>0<c>>>0?j+1|0:j;A=C-b|0;H=s-((C>>>0<b>>>0)+j|0)|0;c=q-x|0;b=t-((q>>>0<x>>>0)+v|0)|0}if((I|0)>=16384){D=D|2147418112;b=0;c=0;break b}l=I+16383|0;if((I|0)<=-16383){e:{if(l){break e}l=i;k=b<<1|c>>>31;m=c<<1;g=(g|0)==(k|0)&m>>>0>f>>>0|k>>>0>g>>>0;m=e&65535;f=A;k=H<<1|f>>>31;c=f<<1|b>>>31;e=c;b=(e|0)==(N|0)&(k|0)==(J|0)?g:(J|0)==(k|0)&e>>>0>N>>>0|k>>>0>J>>>0;c=b+h|0;if(c>>>0<b>>>0){l=l+1|0}b=c;e=b;c=l;e=d+((i|0)==(l|0)&e>>>0<h>>>0|l>>>0<i>>>0)|0;if(e>>>0<d>>>0){m=m+1|0}d=m;if(!(d&65536)){break e}K=e|K;D=d|D;break b}b=0;c=0;break b}j=i;e=e&65535;m=b<<1|c>>>31;r=c<<1;g=(g|0)==(m|0)&r>>>0>=f>>>0|m>>>0>g>>>0;f=A;m=H<<1|f>>>31;c=f<<1|b>>>31;b=(c|0)==(N|0)&(m|0)==(J|0)?g:(J|0)==(m|0)&c>>>0>=N>>>0|m>>>0>J>>>0;c=b+h|0;if(c>>>0<b>>>0){j=j+1|0}b=c;c=j;f=d;d=((i|0)==(j|0)&b>>>0<h>>>0|j>>>0<i>>>0)+d|0;j=l<<16|e;K=d|K;D=D|(d>>>0<f>>>0?j+1|0:j)}p[a>>2]=b;p[a+4>>2]=c;p[a+8>>2]=K;p[a+12>>2]=D;fb=n+192|0;return}p[a>>2]=0;p[a+4>>2]=0;b=!(d|f|(e|g));p[a+8>>2]=b?0:K;p[a+12>>2]=b?2147450880:D;fb=n+192|0}function iG(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=fb-128|0;fb=h;a:{b:{if(g){nj(h+112|0,f,32);p[114610]=0;P(803,h+96|0,f|0,32)|0;i=p[114610];p[114610]=0;if((i|0)!=1){break b}c=I()|0;H()|0;break a}Lb(h+112|0);Lb(h+96|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(kr(c)){i=b+24|0;b=p[i>>2];p[114610]=0;b=J(442,b+484344|0,c&65535)|0;j=p[114610];p[114610]=0;if((j|0)==1){break r}if(b){break q}}p[114610]=0;N(2195,a|0,h+112|0,h+96|0);a=p[114610];p[114610]=0;if((a|0)!=1){break p}}c=I()|0;H()|0;break c}b=Rb(p[i>>2]+484344|0,c);if(!(p[b+12>>2]>(d|0)?(d|0)>=0:0)){p[114610]=0;N(2195,a|0,h+112|0,h+96|0);a=p[114610];p[114610]=0;if((a|0)!=1){break p}break d}if(!(r[p[i>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){p[114610]=0;N(2195,a|0,h+112|0,h+96|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}break p}p[114610]=0;c=P(2196,b|0,d|0,e&65535)|0;b=p[114610];p[114610]=0;if((b|0)==1){break o}Me(h+112|0);Me(h+96|0);p[114610]=0;b=M(556,c|0)|0;d=p[114610];p[114610]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if((d|0)!=1){H:{I:{if(!b){if(!Mr(c)){break I}}b=p[i>>2];d=q[c+1|0];e=q[c|0];p[114610]=0;Q(2197,h- -64|0,b|0,e|0,d|0);d=p[114610];p[114610]=0;b=1;if((d|0)==1){break G}p[114610]=0;N(9,h+80|0,0,h- -64|0);d=p[114610];p[114610]=0;if((d|0)!=1){break H}c=I()|0;H()|0;break E}b=0;p[114610]=0;J(85,h+80|0,38780)|0;d=p[114610];p[114610]=0;if((d|0)==1){break v}}p[114610]=0;J(1251,h+112|0,h+80|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break F}pb(h+80|0);if(b){pb(h- -64|0)}p[114610]=0;b=M(556,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}J:{if(b){p[114610]=0;J(85,h+80|0,38784)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}break J}if(Mr(c)){p[114610]=0;J(85,h+80|0,38788)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break J}break e}p[114610]=0;J(85,h+80|0,38780)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}}p[114610]=0;J(1251,h+96|0,h+80|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break D}pb(h+80|0);j=f+ -1|0;if(j>>>0<5){break w}p[114610]=0;b=J(85,h+80|0,38798)|0;d=p[114610];p[114610]=0;if((d|0)==1){break C}p[114610]=0;J(1251,h+112|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break B}pb(b);p[114610]=0;b=J(85,h+80|0,38798)|0;d=p[114610];p[114610]=0;if((d|0)==1){break A}p[114610]=0;J(1251,h+96|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break z}pb(b);b=c+1|0;K:{if(q[c+1|0]){p[114610]=0;K(840,h+80|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){break K}break f}p[114610]=0;J(85,h+80|0,38792)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}}p[114610]=0;J(1251,h+112|0,h+80|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break y}pb(h+80|0);L:{if(q[b|0]){p[114610]=0;J(85,h+80|0,38795)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break L}break g}p[114610]=0;J(85,h+80|0,38792)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}}p[114610]=0;J(1251,h+96|0,h+80|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break x}c=I()|0;H()|0;pb(h+80|0);break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;pb(h+80|0);if(!b){break c}}pb(h- -64|0);break c}c=I()|0;H()|0;pb(h+80|0);break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;pb(b);break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;pb(b);break c}c=I()|0;H()|0;pb(h+80|0);break c}pb(h+80|0);if(j>>>0<8){break w}p[114610]=0;b=M(1342,c|0)|0;d=p[114610];p[114610]=0;M:{N:{O:{P:{Q:{R:{S:{if((d|0)!=1){T:{if(b){p[114610]=0;b=J(85,h+48|0,38798)|0;d=p[114610];p[114610]=0;if((d|0)==1){break S}p[114610]=0;e=M(1344,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break R}d=0;p[114610]=0;p[h+16>>2]=e&255;K(839,h+32|0,h+16|0);k=p[114610];p[114610]=0;e=1;if((k|0)==1){break R}p[114610]=0;N(138,h+80|0,b|0,h+32|0);b=p[114610];p[114610]=0;if((b|0)!=1){break T}c=I()|0;H()|0;break i}if(q[c+2|0]){b=p[p[i>>2]+8>>2];d=q[c+2|0];p[114610]=0;b=J(2198,b|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break N}p[114610]=0;b=P(803,h+48|0,1,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break N}e=0;p[114610]=0;K(840,h+32|0,c+4|0);k=p[114610];p[114610]=0;d=1;if((k|0)==1){break Q}p[114610]=0;N(138,h+80|0,b|0,h+32|0);b=p[114610];p[114610]=0;if((b|0)!=1){break T}c=I()|0;H()|0;pb(h+32|0);break k}e=0;p[114610]=0;J(85,h+80|0,38812)|0;b=p[114610];p[114610]=0;d=0;if((b|0)==1){break O}}p[114610]=0;J(1251,h+112|0,h+80|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break P}pb(h+80|0);if(d){pb(h+32|0);pb(h+48|0)}if(e){pb(h+32|0);pb(h+48|0)}p[114610]=0;b=M(1342,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break l}U:{if(b){p[114610]=0;J(85,h+80|0,38816)|0;b=p[114610];p[114610]=0;if((b|0)==1){break l}break U}if(q[c+2|0]){p[114610]=0;J(85,h+80|0,38820)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break U}break l}p[114610]=0;J(85,h+80|0,38812)|0;b=p[114610];p[114610]=0;if((b|0)==1){break l}}p[114610]=0;J(1251,h+96|0,h+80|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break M}c=I()|0;H()|0;pb(h+80|0);break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;break h}c=I()|0;H()|0;break k}c=I()|0;H()|0;pb(h+80|0);if(!d){break j}pb(h+32|0);break k}c=I()|0;H()|0;break c}c=I()|0;H()|0;break c}pb(h+80|0);if(j>>>0<12){break w}p[114610]=0;b=J(85,h+80|0,38798)|0;d=p[114610];p[114610]=0;V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{if((d|0)!=1){p[114610]=0;J(1251,h+112|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break ba}pb(b);p[114610]=0;b=J(85,h+80|0,38798)|0;d=p[114610];p[114610]=0;if((d|0)==1){break aa}p[114610]=0;J(1251,h+96|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break $}pb(b);p[114610]=0;b=M(1342,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break _}ca:{if(b){b=0;p[114610]=0;d=M(1343,c|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;p[h+28>>2]=d&4095;K(1062,h+80|0,h+28|0);d=p[114610];p[114610]=0;if((d|0)!=1){break ca}}c=I()|0;H()|0;break c}if(q[c+3|0]){b=p[p[i>>2]+8>>2];d=q[c+3|0];p[114610]=0;b=J(2199,b|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break Z}p[114610]=0;d=P(803,h+16|0,1,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break Z}p[114610]=0;K(840,h|0,c+5|0);e=p[114610];p[114610]=0;b=1;if((e|0)==1){break Y}p[114610]=0;N(138,h+80|0,d|0,h|0);d=p[114610];p[114610]=0;if((d|0)!=1){break ca}c=I()|0;H()|0;pb(h);break m}b=0;p[114610]=0;J(85,h+80|0,38780)|0;d=p[114610];p[114610]=0;if((d|0)==1){break W}}p[114610]=0;J(1251,h+112|0,h+80|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break X}pb(h+80|0);if(b){pb(h);pb(h+16|0)}p[114610]=0;b=M(1342,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break n}da:{if(b){p[114610]=0;J(85,h+80|0,38824)|0;b=p[114610];p[114610]=0;if((b|0)==1){break n}break da}if(q[c+3|0]){p[114610]=0;J(85,h+80|0,38824)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break da}break n}p[114610]=0;J(85,h+80|0,38780)|0;b=p[114610];p[114610]=0;if((b|0)==1){break n}}p[114610]=0;J(1251,h+96|0,h+80|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break V}c=I()|0;H()|0;pb(h+80|0);break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;pb(b);break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;pb(b);break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;break m}c=I()|0;H()|0;pb(h+80|0);if(!b){break c}pb(h);break m}c=I()|0;H()|0;break c}pb(h+80|0);if(!f){break s}}ea:{fa:{if(wb(h+112|0)>>>0>f>>>0){p[114610]=0;Q(232,h+80|0,h+112|0,0,f|0);b=p[114610];p[114610]=0;if((b|0)!=1){break fa}c=I()|0;H()|0;break c}if(g){b=wb(h+112|0);p[114610]=0;b=P(803,h+80|0,f-b|0,32)|0;c=p[114610];p[114610]=0;if((c|0)==1){break u}p[114610]=0;J(1251,h+112|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=I()|0;H()|0;pb(b);break c}pb(b);if(wb(h+96|0)>>>0>f>>>0){break t}break ea}if(wb(h+96|0)>>>0<=f>>>0){break s}break t}xb(h+112|0,h+80|0);pb(h+80|0);if(wb(h+96|0)>>>0>f>>>0){break t}if(!g){break s}}b=wb(h+96|0);p[114610]=0;b=P(803,h+80|0,f-b|0,32)|0;c=p[114610];p[114610]=0;ga:{if((c|0)!=1){p[114610]=0;J(1251,h+96|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break ga}pb(b);break s}c=I()|0;H()|0;break c}c=I()|0;H()|0;pb(b);break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;break c}p[114610]=0;Q(232,h+80|0,h+96|0,0,f|0);b=p[114610];p[114610]=0;if((b|0)!=1){xb(h+96|0,h+80|0);pb(h+80|0);break s}c=I()|0;H()|0;break c}p[114610]=0;N(2195,a|0,h+112|0,h+96|0);a=p[114610];p[114610]=0;if((a|0)==1){break o}}pb(h+96|0);pb(h+112|0);fb=h+128|0;return}c=I()|0;H()|0;break c}c=I()|0;H()|0;break c}pb(h+16|0);break c}c=I()|0;H()|0;break c}pb(h+48|0)}if(!e){break c}}pb(h+32|0)}pb(h+48|0);break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;break c}c=I()|0;H()|0;break c}c=I()|0;H()|0}pb(h+96|0)}pb(h+112|0);L(c|0);E()}function K3(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,r=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=fb-8976|0;fb=h;z=d+e|0;F=0-z|0;a:{b:{while(1){if((c|0)!=48){c:{if((c|0)!=46){break a}c=p[b+4>>2];if(c>>>0>=s[b+104>>2]){break c}p[b+4>>2]=c+1;c=q[c|0];break b}}else{c=p[b+4>>2];if(c>>>0<s[b+104>>2]){k=1;p[b+4>>2]=c+1;c=q[c|0]}else{k=1;c=Sc(b)}continue}break}c=Sc(b)}l=1;if((c|0)!=48){break a}while(1){i=i+ -1|0;c=m+ -1|0;if((c|0)!=-1){i=i+1|0}m=c;c=p[b+4>>2];d:{if(c>>>0<s[b+104>>2]){p[b+4>>2]=c+1;c=q[c|0];break d}c=Sc(b)}if((c|0)==48){continue}break}k=1}p[h+784>>2]=0;e:{f:{o=(c|0)==46;r=c+ -48|0;g:{h:{i:{j:{if(o|r>>>0<=9){while(1){k:{if(o&1){if(!l){m=n;i=j;l=1;break k}k=!k;break j}n=n+1|0;if(n>>>0<1){j=j+1|0}if((u|0)<=2044){y=(c|0)==48?y:n;k=(h+784|0)+(u<<2)|0;o=k;if(t){r=(v(p[k>>2],10)+c|0)+ -48|0}p[o>>2]=r;k=1;r=t+1|0;c=(r|0)==9;t=c?0:r;u=c+u|0;break k}if((c|0)==48){break k}p[h+8960>>2]=p[h+8960>>2]|1;y=18396}c=p[b+4>>2];l:{if(c>>>0<s[b+104>>2]){p[b+4>>2]=c+1;c=q[c|0];break l}c=Sc(b)}o=(c|0)==46;r=c+ -48|0;if(o|r>>>0<10){continue}break}}m=l?m:n;i=l?i:j;if(!(!k|(c&-33)!=69)){l=QD(b,g);c=ib;o=c;m:{if(l|(c|0)!=-2147483648){break m}if(!g){break g}l=0;o=0;if(!p[b+104>>2]){break m}p[b+4>>2]=p[b+4>>2]+ -1}if(!k){break h}i=i+o|0;b=l+m|0;if(b>>>0<l>>>0){i=i+1|0}m=b;break f}k=!k;if((c|0)<0){break i}}if(!p[b+104>>2]){break i}p[b+4>>2]=p[b+4>>2]+ -1}if(!k){break f}}p[114584]=28}n=0;j=0;Rg(b,0,0);c=0;b=0;break e}b=p[h+784>>2];if(!b){Qh(h,+(f|0)*0);n=p[h>>2];j=p[h+4>>2];c=p[h+12>>2];b=p[h+8>>2];break e}if(!((m|0)!=(n|0)|(i|0)!=(j|0)|((j|0)>0?1:(j|0)>=0?n>>>0>9:0)|(b>>>d|0?(d|0)<=30:0))){$f(h+48|0,f);hm(h+32|0,b);jd(h+16|0,p[h+48>>2],p[h+52>>2],p[h+56>>2],p[h+60>>2],p[h+32>>2],p[h+36>>2],p[h+40>>2],p[h+44>>2]);n=p[h+16>>2];j=p[h+20>>2];c=p[h+28>>2];b=p[h+24>>2];break e}if((i|0)>0?1:(i|0)>=0?m>>>0>(e|0)/-2>>>0:0){p[114584]=68;$f(h+96|0,f);jd(h+80|0,p[h+96>>2],p[h+100>>2],p[h+104>>2],p[h+108>>2],-1,-1,-1,2147418111);jd(h- -64|0,p[h+80>>2],p[h+84>>2],p[h+88>>2],p[h+92>>2],-1,-1,-1,2147418111);n=p[h+64>>2];j=p[h+68>>2];c=p[h+76>>2];b=p[h+72>>2];break e}b=e+ -226|0;c=m>>>0<b>>>0;b=b>>31;if((i|0)<(b|0)?1:(i|0)<=(b|0)?c:0){p[114584]=68;$f(h+144|0,f);jd(h+128|0,p[h+144>>2],p[h+148>>2],p[h+152>>2],p[h+156>>2],0,0,0,65536);jd(h+112|0,p[h+128>>2],p[h+132>>2],p[h+136>>2],p[h+140>>2],0,0,0,65536);n=p[h+112>>2];j=p[h+116>>2];c=p[h+124>>2];b=p[h+120>>2];break e}if(t){if((t|0)<=8){c=(h+784|0)+(u<<2)|0;b=p[c>>2];while(1){b=v(b,10);t=t+1|0;if((t|0)!=9){continue}break}p[c>>2]=b}u=u+1|0}n:{l=m;if((y|0)>(l|0)|(y|0)>=9|(l|0)>17){break n}if((l|0)==9){$f(h+192|0,f);hm(h+176|0,p[h+784>>2]);jd(h+160|0,p[h+192>>2],p[h+196>>2],p[h+200>>2],p[h+204>>2],p[h+176>>2],p[h+180>>2],p[h+184>>2],p[h+188>>2]);n=p[h+160>>2];j=p[h+164>>2];c=p[h+172>>2];b=p[h+168>>2];break e}if((l|0)<=8){$f(h+272|0,f);hm(h+256|0,p[h+784>>2]);jd(h+240|0,p[h+272>>2],p[h+276>>2],p[h+280>>2],p[h+284>>2],p[h+256>>2],p[h+260>>2],p[h+264>>2],p[h+268>>2]);$f(h+224|0,p[(0-l<<2)+57328>>2]);SD(h+208|0,p[h+240>>2],p[h+244>>2],p[h+248>>2],p[h+252>>2],p[h+224>>2],p[h+228>>2],p[h+232>>2],p[h+236>>2]);n=p[h+208>>2];j=p[h+212>>2];c=p[h+220>>2];b=p[h+216>>2];break e}b=(v(l,-3)+d|0)+27|0;c=p[h+784>>2];if(c>>>b|0?(b|0)<=30:0){break n}$f(h+352|0,f);hm(h+336|0,c);jd(h+320|0,p[h+352>>2],p[h+356>>2],p[h+360>>2],p[h+364>>2],p[h+336>>2],p[h+340>>2],p[h+344>>2],p[h+348>>2]);$f(h+304|0,p[(l<<2)+57256>>2]);jd(h+288|0,p[h+320>>2],p[h+324>>2],p[h+328>>2],p[h+332>>2],p[h+304>>2],p[h+308>>2],p[h+312>>2],p[h+316>>2]);n=p[h+288>>2];j=p[h+292>>2];c=p[h+300>>2];b=p[h+296>>2];break e}while(1){c=u;u=c+ -1|0;if(!p[(h+784|0)+(u<<2)>>2]){continue}break}t=0;b=(l|0)%9|0;o:{if(!b){k=0;break o}g=(l|0)>-1?b:b+9|0;p:{if(!c){k=0;c=0;break p}r=p[(0-g<<2)+57328>>2];m=1e9/(r|0)|0;o=0;b=0;k=0;while(1){i=o;j=(h+784|0)+(b<<2)|0;n=p[j>>2];o=(n>>>0)/(r>>>0)|0;i=i+o|0;p[j>>2]=i;i=!i&(b|0)==(k|0);k=i?k+1&2047:k;l=i?l+ -9|0:l;o=v(m,n-v(o,r)|0);b=b+1|0;if((c|0)!=(b|0)){continue}break}if(!o){break p}p[(h+784|0)+(c<<2)>>2]=o;c=c+1|0}l=(l-g|0)+9|0}while(1){n=(h+784|0)+(k<<2)|0;q:{while(1){if((l|0)!=36|s[n>>2]>=10384593?(l|0)>=36:0){break q}u=c+2047|0;o=0;r=c;while(1){c=r;j=u&2047;r=(h+784|0)+(j<<2)|0;b=p[r>>2];i=b>>>3|0;g=b<<29;b=g+o|0;if(b>>>0<g>>>0){i=i+1|0}m=b;g=0;r:{if(!i&b>>>0<1000000001|i>>>0<0){break r}g=QNa(b,i,1e9,0);m=m-NNa(g,ib,1e9,0)|0}o=g;p[r>>2]=m;r=(j|0)!=(c+ -1&2047)?c:(j|0)==(k|0)?c:m?c:j;u=j+ -1|0;if((j|0)!=(k|0)){continue}break}t=t+ -29|0;if(!o){continue}break}k=k+ -1&2047;if((r|0)==(k|0)){b=(h+784|0)+((r+2046&2047)<<2)|0;c=r+ -1&2047;p[b>>2]=p[b>>2]|p[(h+784|0)+(c<<2)>>2]}l=l+9|0;p[(h+784|0)+(k<<2)>>2]=o;continue}break}s:{t:while(1){g=c+1&2047;m=(h+784|0)+((c+ -1&2047)<<2)|0;while(1){i=(l|0)>45?9:1;u:{while(1){r=k;b=0;v:{while(1){w:{k=b+r&2047;if((k|0)==(c|0)){break w}k=p[(h+784|0)+(k<<2)>>2];j=p[(b<<2)+57280>>2];if(k>>>0<j>>>0){break w}if(k>>>0>j>>>0){break v}b=b+1|0;if((b|0)!=4){continue}}break}if((l|0)!=36){break v}m=0;i=0;b=0;n=0;j=0;while(1){g=b+r&2047;if((g|0)==(c|0)){c=c+1&2047;p[((c<<2)+h|0)+780>>2]=0}jd(h+768|0,m,i,n,j,0,0,1342177280,1075633366);hm(h+752|0,p[(h+784|0)+(g<<2)>>2]);Of(h+736|0,p[h+768>>2],p[h+772>>2],p[h+776>>2],p[h+780>>2],p[h+752>>2],p[h+756>>2],p[h+760>>2],p[h+764>>2]);n=p[h+744>>2];j=p[h+748>>2];m=p[h+736>>2];i=p[h+740>>2];b=b+1|0;if((b|0)!=4){continue}break}$f(h+720|0,f);jd(h+704|0,m,i,n,j,p[h+720>>2],p[h+724>>2],p[h+728>>2],p[h+732>>2]);n=p[h+712>>2];j=p[h+716>>2];m=0;i=0;l=p[h+704>>2];o=p[h+708>>2];k=t+113|0;e=k-e|0;g=(e|0)<(d|0);d=g?(e|0)>0?e:0:d;if((d|0)<=112){break u}break s}t=i+t|0;k=c;if((c|0)==(r|0)){continue}break}j=1e9>>>i|0;n=-1<<i^-1;b=0;k=r;while(1){o=(h+784|0)+(r<<2)|0;u=p[o>>2];b=(u>>>i|0)+b|0;p[o>>2]=b;b=!b&(k|0)==(r|0);k=b?k+1&2047:k;l=b?l+ -9|0:l;b=v(j,n&u);r=r+1&2047;if((r|0)!=(c|0)){continue}break}if(!b){continue}if((g|0)!=(k|0)){p[(h+784|0)+(c<<2)>>2]=b;c=g;continue t}p[m>>2]=p[m>>2]|1;k=g;continue}break}break}Qh(h+656|0,Jh(1,225-d|0));UD(h+688|0,p[h+656>>2],p[h+660>>2],p[h+664>>2],p[h+668>>2],l,o,n,j);A=p[h+696>>2];B=p[h+700>>2];C=p[h+688>>2];D=p[h+692>>2];Qh(h+640|0,Jh(1,113-d|0));WB(h+672|0,l,o,n,j,p[h+640>>2],p[h+644>>2],p[h+648>>2],p[h+652>>2]);m=p[h+672>>2];i=p[h+676>>2];w=p[h+680>>2];x=p[h+684>>2];iv(h+624|0,l,o,n,j,m,i,w,x);Of(h+608|0,C,D,A,B,p[h+624>>2],p[h+628>>2],p[h+632>>2],p[h+636>>2]);n=p[h+616>>2];j=p[h+620>>2];l=p[h+608>>2];o=p[h+612>>2]}b=r+4&2047;x:{if((b|0)==(c|0)){break x}b=p[(h+784|0)+(b<<2)>>2];y:{if(b>>>0<=499999999){if((r+5&2047)==(c|0)?!b:0){break y}Qh(h+496|0,+(f|0)*.25);Of(h+480|0,m,i,w,x,p[h+496>>2],p[h+500>>2],p[h+504>>2],p[h+508>>2]);w=p[h+488>>2];x=p[h+492>>2];m=p[h+480>>2];i=p[h+484>>2];break y}if((b|0)!=5e8){Qh(h+592|0,+(f|0)*.75);Of(h+576|0,m,i,w,x,p[h+592>>2],p[h+596>>2],p[h+600>>2],p[h+604>>2]);w=p[h+584>>2];x=p[h+588>>2];m=p[h+576>>2];i=p[h+580>>2];break y}E=+(f|0);if((r+5&2047)==(c|0)){Qh(h+528|0,E*.5);Of(h+512|0,m,i,w,x,p[h+528>>2],p[h+532>>2],p[h+536>>2],p[h+540>>2]);w=p[h+520>>2];x=p[h+524>>2];m=p[h+512>>2];i=p[h+516>>2];break y}Qh(h+560|0,E*.75);Of(h+544|0,m,i,w,x,p[h+560>>2],p[h+564>>2],p[h+568>>2],p[h+572>>2]);w=p[h+552>>2];x=p[h+556>>2];m=p[h+544>>2];i=p[h+548>>2]}if((d|0)>111){break x}WB(h+464|0,m,i,w,x,0,0,0,1073676288);if(Wk(p[h+464>>2],p[h+468>>2],p[h+472>>2],p[h+476>>2],0,0,0,0)){break x}Of(h+448|0,m,i,w,x,0,0,0,1073676288);w=p[h+456>>2];x=p[h+460>>2];m=p[h+448>>2];i=p[h+452>>2]}Of(h+432|0,l,o,n,j,m,i,w,x);iv(h+416|0,p[h+432>>2],p[h+436>>2],p[h+440>>2],p[h+444>>2],C,D,A,B);n=p[h+424>>2];j=p[h+428>>2];l=p[h+416>>2];o=p[h+420>>2];z:{if((k&2147483647)<=(-2-z|0)){break z}p[h+408>>2]=n;p[h+412>>2]=j&2147483647;p[h+400>>2]=l;p[h+404>>2]=o;jd(h+384|0,l,o,n,j,0,0,0,1073610752);c=HE(p[h+400>>2],p[h+404>>2],p[h+408>>2],p[h+412>>2],1081081856);b=(c|0)<0;n=b?n:p[h+392>>2];j=b?j:p[h+396>>2];l=b?l:p[h+384>>2];o=b?o:p[h+388>>2];t=((c|0)>-1)+t|0;if(G=!(g&(b|(d|0)!=(e|0))&(Wk(m,i,w,x,0,0,0,0)|0)!=0),H=0,I=(t+110|0)<=(F|0),I?G:H){break z}p[114584]=68}TD(h+368|0,l,o,n,j,t);n=p[h+368>>2];j=p[h+372>>2];c=p[h+380>>2];b=p[h+376>>2]}p[a>>2]=n;p[a+4>>2]=j;p[a+8>>2]=b;p[a+12>>2]=c;fb=h+8976|0}function JAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,M=0,O=0;d=fb-304|0;fb=d;Ac(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!Ds(b,d+208|0)){break j}if(!gO(d+208|0)){break j}if(!Hb(b,dd(fO(d+208|0),ib))){break j}if(!c){C=1;break j}if(!Jc(b,q[d+208|4])){break j}xd(a,268435456);ei(a);p[a+480208>>2]=4;f=Mb(d+88|0,16601);xb(a+1304436|0,f);pb(f);f=Mb(d+88|0,16620);xb(a+1304448|0,f);pb(f);p[a+1304496>>2]=4;Qe(d+16|0,d+208|6,48,3);zc(d+88|0,d+16|0);xb(a+1304400|0,d+88|0);pb(d+88|0);o[a+480188>>1]=q[d+262|0]+1;p[a+480228>>2]=q[d+265|0];p[a+480204>>2]=v(q[d+266|0],1e4);p[a+480196>>2]=q[d+267|0];if(q[d+262|0]){f=0;while(1){o[((f<<5)+a|0)+480284>>1]=v(q[(d+f|0)+268|0],17);f=f+1|0;if(f>>>0<q[d+262|0]){continue}break}}o[a+480190>>1]=q[d+300|0];l=IAa(d+192|0,q[d+302|0]|q[d+303|0]<<8);f=q[d+302|0]|q[d+303|0]<<8;p[114610]=0;P(939,b|0,l|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break i}x=pp(d+176|0);m=pp(d+160|0);f=q[d+301|0];p[114610]=0;P(631,b|0,x|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break f}f=q[d+300|0];p[114610]=0;P(631,b|0,m|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break f}if(q[d+300|0]){s=c&2;t=d+88|4;u=d+126|0;w=d+88|6;f=0;while(1){p[114610]=0;h=f;f=f+1|0;i=v(f,104)+a|0;g=i+484380|0;K(386,g|0,0);e=p[114610];p[114610]=0;k:{l:{if((e|0)!=1){e=Fb(m,h);if(!(q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))){break k}e=Fb(m,h);e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);p[114610]=0;e=J(256,b|0,e|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break c}if(!e){break k}p[114610]=0;e=J(940,b|0,d+88|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break c}if(!e){break k}p[114610]=0;N(748,d+72|0,2,w|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;K(415,d+16|0,d+72|0);e=p[114610];p[114610]=0;if((e|0)!=1){break l}}f=I()|0;H()|0;break b}f=I()|0;H()|0;break b}p[114610]=0;J(369,((f<<5)+a|0)+946300|0,d+16|0)|0;e=p[114610];p[114610]=0;m:{n:{o:{p:{q:{if((e|0)!=1){pb(d+16|0);p[114610]=0;N(941,d+72|0,2,u|0);e=p[114610];p[114610]=0;if((e|0)==1){break q}p[114610]=0;K(415,d+16|0,d+72|0);e=p[114610];p[114610]=0;if((e|0)==1){break q}p[114610]=0;J(370,i+484423|0,d+16|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break p}pb(d+16|0);if(q[d+138|0]<=15){e=i+484414|0;o[e>>1]=r[e>>1]|32;o[i+484408>>1]=v(q[d+138|0],17)}e=q[d+139|0];p[114610]=0;n[d+16|0]=e;n[d+72|0]=64;e=J(391,d+16|0,d+72|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break o}o[i+484412>>1]=q[e|0];p[i+484404>>2]=q[d+141|0]|q[d+142|0]<<8;e=i+484384|0;p[e>>2]=q[d+147|0]|q[d+148|0]<<8|(q[d+149|0]<<16|q[d+150|0]<<24);k=i+484388|0;p[k>>2]=q[d+151|0]|q[d+152|0]<<8|(q[d+153|0]<<16|q[d+154|0]<<24);p[g>>2]=q[d+155|0]|q[d+156|0]<<8|(q[d+157|0]<<16|q[d+158|0]<<24);if(n[d+140|0]&1){break n}j=p[e>>2];e=p[k>>2];break m}f=I()|0;H()|0;pb(d+16|0);break b}f=I()|0;H()|0;break b}f=I()|0;H()|0;pb(d+16|0);break b}f=I()|0;H()|0;break b}j=p[e>>2]>>>1|0;p[e>>2]=j;e=p[k>>2]>>>1|0;p[k>>2]=e;p[g>>2]=p[g>>2]>>>1}r:{if(e>>>0<=j>>>0){break r}e=i+484414|0;o[e>>1]=r[e>>1]|2;if(!(q[d+140|0]&2)){break r}o[e>>1]=r[e>>1]|4}p[114610]=0;S(942,g|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}if(!s){break k}h=Fb(m,h);h=q[h|0]|q[h+1|0]<<8|(q[h+2|0]<<16|q[h+3|0]<<24);e=q[t|0];p[114610]=0;J(256,b|0,e+h|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break c}h=Tc(d+16|0,n[d+140|0]&1?16:8,1,0,1);p[114610]=0;P(400,h|0,g|0,b|0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){break k}f=I()|0;H()|0;break b}if(f>>>0<q[d+300|0]){continue}break}}C=1;s:{if(!(c&1)){break s}p[d+68>>2]=0;i=a+484360|0;Bp(Ob(i));M=d,O=Ub(l),p[M+64>>2]=O;M=d,O=Vb(l),p[M+56>>2]=O;if(Ab(d- -64|0,d+56|0)){k=a+484344|0;w=d+88|5;s=d+88|4;while(1){h=p[d- -64>>2];c=h;t:{if(q[c+3|0]>=q[d+301|0]|q[c+2|0]>q[d+262|0]){break t}c=Fb(x,q[c+3|0]);c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[114610]=0;c=J(256,b|0,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break g}if(!c){break t}p[114610]=0;J(943,b|0,d+88|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break h}if(!q[s|0]){break t}c=q[h|0]|q[h+1|0]<<8;f=q[h|0]|q[h+1|0]<<8;n[d+16|0]=q[w|0];e=q[d+262|0];g=q[h+2|0];p[114610]=0;n[d+72|0]=e-g;e=J(391,d+16|0,d+72|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break d}t=q[e|0];e=q[h|0]|q[h+1|0]<<8;g=q[s|0];p[114610]=0;p[d+52>>2]=e+g;e=J(392,d+68|0,d+52|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}p[d+68>>2]=p[e>>2];p[d+40>>2]=0;p[d+44>>2]=0;p[d+32>>2]=0;p[d+36>>2]=0;p[d+24>>2]=0;p[d+28>>2]=0;p[d+16>>2]=0;p[d+20>>2]=0;if(!q[s|0]){break t}y=c>>>6|0;e=f&63;A=0;while(1){u:{v:{w:{x:{y:{z:{A:{f=e>>>0>63;y=f+y|0;c=y&65535;if(fc(Ob(i))>>>0<=c>>>0){g=Ob(i);p[114610]=0;K(930,g|0,y+1&65535);g=p[114610];p[114610]=0;if((g|0)==1){break A}p[114610]=0;g=P(815,k|0,64,0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break A}M=kc(Ob(i),c),O=g,o[M>>1]=O}u=r[kc(Ob(i),c)>>1];p[114610]=0;c=J(442,k|0,u|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break y}if(!c){break t}c=Rb(k,u);g=q[h+2|0];p[114610]=0;z=f?0:e;f=P(471,c|0,z|0,g|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break v}j=0;B=0;if(t){break z}break w}f=I()|0;H()|0;break b}while(1){p[114610]=0;K(944,d+72|0,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break x}g=Zc(d+72|0);F=Tf(d+72|0);D=vi(d+72|0);G=_b(d+72|0);e=0;c=q[d+72|0];if((c+ -1&255)>>>0<=142){e=(v((c&240)>>>4|0,12)+(c&15)|0)+13|0;n[(d+16|0)+j|0]=e}n[f|0]=e;c=q[g|0];n[f+2|0]=1;n[f+1|0]=c;c=q[F|0];B:{if((c|0)!=255){n[f+4|0]=c;break B}n[f+2|0]=0}c=q[D|0];C:{if(c>>>0>22){break C}n[f+3|0]=q[c+16624|0];g=q[G|0];n[f+5|0]=g;c=f+5|0;D:{switch(q[D|0]+ -4|0){case 3:n[c|0]=g&3|64;break C;case 4:n[c|0]=g&3|48;break C;case 7:if(Bb(l)>>>0<=g>>>0){break C}g=c;c=Fb(l,q[c|0]);e=q[c|0]|q[c+1|0]<<8;n[g|0]=e>>>6;c=Rb(k,u);g=r[a+480188>>1];p[114610]=0;c=P(471,c|0,z|0,g+ -1&65535)|0;g=p[114610];p[114610]=0;if((g|0)!=1){n[c+3|0]=14;n[c+5|0]=e&63;break C}f=I()|0;H()|0;break b;case 8:n[c|0]=p[d+52>>2]>>>6;c=Rb(k,u);e=r[a+480188>>1];p[114610]=0;c=P(471,c|0,z|0,e+ -1&65535)|0;e=p[114610];p[114610]=0;if((e|0)!=1){n[c+3|0]=14;n[c+5|0]=q[d+52|0]&63;break C}f=I()|0;H()|0;break b;case 10:n[c|0]=g&15|128;break C;case 12:p[114610]=0;n[d+15|0]=15;e=J(391,c|0,d+15|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){n[c|0]=q[e|0]|208;break C}f=I()|0;H()|0;break b;case 13:p[114610]=0;n[d+15|0]=15;e=J(391,c|0,d+15|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){n[c|0]=q[e|0]|192;break C}f=I()|0;H()|0;break b;case 14:p[114610]=0;n[d+15|0]=15;e=J(391,c|0,d+15|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){n[c|0]=q[e|0]|224;break C}f=I()|0;H()|0;break b;case 0:case 16:case 17:if(!(g&15)){break C}e=g&240;if(!e|(e|0)==240){break C}n[c|0]=g|15;break C;case 9:case 18:break D;default:break C}}if(e&255){break C}n[f|0]=q[(d+16|0)+j|0]}f=f+6|0;B=B+1|0;j=B&65535;if(j>>>0<t>>>0){continue}break}break w}f=I()|0;H()|0;break b}f=I()|0;H()|0;break b}if(q[w|0]<=t>>>0){break u}c=q[w|0];p[114610]=0;J(338,b|0,v(c-t|0,5)|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break u}}f=I()|0;H()|0;break b}e=z+1|0;A=A+1|0;if(A>>>0<q[s|0]){continue}break}}Rd(d- -64|0);if(Ab(d- -64|0,d+56|0)){continue}break}}E:{b=p[d+68>>2];c=b&63;if(!c){break E}f=Ob(i);p[114610]=0;b=b>>>6|0;f=J(546,f|0,b&65535)|0;h=p[114610];p[114610]=0;if((h|0)!=1){if(!f){break E}b=Rb(a+484344|0,r[kc(Ob(i),b&65535)>>1]);p[114610]=0;U(945,b|0,c|0,0,1)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break E}}f=I()|0;H()|0;break b}b=Ob(i);M=d,O=Ub(b),p[M+88>>2]=O;M=d,O=Vb(b),p[M+16>>2]=O;if(!Ab(d+88|0,d+16|0)){break s}a=a+484344|0;e=65535;while(1){b=p[d+88>>2];if(r[b>>1]==65535){F:{if((e&65535)!=65535){break F}p[114610]=0;e=P(815,a|0,64,0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break F}f=I()|0;H()|0;break b}o[b>>1]=e}te(d+88|0);if(Ab(d+88|0,d+16|0)){continue}break}}qi(m);qi(x);dO(l)}fb=d+304|0;return C|0}f=I()|0;H()|0;break a}f=I()|0;H()|0;break b}f=I()|0;H()|0;break b}f=I()|0;H()|0;break b}f=I()|0;H()|0;break b}f=I()|0;H()|0;break b}f=I()|0;H()|0}qi(m);qi(x)}dO(l);L(f|0);E()}function sna(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;c=fb-32|0;fb=c;a:{if(!qna(a)|!p[a+1074420>>2]){break a}b=KJ(a,a+1074376|0);p[a+1074380>>2]=b;p[a+1074404>>2]=b;u=sd(r[a+480188>>1],1,31);z=a+1074328|0;b:{if(q[z+37|0]){b=p[a+24628>>2];if((b|0)>=129){b=((v(b+ -128|0,u+4|0)|0)/16|0)+128|0}A=v(p[a+480228>>2],b)>>>6|0;break b}A=p[a+480228>>2]}A=q[z+37|0]?(A<<7>>>0)/q[(u>>>1|0)+20688|0]|0:A;o[a+480212>>1]=0;y=a+1304392|0;w=a+1074308|0;C=a+480210|0;D=a+480209|0;while(1){e=v(m,896)+a|0;i=e+1075072|0;c:{if(!(p[i>>2]&4096)|(p[e+1075008>>2]|(p[e+1075004>>2]|p[e+1075680>>2]))){break c}vb(c+24|0,w,64);if(tb(c+24|0)){break c}p[e+1075060>>2]=0;b=e+1075076|0;p[b>>2]=0;p[b+4>>2]=0}b=r[a+480188>>1];g=p[i>>2];d:{if(!(p[e+1075060>>2]|m>>>0<b>>>0?!(g&1024):0)){if(m>>>0<b>>>0){zJ(a,m&65535)}o[e+1075846>>1]=0;break d}h=0;B=e+1075704|0;p[B>>2]=0;l=e+1075664|0;p[l>>2]=0;u=e+1074992|0;f=u;p[f>>2]=0;p[f+4>>2]=0;p[e+1075084>>2]=0;p[c+20>>2]=1065353216;o[c+18>>1]=0;E=e+1075640|0;j=p[E>>2];d=0;f=e+1075684|0;if(p[f>>2]){d=p[e+1075060>>2]!=0}k=e+1074984|0;e:{f:{g:{if(m>>>0>=b>>>0){break g}if(q[((m<<5)+a|0)+480288|0]){break f}if(!j){break g}h=q[j+34|0]!=0}if((d|h)!=1){break e}}p[c+8>>2]=p[e+1075672>>2];p[c+4>>2]=p[e+1075748>>2];vb(c+24|0,w,28);pna(a,k,tb(c+24|0)?c+4|0:c+8|0);ona(a,k);nna(a,k,c+8|0);g=m&65535;mna(a,g,c+8|0);Vd(c+8|0,0,256);b=p[c+8>>2]<<6;p[c+8>>2]=b;h:{i:{if(j){vb(c+24|0,w,31);if(tb(c+24|0)){Or(a,k)}lna(a,k,c+8|0);yJ(k,c+8|0);kna(a,k);ina(k);b=p[c+8>>2];break i}if(!(q[i+1|0]&16)){break i}p[e+1075680>>2]=0;p[c+8>>2]=0;break h}if(!b){break h}if(q[i+3|0]&8){p[l>>2]=0;break h}b=p[c+8>>2];if(q[z+36|0]){h=v(p[c+4>>2],p[e+1075744>>2]);b=b<<8;H=l,I=rc(ONa(NNa(h,h>>31,b,b>>31),ib,1048576,0),ib),p[H>>2]=I;break h}h=v(p[c+4>>2],p[e+1075744>>2]);b=v(b,p[a+1074444>>2]);H=l,I=rc(ONa(NNa(h,h>>31,b,b>>31),ib,1048576,0),ib),p[H>>2]=I}p[B>>2]=p[c+8>>2];j:{if(p[a+480180>>2]==2|p[f>>2]>=p[a+480260>>2]){break j}if(Go(a)){break j}p[f>>2]=p[a+480260>>2]}vb(c+24|0,w,73);if(tb(c+24|0)){Pb(p[f>>2],1,31999)}b=p[f>>2];p[c+12>>2]=b;k:{if((p[i>>2]&1572864)!=1572864){break k}if(q[C|0]&32){if(!es(e+1075794|0)|q[D|0]&16){break k}b=p[c+12>>2]}h=e+1075696|0;l:{if(p[h>>2]==(b|0)){b=p[e+1075700>>2];break l}p[h>>2]=b;x=b;b=e+1075752|0;h=e+1075688|0;b=dg(a,Xr(a,x,p[b>>2],p[h>>2]),p[b>>2],p[h>>2]);p[e+1075700>>2]=b}p[c+12>>2]=b}hna(a,g,c+12|0,c+18|0);if(!(!(q[C|0]&33)|p[c+12>>2]==2147483647)){m:{if(p[a+480180>>2]==2){b=452;g=3424;break m}g=v(p[e+1075752>>2]>>>4&15,24)+20960|0;b=r[g+22>>1];b=b>>>0<904?452:b>>>1|0;g=r[g>>1]<<1}Vd(c+12|0,b,g);Vd(f,b,g)}xJ(a,k);g=p[i>>2]}n:{if(!(g&256)|q[D|0]&64){break n}vb(c+24|0,w,37);if(!tb(c+24|0)){break n}p[e+1075668>>2]=128}b=m&65535;zJ(a,b);o:{if(!d){break o}g=wJ(a,k,c+12|0);if((g|0)<0|!(q[i+1|0]&2)){break o}if(!kd(y)){break o}To(p[y>>2],b,g>>>2&255,1)}p:{if(q[e+1075796|0]!=8){break p}q:{r:{g=q[e+1075797|0];switch(g+ -5|0){case 1:break p;case 0:case 2:break q;default:break r}}if((g|0)!=26){break p}}if(p[a+480180>>2]==4){if(q[D|0]&16){break p}g=e+1075823|0;n[g|0]=q[g|0]+q[e+1075827|0];break p}if(!(p[a+480180>>2]&16777248)){break p}Uj(k,q[e+1075798|0]);vJ(a,b,c+12|0,c+20|0)}vJ(a,b,c+12|0,c+20|0);if(d){p[c+8>>2]=0;gna(a,k,c+12|0,c+20|0,c+8|0);if(p[c+12>>2]<=p[a+480260>>2]){vb(c+24|0,w,81);if(tb(c+24|0)){p[e+1075060>>2]=0}p[c+12>>2]=p[a+480260>>2]}h=dj(k);s:{if(!h){break s}d=e+1075856|0;g=q[d|0];if(p[a+1074392>>2]|!(g&4)?!(g&8):0){break s}GM(k,t[c+20>>2],o[c+18>>1],a);g=q[d|0];if(!(g&8)){n[d|0]=g&251;break s}n[d|0]=g&247}t:{if((p[i>>2]&134219264)!=512){break t}if(!kd(y)){break t}vb(c+24|0,w,99);if(!(H=!(tb(c+24|0)|!(q[i+1|0]&16)),I=0,J=p[a+480180>>2]!=2,J?H:I)){if(!(q[i+1|0]&8?p[a+480180>>2]==2:0)){if(h){f=p[f>>2]}else{f=rK(a,p[c+12>>2],p[e+1075688>>2],p[c+8>>2])}d=NNa(f,0,261625,0)+66904|0;f=ib;d=dd(QNa(d,d>>>0<66904?f+1|0:f,133808,0),ib);g=p[i>>2];f=1;u:{if(g&2048){break u}f=0;if(!(g&4096)){break u}f=!p[e+1075680>>2]}g=p[y>>2];vb(c+24|0,w,95);mta(g,b,d,f,tb(c+24|0))}g=p[y>>2];d=NNa(v(p[e+1075748>>2],v(p[e+1075744>>2],p[B>>2])),0,63,0)+33554432|0;f=ib;f=d>>>0<33554432?f+1|0:f;To(g,b,dd((f&67108863)<<6|d>>>26,f>>>26|0)&255,0);f=e+1075668|0;H=f,I=(kta(p[y>>2],b,p[f>>2])<<7)+128|0,p[H>>2]=I}v:{f=p[E>>2];if(!f|(q[f+60|0]&7)!=1){break v}f=f+48|0;if(cd(f)){break v}if(s[uJ(k,0)+4>>2]<r[_i(f)>>1]){break v}if(q[_i(f)+2|0]){break v}ii(p[y>>2],b,1);vb(c+24|0,w,109);f=tb(c+24|0);b=p[i>>2];if(!f){b=b&-513;p[i>>2]=b}p[i>>2]=b|4096;p[e+1075680>>2]=0;break t}vb(c+24|0,w,99);if(!tb(c+24|0)|!(q[i+1|0]&16)|p[e+1075680>>2]){break t}ii(p[y>>2],b,1);p[i>>2]=p[i>>2]&-513}d=NNa(fx(a,k,p[c+12>>2],p[c+8>>2]),ib,p[a+480240>>2],0);b=ib;g=ONa(d,b,65536,0);h=ib;f=u;x=f;d=d+65535|0;if(d>>>0<65535){b=b+1|0}b=!b&d>>>0<131071|b>>>0<0;p[x>>2]=b?1:g;p[f+4>>2]=b?0:h}w:{if(!j){break w}vb(c+24|0,w,31);if(tb(c+24|0)){break w}Or(a,k)}B=e+1075004|0;x=e+1075008|0;p[i>>2]=p[i>>2]&-65537|((p[B>>2]|(p[x>>2]|p[l>>2]))!=0)<<16;f=e+1075656|0;b=f;p[b>>2]=0;p[b+4>>2]=0;j=e+1075846|0;b=q[j|0];n[j|0]=(b>>>0>4?b:4)+ -4;g=e+1075847|0;b=q[g|0];n[g|0]=(b>>>0>4?b:4)+ -4;x:{y:{z:{A:{B:{b=e+1075088|0;d=p[b>>2];C:{if(!d){break C}if(!ue(d)|!p[e+1075060>>2]){break C}if(yh(k)){break B}}h=e+1075e3|0;p[h>>2]=0;break A}h=e+1075e3|0;b=p[p[b>>2]+20>>2];p[h>>2]=b;if(b){break z}}if(!Zi(k)|q[i+1|0]&24){break y}}F=p[l>>2];G=p[e+1075668>>2];b=(v(F,256-G|0)|0)/16384|0;d=b>>>0<127?b:127;b=n[j|0];if((b|0)<=-1){n[j|0]=d;b=d}d=d>>>1|0;if(d>>>0>(b&255)>>>0){n[j|0]=d}b=(v(F,G)|0)/16384|0;d=b>>>0<127?b:127;b=n[g|0];if((b|0)<=-1){n[g|0]=d;b=d}d=d>>>1|0;if(d>>>0<=(b&255)>>>0){break x}n[g|0]=d;break x}if(q[j|0]>=129){n[j|0]=0}if(q[g|0]<129){break x}n[g|0]=0}D:{if(p[h>>2]){b=e+1075660|0;E:{if(s[a+24624>>2]>=2){p[c+24>>2]=p[e+1075668>>2];Vd(c+24|0,0,256);j=v(p[l>>2],A)>>>(q[z+37|0]?7:8)|0;d=b;F:{G:{H:{switch(p[z+32>>2]){case 0:if(!(q[a+24616|0]&16)){break G};case 1:l=p[c+24>>2];if((l|0)<=127){p[f>>2]=j>>>1;g=(v(j,l)|0)/256|0;break F}p[f>>2]=(v(j,256-l|0)|0)/256;g=j>>>1|0;break F;case 3:break H;default:break G}}fk(c+24|0,255);g=f;h=p[c+24>>2];x=65536;I:{if((h|0)<1){break I}x=r[(0-h<<1)+27808>>1]}p[g>>2]=v(x,j)>>>16;g=v(j,r[(h<<1)+27296>>1])>>>16|0;break F}l=p[c+24>>2];p[f>>2]=(v(j,256-l|0)|0)/256;g=(v(j,l)|0)/256|0}p[d>>2]=g;break E}d=v(p[l>>2],A)>>>8|0;p[f>>2]=d;p[b>>2]=d}d=p[E>>2];J:{if(d){d=q[d+14|0];if(Kp(d)){break J}}d=q[a+480268|0];if(Kp(d)){break J}if(q[C|0]&128){d=255;if(p[a+24668>>2]){break J}}d=q[a+24648|0]}l=e+1075800|0;n[l|0]=d;if(!(q[i+2|0]&2|(p[u>>2]!=0|p[u+4>>2]!=1)|(p[e+1075764>>2]|(d|0)==255))){n[l|0]=0}d=f;g=p[f>>2];f=1<<p[z+28>>2];p[d>>2]=(g|0)/(f|0);f=p[b>>2]/(f|0)|0;p[b>>2]=f;d=p[i>>2];if(!(!(d&256)|p[a+24624>>2]!=2)){p[b>>2]=0-f}if(d&128){b=p[u>>2];f=0-(p[u+4>>2]+(0<b>>>0)|0)|0;p[u>>2]=0-b;p[u+4>>2]=f}fna(a,k);if(q[i+1|0]&2){break D}b=r[a+480212>>1];o[a+480212>>1]=b+1;o[((b<<1)+a|0)+1074466>>1]=m;break D}p[B>>2]=0;p[x>>2]=0;p[e+1075060>>2]=0;if(p[e+1075076>>2]?0:!p[e+1075080>>2]){break D}b=r[a+480212>>1];o[a+480212>>1]=b+1;o[((b<<1)+a|0)+1074466>>1]=m}p[e+1075652>>2]=p[i>>2]}m=m+1|0;if((m|0)!=256){continue}break}d=1;if(s[a+24608>>2]>r[a+480212>>1]){break a}b=a+1074466|0;ena(b,b+(p[a+24608>>2]<<1)|0,b+(r[a+480212>>1]<<1)|0,a)}fb=c+32|0;return d}function wU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0;c=fb-112|0;fb=c;if(b){O=a+12|0;P=a+24592|0;Q=a+24588|0;an(O,b,P,Q);if(s[a+24624>>2]>=3){an(a+8204|0,b,a+24600|0,a+24596|0)}o[c+30>>1]=0;M=a+1074308|0;vb(c+8|0,M,33);d=tb(c+8|0);e=r[a+480212>>1];if(e){Y=d?2:1;Z=a+24648|0;_=a+24596|0;$=a+24600|0;aa=a+8204|0;ba=a+397460|0;ca=a+397456|0;da=a+393352|0;R=a+1074376|0;while(1){x=(N<<1)+R|0;d=v(r[x+90>>1],896);j=d+R|0;A=j;a:{b:{if(p[j+624>>2]){break b}h=a+d|0;if(p[h+1075080>>2]){break b}if(!p[h+1075076>>2]){break a}}f=a+d|0;g=kva(q[f+1075800|0]);l=f+1075072|0;h=p[l>>2];i=h&1;t=h>>>5|0;c:{if(!(h&8388608)){z=O;C=Q;e=h;d=P;if(!(!(e&16777216)&(q[a+24612|0]&32)>>>5)){break c}}z=ifa(da,b);e=p[l>>2];C=ba;d=ca}H=d;d=g|i;g=t&2;h=h>>>12|0;if(!(!(e&256)|s[a+24624>>2]<3)){H=$;C=_;z=aa}g=d|g;i=h&8;h=j+608|0;D=Km(a,r[x+90>>1],2,1);d:{if((!D|0)==(D>>>0<251|0)){break d}e=p[(v(D,160)+a|0)+906140>>2];if(!e){break d}d=p[e+24>>2];if(!d){break d}C=e+36|0;H=e+40|0;if(!(n[e+28|0]&1)){an(d,b,H,C);p[e+28>>2]=p[e+28>>2]|1}z=d}ea=g|i;S=f+1075809|0;fa=f+1075792|0;ga=f+1075680|0;ha=f+1075016|0;ia=f+1075012|0;ja=f+1075660|0;ka=f+1075656|0;w=f+1074992|0;E=f+1075080|0;F=f+1075076|0;T=f+1075008|0;U=f+1075004|0;K=f+1075088|0;I=f+1075068|0;t=f+1075060|0;L=f+1075064|0;G=f+1075084|0;B=0;la=uU(c+8|0,h);x=b;while(1){e:{d=p[G>>2];d=d?x>>>0>d>>>0?d:x:x;p[c+68>>2]=d;y=p[L>>2];k=p[l>>2];g=p[w+4>>2];e=p[w>>2];p[c+56>>2]=e;p[c+60>>2]=g;f:{g:{if(!d|!(e|g)){break g}i=p[t>>2];if(!i){break g}p[A+624>>2]=p[c+8>>2];u=p[h+4>>2];d=u;f=p[h>>2];j=y&k<<30>>31;h:{if((j|0)>(d|0)){if((g|0)<-1?1:(g|0)<=-1){p[c+104>>2]=0;e=j;p[c+108>>2]=e<<1;f=Wf(c+104|0,h);g=ib;d=g;p[h>>2]=f;p[h+4>>2]=d;if(!(p[t>>2]+e>>>1>>>0>d>>>0?(e|0)<=(d|0):0)){f=0;p[h>>2]=f;d=e;p[h+4>>2]=d}i=p[c+60>>2];k=p[c+56>>2];g=k;e=0-(i+(0<g>>>0)|0)|0;g=0-g|0;p[c+56>>2]=g;p[c+60>>2]=e;p[w>>2]=g;p[w+4>>2]=e;e=p[l>>2];i:{if(e&4){e=e&-129;p[l>>2]=e;break i}e=e|128;p[l>>2]=e;u=p[t>>2]+ -1|0;d=u;p[h>>2]=f;p[h+4>>2]=d;p[w>>2]=k;p[w+4>>2]=i}j:{if(!(e&2)){e=p[t>>2];break j}e=p[t>>2];if(e>>>0>d>>>0){break h}}f=h;p[f>>2]=0;p[f+4>>2]=e;break g}if((u|0)>-1){break h}e=0;d=e;p[h>>2]=f;p[h+4>>2]=d;break h}if(i>>>0>u>>>0){break h}if(!(k&2)){break g}if(k&4){if((g|0)>0?1:(g|0)>=0?e>>>0>=1:0){d=0-((0<e>>>0)+g|0)|0;e=0-e|0;p[c+56>>2]=e;p[c+60>>2]=d;p[w>>2]=e;p[w+4>>2]=d}p[l>>2]=k|128;d=1-(0<f>>>0)|0;f=0-f|0;g=((i<<1)-u|0)-d|0;d=g;e=h;p[e>>2]=f;p[e+4>>2]=d;if(d>>>0<i>>>0?d>>>0>y>>>0:0){break h}p[c+104>>2]=Y;d=i-p[Cb(t,c+104|0)>>2]|0;f=p[e>>2];p[h>>2]=f;p[e+4>>2]=d;break h}if((g|0)<-1?1:(g|0)<=-1){f=0-e|0;p[c+56>>2]=f;d=0-((0<e>>>0)+g|0)|0;p[c+60>>2]=d;p[w>>2]=f;p[w+4>>2]=d}p[c+104>>2]=0;p[c+108>>2]=j-i;Kb(h,c+104|0);p[l>>2]=p[l>>2]|8192;f=p[h>>2];d=p[h+4>>2]}p[c+48>>2]=f;p[c+52>>2]=d;k:{l:{e=d;m:{if((j|0)>(d|0)){if((d|p[c+60>>2])>-1){break m}break l}if((d|0)<0?1:(d|0)<=0?f>>>0<0:0){break l}}d=0;if(s[t>>2]<=e>>>0){break k}V=p[c+68>>2];p[c+44>>2]=V;d=p[c+56>>2];f=p[c+60>>2];vc(c+68|0,p[c+20>>2]);ma=c,na=$t(c+56|0,p[c+68>>2]+ -1|0),p[ma+32>>2]=na;p[c+36>>2]=ib;e=d;g=f;d=f>>31;f=f>>31;k=g;g=d;d=k+d|0;i=f+e|0;if(i>>>0<f>>>0){d=d+1|0}y=i;i=d;d=p[c+36>>2]+p[c+52>>2]|0;e=p[c+48>>2];k=e+p[c+32>>2]|0;if(k>>>0<e>>>0){d=d+1|0}e=p[L>>2];W=e+16|0;J=p[c+52>>2];k=J;u=p[c+48>>2];X=e>>>0>k>>>0;if(!(W>>>0>k>>>0?!X:0)){p[l>>2]=p[l>>2]&-8193}y=f^y;g=g^i;f=d;n:{o:{p:{if(!p[c+12>>2]){i=p[c+60>>2];break p}d=p[c+16>>2];if(d>>>0<=J>>>0){f=c;e=p[c+60>>2];q:{if((e|0)<-1?1:(e|0)<=-1){p[c+96>>2]=u;p[c+100>>2]=k;p[c+104>>2]=0;p[c+108>>2]=d;ma=c,na=Wf(c+96|0,c+104|0),p[ma+80>>2]=na;p[c+84>>2]=ib;p[c+72>>2]=1;p[c+76>>2]=0;ma=c,na=Wf(c+80|0,c+72|0),p[ma+88>>2]=na;p[c+92>>2]=ib;d=Il(c+88|0,y,g);break q}d=p[I>>2];p[c+104>>2]=u;p[c+108>>2]=k;p[c+96>>2]=0;p[c+100>>2]=d;ma=c,na=Wf(c+96|0,c+104|0),p[ma+80>>2]=na;p[c+84>>2]=ib;p[c+72>>2]=1;p[c+76>>2]=0;ma=c,na=Wf(c+80|0,c+72|0),p[ma+88>>2]=na;p[c+92>>2]=ib;d=Il(c+88|0,y,g)}p[f+44>>2]=d+1;p[A+624>>2]=p[c+12>>2];break n}if(!(X|!(q[l+1|0]&32)|W>>>0<=J>>>0)){p[c+104>>2]=u;p[c+108>>2]=k;p[c+96>>2]=0;p[c+100>>2]=j+16;ma=c,na=Wf(c+96|0,c+104|0),p[ma+80>>2]=na;p[c+84>>2]=ib;p[c+72>>2]=1;p[c+76>>2]=0;ma=c,na=Wf(c+80|0,c+72|0),p[ma+88>>2]=na;p[c+92>>2]=ib;ma=c,na=Il(c+88|0,y,g)+1|0,p[ma+44>>2]=na;ma=A,na=p[c+12>>2]+v(p[I>>2]-j|0,Fn(p[K>>2]))|0,p[ma+624>>2]=na;break n}J=p[c+60>>2];i=J;if((i|0)<0?1:(i|0)<=0?s[c+56>>2]<1:0){break p}if(V>>>0<2|d>>>0>f>>>0){break o}p[c+104>>2]=u;p[c+108>>2]=k;p[c+96>>2]=0;p[c+100>>2]=d;ma=c,na=Wf(c+96|0,c+104|0),p[ma+80>>2]=na;p[c+84>>2]=ib;p[c+72>>2]=1;p[c+76>>2]=0;ma=c,na=Wf(c+80|0,c+72|0),p[ma+88>>2]=na;p[c+92>>2]=ib;ma=c,na=Il(c+88|0,y,g)+1|0,p[ma+44>>2]=na;break n}if((i|0)>-1){break o}if((j|0)<=(f|0)){break n}p[c+96>>2]=u;p[c+100>>2]=k;p[c+104>>2]=0;p[c+108>>2]=e;ma=c,na=Wf(c+96|0,c+104|0),p[ma+80>>2]=na;p[c+84>>2]=ib;p[c+72>>2]=1;p[c+76>>2]=0;ma=c,na=Wf(c+80|0,c+72|0),p[ma+88>>2]=na;p[c+92>>2]=ib;ma=c,na=Il(c+88|0,y,g)+1|0,p[ma+44>>2]=na;break n}d=p[t>>2];if((d|0)>(f|0)){break n}p[c+104>>2]=u;p[c+108>>2]=k;p[c+96>>2]=0;p[c+100>>2]=d;ma=c,na=Wf(c+96|0,c+104|0),p[ma+80>>2]=na;p[c+84>>2]=ib;p[c+72>>2]=1;p[c+76>>2]=0;ma=c,na=Wf(c+80|0,c+72|0),p[ma+88>>2]=na;p[c+92>>2]=ib;ma=c,na=Il(c+88|0,y,g)+1|0,p[ma+44>>2]=na}En(c+44|0,1,p[c+68>>2]);d=p[c+44>>2];break k}d=0}if((d|0)>0){break f}}p[A+624>>2]=0;p[t>>2]=0;p[h>>2]=0;p[h+4>>2]=0;p[G>>2]=0;eva(h,z,x);p[H>>2]=p[H>>2]+p[F>>2];p[C>>2]=p[C>>2]+p[E>>2];p[E>>2]=0;p[F>>2]=0;p[l>>2]=p[l>>2]&-129;break e}r:{s:{if(s[a+24608>>2]>r[c+30>>1]){B=4;if(p[G>>2]){break s}B=0;if(p[T>>2]|p[U>>2]){break s}}ma=c,na=NNa(p[w>>2],p[w+4>>2],d,d>>31),p[ma+104>>2]=na;p[c+108>>2]=ib;Kb(h,c+104|0);B=0;p[E>>2]=0;p[F>>2]=0;z=(d<<3)+z|0;break r}f=(d<<3)+z|0;e=f+ -8|0;p[F>>2]=0-p[e>>2];j=f+ -4|0;p[E>>2]=0-p[j>>2];m[p[((B|ea)<<2)+77504>>2]](h,Z,z,d);p[F>>2]=p[F>>2]+p[e>>2];p[E>>2]=p[E>>2]+p[j>>2];B=1;z=f}f=p[G>>2];t:{if(!f){break t}if(f>>>0<=d>>>0){p[G>>2]=0;p[U>>2]=p[ka>>2];p[T>>2]=p[ja>>2];p[ia>>2]=0;p[ha>>2]=0;if(p[ga>>2]|!(q[l+1|0]&16)){break t}p[t>>2]=0;p[A+624>>2]=0;break t}p[G>>2]=f-d}f=0;e=0;j=p[h+4>>2];if(s[I>>2]<=j>>>0){e=(q[l|0]&2)>>>1|0}g=p[t>>2];if(!(p[l>>2]&2|(g>>>0>j>>>0|!g))){f=!r[fa>>1]}x=x-d|0;vb(c+104|0,M,85);u:{v:{w:{x:{if(!tb(c+104|0)){break x}d=q[S|0];if(!d|r[a+480190>>1]<d>>>0){break x}g=!(f|e);j=p[K>>2];d=v(q[S|0],104)+a|0;f=d+484380|0;if(g|(j|0)==(f|0)){break w}p[K>>2]=f;p[A+624>>2]=p[d+484400>>2];f=r[d+484414>>1];p[l>>2]=f|p[l>>2]&-768;e=f<<30>>31;f=p[d+484388>>2];p[t>>2]=e&f;d=p[d+484384>>2];p[L>>2]=d;p[I>>2]=f;p[h+4>>2]=d;QA(la,h);if(!p[A+624>>2]){break e}if((x|0)>0){continue}break e}if(e){break v}break u}if(!e|(f|0)!=(j|0)){break u}}vb(c+104|0,M,83);if(!tb(c+104|0)|p[L>>2]){break u}p[h>>2]=p[h>>2];p[h+4>>2]=0;d=p[p[K>>2]+8>>2];p[t>>2]=d;p[I>>2]=d}if((x|0)>0){continue}}break}p[A+624>>2]=p[c+8>>2];o[c+30>>1]=r[c+30>>1]+B;y:{if(!B|(!D|D>>>0>250)){break y}d=p[(v(D,160)+a|0)+906140>>2];if(!d){break y}m[p[p[d>>2]+144>>2]](d)}e=r[a+480212>>1]}N=N+1|0;if(N>>>0<(e&65535)>>>0){continue}break}}ma=a,na=r[Bi(a+480214|0,c+30|0)>>1],o[ma+480214>>1]=na}fb=c+112|0}function kIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0;d=fb-272|0;fb=d;Ac(b);e=d+112|0;g=hIa(b,e);if(!g){UQ(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!g){break i}if(!WQ(d+112|0)){break i}if(!c){f=1;break i}xd(a,p[((q[d+228|0]|q[d+229|0]<<8)<<2)+12976>>2]);e=Mb(d+16|0,13016);xb(a+1304436|0,e);pb(e);e=Mb(d+16|0,13038);xb(a+1304448|0,e);pb(e);e=Mb(d+80|0,13042);p[114610]=0;K(219,d+96|0,e|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(427,d+16|0,d+96|0,d+191|0,d+188|0);f=p[114610];p[114610]=0;if((f|0)==1){break d}xb(a+1304460|0,d+16|0);pb(d+16|0);yb(d+96|0);pb(e);Ec(a+1304484|0,((q[d+228|0]|q[d+229|0]<<8)<<2)+13072|0);Ec(a+1304472|0,p[((q[d+228|0]|q[d+229|0]<<8)<<2)+77408>>2]);p[a+1304496>>2]=4;Eg(d+96|0,2,d+112|4);zc(d+16|0,d+96|0);xb(a+1304400|0,d+16|0);pb(d+16|0);Eg(d+96|0,2,d+148|0);zc(d+16|0,d+96|0);if(tz(d+16|0,13112)){p[114610]=0;N(13,d+96|0,4,d+16|0);e=p[114610];p[114610]=0;if((e|0)==1){break h}xb(a+1304412|0,d+96|0);pb(d+96|0)}pb(d+16|0);o[a+480188>>1]=32;e=0;j:{while(1){g=(e<<5)+a|0;i=g+480280|0;Fg(i);k:{f=d+e|0;if(q[f+193|0]<=15){p[d+16>>2]=q[f+193|0]<<4|8;p[d+96>>2]=256;x=g+480284|0,y=p[Yd(d+16|0,d+96|0)>>2],o[x>>1]=y;break k}if(q[f+193|0]==16){o[g+480284>>1]=128;p[i>>2]=256;break k}if(q[f+193|0]!=255){break k}o[a+480188>>1]=e;break j}e=e+1|0;if((e|0)!=32){continue}break}e=r[a+480188>>1]}f=0;if(!(e&65535)){break i}p[d+16>>2]=q[d+225|0]<<2;p[d+96>>2]=256;x=a,y=p[Cb(d+16|0,d+96|0)>>2],p[x+480200>>2]=y;p[a+480196>>2]=q[d+226|0];p[a+480204>>2]=v(q[d+227|0],1e4);if(Jc(b,q[d+230|0]|q[d+231|0]<<8|(q[d+232|0]<<16|q[d+233|0]<<24))){rp(Ob(a+484360|0),b,q[d+234|0]+1|0,255,254)}if(!Jc(b,q[d+240|0]|q[d+241|0]<<8|(q[d+242|0]<<16|q[d+243|0]<<24))){break i}o[a+480190>>1]=q[d+248|0]+1;h=d+48|0;e=1;i=1;while(1){if(jIa(b,d+16|0)){f=v(e,104)+a|0;g=f+484380|0;vd(g,0);Eg(d,2,d+16|0);zc(d+96|0,d);p[114610]=0;J(369,((e<<5)+a|0)+946300|0,d+96|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break e}pb(d+96|0);mk(d,2,h);zc(d+96|0,d);p[114610]=0;J(370,f+484423|0,d+96|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break f}pb(d+96|0);e=f+484404|0;p[e>>2]=q[d+74|0]|q[d+75|0]<<8;l:{if(!dt(a)){break l}j=p[e>>2];e=0;while(1){if((j|0)==r[(e<<1)+13120>>1]){n[f+484417|0]=e<<4;break l}e=e+1|0;if((e|0)!=16){continue}break}}o[f+484412>>1]=64;p[g>>2]=q[d+61|0]|q[d+62|0]<<8|(q[d+63|0]<<16|q[d+64|0]<<24);if(q[d+73|0]&2){e=f+484414|0;o[e>>1]=r[e>>1]|1;p[g>>2]=p[g>>2]>>>1}p[f+484384>>2]=q[d+65|0]|q[d+66|0]<<8|(q[d+67|0]<<16|q[d+68|0]<<24);p[f+484388>>2]=(q[d+69|0]|q[d+70|0]<<8|(q[d+71|0]<<16|q[d+72|0]<<24))+ -1;if(n[d+73|0]&1){e=f+484414|0;o[e>>1]=r[e>>1]|2}m:{if(q[d+73|0]&4){n[d+96|0]=q[d+76|0];n[d|0]=64;x=f+484410|0,y=q[hc(d+96|0,d)|0]<<2,o[x>>1]=y;break m}e=f+484414|0;o[e>>1]=r[e>>1]|32768}n:{if(!(q[d+73|0]&8)){o[f+484408>>1]=128;break n}e=f+484414|0;o[e>>1]=r[e>>1]|32;g=f+484408|0;if(q[d+77|0]<=15){f=q[d+77|0];p[d>>2]=256;p[d+96>>2]=f<<4|8;k=p[Yd(d+96|0,d)>>2]}else{k=128}o[g>>1]=k;o[e>>1]=r[e>>1]&65279|(q[d+77|0]==16)<<8}i=i+1|0;e=i&65535;if(e>>>0<=r[a+480190>>1]){continue}}break}o:{if(!(c&2)){break o}if(!Jc(b,q[d+244|0]|q[d+245|0]<<8|(q[d+246|0]<<16|q[d+247|0]<<24))|!r[a+480190>>1]){break o}e=1;while(1){f=v(e&65535,104)+a|0;fg(Tc(d+16|0,o[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);e=e+1|0;if((e&65535)>>>0<=r[a+480190>>1]){continue}break}}m=a+484344|0;Pf(m,q[d+239|0]+1|0);j=Tna(Bo(a));Jc(b,q[d+235|0]|q[d+236|0]<<8|(q[d+237|0]<<16|q[d+238|0]<<24));u=c&1;i=0;s=1;while(1){c=kg(b);if(c>>>0>=3){ld(d+16|0,b,c+ -2|0);p:{if(!u){break p}p[114610]=0;c=M(337,d+16|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break g}if(!c){break p}p[114610]=0;c=P(402,m|0,i&65535,64)|0;e=p[114610];p[114610]=0;if((e|0)==1){break g}l=0;if(!c){break p}while(1){c=Rb(m,i);p[114610]=0;w=J(497,c|0,l|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break g}q:{r:while(1){p[114610]=0;c=M(387,d+16|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break g}if(!c){break q}e=c&31;if(r[a+480188>>1]<=e>>>0){break q}f=v(e,6)+w|0;s:{if(c&32){p[114610]=0;K(472,d+96|0,d+16|0);e=p[114610];p[114610]=0;if((e|0)==1){break g}g=Zc(d+96|0);e=d+96|0;h=q[e|0];if(h){k=e;e=(h&127)+ -1|0;n[k|0]=e;n[f|0]=(v((e&240)>>>4|0,12)+(e&15)|0)+13;p[114610]=0;e=M(614,f|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break s}s=e&s}n[f+1|0]=q[g|0]}if(!(c&64)){continue}n[f+2|0]=0;n[f+3|0]=0;g=f+5|0;while(1){p[114610]=0;c=J(258,d+16|0,2)|0;e=p[114610];p[114610]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if((e|0)!=1){if(!c){continue r}k=q[g|0];c=q[f+3|0];p[114610]=0;K(472,d+96|0,d+16|0);e=p[114610];p[114610]=0;if((e|0)==1){break g}h=q[Zc(d+96|0)|0];n[g|0]=h;t=d+96|0;e=q[(q[t|0]&31)+13152|0];n[f+3|0]=e;switch(e+ -2|0){case 2:case 3:case 6:case 7:case 8:case 9:case 10:case 12:case 14:case 15:case 16:break v;case 18:break z;case 13:break A;case 17:break B;case 11:break C;case 5:break D;case 4:break E;case 1:break F;case 0:break G;default:break y}}break g}if(h>>>0<224){break t}break u}if(h>>>0>=224){break u}break t}e=h&240;if(!e){break t}n[g|0]=e;break w}e=h&240;if(!e){break t}n[g|0]=e;break w}p[114610]=0;n[d|0]=64;e=J(391,g|0,d|0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){n[g|0]=q[e|0];p[114610]=0;e=J(615,j|0,1)|0;h=p[114610];p[114610]=0;if((h|0)==1){break g}if(!e){break w}n[f+2|0]=1;n[f+4|0]=q[g|0];n[f+3|0]=c;n[g|0]=k;e=c;break v}break g}p[114610]=0;e=J(616,j|0,19)|0;h=p[114610];p[114610]=0;if((h|0)==1){break g}if(e){break w}p[114610]=0;S(617,f|0);e=p[114610];p[114610]=0;if((e|0)!=1){break w}break g}p[114610]=0;e=J(616,j|0,15)|0;h=p[114610];p[114610]=0;if((h|0)==1){break g}if(e){break w}p[114610]=0;e=J(616,j|0,19)|0;h=p[114610];p[114610]=0;if((h|0)==1){break g}if(!e){break w}n[f+3|0]=19;n[g|0]=q[g|0]&15|144;break t}H:{e=h>>>4|0;if((e|0)!=8){if(e){break H}I:{switch(h&15){case 4:n[f+3|0]=20;n[g|0]=158;break t;case 0:case 1:break x;case 5:break I;default:break H}}n[f+3|0]=20;n[g|0]=159;break t}p[114610]=0;e=J(616,j|0,20)|0;h=p[114610];p[114610]=0;if((h|0)==1){break g}if(e){break w}n[f+3|0]=19;break t}n[f+3|0]=0;break t}if((e|0)!=31){break v}n[f+3|0]=17;break t}n[g|0]=h+ -112}e=q[f+3|0]}if((e&255)!=20){break t}e=q[g|0];if(q[f+2|0]|(e&240)!=128){break t}n[f+2|0]=2;n[f+4|0]=(((e&15)<<6|8)>>>0)/15;n[f+3|0]=c;n[g|0]=k;break t}n[g|0]=223}if(q[t|0]&32){continue}break}continue}break}break g}l=l+1|0;if((l|0)!=64){continue}break}}sb(d+16|0)}c=i>>>0<q[d+239|0];i=i+1|0;if(c){continue}break}c=a;if((s^-1|r[a+480188>>1]!=4)&1|p[a+480180>>2]!=1){e=p[a+480208>>2]&-8454145}else{e=p[a+480208>>2]|8454144}p[c+480208>>2]=e;f=1;if(!(q[d+253|0]|q[d+254|0]<<8|(q[d+255|0]<<16|q[d+256|0]<<24))){break i}if(!Jc(b,q[d+249|0]|q[d+250|0]<<8|(q[d+251|0]<<16|q[d+252|0]<<24))){break i}fy(a+1304424|0,b,q[d+253|0]|q[d+254|0]<<8|(q[d+255|0]<<16|q[d+256|0]<<24),4)}fb=d+272|0;return f|0}f=I()|0;H()|0;pb(d+16|0);break a}f=I()|0;H()|0;sb(d+16|0);break a}f=I()|0;H()|0;pb(d+96|0);break a}f=I()|0;H()|0;pb(d+96|0);break a}f=I()|0;H()|0;yb(d+96|0);break b}f=I()|0;H()|0}pb(e)}L(f|0);E()}function eNa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0;e=fb-176|0;fb=e;Ac(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!mT(b,e+128|0)){break h}if(!nT(e+128|0)){break h}if(!c){m=1;break h}xd(a,2048);ei(a);d=Mb(e+96|0,12026);p[114610]=0;K(219,e+112|0,d|0);i=p[114610];p[114610]=0;if((i|0)==1){break c}p[114610]=0;k=e+128|3;N(383,e+80|0,e+112|0,k|0);i=p[114610];p[114610]=0;if((i|0)==1){break d}xb(a+1304436|0,e+80|0);pb(e+80|0);yb(e+112|0);pb(d);d=Mb(e+80|0,12022);xb(a+1304448|0,d);pb(d);p[a+1304496>>2]=4;o[a+480188>>1]=q[e+168|0];o[a+480190>>1]=q[e+164|0];Eg(e+112|0,2,e+128|4);zc(e+80|0,e+112|0);xb(a+1304400|0,e+80|0);pb(e+80|0);if(q[k|0]<=9){o[a+480188>>1]=4;jg(b,1);Xi(a,1)}d=q[k|0];i:{if(q[k|0]>=11){i=d>>>0>11?32:16;d=0;while(1){h=((d<<5)+a|0)+480284|0;g=DT(b)<<1;g=(g|0)>-128?g:-128;j:{if((g|0)<129){d=g+128|0;break j}p[((d<<5)+a|0)+480280>>2]=256;d=128}o[h>>1]=d;f=f+1|0;d=f&65535;if(i>>>0>d>>>0){continue}break}break i}if((d|0)!=10){break i}lT(b,e+80|0);d=0;while(1){o[((d<<5)+a|0)+480284>>1]=n[(e+80|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}k:{if(q[k|0]>=13){Dt(e+80|0,b);f=Zc(e+80|0);i=a;h=e+80|0;d=q[h|0];if(d>>>0<=31){n[h|0]=125;d=125}p[i+480204>>2]=v(d,1e4);p[a+480196>>2]=q[f|0];break k}p[a+480196>>2]=6;p[a+480204>>2]=125e4}i=a+484360|0;ig(Ob(i),q[e+165|0]);t=wn(e+112|0);w=p[b+8>>2];j=q[k|0];l:{if(q[k|0]<14){break l}d=q[e+165|0];p[114610]=0;K(384,t|0,d|0);d=p[114610];p[114610]=0;if((d|0)!=1){break l}b=I()|0;H()|0;break e}m:{n:{o:{p:{q:{r:{s:{t:{u:{if(q[e+165|0]){d=0;while(1){z=kc(Ob(i),d),A=d,o[z>>1]=A;if(q[k|0]>=14){p[114610]=0;f=M(357,b|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break u}z=kc(t,d),A=f,o[z>>1]=A}f=r[a+480188>>1];p[114610]=0;J(338,b|0,f<<1)|0;f=p[114610];p[114610]=0;if((f|0)==1){break u}d=d+1|0;if(d>>>0<q[e+165|0]){continue}break}}d=r[a+480190>>1];p[114610]=0;p[e+80>>2]=0;u=P(385,e- -64|0,d|0,e+80|0)|0;d=p[114610];p[114610]=0;f=1;if((d|0)!=1){p[e+60>>2]=0;v:{if(r[a+480190>>1]){i=1;while(1){p[114610]=0;h=v(f,104)+a|0;g=h+484380|0;K(386,g|0,0);d=p[114610];p[114610]=0;if((d|0)==1){break v}p[114610]=0;l=M(387,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}p[114610]=0;P(388,b|0,((f<<5)+a|0)+946300|0,32)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}p[114610]=0;P(389,b|0,h+484423|0,13)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}p[114610]=0;d=M(390,b|0)|0;m=p[114610];p[114610]=0;if((m|0)==1){break g}m=f+ -1|0;z=Fb(u,m),A=d,p[z>>2]=A;w:{if(q[k|0]<=9){p[114610]=0;f=M(357,b|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break w}break g}p[114610]=0;f=M(390,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}}p[g>>2]=f;p[114610]=0;d=M(357,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break g}p[h+484404>>2]=d;p[114610]=0;d=M(387,b|0)|0;f=p[114610];p[114610]=0;x:{y:{z:{if((f|0)!=1){p[114610]=0;n[e+80|0]=d;n[e+48|0]=64;d=J(391,e+80|0,e+48|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break z}o[h+484410>>1]=q[d|0]<<2;if(q[k|0]>9){break y}p[114610]=0;d=M(357,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break g}p[h+484384>>2]=d;p[114610]=0;d=M(357,b|0)|0;break x}b=I()|0;H()|0;break f}b=I()|0;H()|0;break f}p[114610]=0;d=M(390,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break g}p[h+484384>>2]=d;p[114610]=0;d=M(390,b|0)|0}f=p[114610];p[114610]=0;if((f|0)==1){break g}f=h+484388|0;p[f>>2]=d;if(l){l=h+484384|0;A:{if(!(d>>>0<=p[l>>2]+2>>>0|d>>>0>s[g>>2])){d=h+484414|0;o[d>>1]=r[d>>1]|2;break A}p[f>>2]=0;p[l>>2]=0}d=Fb(u,m);p[114610]=0;d=J(392,e+60|0,d|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break g}p[e+60>>2]=p[d>>2]}i=i+1|0;f=i&65535;if(f>>>0<=r[a+480190>>1]){continue}break}}h=Ct(e+48|0);d=q[e+166|0]|q[e+167|0]<<8;p[114610]=0;m=P(393,b|0,h|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break t}if(!m){break m}i=0;B:{if(!cd(h)){d=Ub(h);i=Vb(h);p[114610]=0;d=J(394,d|0,i|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break B}p[e+80>>2]=d;d=p[e+80>>2];i=q[d|0]|q[d+1|0]<<8}p[114610]=0;f=i;l=J(395,e+32|0,f|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){C:{if(f){d=0;while(1){p[114610]=0;J(396,b|0,e+24|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break s}p[114610]=0;N(341,e+80|0,b|0,v(q[e+24|0]|q[e+25|0]<<8|q[e+26|0]<<16,3)|0);g=p[114610];p[114610]=0;if((g|0)==1){break C}Nd(jc(l,d),e+80|0);sb(e+80|0);d=d+1|0;if((f|0)!=(d|0)){continue}break}}if(c&2){x=Tc(e+24|0,8,1,0,1);p[114610]=0;g=J(397,e+80|0,u|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break q}d=Ub(g);f=Vb(g);p[114610]=0;K(398,d|0,f|0);d=p[114610];p[114610]=0;if((d|0)==1){break r}d=Ub(g);f=Vb(g);p[114610]=0;d=J(399,d|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break r}p[e+16>>2]=d;z=e,A=Ub(g),p[z+8>>2]=A;D:{if(!Ab(e+8|0,e+16|0)){break D}while(1){p[114610]=0;d=J(258,b|0,1)|0;f=p[114610];p[114610]=0;E:{if((f|0)!=1){if(!d){break D}d=0;if(!r[a+480190>>1]){break E}while(1){p[114610]=0;f=J(258,b|0,1)|0;y=p[114610];p[114610]=0;if((y|0)==1){break r}if(!f){break E}f=d+1|0;if(p[p[e+8>>2]>>2]!=p[Fb(u,d)>>2]){d=f;if(d>>>0>=r[a+480190>>1]){break E}continue}break}p[114610]=0;P(400,x|0,(v(f,104)+a|0)+484380|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break E}break r}break r}gT(e+8|0);if(Ab(e+8|0,e+16|0)){continue}break}}be(g)}if(!(c&1)){break n}c=q[e+165|0];p[114610]=0;g=a+484344|0;K(401,g|0,c|0);c=p[114610];p[114610]=0;F:{if((c|0)!=1){if(!q[e+165|0]){break n}w=w+((j>>>0>13)<<1)|0;c=0;while(1){G:{f=64;if(fc(t)>>>0>c>>>0){f=r[kc(t,c)>>1]}p[114610]=0;d=P(402,g|0,c&65535,f&65535)|0;f=p[114610];p[114610]=0;if((f|0)==1){break F}H:{if(d){d=r[a+480188>>1];f=q[k|0];p[114610]=0;J(256,b|0,w+v(((f>>>0>13)<<1)+(d<<1)|0,c)|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break F}f=Ct(e+80|0);d=r[a+480188>>1];p[114610]=0;d=P(393,b|0,f|0,d|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break H}I:{if(!d){break I}d=0;if(!r[a+480188>>1]){break I}while(1){J:{j=kc(f,d);if(!(q[j|0]|q[j+1|0]<<8)){break J}j=kc(f,d);if((q[j|0]|q[j+1|0]<<8)>>>0>(q[e+166|0]|q[e+167|0]<<8)>>>0){break J}j=kc(f,d);j=kc(h,(q[j|0]|q[j+1|0]<<8)+ -1|0);j=(q[j|0]|q[j+1|0]<<8)+ -1&65535;if(j>>>0>=i>>>0){break J}x=Rb(g,c);j=jc(l,j);p[114610]=0;N(403,x|0,d&65535,j|0);j=p[114610];p[114610]=0;if((j|0)!=1){break J}break G}d=d+1|0;if(d>>>0<r[a+480188>>1]){continue}break}}tk(f)}c=c+1|0;if(c>>>0>=q[e+165|0]){break n}continue}}break}b=I()|0;H()|0;tk(f);break p}b=I()|0;H()|0;break p}b=I()|0;H()|0;break p}b=I()|0;H()|0;break p}b=I()|0;H()|0;break o}b=I()|0;H()|0;break o}b=I()|0;H()|0;break f}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;break o}b=I()|0;H()|0;break p}b=I()|0;H()|0;be(g);break p}b=I()|0;H()|0}$c(l)}tk(h);break f}$c(l)}tk(h);be(u);qf(t)}fb=e+176|0;return m|0}b=I()|0;H()|0}be(u)}qf(t);break a}b=I()|0;H()|0;yb(e+112|0);break b}b=I()|0;H()|0}pb(d)}L(b|0);E()}function yCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,J=0,O=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=fb-336|0;fb=d;a:{if(!Jc(b,1080)){break a}if(!ln(b,d+332|0)){break a}xd(a,1);t=WO(d+312|0);if(!VO(d+332|0,t)){break a}f=r[t+8>>1];if((f+ -1&65535)>>>0>126){break a}if(!c){e=1;break a}o[a+480188>>1]=f;_=q[t+12|0];Q=q[t+11|0];e=q[t+10|0];F=1;if(!Sd(d+332|0,15570)){F=Sd(d+332|0,15575)}if(q[t+13|0]){Eb(a+1074308|0,5,1)}B=a+480188|0;x=Q?r[B>>1]==8:0;y=Sd(d+332|0,15580);f=1;if(!Sd(d+332|0,15585)){f=Sd(d+332|0,15590)}Jc(b,0);Zz(b,a+1304400|0,20);o[a+480190>>1]=31;j=(e|0)!=0;g=d+204|0;i=d+198|0;l=d+200|0;e=1;while(1){w=v(e,104)+a|0;m=w+484380|0;z=Jy(b,d+176|0,m,((e<<5)+a|0)+946300|0,r[a+480188>>1]==4);m=p[m>>2];b:{if(f){n[w+484417|0]=0-(q[l|0]<<3);break b}j=m>>>0<65536&j}G=q[i|0]|q[i+1|0]<<8?!(q[g|0]|q[g+1|0]<<8)|G:G;J=z+J|0;h=h+m|0;e=e+1|0;if((e|0)!=32){continue}break}c:{d:{e:{f:{g:{h:{i:{j:{R=p[t+4>>2];if(J>>>0<=R>>>0){Iy(b,d+176|0);Sb(b,4);e=128;i=a+484360|0;qn(Ob(i),d+176|2,128,65535,65535);f=q[d+176|0];k:{if(f>>>0>128){break k}e=f;if(e){break k}f=128;while(1){g=f+ -1|0;if(!r[kc(Ob(i),g)>>1]){e=1;f=g;if(g>>>0>1){continue}break k}break}e=f}h=TO(b,Ob(i),e&65535,h,B,y);if(!(!y|r[a+480188>>1]!=8)){p[t>>2]=15595}l:{if(!x){break l}f=Ob(i);da=d,ea=Ub(f),p[da+160>>2]=ea;da=d,ea=Vb(f),p[da+144>>2]=ea;if(!Ab(d+160|0,d+144|0)){break l}while(1){f=p[d+160>>2];o[f>>1]=r[f>>1]>>>1;te(d+160|0);if(Ab(d+160|0,d+144|0)){continue}break}}w=d+176|1;Pe(Ob(i),q[w|0]);S=e+ -1&65535;if(!(q[w|0]!=120|r[B>>1]!=4?S>>>0>=q[w|0]:0)){Pe(Ob(i),0)}p[a+480260>>2]=56;p[a+480264>>2]=13696;p[a+480204>>2]=125e4;p[a+480196>>2]=6;e=0;f=Pb(256/r[a+480188>>1]|0,32,128);p[a+480208>>2]=0;p[a+480228>>2]=f;Xi(a,0);n[d+175|0]=0;z=1;T=1;if(!(j&1)){m:{if(!h){m=0;j=0;e=y;break m}A=d+160|5;e=y;g=0;j=0;m=0;while(1){i=0;f=0;while(1){l=jj(d+160|0);Ns(b,l);l=VQ(l);k=q[d+163|0];n:{if((k+ -7&255)>>>0>=3){e=l?e:0;o:{p:{switch(k+ -13|0){case 1:k=q[d+165|0];e=k>>>0>1?0:e;if((k&240)!=128){break n}n[d+144|0]=k<<4;da=d,ea=q[dh(d+175|0,d+144|0)|0],n[da+175|0]=ea;break n;case 2:if(q[d+165|0]>31){break o}break n;case 0:break p;default:break n}}f=f+1|0;if((f&65535)>>>0<2){break n}}e=0;break n}e=0;if((k|0)!=8){break n}da=d,ea=q[dh(d+175|0,A)|0],n[da+175|0]=ea;k=n[d+165|0];if((k|0)>-1){m=1;break n}j=(k|0)!=-92&(k&255)>>>0>143|j}z=l&z;i=i+1|0;if((i|0)!=256){continue}break}g=g+1|0;if((g&65535)>>>0<h>>>0){continue}break}}T=e&1;e=(j^1)&m}Jc(b,1084);m=4;m=x?m:r[B>>1];A=a+484344|0;C=h+x&65535;Pf(A,C);q:{r:{s:{t:{u:{if(!C){break u}$=a+1074308|0;aa=e^1;ba=c&1;l=0;while(1){f=!ba;v:{if(x){e=(l&65534)>>>1|0;h=l&1;if(!h){if(!ag(A,e,64)){break u}}j=_e(Rb(A,e),0,h<<2);break v}if(!ag(A,l&65535,64)){break u}j=_e(Rb(A,l),0,0)}if(f|!j){break u}e=r[a+480188>>1];n[d+144|0]=0;k=pt(d+160|0,e,d+144|0);e=r[a+480188>>1];p[114610]=0;n[d+64|0]=0;D=P(886,d+144|0,e|0,d- -64|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break t}O=0;while(1){f=0;U=0;i=0;e=0;if(m){while(1){p[114610]=0;g=v(i,6)+j|0;K(887,b|0,g|0);h=p[114610];p[114610]=0;w:{x:{y:{if((h|0)==1){break y}h=q[g+3|0];z:{A:{B:{if(!h){if(q[g+5|0]){break B}break A}if(!Q){break B}C:{switch(h+ -14|0){case 0:n[g+3|0]=0;n[g+5|0]=0;break B;case 1:break C;default:break B}}if(q[g+5|0]<32){break B}n[g+5|0]=31}fj(g);h=1;D:{E:{F:{s=q[g+3|0];switch(s+ -14|0){case 2:break z;case 0:break E;case 3:break F;default:break D}}V=q[g+5|0]<100|V;U=1;break A}if(!T){break A}n[g+5|0]=0;break A}if(!(((s|0)!=9|aa)&1)){h=q[g+5|0];if((h|0)==164){n[g+3|0]=20;n[g+5|0]=145;break A}p[114610]=0;h=M(888,h<<1)|0;s=p[114610];p[114610]=0;if((s|0)==1){break y}n[g+5|0]=h;break A}if((s|0)!=19){break A}h=q[g+5|0];if(h>>>0>15){break A}s=h&1;h=s^1;ca=!s;s=W&1;W=(s|0)==(h|0)?W:ca;X=((h|0)!=(s|0))+X|0}h=f}if(q[g|0]){break x}if(!q[g+1|0]|x){break w}if(!q[oc(k,i)|0]){break w}if(q[oc(k,i)|0]==q[g+1|0]){break w}s=oc(D,i);f=q[s|0]+1|0;n[s|0]=f;if((f&255)>>>0<4){break w}p[114610]=0;P(478,$|0,85,1)|0;f=p[114610];p[114610]=0;if((f|0)!=1){break w}}e=I()|0;H()|0;Xd(D);break s}da=oc(D,i),ea=0,n[da|0]=ea}f=q[g+1|0];if(f){da=oc(k,i),ea=f,n[da|0]=ea}f=h;e=e+1|0;i=e&65535;if(m>>>0>i>>>0){continue}break}}Y=f&U|Y;j=v(r[B>>1],6)+j|0;O=O+1|0;if((O|0)!=64){continue}break}Xd(D);Xd(k);l=l+1|0;if((C|0)!=(l|0)){continue}break}}G:{f=z^1;if((f|G)&1){break G}H:{if(Sd(d+332|0,15580)){break H}if(Sd(d+332|0,15607)){break H}if(!Sd(d+332|0,15612)){break G}}p[a+480208>>2]=p[a+480208>>2]|2162688;e=a+1074308|0;Eb(e,85,1);Eb(e,91,1);Eb(e,92,1);I:{if(q[d+175|0]>31){break I}Eb(e,84,1);if(q[w|0]==127){break I}Eb(e,83,1)}if(!z){break q}break r}if(z){break r}if(y^1|q[w|0]!=127|q[w|0]+1>>>0<S>>>0){break q}p[t>>2]=15617;break q}e=I()|0;H()|0}Xd(k);break c}if((X|0)>6|_){break q}p[a+480208>>2]=p[a+480208>>2]|8388608}if(F){Eb(a+1074308|0,84,1)}if(c&2){Jc(b,(v(m,C)<<8)+1084|0);h=f|y^1;e=1;while(1){j=v(e,104)+a|0;c=j+484380|0;if(p[c>>2]){g=d+160|0;if(F){f=2}else{f=SO(b,15631)?11:0}f=Tc(g,8,1,0,f);x=p[b+8>>2]+JQ(f,p[c>>2])|0;if(!h){da=c,ea=p[Uc(c,j+484388|0)>>2],p[da>>2]=ea}fg(f,c,b);Jc(b,x)}e=e+1|0;if((e|0)!=32){continue}break}}J:{if((y&V^-1|Y)&1){break J}b=RO(d+120|0,0);c=p[b+20>>2];p[d+40>>2]=p[b+16>>2];p[d+44>>2]=c;c=p[b+12>>2];p[d+32>>2]=p[b+8>>2];p[d+36>>2]=c;c=p[b+4>>2];p[d+24>>2]=p[b>>2];p[d+28>>2]=c;ds(d+160|0,a,0,d+24|0);Z=u[p[d+160>>2]>>3];ck(d+160|0);if(Z<600){break J}c=a+1074308|0;Eb(c,5,1);b=QO(d+96|0,Z);e=p[b+20>>2];p[d+16>>2]=p[b+16>>2];p[d+20>>2]=e;e=p[b+12>>2];p[d+8>>2]=p[b+8>>2];p[d+12>>2]=e;e=p[b+4>>2];p[d>>2]=p[b>>2];p[d+4>>2]=e;ds(d+160|0,a,0,d);b=q[p[d+160>>2]+26|0];ck(d+160|0);if(b){Ag(c,5);break J}p[t>>2]=15637}xCa(d+332|0,_b(d+332|0),d+332|0);b=Mb(d+80|0,15657);p[114610]=0;K(219,d+144|0,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break j}c=_b(d+332|0);p[114610]=0;c=P(889,d+48|0,d+332|0,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}p[114610]=0;N(13,d- -64|0,1,c|0);e=p[114610];p[114610]=0;if((e|0)==1){break h}p[114610]=0;N(247,d+160|0,d+144|0,d- -64|0);e=p[114610];p[114610]=0;if((e|0)==1){break g}xb(a+1304436|0,d+160|0);pb(d+160|0);pb(d- -64|0);pb(c);yb(d+144|0);pb(b);b=Mb(d+160|0,15677);xb(a+1304448|0,b);pb(b);b=p[t>>2];if(b){Ec(a+1304460|0,b)}p[a+1304496>>2]=2}e=J>>>0<=R>>>0;break a}e=I()|0;H()|0;break d}e=I()|0;H()|0;break e}e=I()|0;H()|0;break f}e=I()|0;H()|0;pb(d- -64|0)}pb(c)}yb(d+144|0)}pb(b)}L(e|0);E()}fb=d+336|0;return e|0}function N0(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,o=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;l=fb-560|0;fb=l;p[l+548>>2]=k;p[l+552>>2]=b;p[l+96>>2]=2482;s=Hd(l+136|0,l+144|0,l+96|0);b=p[s>>2];p[l+132>>2]=b;p[l+128>>2]=b+400;u=Lb(l+96|0);r=Ue(l+80|0);m=Ue(l- -64|0);o=Ue(l+48|0);t=Ue(l+32|0);p[114610]=0;ga(2494,c|0,d|0,l+120|0,l+116|0,l+112|0,u|0,r|0,m|0,o|0,l+28|0);b=p[114610];p[114610]=0;if((b|0)!=1){a:{p[j>>2]=p[i>>2];v=e&512;w=v>>>9|0;k=0;e=0;while(1){b=e;b:{c:{d:{e:{if((k|0)==4){break e}p[114610]=0;c=J(2454,a|0,l+552|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(!c){break e}c=0;f:{g:{h:{i:{j:{switch(n[(l+120|0)+k|0]){case 1:if((k|0)==3){break c}p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;c=P(2495,h|0,8192,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(c){p[114610]=0;N(2496,l+16|0,a|0,0);c=p[114610];p[114610]=0;if((c|0)!=1){c=p[l+16>>2];p[114610]=0;K(112,t|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){break i}}break a}p[f>>2]=p[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((k|0)==3){break c}}while(1){p[114610]=0;c=J(2454,a|0,l+552|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(!c){break c}p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;c=P(2495,h|0,8192,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(!c){break c}p[114610]=0;N(2496,l+16|0,a|0,0);c=p[114610];p[114610]=0;if((c|0)!=1){c=p[l+16>>2];p[114610]=0;K(112,t|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}if((wb(m)|0)==(0-wb(o)|0)){break c}k:{if(wb(m)){if(wb(o)){break k}}if(wb(m)){p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if((c|0)==p[Ib(m)>>2]){p[114610]=0;M(2458,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}e=wb(m)>>>0>1?m:b;break b}n[g|0]=1;break c}p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if((c|0)!=p[Ib(o)>>2]){break c}p[114610]=0;M(2458,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}n[g|0]=1;e=wb(o)>>>0>1?o:b;break b}p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if((c|0)==p[Ib(m)>>2]){p[114610]=0;M(2458,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}e=wb(m)>>>0>1?m:b;break b}p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if((c|0)==p[Ib(o)>>2]){p[114610]=0;M(2458,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}n[g|0]=1;e=wb(o)>>>0>1?o:b;break b}p[f>>2]=p[f>>2]|4;a=0;break d}if(!(b|k>>>0<2)){e=0;if(((k|0)==2&q[l+123|0]!=0|w)!=1){break b}}y=l,z=wd(r),p[y+8>>2]=z;c=Ld(l+16|0,l+8|0);l:{if(!k|q[(k+l|0)+119|0]>1){break l}m:{while(1){y=l,z=Aj(r),p[y+8>>2]=z;if(!Ab(c,l+8|0)){break m}d=p[p[c>>2]>>2];p[114610]=0;d=P(2495,h|0,8192,d|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){if(!d){break m}Rd(c);continue}break}break a}y=l,z=wd(r),p[y+8>>2]=z;c=Ts(c,l+8|0);if(c>>>0<=wb(t)>>>0){y=l,z=Aj(t),p[y+8>>2]=z;c=DM(l+8|0,c);d=Aj(t);e=wd(r);p[114610]=0;c=cD(c,d,e);d=p[114610];p[114610]=0;if((d|0)==1){break a}if(c){break l}}y=l,z=wd(r),p[y>>2]=z;Ld(l+8|0,l);p[l+16>>2]=p[l+8>>2]}p[l+8>>2]=p[l+16>>2];n:{while(1){y=l,z=Aj(r),p[y>>2]=z;if(!Ab(l+8|0,l)){break n}p[114610]=0;c=J(2454,a|0,l+552|0)|0;d=p[114610];p[114610]=0;o:{if((d|0)==1){break o}if(!c){break n}p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break o}if((c|0)!=p[p[l+8>>2]>>2]){break n}p[114610]=0;M(2458,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}Rd(l+8|0);continue}break}break a}if(!v){break c}y=l,z=Aj(r),p[y>>2]=z;if(!Ab(l+8|0,l)){break c}p[f>>2]=p[f>>2]|4;a=0;break d}p:{while(1){q:{p[114610]=0;d=J(2454,a|0,l+552|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break q}if(!d){break p}p[114610]=0;e=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;d=P(2495,h|0,2048,e|0)|0;x=p[114610];p[114610]=0;if((x|0)==1){break a}r:{if(d){d=p[j>>2];if((d|0)==p[l+548>>2]){p[114610]=0;N(2498,i|0,j|0,l+548|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[j>>2]}p[j>>2]=d+4;p[d>>2]=e;c=c+1|0;break r}if(!c|!wb(u)|(e|0)!=p[l+112>>2]){break p}e=p[l+132>>2];if((e|0)==p[l+128>>2]){p[114610]=0;N(2489,s|0,l+132|0,l+128|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}e=p[l+132>>2]}p[l+132>>2]=e+4;p[e>>2]=c;c=0}p[114610]=0;M(2458,a|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){continue}}break}break a}d=p[s>>2];s:{if(!c){break s}e=p[l+132>>2];if((d|0)==(e|0)){break s}if(p[l+128>>2]==(e|0)){p[114610]=0;N(2489,s|0,l+132|0,l+128|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}e=p[l+132>>2]}p[l+132>>2]=e+4;p[e>>2]=c}t:{if(p[l+28>>2]<1){break t}p[114610]=0;c=J(2455,a|0,l+552|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}u:{if(!c){p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if((c|0)==p[l+116>>2]){break u}}p[f>>2]=p[f>>2]|4;a=0;break d}p[114610]=0;M(2458,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}while(1){if(p[l+28>>2]<1){break t}p[114610]=0;c=J(2455,a|0,l+552|0)|0;d=p[114610];p[114610]=0;v:{if((d|0)==1){break v}w:{if(!c){p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break v}p[114610]=0;c=P(2495,h|0,2048,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break v}if(c){break w}}p[f>>2]=p[f>>2]|4;a=0;break d}if(p[j>>2]==p[l+548>>2]){p[114610]=0;N(2498,i|0,j|0,l+548|0);c=p[114610];p[114610]=0;if((c|0)==1){break v}}p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break v}d=p[j>>2];p[j>>2]=d+4;p[d>>2]=c;p[114610]=0;p[l+28>>2]=p[l+28>>2]+ -1;M(2458,a|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}e=b;if(p[i>>2]!=p[j>>2]){break b}p[f>>2]=p[f>>2]|4;a=0;break d}x:{if(!b){break x}e=1;while(1){if(e>>>0>=wb(b)>>>0){break x}p[114610]=0;c=J(2455,a|0,l+552|0)|0;d=p[114610];p[114610]=0;y:{if((d|0)==1){break y}z:{if(!c){p[114610]=0;c=M(2456,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break y}if((c|0)==p[Ui(b,e)>>2]){break z}}p[f>>2]=p[f>>2]|4;a=0;break d}p[114610]=0;M(2458,a|0)|0;c=p[114610];p[114610]=0;e=e+1|0;if((c|0)!=1){continue}}break}break a}A:{if(p[s>>2]==p[l+132>>2]){break A}p[l+16>>2]=0;a=p[s>>2];p[114610]=0;we(u,a,p[l+132>>2],l+16|0);a=p[114610];p[114610]=0;if((a|0)!=1){if(!p[l+16>>2]){break A}p[f>>2]=p[f>>2]|4;a=0;break d}break a}a=1}yc(t);yc(o);yc(m);yc(r);pb(u);wc(s);fb=l+560|0;return a|0}e=b}k=k+1|0;continue}}}a=I()|0;H()|0;yc(t);yc(o);yc(m);yc(r);pb(u);wc(s);L(a|0);E()}function Yza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0;d=fb-272|0;fb=d;Ac(b);e=d+120|0;g=tza(b,e);if(!g){EN(e)}a:{b:{c:{d:{e:{if(!g){break e}if(!ON(d+120|0)){break e}if(!c){i=1;break e}xd(a,4194304);e=Mb(d+40|0,16806);xb(a+1304436|0,e);pb(e);e=Mb(d+40|0,16802);xb(a+1304448|0,e);pb(e);p[a+1304496>>2]=4;m=a,s=sd(q[d+198|0]|q[d+199|0]<<8,q[d+200|0]|q[d+201|0]<<8,127),o[m+480188>>1]=s;e=q[d+189|0];p[a+480228>>2]=(e|0)==255?48:e;p[a+480196>>2]=q[d+187|0];p[a+480204>>2]=v(q[d+188|0],1e4);Qe(d+104|0,d+120|4,59,3);zc(d+40|0,d+104|0);xb(a+1304400|0,d+40|0);pb(d+40|0);f:{if((q[d+202|0]|q[d+203|0]<<8|(q[d+204|0]<<16|q[d+205|0]<<24))>>>0<5){break f}if(!Jc(b,(q[d+202|0]|q[d+203|0]<<8|(q[d+204|0]<<16|q[d+205|0]<<24))+ -4|0)){break f}if(!Dh(b,16840)){break f}rp(Ob(a+484360|0),b,q[d+192|0]|q[d+193|0]<<8,65535,65535)}g:{if((q[d+206|0]|q[d+207|0]<<8|(q[d+208|0]<<16|q[d+209|0]<<24))>>>0<5){break g}if(!Jc(b,(q[d+206|0]|q[d+207|0]<<8|(q[d+208|0]<<16|q[d+209|0]<<24))+ -4|0)){break g}if(!Dh(b,16845)){break g}while(1){e=(i<<5)+a|0;Fg(e+480280|0);m=e+480284|0,s=((((td(b)^-1)&15)<<8|8)>>>0)/15|0,o[m>>1]=s;i=i+1|0;if((i|0)!=32){continue}break}}h:{if((q[d+214|0]|q[d+215|0]<<8|(q[d+216|0]<<16|q[d+217|0]<<24))>>>0<5){break h}if(!Jc(b,(q[d+214|0]|q[d+215|0]<<8|(q[d+216|0]<<16|q[d+217|0]<<24))+ -4|0)){break h}if(!Dh(b,16850)){break h}ld(d+104|0,b,(q[d+196|0]|q[d+197|0]<<8)<<6);i:{if(!(q[d+196|0]|q[d+197|0]<<8)){break i}i=c&2;g=a+480190|0;k=d+53|0;while(1){p[114610]=0;e=J(981,d+104|0,d+40|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break d}if(!e){break i}e=q[d+85|0]|q[d+86|0]<<8;o[d+38>>1]=e;j:{if((e+ -1&65535)>>>0>3998){break j}if(ue((v(e,104)+a|0)+484380|0)){break j}p[114610]=0;e=J(452,g|0,d+38|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break c}o[a+480190>>1]=r[e>>1];p[114610]=0;K(982,d+40|0,(v(r[d+38>>1],104)+a|0)+484380|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;N(983,d+8|0,1,k|0);e=p[114610];p[114610]=0;k:{l:{if((e|0)==1){break l}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break l}p[114610]=0;J(369,((r[d+38>>1]<<5)+a|0)+946300|0,d+24|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}pb(d+24|0);if(!i){break j}e=q[d+77|0]|q[d+78|0]<<8|(q[d+79|0]<<16|q[d+80|0]<<24);p[114610]=0;J(256,b|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(984,d+24|0,d+40|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;P(400,d+24|0,(v(r[d+38>>1],104)+a|0)+484380|0,b|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break j}}b=I()|0;H()|0;break b}b=I()|0;H()|0;break b}b=I()|0;H()|0;pb(d+24|0);break b}h=h+1|0;if((h&65535)>>>0<(q[d+196|0]|q[d+197|0]<<8)>>>0){continue}break}}sb(d+104|0)}i=1;if(!(c&1)){break e}m:{if((q[d+210|0]|q[d+211|0]<<8|(q[d+212|0]<<16|q[d+213|0]<<24))>>>0<5){break m}if(!Jc(b,(q[d+210|0]|q[d+211|0]<<8|(q[d+212|0]<<16|q[d+213|0]<<24))+ -4|0)){break m}if(!Dh(b,16855)){break m}j=a+484344|0;Pf(j,q[d+194|0]|q[d+195|0]<<8);if(!(q[d+194|0]|q[d+195|0]<<8)){break m}k=d+24|2;g=0;while(1){if(!vp(b,d+24|0)){break m}if((q[d+24|0]|q[d+25|0]<<8)>>>0>3){ld(d+40|0,b,((q[d+24|0]|q[d+25|0]<<8)+15&131056)+ -4|0);c=q[k|0];p[114610]=0;c=P(402,j|0,g&65535,c|0)|0;e=p[114610];p[114610]=0;n:{if((e|0)!=1){o:{h=0;if(!c){break n}while(1){p[114610]=0;c=J(258,d+40|0,1)|0;e=p[114610];p[114610]=0;p:{q:{r:{if((e|0)!=1){if(!c|h>>>0>=q[k|0]){break q}p[114610]=0;e=M(387,d+40|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break o}if(e){break r}h=h+1|0;continue}break o}c=Rb(j,g);o[d+104>>1]=e&31;f=r[a+480188>>1];p[114610]=0;o[d+8>>1]=f+ -1;f=J(477,d+104|0,d+8|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break o}f=r[f>>1];p[114610]=0;c=P(471,c|0,h|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break o}if(e&128){p[114610]=0;K(472,d+104|0,d+40|0);f=p[114610];p[114610]=0;if((f|0)==1){break o}f=Zc(d+104|0);n[c|0]=q[d+104|0]+36;n[c+1|0]=q[f|0]}if(!(e&64)){break p}n[c+2|0]=1;p[114610]=0;f=M(387,d+40|0)|0;l=p[114610];p[114610]=0;s:{if((l|0)!=1){p[114610]=0;n[d+104|0]=f;n[d+8|0]=64;f=J(391,d+104|0,d+8|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break s}n[c+4|0]=q[f|0];break p}break o}break o}if(q[k|0]==64){break n}c=Rb(j,g);p[114610]=0;e=P(498,d+104|0,14,0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){e=wi(Oe(e,q[k|0]+ -1|0));p[114610]=0;J(499,c|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break n}}break o}if(!(e&32)){continue}p[114610]=0;K(472,d+104|0,d+40|0);e=p[114610];p[114610]=0;if((e|0)!=1){e=q[Zc(d+104|0)|0];n[c+5|0]=e;t:{switch(q[d+104|0]+ -1|0){case 0:n[c+3|0]=11;n[c+5|0]=e<<4|15;continue;case 1:n[c+3|0]=11;n[c+5|0]=e<<4;continue;case 2:n[c+3|0]=11;n[c+5|0]=e|240;continue;case 3:n[c+3|0]=11;n[c+5|0]=e&15;continue;case 9:n[c+3|0]=2;n[c+5|0]=e|240;continue;case 10:n[c+3|0]=2;continue;case 11:n[c+3|0]=3;n[c+5|0]=e|240;continue;case 12:n[c+3|0]=3;continue;case 13:n[c+3|0]=4;continue;case 14:n[c+3|0]=20;n[c+5|0]=e|16;continue;case 15:n[c+3|0]=6;n[c+5|0]=e<<4;continue;case 16:n[c+3|0]=6;n[c+5|0]=e&15;continue;case 19:n[c+3|0]=5;continue;case 20:n[c+3|0]=20;n[c+5|0]=e|48;continue;case 21:n[c+3|0]=7;n[c+5|0]=e<<4;continue;case 22:n[c+3|0]=7;n[c+5|0]=e&15;continue;case 29:n[c+3|0]=8;continue;case 30:n[c+3|0]=20;n[c+5|0]=e|64;continue;case 39:n[c+3|0]=10;p[114610]=0;e=M(387,d+40|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){n[c+5|0]=e;p[114610]=0;J(338,d+40|0,1)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break o;case 40:n[c+3|0]=15;n[c+5|0]=e&15;continue;case 41:n[c+3|0]=20;n[c+5|0]=e|192;continue;case 42:n[c+3|0]=20;n[c+5|0]=e|208;continue;case 49:n[c+3|0]=12;continue;case 50:n[c+3|0]=14;continue;case 51:n[c+3|0]=20;n[c+5|0]=e|176;continue;case 52:n[c+3|0]=20;n[c+5|0]=e|224;continue;case 59:n[c+3|0]=16;continue;case 60:n[c+3|0]=17;continue;case 69:n[c+3|0]=1;continue;case 70:n[c+3|0]=20;n[c+5|0]=e&15|32;continue;case 71:n[c+3|0]=20;n[c+5|0]=e&15|128;continue;default:break t}}n[c+3|0]=0;continue}break}}}b=I()|0;H()|0;sb(d+40|0);break a}sb(d+40|0)}g=g+1|0;if(g>>>0<(q[d+194|0]|q[d+195|0]<<8)>>>0){continue}break}}if(!(q[d+218|0]|q[d+219|0]<<8|(q[d+220|0]<<16|q[d+221|0]<<24))){break e}Jc(b,q[d+218|0]|q[d+219|0]<<8|(q[d+220|0]<<16|q[d+221|0]<<24));fy(a+1304424|0,b,kg(b),4)}fb=d+272|0;return i|0}b=I()|0;H()|0;break b}b=I()|0;H()|0}sb(d+104|0)}L(b|0);E()}function sW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=fb-1424|0;fb=e;Ac(b);hq(a);a:{if(!CB(b,e+1408|0)){break a}if(!EB(e+1408|0)){break a}if(!BB(b,e+1392|0)){break a}if(!DB(e+1392|0)){break a}b:{if(!c){break b}A=e+1400|0;c=A;if((q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))>>>0>qj(b)>>>0){break a}c=A;u=e+1392|2;if((q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))+((q[u|0]|q[u+1|0]<<8)<<2)>>>0>qj(b)>>>0){break a}vu(a);uu(e+40|0);tu(qg(a)+28|0,e+40|0);gq(e+40|0);m=p[qg(a)+28>>2];c=e+1392|4;Tn(m,q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24));Jb(e+1136|0,0,256);c:{d:{if(q[u|0]|q[u+1|0]<<8){k=e+1112|4;l=e+1128|0;z=e+1130|0;v=e+1126|0;h=e+1124|0;while(1){d=0;c=A;if(!Jc(b,(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))+(B<<2)|0)){break a}if(!Hb(b,4)){break a}f=Lf(b);if(!Jc(b,f)){break a}if(!su(b,e+1112|0)){break a}x=pW(e+1096|0,q[h|0]|q[h+1|0]<<8);c=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if(!(q[h|0]|q[h+1|0]<<8)){break v}w:{while(1){d=Fk(x,c);p[114610]=0;d=J(254,b|0,d|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break w}if(d){c=c+1|0;if(c>>>0>=(q[h|0]|q[h+1|0]<<8)>>>0){break v}continue}break}break u}d=I()|0;H()|0;break c}if(q[h|0]|q[h+1|0]<<8){d=p[x>>2]}else{d=0}c=q[h|0]|q[h+1|0]<<8;p[114610]=0;i=M(255,b|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break t}g=c<<3;c=f+20|0;if(g+c>>>0<i>>>0){j=c+((q[h|0]|q[h+1|0]<<8)<<3)|0;x:{if(!(n[v|0]&1)){f=0;if(!(q[h|0]|q[h+1|0]<<8)){break e}while(1){if(!d){break x}if(!Nn(m,d)){break x}p[114610]=0;c=J(256,b|0,j|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break s}if(!c){break x}i=oc(m,q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24));c=d;o=q[c+4|0]|q[c+5|0]<<8|(q[c+6|0]<<16|q[c+7|0]<<24);p[114610]=0;i=P(257,b|0,i|0,o|0)|0;o=p[114610];p[114610]=0;if((o|0)==1){break s}if((i|0)!=(q[c+4|0]|q[c+5|0]<<8|(q[c+6|0]<<16|q[c+7|0]<<24))){break x}d=d+8|0;f=f+1|0;if(f>>>0<(q[h|0]|q[h+1|0]<<8)>>>0){continue}break}break e}y:{z:{A:{B:{if(q[v|0]&4){if(!d){break y}if(!Nn(m,d)){break y}o=oc(m,q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24));y=q[d+4|0]|q[d+5|0]<<8|(q[d+6|0]<<16|q[d+7|0]<<24);i=q[z|0]|q[z+1|0]<<8;c=q[l|0]|q[l+1|0]<<8;p[114610]=0;c=J(256,b|0,c+j|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break r}if(!c){break y}c=q[k|0]|q[k+1|0]<<8|(q[k+2|0]<<16|q[k+3|0]<<24);f=q[l|0]|q[l+1|0]<<8;p[114610]=0;c=J(258,b|0,c-f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break r}if(!c){break y}c=q[k|0]|q[k+1|0]<<8|(q[k+2|0]<<16|q[k+3|0]<<24);f=q[l|0]|q[l+1|0]<<8;p[114610]=0;N(259,e+24|0,b|0,c-f|0);c=p[114610];p[114610]=0;if((c|0)==1){break d}s=Tl(e+40|0,e+24|0);sb(e+24|0);w=0;f=0;j=0;if(!(q[h|0]|q[h+1|0]<<8)){break h}while(1){C:{p[114610]=0;c=J(260,s|0,i+1|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break C}g=i&15;t=r[(g<<1)+11024>>1];D:{E:{if(c>>>0>=t>>>0){p[114610]=0;g=q[g+11104|0];C=J(260,s|0,g|0)|0;D=p[114610];p[114610]=0;if((D|0)==1){break j}c=C+(c-t<<g)|0;if((c|0)!=(i|0)){i=c&15;break D}p[114610]=0;c=J(260,s|0,4)|0;g=p[114610];p[114610]=0;if((g|0)==1){break j}if((c|0)==15){p[114610]=0;g=J(260,s|0,1)|0;c=p[114610];p[114610]=0;if((c|0)==1){break j}c=65535;if(!g){break E}sb(e+40|0);break e}c=c+65520|0}if(c>>>0>65535){break D}}c=c&1?0-(c+1>>>1|0)|0:c>>>1|0;g=f+o|0;t=g;F:{if(q[v|0]&2){w=c+w|0;c=w;break F}c=q[v+1|0]&2?c:c^32768}n[t|0]=c;n[g+1|0]=c>>>8;f=f+2|0}if(f>>>0>=y>>>0){j=j+1|0;if(j>>>0>=(q[h|0]|q[h+1|0]<<8)>>>0){break z}c=(j<<3)+d|0;if(!Nn(m,c)){break B}y=q[c+4|0]|q[c+5|0]<<8|(q[c+6|0]<<16|q[c+7|0]<<24);o=oc(m,q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24));f=0}if(j>>>0<(q[h|0]|q[h+1|0]<<8)>>>0){continue}break h}break}d=O(77024)|0;break i}if(!d){break y}if(!Nn(m,d)){break y}w=oc(m,q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24));y=q[d+4|0]|q[d+5|0]<<8|(q[d+6|0]<<16|q[d+7|0]<<24);i=q[z|0]|q[z+1|0]<<8;if((q[l|0]|q[l+1|0]<<8)>>>0>256){break y}p[114610]=0;c=J(256,b|0,j|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break q}if(!c){break y}c=q[l|0]|q[l+1|0]<<8;p[114610]=0;c=P(261,b|0,e+1136|0,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break q}if(c>>>0<(q[l|0]|q[l+1|0]<<8)>>>0){break y}c=q[k|0]|q[k+1|0]<<8|(q[k+2|0]<<16|q[k+3|0]<<24);f=q[l|0]|q[l+1|0]<<8;p[114610]=0;c=J(258,b|0,c-f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break q}if(!c){break y}c=q[k|0]|q[k+1|0]<<8|(q[k+2|0]<<16|q[k+3|0]<<24);f=q[l|0]|q[l+1|0]<<8;p[114610]=0;N(259,e+24|0,b|0,c-f|0);c=p[114610];p[114610]=0;if((c|0)==1){break k}s=Tl(e+40|0,e+24|0);sb(e+24|0);o=0;f=0;j=0;if(!(q[h|0]|q[h+1|0]<<8)){break n}G:{while(1){H:{p[114610]=0;c=J(260,s|0,i+1|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break H}g=i&7;t=q[g+11056|0];I:{J:{if(c>>>0>=t>>>0){p[114610]=0;g=q[g+11064|0];C=J(260,s|0,g|0)|0;D=p[114610];p[114610]=0;if((D|0)==1){break p}c=C+(c-t<<g)|0;if((c|0)!=(i|0)){i=c&7;break I}p[114610]=0;c=J(260,s|0,3)|0;g=p[114610];p[114610]=0;if((g|0)==1){break p}if((c|0)==7){p[114610]=0;g=J(260,s|0,1)|0;c=p[114610];p[114610]=0;if((c|0)==1){break p}c=255;if(!g){break J}sb(e+40|0);break e}c=c+248|0}if(c>>>0>255){break I}}c=q[(e+1136|0)+c|0];g=c+o|0;t=c;c=(q[v|0]|q[v+1|0]<<8)&2;n[f+w|0]=c?g:t;o=c?g:o;f=f+1|0}if(f>>>0>=y>>>0){j=j+1|0;if(j>>>0>=(q[h|0]|q[h+1|0]<<8)>>>0){break G}c=(j<<3)+d|0;if(!Nn(m,c)){break A}y=q[c+4|0]|q[c+5|0]<<8|(q[c+6|0]<<16|q[c+7|0]<<24);w=oc(m,q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24));f=0}if(j>>>0<(q[h|0]|q[h+1|0]<<8)>>>0){continue}break n}break}d=O(77024)|0;break o}sb(e+40|0);break e}sb(e+40|0);break u}sb(e+40|0);break u}sb(e+40|0);break e}}}}ru(x);d=0;break a}d=I()|0;H()|0;break c}d=I()|0;H()|0;break c}d=I()|0;H()|0;break c}d=I()|0;H()|0;break c}d=O(77024)|0}if((H()|0)!=($(77024)|0)){break l}T(d|0)|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;if((c|0)==1){break m}}sb(e+40|0);break e}d=I()|0;H()|0}sb(e+40|0);break c}d=I()|0;H()|0;break c}d=O(77024)|0}if((H()|0)!=($(77024)|0)){break f}T(d|0)|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;if((c|0)==1){break g}}sb(e+40|0);break e}d=I()|0;H()|0}sb(e+40|0);break c}ru(x);B=B+1|0;if(B>>>0<(q[u|0]|q[u+1|0]<<8)>>>0){continue}break}}Ei(e+8|0,m);qu(e+16|0,e+8|0);b=Ln(e+40|0,e+16|0);Nd(qg(a)+12|0,b);sb(b);break b}d=I()|0;H()|0}ru(x);L(d|0);E()}d=1}fb=e+1424|0;return d|0}function bs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0;h=fb-32|0;fb=h;p[h+28>>2]=c;a:{if((c|0)<1){break a}i=p[b+104>>2];j=p[b+656>>2];if(!(!j|p[a+480180>>2]!=16777216)){m=p[j+44>>2]!=0}b:{if(!(!j|128<(c|0))){k=r[Yc(j+236|0,c+ -1|0)>>1];c:{if((k+ -1&65535)>>>0<=3998){i=(v(k,104)+a|0)+484380|0;break c}vb(h+16|0,a+1074308|0,43);if(!tb(h+16|0)){break c}if(!Zi(b)){break a}}k=q[Yb(j+108|0,p[h+28>>2]+ -1|0)|0];p[h+28>>2]=k;break b}k=c}if((k|0)>=121){d:{if(!(p[a+480180>>2]&16777248?(k|0)!=255:0)){Nm(a,b);if(d){break d}vb(h+16|0,a+1074308|0,100);if(!tb(h+16|0)|!(q[a+480208|0]&4)|!q[b+811|0]){break d}p[b+88>>2]=p[b+88>>2]&-6145;break d}if(!r[a+480192>>1]){break d}p[b+88>>2]=p[b+88>>2]|4096}e:{if(p[h+28>>2]!=254){break e}f:{c=p[b+88>>2];if(!(c&512)){break f}c=p[b+88>>2];if(p[a+480180>>2]!=2){break f}p[b+88>>2]=c|2048;break e}p[b+88>>2]=c|2101248;g:{if(p[a+480180>>2]&16777248){if(!r[a+480192>>1]){break g}vb(h+16|0,a+1074308|0,50);if(tb(h+16|0)){break g}}p[b+688>>2]=0}vb(h+16|0,a+1074308|0,50);if(tb(h+16|0)){p[b+8>>2]=0;p[b+12>>2]=0}p[b+696>>2]=0}vb(h+16|0,a+1074308|0,20);if(!tb(h+16|0)){break a}n[b+819|0]=0;n[b+824|0]=0;break a}h:{i:{j:{if(m){if(d){l=q[b+819|0];if(l){break j}}p[b+708>>2]=0}if(d){break i}if(!(!i|!(p[a+480180>>2]&1048588))){p[b+772>>2]=n[i+36|0];p[b+768>>2]=n[i+37|0]}if(i){vb(h+16|0,a+1074308|0,24);k=0;t=1;if(!tb(h+16|0)){break h}p[b+704>>2]=p[i+24>>2];break h}k=0;break h}t=p[j+44>>2];o[h>>1]=l;o[h+14>>1]=k;p[h+16>>2]=0;k=(p[h+16>>2]+v(o[t+36>>1]+1|0,o[h+14>>1]-o[h>>1]|0)|0)-p[b+876>>2]|0;p[b+708>>2]=k;p[b+876>>2]=0-k}t=(i|0)!=0;k=1;if(yh(b)){break h}k=a+1074308|0;vb(h+16|0,k,54);if(tb(h+16|0)){p[b+700>>2]=0;break a}vb(h+16|0,k,39);k=(tb(h+16|0)^-1)&d}k:{if(dt(a)){p[h+28>>2]=p[h+28>>2]+p[b+772>>2];Vd(h+28|0,12,131);break k}yO(h+28|0)}l=a+1074308|0;vb(h+16|0,l,34);d=b;l:{if(tb(h+16|0)){c=up(c);break l}c=p[h+28>>2]}n[d+819|0]=c;n[b+872|0]=q[b+872|0]|8;if(!(p[a+480180>>2]&16777250?0:k)){n[b+825|0]=0}d=dg(a,p[h+28>>2],p[b+768>>2],p[b+704>>2]);n[b+851|0]=0;vb(h+16|0,l,48);if(tb(h+16|0)){RK(a,b,j,i)}m:{if(e^1|k){break m}p[b+788>>2]=0;p[b+792>>2]=0;if(!j){break m}vb(h+16|0,l,29);if(tb(h+16|0)){n[b+820|0]=q[j+16|0]}if(!(q[j+60|0]&8)){fi(b+724|0)}if(!(q[j+80|0]&8)){fi(b+736|0)}if(!(q[j+100|0]&8)){fi(b+748|0)}if(q[j+20|0]){c=_r(Mm(a));u=q[j+20|0];vb(h+16|0,l,28);w=((v(c,u)|0)/64|0)+1|0;c=b;n:{if(tb(h+16|0)){u=p[b+764>>2];break n}u=(p[b+688>>2]+1|0)/2|0}o[c+788>>1]=(v(u,w)|0)/199}o:{if(!q[j+19|0]){break o}x=b,y=(v(_r(Mm(a)),q[j+19|0])|0)/32|0,o[x+790>>1]=y;vb(h+16|0,l,28);if(tb(h+16|0)|r[b+796>>1]){break o}o[b+796>>1]=r[b+692>>1]+1}c=q[j+23|0];if(c){u=_r(Mm(a));w=q[b+857|0];n[b+818|0]=w+1;o[b+792>>1]=(v(w,(v(c,u+1|0)|0)/128|0)+1|0)/128}c=q[j+24|0];if(!c){break m}u=_r(Mm(a));w=q[b+858|0];n[b+817|0]=w+1;o[b+794>>1]=(v(w,(v(c,u+1|0)|0)/128|0)+1|0)/128}if(!t){break a}c=0;p:{q:{if(!d){break q}r:{s:{t:{if(k){u:{if(!p[b+700>>2]){p[b+700>>2]=d;if(!m){break u}break t}if(m){break t}}p[b+708>>2]=d;break t}p[b+700>>2]=d;if(m){break s}vb(h+16|0,l,69);if(tb(h+16|0)){break s}vb(h,l,46);if(tb(h)|p[a+480180>>2]==1){break s}p[b+708>>2]=d;break s}if(p[b+76>>2]|p[a+480180>>2]&2){break r}}p[b+104>>2]=i;d=p[i>>2];p[b+84>>2]=d;p[b+76>>2]=d;p[b+80>>2]=0;p[b>>2]=0;p[b+4>>2]=0;v:{w:{if(!(p[a+480208>>2]&2097152)){vb(h+16|0,l,96);if(!tb(h+16|0)){break w}}if(q[b+811|0]){break w}p[h+16>>2]=p[b+76>>2]+ -1;x=b,y=p[Cb(b+660|0,h+16|0)>>2],p[x+4>>2]=y;break v}p[b+660>>2]=0}d=r[i+34>>1];m=d&1023;t=m|p[b+88>>2]&-525056;p[b+88>>2]=t;x:{if(d&8){p[b+80>>2]=p[i+12>>2];d=p[i+16>>2];p[b+88>>2]=(m&16?t|4:t&-524295)|2;p[b+84>>2]=d;if(s[b+76>>2]<=d>>>0){break x}p[b+76>>2]=d;break x}if(!(m&2)){break x}p[b+80>>2]=p[i+4>>2];d=p[i+8>>2];p[b+84>>2]=d;if(s[b+76>>2]<=d>>>0){break x}p[b+76>>2]=d}vb(h+16|0,l,83);if(!(!tb(h+16|0)|p[b+80>>2])){d=p[i>>2];p[b+84>>2]=d;p[b+76>>2]=d}d=p[b+88>>2];if(d&128){p[b+88>>2]=d|128;p[b+4>>2]=p[b+76>>2]+ -1}y:{if(q[b+842|0]>3){break y}vb(h+16|0,l,21);if(!(tb(h+16|0)|!(p[a+480180>>2]&16777248)|p[a+480208>>2]&4)){n[b+839|0]=16;break y}if(p[a+480180>>2]==16){n[b+839|0]=32;break y}if(p[a+480180>>2]&67633152){break y}n[b+839|0]=0}vb(h+16|0,l,21);if(tb(h+16|0)|q[b+845|0]>3){break r}n[b+840|0]=0}i=p[b>>2];if(s[b+76>>2]<=s[b+4>>2]){d=i;i=p[b+80>>2];p[b>>2]=d;p[b+4>>2]=i}if(!k){break q}c=1;if(!(p[a+480180>>2]&17301536)|(p[b+696>>2]?0:q[b+89|0]&16)){break q}if(!(q[a+480208|0]&8)|!q[b+811|0]){break p}}if(!(p[b+696>>2]|(!(p[a+480180>>2]&17301536)|!(q[b+89|0]&16)))){jl(b);vb(h+16|0,l,21);if(!tb(h+16|0)){n[b+838|0]=0;p[b+780>>2]=0}p[b+696>>2]=65536;p[b+88>>2]=p[b+88>>2]&-4097}if(!(q[b+811|0]|(!c|!(q[a+480208|0]&8)))){c=1;break p}if(q[b+811|0]?0:p[a+480180>>2]&1048580){break p}p[b+696>>2]=65536;p[b+88>>2]=p[b+88>>2]&-4097}vb(h+16|0,l,40);z:{A:{if(tb(h+16|0)){if(c){if(!(!(q[a+480208|0]&8)|!q[b+811|0])){p[b+88>>2]=p[b+88>>2]&-4196353;break z}p[b+88>>2]=p[b+88>>2]&-4194305;break z}i=p[b+88>>2]&-4196353;p[b+88>>2]=i;break A}i=p[b+88>>2]&-4196353;p[b+88>>2]=i;if(c){break z}}o[b+862>>1]=65535;p[b+88>>2]=i&-6326273|2097152;vb(h+16|0,l,23);B:{if(tb(h+16|0)){break B}vb(h,l,22);if(tb(h)){break B}vb(h+16|0,l,52);if(tb(h+16|0)){break B}vb(h,l,71);if(tb(h)){break B}n[b+859|0]=0;o[b+798>>1]=0}if(e){n[b+838|0]=0;p[b+780>>2]=0}p[b+20>>2]=0;p[b+24>>2]=0;d=p[a+480208>>2]&8192;C:{if(j){D:{E:{if(!yA(j)){if(Ot(j)){break E}d=d>>>13^1;if(d){break D}i=(d|0)!=0;break C}x=b,y=zA(j),n[x+858|0]=y;if(!Ot(j)){break D}}x=b,y=BA(j),n[x+857|0]=y}i=1;d=q[j+25|0];if((d|0)==255){break C}n[b+865|0]=d;break C}p[b+788>>2]=0;p[b+792>>2]=0;i=!d}if(q[b+857|0]>=127){vb(h+16|0,l,36);if(!tb(h+16|0)){break z}}if(!i){break z}if((Oo(a,b,1,256)|0)<0|!(q[b+89|0]&2)){break z}d=a+1304392|0;if(!kd(d)|(g|0)==65535){break z}To(p[d>>2],g,q[b+857|0]>>>1|0,1)}d=p[b+88>>2];if(f){d=d&-1025;p[b+88>>2]=d}F:{G:{if(q[a+24618|0]&16?d&1024:0){break G}a=p[b+104>>2];if(f?0:!(!a|!(q[a+35|0]&4))){break G}a=p[b+656>>2];if(!a|!(q[a+15|0]&2)){break F}}if(f){break F}p[b+700>>2]=0}if(c){break a}o[b+136>>1]=0;p[b+132>>2]=4194304;p[b+112>>2]=0;p[b+116>>2]=0}fb=h+32|0}function X0(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,o=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=fb-560|0;fb=l;p[l+548>>2]=k;p[l+552>>2]=b;p[l+104>>2]=2482;s=Hd(l+136|0,l+144|0,l+104|0);b=p[s>>2];p[l+132>>2]=b;p[l+128>>2]=b+400;u=Lb(l+104|0);r=Lb(l+88|0);m=Lb(l+72|0);o=Lb(l+56|0);t=Lb(l+40|0);p[114610]=0;ga(2485,c|0,d|0,l+120|0,l+119|0,l+118|0,u|0,r|0,m|0,o|0,l+36|0);b=p[114610];p[114610]=0;if((b|0)!=1){a:{p[j>>2]=p[i>>2];v=e&512;w=v>>>9|0;b=0;e=0;while(1){k=e;b:{c:{d:{e:{if((b|0)==4){break e}p[114610]=0;c=J(2422,a|0,l+552|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(!c){break e}c=0;f:{g:{h:{i:{j:{switch(n[(l+120|0)+b|0]){case 1:if((b|0)==3){break c}p[114610]=0;c=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(wg(h,8192,c)){p[114610]=0;N(2486,l+24|0,a|0,0);c=p[114610];p[114610]=0;if((c|0)!=1){c=n[l+24|0];p[114610]=0;K(110,t|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){break i}}break a}p[f>>2]=p[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((b|0)==3){break c}}while(1){p[114610]=0;c=J(2422,a|0,l+552|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(!c){break c}p[114610]=0;c=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(!wg(h,8192,c)){break c}p[114610]=0;N(2486,l+24|0,a|0,0);c=p[114610];p[114610]=0;if((c|0)!=1){c=n[l+24|0];p[114610]=0;K(110,t|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}if((wb(m)|0)==(0-wb(o)|0)){break c}k:{if(wb(m)){if(wb(o)){break k}}if(wb(m)){p[114610]=0;c=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(q[cc(m,0)|0]==(c&255)){p[114610]=0;M(2426,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}e=wb(m)>>>0>1?m:k;break b}n[g|0]=1;break c}p[114610]=0;c=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(q[cc(o,0)|0]!=(c&255)){break c}p[114610]=0;M(2426,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}n[g|0]=1;e=wb(o)>>>0>1?o:k;break b}p[114610]=0;c=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(q[cc(m,0)|0]==(c&255)){p[114610]=0;M(2426,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}e=wb(m)>>>0>1?m:k;break b}p[114610]=0;c=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(q[cc(o,0)|0]==(c&255)){p[114610]=0;M(2426,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}n[g|0]=1;e=wb(o)>>>0>1?o:k;break b}p[f>>2]=p[f>>2]|4;a=0;break d}if(!(k|b>>>0<2)){e=0;if(((b|0)==2&q[l+123|0]!=0|w)!=1){break b}}x=l,y=wd(r),p[x+16>>2]=y;c=Ld(l+24|0,l+16|0);l:{if(!b|q[(b+l|0)+119|0]>1){break l}while(1){m:{x=l,y=jf(r),p[x+16>>2]=y;if(!Ab(c,l+16|0)){break m}if(!wg(h,8192,n[p[c>>2]])){break m}bg(c);continue}break}x=l,y=wd(r),p[x+16>>2]=y;c=Mn(c,l+16|0);if(c>>>0<=wb(t)>>>0){x=l,y=jf(t),p[x+16>>2]=y;c=lf(l+16|0,0-c|0);d=jf(t);e=wd(r);p[114610]=0;c=hD(c,d,e);d=p[114610];p[114610]=0;if((d|0)==1){break a}if(c){break l}}x=l,y=wd(r),p[x+8>>2]=y;Ld(l+16|0,l+8|0);p[l+24>>2]=p[l+16>>2]}p[l+16>>2]=p[l+24>>2];n:{while(1){x=l,y=jf(r),p[x+8>>2]=y;if(!Ab(l+16|0,l+8|0)){break n}p[114610]=0;c=J(2422,a|0,l+552|0)|0;d=p[114610];p[114610]=0;o:{if((d|0)==1){break o}if(!c){break n}p[114610]=0;c=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break o}if(q[p[l+16>>2]]!=(c&255)){break n}p[114610]=0;M(2426,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}bg(l+16|0);continue}break}break a}if(!v){break c}x=l,y=jf(r),p[x+8>>2]=y;if(!Ab(l+16|0,l+8|0)){break c}p[f>>2]=p[f>>2]|4;a=0;break d}p:{while(1){q:{p[114610]=0;d=J(2422,a|0,l+552|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break q}if(!d){break p}p[114610]=0;e=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}r:{if(wg(h,2048,e)){d=p[j>>2];if((d|0)==p[l+548>>2]){p[114610]=0;N(2488,i|0,j|0,l+548|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[j>>2]}p[j>>2]=d+1;n[d|0]=e;c=c+1|0;break r}if(!c|!wb(u)|q[l+118|0]!=(e&255)){break p}e=p[l+132>>2];if((e|0)==p[l+128>>2]){p[114610]=0;N(2489,s|0,l+132|0,l+128|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}e=p[l+132>>2]}p[l+132>>2]=e+4;p[e>>2]=c;c=0}p[114610]=0;M(2426,a|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){continue}}break}break a}d=p[s>>2];s:{if(!c){break s}e=p[l+132>>2];if((d|0)==(e|0)){break s}if(p[l+128>>2]==(e|0)){p[114610]=0;N(2489,s|0,l+132|0,l+128|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}e=p[l+132>>2]}p[l+132>>2]=e+4;p[e>>2]=c}t:{if(p[l+36>>2]<1){break t}p[114610]=0;c=J(2423,a|0,l+552|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}u:{if(!c){p[114610]=0;c=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}if(q[l+119|0]==(c&255)){break u}}p[f>>2]=p[f>>2]|4;a=0;break d}p[114610]=0;M(2426,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}while(1){if(p[l+36>>2]<1){break t}p[114610]=0;c=J(2423,a|0,l+552|0)|0;d=p[114610];p[114610]=0;v:{if((d|0)==1){break v}w:{if(!c){p[114610]=0;c=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break v}if(wg(h,2048,c)){break w}}p[f>>2]=p[f>>2]|4;a=0;break d}if(p[j>>2]==p[l+548>>2]){p[114610]=0;N(2488,i|0,j|0,l+548|0);c=p[114610];p[114610]=0;if((c|0)==1){break v}}p[114610]=0;c=M(2424,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break v}d=p[j>>2];p[j>>2]=d+1;n[d|0]=c;p[114610]=0;p[l+36>>2]=p[l+36>>2]+ -1;M(2426,a|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}e=k;if(p[i>>2]!=p[j>>2]){break b}p[f>>2]=p[f>>2]|4;a=0;break d}x:{if(!k){break x}e=1;while(1){if(e>>>0>=wb(k)>>>0){break x}p[114610]=0;b=J(2423,a|0,l+552|0)|0;c=p[114610];p[114610]=0;y:{if((c|0)==1){break y}z:{if(!b){p[114610]=0;b=M(2424,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break y}if(q[cc(k,e)|0]==(b&255)){break z}}p[f>>2]=p[f>>2]|4;a=0;break d}p[114610]=0;M(2426,a|0)|0;b=p[114610];p[114610]=0;e=e+1|0;if((b|0)!=1){continue}}break}break a}A:{if(p[s>>2]==p[l+132>>2]){break A}p[l+24>>2]=0;a=p[s>>2];p[114610]=0;we(u,a,p[l+132>>2],l+24|0);a=p[114610];p[114610]=0;if((a|0)!=1){if(!p[l+24>>2]){break A}p[f>>2]=p[f>>2]|4;a=0;break d}break a}a=1}pb(t);pb(o);pb(m);pb(r);pb(u);wc(s);fb=l+560|0;return a|0}e=k}b=b+1|0;continue}}}a=I()|0;H()|0;pb(t);pb(o);pb(m);pb(r);pb(u);wc(s);L(a|0);E()}function fKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,s=0,t=0;d=fb-272|0;fb=d;Ac(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!Lz(b,d+200|0)){break l}if(!HR(d+200|0)){break l}if(!c){l=1;break l}xd(a,131072);e=Mb(d+184|0,12688);p[114610]=0;K(219,d+32|0,e|0);g=p[114610];p[114610]=0;m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((g|0)!=1){p[114610]=0;N(537,d+136|0,d+32|0,d+200|4);g=p[114610];p[114610]=0;if((g|0)==1){break B}xb(a+1304436|0,d+136|0);pb(d+136|0);yb(d+32|0);pb(e);e=Mb(d+136|0,12702);xb(a+1304448|0,e);pb(e);p[a+1304496>>2]=4;cS(d+32|0,3,d+213|0);zc(d+136|0,d+32|0);xb(a+1304400|0,d+136|0);pb(d+136|0);pn(d+120|0,3,d+243|0);zc(d+32|0,d+120|0);p[114610]=0;N(13,d+136|0,4,d+32|0);e=p[114610];p[114610]=0;if((e|0)==1){break j}xb(a+1304412|0,d+136|0);pb(d+136|0);pb(d+32|0);e=wp(d+136|0);s=e,t=sd(q[d+263|0],1,31),p[s+12>>2]=t;s=e,t=sd(q[d+264|0],1,12)+ -1|0,p[s+16>>2]=t;p[e+20>>2]=q[d+265|0];g=a+1304500|0;Kz(g);GR(g,e);m=rk(d+120|0,b);p[114610]=0;N(538,d+104|0,m|0,1);b=p[114610];p[114610]=0;if((b|0)==1){break z}p[114610]=0;b=M(277,d+88|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break y}p[114610]=0;N(539,d+32|0,d+104|0,1431389523);e=p[114610];p[114610]=0;if((e|0)==1){break k}Nd(b,d+32|0);sb(d+32|0);p[114610]=0;l=J(540,b|0,d+80|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break p}if(!l){break m}g=a+484360|0;e=Ob(g);p[114610]=0;f=M(255,b|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break p}p[114610]=0;Z(441,e|0,b|0,f+ -4>>>1|0,65535,65535)|0;e=p[114610];p[114610]=0;if((e|0)==1){break p}p[114610]=0;N(539,d+32|0,d+104|0,1414807888);e=p[114610];p[114610]=0;if((e|0)==1){break x}Nd(b,d+32|0);sb(d+32|0);p[114610]=0;e=M(337,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break p}if(!(c&1)|e^1){break q}p[114610]=0;J(541,b|0,d+72|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break w}s=a,t=sd(q[d+72|2],1,32)+1|0,o[s+480188>>1]=t;e=q[d+72|0]|q[d+73|0]<<8;p[114610]=0;e=J(395,d|0,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break v}s=d,t=Ub(e),p[s+64>>2]=t;s=d,t=Vb(e),p[s+56>>2]=t;if(Ab(d- -64|0,d+56|0)){f=d+16|4;while(1){h=p[d- -64>>2];p[114610]=0;J(542,b|0,d+16|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break u}jg(b,8);i=q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24);p[114610]=0;N(341,d+32|0,b|0,i+8|0);i=p[114610];p[114610]=0;if((i|0)==1){break t}Nd(h,d+32|0);sb(d+32|0);Ff(d- -64|0);if(Ab(d- -64|0,d+56|0)){continue}break}}f=r[a+480188>>1];p[114610]=0;h=J(543,d+32|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break s}f=Ob(g);p[114610]=0;f=M(544,f|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break f}p[114610]=0;i=a+484344|0;K(401,i|0,f|0);f=p[114610];p[114610]=0;if((f|0)==1){break f}f=Ob(g);s=d,t=Ub(f),p[s+16>>2]=t;s=d,t=Vb(f),p[s+64>>2]=t;if(Ab(d+16|0,d- -64|0)){while(1){f=p[d+16>>2];j=r[f>>1];if(gd(e)>>>0>j>>>0){j=jc(e,r[f>>1]);p[114610]=0;j=P(545,j|0,h|0,a|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break f}o[f>>1]=j}te(d+16|0);if(Ab(d+16|0,d- -64|0)){continue}break}}j=Ob(g);f=d+80|2;k=q[f|0]|q[f+1|0]<<8;p[114610]=0;j=J(546,j|0,k|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break f}if(!j){break r}if(!(q[d+80|0]|q[d+81|0]<<8)){j=q[f|0]|q[f+1|0]<<8;k=Ob(g);p[114610]=0;k=M(547,k|0)|0;n=p[114610];p[114610]=0;if((n|0)==1){break f}if(j>>>0>=k>>>0){break r}}g=r[kc(Ob(g),q[f|0]|q[f+1|0]<<8)>>1];f=Rb(i,g);j=q[d+80|0];p[114610]=0;j=P(498,d+16|0,12,j|0)|0;k=p[114610];p[114610]=0;if((k|0)!=1){g=on(Oe(j,p[Rb(i,g)+12>>2]+ -1|0));p[114610]=0;J(499,f|0,g|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break r}}break f}a=I()|0;H()|0;break A}a=I()|0;H()|0;yb(d+32|0)}pb(e);break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;break c}a=I()|0;H()|0;break d}a=I()|0;H()|0;break d}a=I()|0;H()|0;break d}a=I()|0;H()|0;break e}a=I()|0;H()|0;break e}a=I()|0;H()|0;break e}yR(h);$c(e)}p[114610]=0;N(539,d+32|0,d+104|0,1196641603);e=p[114610];p[114610]=0;if((e|0)==1){break o}Nd(b,d+32|0);sb(d+32|0);p[114610]=0;e=M(337,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break p}if(!e){break n}p[114610]=0;J(338,b|0,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break p}p[114610]=0;e=M(548,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break p}p[114610]=0;Z(549,a+1304424|0,b|0,e|0,40,0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break n}}a=I()|0;H()|0;break d}a=I()|0;H()|0;break d}p[114610]=0;N(539,d+32|0,d+104|0,1146113363);e=p[114610];p[114610]=0;if((e|0)==1){break i}p[114610]=0;N(539,d+16|0,d+104|0,1229999443);e=p[114610];p[114610]=0;C:{if((e|0)!=1){Nd(b,d+16|0);sb(d+16|0);p[114610]=0;e=M(387,b|0)|0;g=p[114610];p[114610]=0;D:{if((g|0)!=1){o[a+480190>>1]=e;if(r[a+480190>>1]){g=c&2;c=1;e=1;while(1){p[114610]=0;P(431,b|0,((c<<5)+a|0)+946300|0,-1)|0;f=p[114610];p[114610]=0;E:{if((f|0)!=1){p[114610]=0;J(550,b|0,d+16|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break h}p[114610]=0;c=v(c,104)+a|0;f=c+484380|0;K(551,d+16|0,f|0);h=p[114610];p[114610]=0;if((h|0)==1){break h}if(q[d+204|0]<8){break E}p[114610]=0;P(552,b|0,c+484423|0,8)|0;h=p[114610];p[114610]=0;if((h|0)!=1){break E}break h}a=I()|0;H()|0;break g}p[114610]=0;J(338,b|0,6)|0;h=p[114610];p[114610]=0;if((h|0)==1){break h}p[114610]=0;h=M(390,d+32|0)|0;i=p[114610];p[114610]=0;F:{G:{if((i|0)==1){break G}p[114610]=0;N(341,d|0,d+32|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break G}p[114610]=0;h=M(337,d|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break D}if(!g|h^1){break F}c=Tc(d- -64|0,o[c+484414>>1]&1?16:8,1,0,(q[d+31|0]&12)==4?7:0);p[114610]=0;P(400,c|0,f|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break F}break D}a=I()|0;H()|0;break g}sb(d);e=e+1|0;c=e&65535;if(c>>>0<=r[a+480190>>1]){continue}break}}p[114610]=0;S(476,a|0);c=p[114610];p[114610]=0;if((c|0)!=1){break C}}a=I()|0;H()|0;break g}a=I()|0;H()|0;sb(d);break g}a=I()|0;H()|0;break g}p[a+480204>>2]=12e5;p[a+480208>>2]=24;p[a+480196>>2]=6;p[a+480200>>2]=256;p[a+480228>>2]=48;p[a+480232>>2]=48;sb(d+32|0)}sb(b);Iz(d+104|0);sb(m)}fb=d+272|0;return l|0}a=I()|0;H()|0;break d}a=I()|0;H()|0;pb(d+32|0);break a}a=I()|0;H()|0;break d}a=I()|0;H()|0}sb(d+32|0);break d}a=I()|0;H()|0;yR(h)}$c(e)}sb(b)}Iz(d+104|0)}sb(m)}L(a|0);E()}function yHa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0;e=fb-176|0;fb=e;a:{b:{c:{d:{e:{f:{g:{h:{if(!Dh(b,14021)){break h}if(d){n[d|0]=1}k=a+1074308|0;bt(k);i:{if(!Hb(b,7)){break i}m=a+480216|0;t=a+480220|0;u=a+480224|0;w=a+1074368|0;x=a+480228|0;y=a+480232|0;z=a+480200|0;A=a+484360|0;l=a+480268|0;B=a+1304412|0;C=a+480248|0;while(1){f=Lf(b);d=kg(b);if((f|0)==(q[14475]|q[14476]<<8|(q[14477]<<16|q[14478]<<24))){jg(b,6);break i}if(!(f&1616928864)|f&-2139062144){break i}if(!Hb(b,d)){break i}ld(e+160|0,b,d);j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)<=1347243309){if((f|0)<=1146367533){if((f|0)<=1130917458){if((f|0)==1127099950){break y}if((f|0)!=1129797166){break j}p[114610]=0;p[e>>2]=0;N(675,e+160|0,d|0,e|0);d=p[114610];p[114610]=0;if((d|0)==1){break v}p[a+1074300>>2]=p[e>>2];break j}if((f|0)==1130917459){break q}if((f|0)!=1145525806){break j}p[114610]=0;N(675,e+160|0,d|0,z|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}break j}if((f|0)<=1213486400){if((f|0)==1146367534){break A}if((f|0)!=1196316499|d>>>0<3){break j}p[114610]=0;K(676,e+144|0,e+160|0);d=p[114610];p[114610]=0;if((d|0)==1){break o}p[114610]=0;g=P(677,e|0,e+144|0,8)|0;d=p[114610];p[114610]=0;if((d|0)==1){break n}pb(e+144|0);p[114610]=0;f=M(255,e+160|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break m}p[114610]=0;N(678,e|0,C|0,f|0);d=p[114610];p[114610]=0;if((d|0)==1){break m}ff(g);break j}if((f|0)==1213486401){break r}if((f|0)==1280530262){break u}if((f|0)!=1297303086){break j}bt(k);h=0;break l}if((f|0)<=1380994349){if((f|0)<=1380340803){if((f|0)==1347243310){break w}if((f|0)!=1347244882){break j}p[114610]=0;N(679,e+160|0,d|0,l|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}if(Kp(q[l|0])){break j}n[l|0]=5;break j}if((f|0)==1380340804){break z}if((f|0)==1380986414){break s}if((f|0)!=1380991534){break j}p[114610]=0;N(675,e+160|0,d|0,m|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}break j}if((f|0)<=1397768493){if((f|0)==1380994350){break k}if((f|0)!=1397052739|d>>>0<3){break j}p[114610]=0;f=M(357,e+160|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}if(!f|f>>>0>r[a+480190>>1]){break j}f=v(f,104)+a|0;d=f+484448|0;j=f+484484|0;while(1){p[114610]=0;g=M(390,e+160|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break p}p[d>>2]=g;d=d+4|0;if((j|0)!=(d|0)){continue}break}break j}if((f|0)==1397768494){break t}if((f|0)==1414344238){break x}if((f|0)!=1448301654){break j}p[114610]=0;N(675,e+160|0,d|0,y|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}break j}p[114610]=0;N(675,e+160|0,d|0,e|0);d=p[114610];p[114610]=0;if((d|0)==1){break g}p[a+480204>>2]=v(p[e>>2],1e4)+(s[a+480204>>2]%1e4|0);break j}p[114610]=0;N(675,e+160|0,d|0,e|0);d=p[114610];p[114610]=0;if((d|0)!=1){d=p[a+480204>>2];p[a+480204>>2]=d-((d>>>0)%1e4|0)+s[e>>2]%1e4;break j}d=I()|0;H()|0;break a}if(c){break j}p[114610]=0;o[e>>1]=0;N(680,e+160|0,d|0,e|0);d=p[114610];p[114610]=0;if((d|0)!=1){D=a,F=sd(r[e>>1],r[a+480188>>1],127),o[D+480188>>1]=F;break j}d=I()|0;H()|0;break a}p[114610]=0;N(681,e+160|0,d|0,u|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}break j}p[114610]=0;N(682,e+160|0,d|0,w|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}break j}d=I()|0;H()|0;break a}p[114610]=0;p[e>>2]=0;N(675,e+160|0,d|0,e|0);d=p[114610];p[114610]=0;if((d|0)==1){break f}d=p[e>>2];if(!d){break j}p[a+1074304>>2]=d;break j}p[114610]=0;N(675,e+160|0,d|0,x|0);d=p[114610];p[114610]=0;if((d|0)!=1){break j}break b}if(p[a+480180>>2]==4){break j}p[114610]=0;N(680,e+160|0,d|0,e|0);d=p[114610];p[114610]=0;if((d|0)!=1){Pe(Ob(A),r[e>>1]);break j}d=I()|0;H()|0;break a}g=Lb(e);p[114610]=0;f=M(255,e+160|0)|0;d=p[114610];p[114610]=0;B:{if((d|0)==1){break B}p[114610]=0;P(463,e+160|0,g|0,f|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break B}p[114610]=0;N(13,e+144|0,0,g|0);d=p[114610];p[114610]=0;if((d|0)==1){break B}xb(B,e+144|0);pb(e+144|0);pb(g);break j}d=I()|0;H()|0;pb(g);break a}if(d&1|d>>>0>126){break j}o[e>>1]=(d>>>1|0)- -64;p[114610]=0;o[e+144>>1]=127;f=J(477,e|0,e+144|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}j=r[f>>1];if(j>>>0<65){break j}h=64;while(1){p[114610]=0;K(472,e|0,e+160|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}d=Zc(e);f=e;C:{if(q[e|0]==255){break C}d=q[d|0];i=(h<<5)+a|0;g=i+480284|0;o[g>>1]=128;o[i+480286>>1]=d;i=i+480280|0;p[i>>2]=0;p[i>>2]=(q[f|0]&128)<<3;d=q[f|0]&127;n[f|0]=d;if(d>>>0<65){o[g>>1]=d<<2;d=q[f|0]}if((d|0)!=100){break C}p[i>>2]=p[i>>2]|256}h=h+1|0;if((j|0)!=(h|0)){continue}break}break j}d=I()|0;H()|0;break a}d=I()|0;H()|0;break a}d=I()|0;H()|0;pb(e+144|0);break a}d=I()|0;H()|0;ff(g);break a}D:{E:{F:while(1){p[114610]=0;f=J(258,e+160|0,1)|0;d=p[114610];p[114610]=0;if((d|0)==1){break E}if(!f|h>>>0>=110){break j}p[114610]=0;g=M(387,e+160|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break D}d=0;while(1){G:{if(!(!(g>>>d&1)|h>>>0>=110)){p[114610]=0;P(478,k|0,h|0,1)|0;f=p[114610];p[114610]=0;if((f|0)==1){break G}}h=h+1|0;d=d+1|0;if((d|0)!=8){continue}continue F}break}break}d=I()|0;H()|0;break a}d=I()|0;H()|0;break a}d=I()|0;H()|0;break a}p[114610]=0;N(675,e+160|0,d|0,t|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}}sb(e+160|0);if(Hb(b,7)){continue}break}}En(a+480204|0,v(p[p[a+8>>2]+20>>2],1e4),v(p[p[a+8>>2]+24>>2],1e4));if(p[a+480224>>2]>=3){p[a+480224>>2]=0}if(p[a+1074368>>2]>=6){p[a+1074368>>2]=0}vc(a+480200|0,256);b=a+480248|0;if(cd(b)){break h}lz(b,p[a+480216>>2],16777216)}fb=e+176|0;return}d=I()|0;H()|0;break a}d=I()|0;H()|0;break a}d=I()|0;H()|0;break a}d=I()|0;H()|0;break a}d=I()|0;H()|0;break a}d=I()|0;H()|0}sb(e+160|0);L(d|0);E()}function J3(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,r=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=w(0),F=0;f=fb-304|0;fb=f;e=q[b|0];a:{if(!e){break a}b:{c:{d:{while(1){e:{f:{if(im(e&255)){while(1){e=b;b=b+1|0;if(im(q[e+1|0])){continue}break}Rg(a,0,0);while(1){b=p[a+4>>2];g:{if(b>>>0<s[a+104>>2]){p[a+4>>2]=b+1;b=q[b|0];break g}b=Sc(a)}if(im(b)){continue}break}h:{if(!p[a+104>>2]){b=p[a+4>>2];break h}b=p[a+4>>2]+ -1|0;p[a+4>>2]=b}d=b-p[a+8>>2]|0;b=d;d=d>>31;g=b;i=i+p[a+124>>2]|0;b=m+p[a+120>>2]|0;if(b>>>0<m>>>0){i=i+1|0}m=g+b|0;i=d+i|0;i=m>>>0<b>>>0?i+1|0:i;break f}i:{j:{k:{e=q[b|0];if((e|0)==37){d=q[b+1|0];if((d|0)==42){break k}if((d|0)!=37){break j}}Rg(a,0,0);e=((e|0)==37)+b|0;b=p[a+4>>2];l:{if(b>>>0<s[a+104>>2]){p[a+4>>2]=b+1;b=q[b|0];break l}b=Sc(a)}if((b|0)!=q[e|0]){if(p[a+104>>2]){p[a+4>>2]=p[a+4>>2]+ -1}A=0;if((b|0)>=0){break a}break c}b=m+1|0;if(b>>>0<1){i=i+1|0}m=b;break f}k=0;e=b+2|0;break i}if(!(!Sg(d)|q[b+2|0]!=36)){k=I3(c,q[b+1|0]+ -48|0);e=b+3|0;break i}k=p[c>>2];c=c+4|0;e=b+1|0}A=0;b=0;if(Sg(q[e|0])){while(1){b=(q[e|0]+v(b,10)|0)+ -48|0;d=q[e+1|0];e=e+1|0;if(Sg(d)){continue}break}}d=e;g=q[d|0];m:{if((g|0)!=109){break m}l=0;A=(k|0)!=0;g=q[e+1|0];r=0;d=e+1|0}e=d+1|0;j=3;n:{o:{switch(g+ -65|0){case 39:g=d+2|0;d=q[d+1|0]==104;e=d?g:e;j=d?-2:-1;break n;case 43:g=d+2|0;d=q[d+1|0]==108;e=d?g:e;j=d?3:1;break n;case 51:case 57:j=1;break n;case 11:j=2;break n;case 41:break n;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break o;default:break c}}j=0;e=d}g=q[e|0];d=(g&47)==3;z=d?1:j;x=d?g|32:g;p:{if((x|0)==91){break p}q:{if((x|0)!=110){if((x|0)!=99){break q}b=(b|0)>1?b:1;break p}ND(k,z,m,i);break f}Rg(a,0,0);while(1){d=p[a+4>>2];r:{if(d>>>0<s[a+104>>2]){p[a+4>>2]=d+1;d=q[d|0];break r}d=Sc(a)}if(im(d)){continue}break}s:{if(!p[a+104>>2]){d=p[a+4>>2];break s}d=p[a+4>>2]+ -1|0;p[a+4>>2]=d}d=d-p[a+8>>2]|0;g=d;d=d>>31;h=g;g=i+p[a+124>>2]|0;i=m+p[a+120>>2]|0;if(i>>>0<m>>>0){g=g+1|0}m=h+i|0;d=d+g|0;d=m>>>0<i>>>0?d+1|0:d;i=d}g=b;C=b>>31;Rg(a,b,C);h=p[a+4>>2];d=p[a+104>>2];t:{if(h>>>0<d>>>0){p[a+4>>2]=h+1;break t}if((Sc(a)|0)<0){break c}d=p[a+104>>2]}if(d){p[a+4>>2]=p[a+4>>2]+ -1}d=16;u:{v:{w:{x:{y:{z:{A:{switch(x+ -88|0){default:b=x+ -65|0;if(b>>>0>6|!(1<<b&113)){break u};case 9:case 13:case 14:case 15:RD(f,a,z,0);d=p[a+4>>2]-p[a+8>>2]|0;if(p[a+120>>2]==(0-d|0)&p[a+124>>2]==(0-((d>>31)+(0<d>>>0)|0)|0)){break b}if(!k){break u}h=p[f+8>>2];g=p[f+12>>2];d=p[f>>2];b=p[f+4>>2];switch(z|0){case 2:break w;case 1:break x;case 0:break y;default:break u};case 3:case 11:case 27:if((x&239)==99){Jb(f+32|0,-1,257);n[f+32|0]=0;if((x|0)!=115){break v}n[f+65|0]=0;n[f+46|0]=0;o[f+42>>1]=0;o[f+44>>1]=0;break v}y=q[e+1|0];h=(y|0)==94;Jb(f+32|0,h,257);n[f+32|0]=0;d=h?e+2|0:e+1|0;B:{C:{D:{e=q[(h?2:1)+e|0];if((e|0)!=45){if((e|0)==93){break D}j=(y|0)!=94;break B}j=(y|0)!=94;n[f+78|0]=j;break C}j=(y|0)!=94;n[f+126|0]=j}d=d+1|0}e=d;while(1){d=q[e|0];E:{if((d|0)!=45){if(!d){break c}if((d|0)!=93){break E}break v}d=45;y=q[e+1|0];if(!y|(y|0)==93){break E}h=e+1|0;e=q[e+ -1|0];F:{if(e>>>0>=y>>>0){d=y;break F}while(1){e=e+1|0;n[e+(f+32|0)|0]=j;d=q[h|0];if(e>>>0<d>>>0){continue}break}}e=h}n[(d+f|0)+33|0]=j;e=e+1|0;continue};case 23:d=8;break z;case 12:case 29:d=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break u;case 0:case 24:case 32:break z;case 17:break A}}d=0}h=PD(a,d,0,-1,-1);g=ib;d=p[a+4>>2]-p[a+8>>2]|0;if(p[a+120>>2]==(0-d|0)&p[a+124>>2]==(0-((d>>31)+(0<d>>>0)|0)|0)){break b}if(!(!k|(x|0)!=112)){p[k>>2]=h;break u}ND(k,z,h,g);break u}D=k,E=OD(d,b,h,g),t[D>>2]=E;break u}D=k,F=Av(d,b,h,g),u[D>>3]=F;break u}p[k>>2]=d;p[k+4>>2]=b;p[k+8>>2]=h;p[k+12>>2]=g;break u}x=(x|0)==99;j=x?b+1|0:31;y=(z|0)!=1;G:{if(!y){d=k;if(A){d=fd(j<<2);if(!d){break d}}p[f+296>>2]=0;p[f+300>>2]=0;b=0;l=(A|0)!=0;while(1){r=d;H:{while(1){d=p[a+4>>2];I:{if(d>>>0<s[a+104>>2]){p[a+4>>2]=d+1;d=q[d|0];break I}d=Sc(a)}if(!q[(d+f|0)+33|0]){break H}n[f+27|0]=d;d=Zn(f+28|0,f+27|0,1,f+296|0);if((d|0)==-2){continue}if((d|0)==-1){break e}if(r){p[(b<<2)+r>>2]=p[f+28>>2];b=b+1|0}if(l^1|(b|0)!=(j|0)){continue}break}j=j<<1|1;d=oq(r,j<<2);if(d){continue}break e}break}d=f+296|0;h=1;J:{if(!d){break J}h=!p[d>>2]}if(!h){break e}l=0;break G}if(A){b=0;d=fd(j);if(!d){break d}while(1){l=d;while(1){d=p[a+4>>2];K:{if(d>>>0<s[a+104>>2]){p[a+4>>2]=d+1;d=q[d|0];break K}d=Sc(a)}if(!q[(d+f|0)+33|0]){r=0;break G}n[b+l|0]=d;b=b+1|0;if((j|0)!=(b|0)){continue}break}r=0;j=j<<1|1;d=oq(l,j);if(d){continue}break}break c}b=0;if(k){while(1){d=p[a+4>>2];L:{if(d>>>0<s[a+104>>2]){p[a+4>>2]=d+1;d=q[d|0];break L}d=Sc(a)}if(q[(d+f|0)+33|0]){n[b+k|0]=d;b=b+1|0;continue}else{r=0;l=k;break G}}}while(1){b=p[a+4>>2];M:{if(b>>>0<s[a+104>>2]){p[a+4>>2]=b+1;b=q[b|0];break M}b=Sc(a)}if(q[(b+f|0)+33|0]){continue}break}l=0;r=0;b=0}N:{if(!p[a+104>>2]){d=p[a+4>>2];break N}d=p[a+4>>2]+ -1|0;p[a+4>>2]=d}d=d-p[a+8>>2]|0;h=d;z=d+p[a+120>>2]|0;d=p[a+124>>2]+(d>>31)|0;d=z>>>0<h>>>0?d+1|0:d;h=z;if(!(d|h)|(x?(g|0)!=(h|0)|(d|0)!=(C|0):0)){break b}O:{if(!A){break O}if(!y){p[k>>2]=r;break O}p[k>>2]=l}if(x){break u}if(r){p[(b<<2)+r>>2]=0}if(!l){l=0;break u}n[b+l|0]=0}d=p[a+4>>2]-p[a+8>>2]|0;b=d;d=d>>31;g=b;i=i+p[a+124>>2]|0;b=m+p[a+120>>2]|0;if(b>>>0<m>>>0){i=i+1|0}m=g+b|0;i=d+i|0;i=m>>>0<b>>>0?i+1|0:i;B=((k|0)!=0)+B|0}b=e+1|0;e=q[e+1|0];if(e){continue}break a}break}l=0;break c}l=0;r=0}B=B?B:-1}if(!A){break a}Nb(l);Nb(r)}fb=f+304|0;return B}function Ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=w(0),f=w(0),g=w(0),h=w(0),i=w(0),j=0,k=w(0),l=w(0),m=w(0),o=w(0),r=0,s=0,u=w(0),v=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=w(0),U=0,V=0,W=0,X=w(0);a:{if(!q[a+5046|0]){break a}h=t[a+4268>>2];jH(a);if(h==t[a+4268>>2]){break a}rw(a)}b:{if(!q[a+5045|0]){break b}v=a+44|0;if(!fh(v)){break b}x=Fd(v,0);B=Fd(v,1);r=_c(v,0);s=_c(v,1);c:{if(!(!q[a+5044|0]|(!d|q[a+4264|0]&2))){p[r>>2]=p[a+5036>>2];p[s>>2]=p[a+5040>>2];n[a+5044|0]=0;B=B+4|0;x=x+4|0;s=s+4|0;r=r+4|0;j=d+ -1|0;break c}j=d}y=j;d:{if(!y){break d}S=a+4960|0;D=a+4648|0;E=a+4672|0;O=a+4936|0;F=a+4696|0;G=a+4720|0;H=a+4744|0;I=a+4768|0;P=a+4840|0;C=a+4504|0;J=a+4528|0;Q=a+4912|0;K=a+4552|0;L=a+4576|0;M=a+4600|0;N=a+4624|0;R=a+4816|0;z=a+4888|0;A=a+4864|0;while(1){h=t[x>>2];h=w(w(w(t[a+5008>>2]-h)*t[a+4276>>2])+h);t[a+5008>>2]=h;W=sc(A,p[a+4880>>2]),X=h,t[W>>2]=X;h=t[B>>2];h=w(w(w(t[a+5012>>2]-h)*t[a+4276>>2])+h);t[a+5012>>2]=h;W=sc(z,p[a+4904>>2]),X=h,t[W>>2]=X;h=Ug(A,p[a+4356>>2]);f=Ug(A,p[a+4360>>2]);e=Ug(A,p[a+4364>>2]);g=Ug(A,p[a+4368>>2]);h=w(w(w(h*w(.6800000071525574))+w(w(e+Ug(A,p[a+4372>>2]))*w(-.6200000047683716)))+w(w(g+f)*w(-.5)));if(n[a+4264|0]&1){f=h;h=w(t[sc(R,p[a+4836>>2])>>2]+w(f*w(.6180340051651001)));W=sc(R,p[a+4832>>2]),X=w(f-w(h*w(.6180340051651001))),t[W>>2]=X}T=t[a+4280>>2];W=a,X=w(Ug(A,p[a+4352>>2])+t[a+5020>>2]),t[W+5020>>2]=X;f=w(Ug(z,p[a+4376>>2])+t[a+5024>>2]);t[a+5024>>2]=f;e=t[a+5020>>2];g=t[a+4980>>2];m=t[sc(N,p[a+4644>>2])>>2];o=t[a+4444>>2];g=w(t[sc(N,p[a+4644>>2])>>2]+w(o*w(g-m)));t[a+4980>>2]=g;m=t[a+4272>>2];o=w(e*w(-.7070000171661377));k=w(f*w(.7070000171661377));e=w(o+k);f=w(w(m*e)+w(t[a+4440>>2]*g));W=sc(N,p[a+4640>>2]),X=w(e-w(m*f)),t[W>>2]=X;e=t[a+4976>>2];g=t[sc(M,p[a+4620>>2])>>2];m=t[a+4436>>2];e=w(t[sc(M,p[a+4620>>2])>>2]+w(m*w(e-g)));t[a+4976>>2]=e;g=t[a+4272>>2];e=w(w(g*f)+w(t[a+4432>>2]*e));W=sc(M,p[a+4616>>2]),X=w(f-w(g*e)),t[W>>2]=X;m=w(w(f*w(-.15000000596046448))+w(e*w(-.20000000298023224)));if(n[a+4264|0]&1){f=t[a+4972>>2];g=t[sc(L,p[a+4596>>2])>>2];i=t[a+4428>>2];f=w(t[sc(L,p[a+4596>>2])>>2]+w(i*w(f-g)));t[a+4972>>2]=f;g=t[a+4272>>2];f=w(w(g*e)+w(t[a+4424>>2]*f));W=sc(L,p[a+4592>>2]),X=w(e-w(g*f)),t[W>>2]=X;e=t[a+4968>>2];g=t[sc(K,p[a+4572>>2])>>2];i=t[a+4420>>2];e=w(t[sc(K,p[a+4572>>2])>>2]+w(i*w(e-g)));t[a+4968>>2]=e;g=t[a+4272>>2];e=w(w(g*f)+w(t[a+4416>>2]*e));W=sc(K,p[a+4568>>2]),X=w(f-w(g*e)),t[W>>2]=X;m=w(w(w(f*w(.3499999940395355))+m)+w(e*w(-.3799999952316284)))}k=w(o-k);W=sc(Q,p[a+4928>>2]),X=e,t[W>>2]=X;j=sc(Q,p[a+4932>>2]);f=w(t[a+4496>>2]*t[j>>2]);t[a+5028>>2]=w(w(t[a+5028>>2]-f)*t[a+4500>>2])+f;f=t[a+4964>>2];e=t[sc(J,p[a+4548>>2])>>2];g=t[a+4412>>2];f=w(t[sc(J,p[a+4548>>2])>>2]+w(g*w(f-e)));t[a+4964>>2]=f;e=w(t[a+4408>>2]*f);f=t[a+4272>>2];g=t[a+5028>>2];e=w(e+w(f*g));W=sc(J,p[a+4544>>2]),X=w(g-w(f*e)),t[W>>2]=X;f=t[a+4960>>2];g=t[sc(C,p[a+4524>>2])>>2];o=t[a+4404>>2];f=w(t[sc(C,p[a+4524>>2])>>2]+w(o*w(f-g)));t[a+4960>>2]=f;g=t[a+4272>>2];o=w(w(g*e)+w(t[a+4400>>2]*f));W=sc(C,p[a+4520>>2]),X=w(e-w(g*o)),t[W>>2]=X;t[a+5020>>2]=o;f=Ug(z,p[a+4380>>2]);g=Ug(z,p[a+4384>>2]);i=Ug(z,p[a+4388>>2]);u=Ug(z,p[a+4392>>2]);f=w(w(w(f*w(.7070000171661377))+w(w(i+Ug(z,p[a+4396>>2]))*w(-.5)))+w(w(u+g)*w(-.6000000238418579)));i=w(e*w(.3799999952316284));if(n[a+4264|0]&1){e=f;f=w(t[sc(P,p[a+4860>>2])>>2]+w(e*w(.6180340051651001)));W=sc(P,p[a+4856>>2]),X=w(e-w(f*w(.6180340051651001))),t[W>>2]=X}u=t[a+4280>>2];e=t[a+5004>>2];g=t[sc(I,p[a+4788>>2])>>2];l=t[a+4492>>2];e=w(t[sc(I,p[a+4788>>2])>>2]+w(l*w(e-g)));t[a+5004>>2]=e;l=t[a+4272>>2];g=w(w(l*k)+w(t[a+4488>>2]*e));W=sc(I,p[a+4784>>2]),X=w(k-w(l*g)),t[W>>2]=X;e=t[a+5e3>>2];k=t[sc(H,p[a+4764>>2])>>2];l=t[a+4484>>2];e=w(t[sc(H,p[a+4764>>2])>>2]+w(l*w(e-k)));t[a+5e3>>2]=e;k=t[a+4272>>2];e=w(w(k*g)+w(t[a+4480>>2]*e));W=sc(H,p[a+4760>>2]),X=w(g-w(k*e)),t[W>>2]=X;k=w(w(e*w(-.20000000298023224))+w(i+w(g*w(-.15000000596046448))));if(n[a+4264|0]&1){g=t[a+4996>>2];i=t[sc(G,p[a+4740>>2])>>2];l=t[a+4476>>2];g=w(t[sc(G,p[a+4740>>2])>>2]+w(l*w(g-i)));t[a+4996>>2]=g;i=t[a+4272>>2];g=w(w(i*e)+w(t[a+4472>>2]*g));W=sc(G,p[a+4736>>2]),X=w(e-w(i*g)),t[W>>2]=X;e=t[a+4992>>2];i=t[sc(F,p[a+4716>>2])>>2];l=t[a+4468>>2];e=w(t[sc(F,p[a+4716>>2])>>2]+w(l*w(e-i)));t[a+4992>>2]=e;i=t[a+4272>>2];e=w(w(i*g)+w(t[a+4464>>2]*e));W=sc(F,p[a+4712>>2]),X=w(g-w(i*e)),t[W>>2]=X;k=w(w(w(g*w(.3499999940395355))+k)+w(e*w(-.3799999952316284)))}U=B+4|0;V=x+4|0;g=w(u*f);W=sc(O,p[a+4952>>2]),X=e,t[W>>2]=X;j=sc(O,p[a+4956>>2]);f=w(t[a+4496>>2]*t[j>>2]);t[a+5032>>2]=w(w(t[a+5032>>2]-f)*t[a+4500>>2])+f;f=t[a+4988>>2];e=t[sc(E,p[a+4692>>2])>>2];i=t[a+4460>>2];f=w(t[sc(E,p[a+4692>>2])>>2]+w(i*w(f-e)));t[a+4988>>2]=f;e=t[a+4272>>2];i=t[a+5032>>2];f=w(w(t[a+4456>>2]*f)+w(e*i));W=sc(E,p[a+4688>>2]),X=w(i-w(e*f)),t[W>>2]=X;i=t[a+4284>>2];e=t[a+4984>>2];u=t[sc(D,p[a+4668>>2])>>2];l=t[a+4452>>2];e=w(t[sc(D,p[a+4668>>2])>>2]+w(l*w(e-u)));t[a+4984>>2]=e;u=t[a+4272>>2];e=w(w(u*f)+w(t[a+4448>>2]*e));W=sc(D,p[a+4664>>2]),X=w(f-w(u*e)),t[W>>2]=X;t[a+5024>>2]=e;e=w(e*w(.3799999952316284));h=w(w(i*w(w(w(f-o)*w(.3799999952316284))+m))+w(T*h));f=t[a+4288>>2];j=C;while(1){Sfa(j);j=j+24|0;if((S|0)!=(j|0)){continue}break}f=w(w(f*w(k-e))+g);e:{f:{if(q[a+4264|0]&2){x=V;j=U;break f}t[r>>2]=w(t[a+5036>>2]+h)*w(.5);t[s>>2]=w(t[a+5040>>2]+f)*w(.5);t[a+5040>>2]=f;t[a+5036>>2]=h;if((y|0)==1){break e}y=y+ -1|0;x=x+8|0;s=s+4|0;r=r+4|0;j=B+8|0}B=j;t[r>>2]=h;t[s>>2]=f;s=s+4|0;r=r+4|0;y=y+ -1|0;if(y){continue}break d}break}n[a+5044|0]=1}Zh(a,b,c,_c(v,0),_c(v,1),d)}}function Mo(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0;i=fb-16|0;fb=i;g=r[a+480192>>1]>=c>>>0?p[((c<<2)+a|0)+900380>>2]:g;y=p[b+764>>2];h=q[b+824|0];a:{if(!h){vb(i+8|0,a+1074308|0,11);if(tb(i+8|0)){break a}}b:{c:{if(!g){break c}if(!Ud(h)){break c}d:{j=g+236|0;k=h+ -1|0;if(r[Yc(j,k)>>1]){break d}vb(i+8|0,a+1074308|0,43);if(!tb(i+8|0)){break d}if(gi(g)){break d}p[b+656>>2]=g;break a}if(q[Yb(g+108|0,k)|0]>120){break a}k=r[Yc(j,k)>>1];k=(k+ -1&65535)>>>0<3999?(v(k,104)+a|0)+484380|0:0;break b}k=(v(c,104)+a|0)+484380|0;if(!r[a+480192>>1]){break b}if(h>>>0>250){break a}vb(i+8|0,a+1074308|0,43);if(tb(i+8|0)){if(g){k=0;if(gi(g)){break b}}n[b+825|0]=0;p[b+656>>2]=0;break a}k=0}j=p[b+656>>2];x=p[a+480180>>2];m=!d;l=p[b+104>>2];t=!l|(k|0)==(l|0);u=t;h=0;e:{if(!g){break e}h=0;if((x|0)!=16777216){break e}h=p[g+44>>2]!=0}x=h;if(p[b+656>>2]==(g|0)?!(!h|u|m):0){break a}h=(k|0)!=(l|0);l=(l|0)!=0;u=d^1;f:{if(t|u){break f}m=a+1074308|0;vb(i+8|0,m,32);if(!(!tb(i+8|0)|!(q[a+480208|0]&8))){k=p[b+8>>2]|p[b+12>>2]?p[b+104>>2]:k}g:{if(p[a+480180>>2]==268435456|(p[a+480180>>2]&1048580?!(!g|(g|0)!=(j|0)):0)){break g}if(p[a+480180>>2]==1){if(yh(b)){break g}}vb(i+8|0,m,79);if(!tb(i+8|0)){break f}if(!yh(b)){break f}}w=1}m=h&l;h:{if(!p[b+16>>2]|(!m|(!r[a+480192>>1]|(g|0)!=(j|0)))){break h}vb(i+8|0,a+1074308|0,87);if(!tb(i+8|0)){break h}w=Sf(b+810|0)^1|w}i:{j:{k:{l:{if(!(yh(b)|!(p[a+480180>>2]&16777248))){if(!g){break l}if(!gi(g)){break l}}if((g|0)==(j|0)){break k}}m:{n:{if(!d){break n}vb(i+8|0,a+1074308|0,61);if(!tb(i+8|0)){break n}j=p[b+656>>2];if(j){break m}l=0;j=0;h=p[b+104>>2];if(h){break i}}l=1;break j}h=p[b+104>>2];l=0;break i}l=0}p[b+656>>2]=g;h=k;j=g}o:{p:{q:{if(!e){break q}r:{if(p[a+480180>>2]&3){if(h){if(ue(h)){break r}}if(!Zi(b)){break q}}if(!h){break p}}if(o[h+34>>1]<0){break q}p[b+688>>2]=r[h+30>>1]}g=(h|0)!=0;if((m&g&w)!=1){break o}vb(i+8|0,a+1074308|0,85);if(tb(i+8|0)){p[b+768>>2]=n[h+37|0]}g=1;if(p[a+480180>>2]!=2){break o}if(!ue(h)){break o}p[b+704>>2]=p[h+24>>2];break o}if(!(!j|!q[j+34|0])){g=b;k=b;t=p[b+656>>2];s:{if(t){k=p[t+4>>2]<<2;break s}k=p[k+688>>2]}p[g+688>>2]=k;g=0;break o}g=0;p[b+688>>2]=0}if(w){break a}n[b+825|0]=0;t:{if(!j){break t}vb(i+8|0,a+1074308|0,29);if(z=0,A=!((tb(i+8|0)^1)&g),B=q[j+34|0]!=0|l,B?z:A){break t}n[b+820|0]=q[j+16|0]}$ua(b,h,j);u:{if(p[a+480180>>2]&1048580?!e:0){break u}vb(i+8|0,a+1074308|0,48);if(tb(i+8|0)){break u}RK(a,b,j,h)}v:{w:{x:{if(!f){break x}e=a+1074308|0;vb(i+8|0,e,19);y:{z:{A:{B:{C:{D:{E:{F:{if(tb(i+8|0)){if(!p[b+76>>2]){k=1;break E}if(!(!c|u)){k=(q[a+480208|0]&8)>>>3|0;if(k){break E}break F}k=0;if(c){break F}break E}k=1;G:{if(!d|!(p[a+480180>>2]&17301536)|(!p[b+76>>2]|q[a+480208|0]&8)){break G}k=0;if(!(q[b+89|0]&16)){break G}k=!p[b+696>>2]}if(!(p[a+480180>>2]&17301536)|(!j|l)){break C}if(!k){break B}c=p[b+88>>2];f=c&6144;break D}if(d){break E}if(!(q[b+89|0]&24)){k=0;break E}k=(q[a+480208|0]&4)>>>2|0}if(!p[b+696>>2]|l){break C}if(!k){break B}c=p[b+88>>2];f=c&2048}p[b+88>>2]=c|2097152;if(!j){break y}if(f){break z}if(!(q[j+60|0]&8)){fi(b+724|0)}if(!(q[j+80|0]&8)){fi(b+736|0)}if(q[j+100|0]&8){break y}fi(b+748|0);break y}if(k){break A}}if(j){if(n[j+60|0]&1){break x}vb(i+8|0,e,32);if(tb(i+8|0)){fi(b+724|0);break x}jl(b);break x}c=0;if(!h){break w}break v}p[b+88>>2]=p[b+88>>2]|2097152;if(!j){break y}}jl(b)}vb(i+8|0,e,21);if(tb(i+8|0)){break x}n[b+838|0]=0;p[b+780>>2]=0}c=0;if(h){break v}if(!j){break w}c=1;if(gi(j)){break v}}p[b+764>>2]=0;p[b+104>>2]=0;break a}H:{I:{J:{K:{L:{if(!(!d|(g^1|p[b+104>>2]!=(h|0)))){if(p[b+76>>2]?p[a+480180>>2]&16777250:0){break a}if(p[a+480180>>2]!=4){break L}vb(i+8|0,a+1074308|0,40);if(!tb(i+8|0)|q[b+811|0]){break L}g=p[b+88>>2];break K}p[b+88>>2]=p[b+88>>2]&-6145;g=a+1074308|0;vb(i+8|0,g,18);e=b;M:{if(!(z=!tb(i+8|0),A=0,B=p[a+480180>>2]&16777248,B?z:A)){f=-640;if(!(p[b+104>>2]!=(h|0)|l)){break M}}f=-768}p[e+88>>2]=f&p[b+88>>2];N:{if(!j){break N}n[b+724|0]=q[j+60|0];n[b+736|0]=q[j+80|0];n[b+748|0]=q[j+100|0];O:{if((q[j+100|0]&17)!=17){break O}vb(i+8|0,g,36);if(tb(i+8|0)|q[b+857|0]){break O}n[b+857|0]=127}if(Ot(j)){z=b,A=BA(j),n[z+857|0]=A}if(!yA(j)){break N}z=b,A=zA(j),n[z+858|0]=A}if(c){break J}if(!d){break H}break I}g=p[b+88>>2]&-6145;p[b+88>>2]=g}p[b+88>>2]=g&-640;if(!c){break I}}p[b+76>>2]=0;p[b+104>>2]=0;break a}if(p[b+76>>2]){break H}c=a+1074308|0;vb(i+8|0,c,54);if(!tb(i+8|0)){vb(i,c,39);if(!tb(i)){break H}}p[b+8>>2]=0;p[b+12>>2]=0}P:{if(q[b+810|0]!=255){break P}vb(i+8|0,a+1074308|0,100);if(!tb(i+8|0)|(!(p[a+480208>>2]&4)|m^1)){break P}c=p[b+104>>2];if(c){p[b+88>>2]=p[b+88>>2]|r[c+34>>1]&1023}p[b+764>>2]=y;p[b+688>>2]=r[h+30>>1];if(!(q[h+34|0]&32)){break a}ts(b,r[h+28>>1],a);break a}p[b+104>>2]=h;p[b+76>>2]=p[h>>2];p[b+80>>2]=p[h+4>>2];p[b+84>>2]=p[h+8>>2];d=a+1074308|0;vb(i+8|0,d,83);if(!(!tb(i+8|0)|p[b+80>>2])){p[b+84>>2]=p[h>>2]}p[b+88>>2]=p[b+88>>2]|r[h+34>>1]&1023;vb(i+8|0,d,21);if(tb(i+8|0)){n[b+838|0]=0;p[b+780>>2]=0}c=b;Q:{R:{if(x){p[b+704>>2]=p[h+24>>2];n[b+872|0]=q[b+872|0]|8;e=0;break R}if(p[a+480180>>2]&5?!(m|u):0){break Q}p[b+704>>2]=p[h+24>>2];e=n[h+37|0]}p[c+768>>2]=e}p[b+772>>2]=n[h+36|0];vb(i+8|0,d,69);if(!(tb(i+8|0)|p[a+480180>>2]==1)){p[b+708>>2]=0}p[b+876>>2]=0;g=p[b+88>>2];if(g&8){p[b+80>>2]=p[h+12>>2];p[b+84>>2]=p[h+16>>2];if(g&16){g=g|4;p[b+88>>2]=g}g=g|2;p[b+88>>2]=g}S:{if(!(g&2)){g=p[b+76>>2];break S}c=p[b+84>>2];g=p[b+76>>2];if(c>>>0>=g>>>0){break S}p[b+76>>2]=c;g=c}if(!(p[a+480180>>2]&16777248)|g>>>0>s[b+4>>2]){break a}p[b>>2]=0;p[b+4>>2]=0}fb=i+16|0}function C5(a,b,c,d,f,g){a=a|0;b=+b;c=c|0;d=d|0;f=f|0;g=g|0;var i=0,j=0,k=0,l=0,m=0,o=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;o=fb-560|0;fb=o;p[o+44>>2]=0;h(+b);i=e(1)|0;e(0)|0;a:{if((i|0)<-1?1:(i|0)<=-1){D=1;b=-b;h(+b);i=e(1)|0;e(0)|0;y=55568;break a}D=1;y=55571;if(f&2048){break a}y=55574;if(f&1){break a}D=0;C=1;y=55569}b:{if((i&2146435072)==2146435072){m=D+3|0;vf(a,32,c,m,f&-65537);Fe(a,y,D);d=g&32;Fe(a,b!=b?d?55595:55599:d?55587:55591,3);break b}z=o+16|0;c:{d:{e:{b=PE(b,o+44|0);b=b+b;if(b!=0){i=p[o+44>>2];p[o+44>>2]=i+ -1;E=g|32;if((E|0)!=97){break e}break c}E=g|32;if((E|0)==97){break c}m=p[o+44>>2];r=(d|0)<0?6:d;break d}m=i+ -29|0;p[o+44>>2]=m;b=b*268435456;r=(d|0)<0?6:d}t=(m|0)<0?o+48|0:o+336|0;l=t;while(1){d=l;if(b<4294967296&b>=0){i=~~b>>>0}else{i=0}p[d>>2]=i;l=l+4|0;b=(b- +(i>>>0))*1e9;if(b!=0){continue}break}f:{if((m|0)<1){d=m;i=l;j=t;break f}j=t;d=m;while(1){s=(d|0)<29?d:29;i=l+ -4|0;g:{if(i>>>0<j>>>0){break g}d=s;k=0;while(1){w=i;F=k;G=p[i>>2];u=d&31;if(32<=(d&63)>>>0){k=G<<u;G=0}else{k=(1<<u)-1&G>>>32-u;G=G<<u}u=F+G|0;k=k+H|0;k=u>>>0<G>>>0?k+1|0:k;k=QNa(u,k,1e9,0);F=w;w=NNa(k,ib,1e9,0);p[F>>2]=u-w;i=i+ -4|0;if(i>>>0>=j>>>0){continue}break}if(!k){break g}j=j+ -4|0;p[j>>2]=k}while(1){i=l;if(i>>>0>j>>>0){l=i+ -4|0;if(!p[l>>2]){continue}}break}d=p[o+44>>2]-s|0;p[o+44>>2]=d;l=i;if((d|0)>0){continue}break}}if((d|0)<=-1){A=((r+25|0)/9|0)+1|0;s=(E|0)==102;while(1){k=(d|0)<-9?9:0-d|0;h:{if(j>>>0>=i>>>0){j=p[j>>2]?j:j+4|0;break h}w=1e9>>>k|0;u=-1<<k^-1;d=0;l=j;while(1){F=d;d=p[l>>2];p[l>>2]=F+(d>>>k|0);d=v(w,d&u);l=l+4|0;if(l>>>0<i>>>0){continue}break}j=p[j>>2]?j:j+4|0;if(!d){break h}p[i>>2]=d;i=i+4|0}d=p[o+44>>2]+k|0;p[o+44>>2]=d;l=s?t:j;i=i-l>>2>(A|0)?l+(A<<2)|0:i;if((d|0)<0){continue}break}}l=0;i:{if(j>>>0>=i>>>0){break i}l=v(t-j>>2,9);d=10;k=p[j>>2];if(k>>>0<10){break i}while(1){l=l+1|0;d=v(d,10);if(k>>>0>=d>>>0){continue}break}}d=(r-((E|0)==102?0:l)|0)-((E|0)==103&(r|0)!=0)|0;if((d|0)<(v(i-t>>2,9)+ -9|0)){k=d+9216|0;s=(k|0)/9|0;m=((s<<2)+((m|0)<0?o+48|4:o+340|0)|0)+ -4096|0;d=10;k=k-v(s,9)|0;if((k|0)<=7){while(1){d=v(d,10);k=k+1|0;if((k|0)!=8){continue}break}}s=p[m>>2];w=(s>>>0)/(d>>>0)|0;A=m+4|0;k=s-v(d,w)|0;j:{if(k?0:(A|0)==(i|0)){break j}u=d>>>1|0;B=k>>>0<u>>>0?.5:(i|0)==(A|0)?(u|0)==(k|0)?1:1.5:1.5;b=w&1?9007199254740994:9007199254740992;if(!(q[y|0]!=45|C)){B=-B;b=-b}k=s-k|0;p[m>>2]=k;if(b+B==b){break j}d=d+k|0;p[m>>2]=d;if(d>>>0>=1e9){while(1){p[m>>2]=0;m=m+ -4|0;if(m>>>0<j>>>0){j=j+ -4|0;p[j>>2]=0}d=p[m>>2]+1|0;p[m>>2]=d;if(d>>>0>999999999){continue}break}}l=v(t-j>>2,9);d=10;k=p[j>>2];if(k>>>0<10){break j}while(1){l=l+1|0;d=v(d,10);if(k>>>0>=d>>>0){continue}break}}d=m+4|0;i=i>>>0>d>>>0?d:i}while(1){d=i;m=i>>>0<=j>>>0;if(!m){i=d+ -4|0;if(!p[i>>2]){continue}}break}k:{if((E|0)!=103){C=f&8;break k}i=r?r:1;k=(i|0)>(l|0)&(l|0)>-5;r=(k?l^-1:-1)+i|0;g=(k?-1:-2)+g|0;C=f&8;if(C){break k}i=-9;l:{if(m){break l}s=p[d+ -4>>2];if(!s){break l}k=10;i=0;if((s>>>0)%10|0){break l}while(1){m=i;i=i+1|0;k=v(k,10);if(!((s>>>0)%(k>>>0)|0)){continue}break}i=m^-1}m=v(d-t>>2,9);if((g&-33)==70){C=0;i=(i+m|0)+ -9|0;i=(i|0)>0?i:0;r=(r|0)<(i|0)?r:i;break k}C=0;i=((l+m|0)+i|0)+ -9|0;i=(i|0)>0?i:0;r=(r|0)<(i|0)?r:i}s=r|C;w=(s|0)!=0;F=a;k=c;u=g&-33;i=(l|0)>0?l:0;m:{if((u|0)==70){break m}i=l>>31;i=pm(i+l^i,0,z);if((z-i|0)<=1){while(1){i=i+ -1|0;n[i|0]=48;if((z-i|0)<2){continue}break}}A=i+ -2|0;n[A|0]=g;n[i+ -1|0]=(l|0)<0?45:43;i=z-A|0}m=(i+(w+(r+D|0)|0)|0)+1|0;vf(F,32,k,m,f);Fe(a,y,D);vf(a,48,c,m,f^65536);n:{o:{p:{if((u|0)==70){g=o+16|8;l=o+16|9;k=j>>>0>t>>>0?t:j;j=k;while(1){i=pm(p[j>>2],0,l);q:{if((j|0)!=(k|0)){if(i>>>0<=o+16>>>0){break q}while(1){i=i+ -1|0;n[i|0]=48;if(i>>>0>o+16>>>0){continue}break}break q}if((i|0)!=(l|0)){break q}n[o+24|0]=48;i=g}Fe(a,i,l-i|0);j=j+4|0;if(j>>>0<=t>>>0){continue}break}if(s){Fe(a,55603,1)}if((r|0)<1|j>>>0>=d>>>0){break p}while(1){i=pm(p[j>>2],0,l);if(i>>>0>o+16>>>0){while(1){i=i+ -1|0;n[i|0]=48;if(i>>>0>o+16>>>0){continue}break}}Fe(a,i,(r|0)<9?r:9);i=r+ -9|0;j=j+4|0;if(j>>>0>=d>>>0){break o}g=(r|0)>9;r=i;if(g){continue}break}break o}r:{if((r|0)<0){break r}t=d>>>0>j>>>0?d:j+4|0;d=o+16|8;g=o+16|9;l=j;while(1){i=pm(p[l>>2],0,g);if((g|0)==(i|0)){n[o+24|0]=48;i=d}s:{if((j|0)!=(l|0)){if(i>>>0<=o+16>>>0){break s}while(1){i=i+ -1|0;n[i|0]=48;if(i>>>0>o+16>>>0){continue}break}break s}Fe(a,i,1);i=i+1|0;if((r|0)<1?!C:0){break s}Fe(a,55603,1)}w=i;i=g-i|0;Fe(a,w,(r|0)>(i|0)?i:r);r=r-i|0;l=l+4|0;if(l>>>0>=t>>>0){break r}if((r|0)>-1){continue}break}}vf(a,48,r+18|0,18,0);Fe(a,A,z-A|0);break n}i=r}vf(a,48,i+9|0,9,0)}break b}m=g&32;r=m?y+9|0:y;t:{if(d>>>0>11){break t}i=12-d|0;if(!i){break t}B=8;while(1){B=B*16;i=i+ -1|0;if(i){continue}break}if(q[r|0]==45){b=-(B+(-b-B));break t}b=b+B-B}j=p[o+44>>2];i=j>>31;i=pm(i^i+j,0,z);if((z|0)==(i|0)){n[o+15|0]=48;i=o+15|0}t=D|2;j=p[o+44>>2];l=i+ -2|0;n[l|0]=g+15;n[i+ -1|0]=(j|0)<0?45:43;k=f&8;j=o+16|0;while(1){g=j;w=j;j=m;if(x(b)<2147483648){i=~~b}else{i=-2147483648}n[w|0]=j|q[i+55552|0];j=g+1|0;b=(b- +(i|0))*16;if(!((j-(o+16|0)|0)!=1|(b==0?!(k|(d|0)>0):0))){n[g+1|0]=46;j=g+2|0}if(b!=0){continue}break}d=!d|((j-o|0)+ -18|0)>=(d|0)?((z-(o+16|0)|0)-l|0)+j|0:((d+z|0)-l|0)+2|0;m=d+t|0;vf(a,32,c,m,f);Fe(a,r,t);vf(a,48,c,m,f^65536);g=j-(o+16|0)|0;Fe(a,o+16|0,g);i=d;d=z-l|0;vf(a,48,i-(d+g|0)|0,0,0);Fe(a,l,d)}vf(a,32,c,m,f^8192);fb=o+560|0;return((m|0)<(c|0)?c:m)|0}function oma(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-48|0;fb=e;d=a+1074304|0;if(!(p[d>>2]==18284544|s[a+1074304>>2]>=18285126)){Ag(a+1074308|0,0)}f=a+1074308|0;vb(e+32|0,f,0);if(tb(e+32|0)){h=(p[a+480180>>2]&16777248)!=0}vb(e+32|0,f,0);if(tb(e+32|0)){j=p[a+480180>>2]==4}if(s[d>>2]<18874368){a:{if(!r[a+480192>>1]){break a}c=1;while(1){b:{b=p[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}p[e+32>>2]=v(q[b+20|0],100)>>>6;p[e+16>>2]=100;k=b,l=p[Cb(e+32|0,e+16|0)>>2],n[k+20|0]=l;c:{d:{if(h){if(s[d>>2]<18350080){g=n[b+26|0];n[b+26|0]=(((g|0)>-1?1:-1)+g|0)/2}if(s[d>>2]<18285314){break d}break c}g=n[b+26|0];n[b+26|0]=(((g|0)>-1?1:-1)+g|0)/2}EM(Jt(b,2),4,p[a+480180>>2])}e:{if(!q[b+34|0]|(s[d>>2]<18284544|s[d>>2]>=18285136)){break e}if(!gi(b)){break e}Eb(f,2,1)}if(!(q[b+24|0]|(q[b+23|0]|(q[b+19|0]|q[b+20|0])))|s[d>>2]>=18285136){break b}Eb(f,1,1);break a}c=c+1|0;if((c&65535)>>>0<=r[a+480192>>1]){continue}break}}f:{if(!(p[a+480180>>2]&16777248)){break f}b=1;if(!r[a+480190>>1]|(h^1?0:s[d>>2]>=18285314)){break f}while(1){c=v(b&65535,104)+a|0;g=c+484419|0;if(!(q[g|0]|!(q[c+484421|0]|q[c+484420|0]))){n[g|0]=255}b=b+1|0;if((b&65535)>>>0<=r[a+480190>>1]){continue}break}}ixa(a+901404|0)}g:{if(p[d>>2]==18874368|s[d>>2]>=18874896|(!(p[a+480180>>2]&16777252)|!r[a+480192>>1])){break g}b=1;c=0;while(1){h:{g=p[(((b&65535)<<2)+a|0)+900380>>2];if(!(q[g+31|0]?g:0)){b=b+1|0;if((b&65535)>>>0<=r[a+480192>>1]){continue}if(c){break h}break g}n[g+33|0]=13;c=1;b=b+1|0;if((b&65535)>>>0<=r[a+480192>>1]){continue}}break}Eb(f,3,1)}i:{if(!(p[a+480180>>2]&16777248)|(p[d>>2]==19005440|s[d>>2]>=19006226)){break i}vb(e+32|0,f,0);if(!tb(e+32|0)){vb(e+16|0,f,1);if(!tb(e+16|0)){break i}}if(!r[a+480192>>1]){break i}b=1;while(1){c=p[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!q[c+19|0]|!(n[c+80|0]&1))){n[c+19|0]=0}b=b+1|0;if((b&65535)>>>0<=r[a+480192>>1]){continue}break}}j:{k:{l:{if(s[d>>2]<19007233){c=a+946300|0;b=a+906300|0;while(1){g=b+80|0;nma(e+16|0,g);p[114610]=0;Q(438,e+32|0,0,7,e+16|0);i=p[114610];p[114610]=0;if((i|0)==1){break k}pb(e+16|0);p[114610]=0;J(507,g|0,e+32|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break l}pb(e+32|0);b=b+160|0;if((c|0)!=(b|0)){continue}break}}if(!(p[a+480180>>2]!=4|s[d>>2]<19007257|(p[a+1074368>>2]!=4|s[d>>2]>=19071236))){qx(a,5)}if(!(!r[a+480192>>1]|(p[d>>2]==19202048|s[d>>2]>=19202055))){c=1;while(1){i=(((c&65535)<<2)+a|0)+900380|0;b=p[i>>2];m:{if(!b|!q[b+20|0]|!q[b+31|0]){break m}b=b+236|0;g=xs(b);if((b|0)!=(g|0)){while(1){if(r[b>>1]){break m}b=b+2|0;if((g|0)!=(b|0)){continue}break}}n[p[i>>2]+20|0]=0}c=c+1|0;if((c&65535)>>>0<=r[a+480192>>1]){continue}break}}if(!(!r[a+480192>>1]|s[d>>2]>=19267584)){c=1;while(1){b=p[(((c&65535)<<2)+a|0)+900380>>2];n:{if(!b){break n}g=n[b+26|0];n[b+26|0]=(((g|0)>-1?1:-1)+g|0)/2;if(s[d>>2]>=18350080?h:0){break n}n[b+19|0]=q[b+19|0]+3>>>2}c=c+1|0;if((c&65535)>>>0<=r[a+480192>>1]){continue}break}}o:{if(!r[a+480192>>1]|s[d>>2]>=19398674){break o}b=1;while(1){c=p[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|q[c+65|0]==255)){Eb(f,94,1);break o}b=b+1|0;if((b&65535)>>>0<=r[a+480192>>1]){continue}break}}p:{if(!r[a+480192>>1]|s[d>>2]>=19399428){break p}b=1;while(1){c=p[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|q[c+36|0]>1)){Eb(f,101,1);break p}b=b+1|0;if((b&65535)>>>0<=r[a+480192>>1]){continue}break}}b=mma(e+8|0,a);c=p[b+4>>2];p[e>>2]=p[b>>2];p[e+4>>2]=c;lma(e+32|0,a+484344|0,e);q:{r:{if(!h){break r}b=p[d>>2];if(b>>>0>=19267584){break r}Eb(f,8,(b|0)==18284544|b>>>0>18285313);b=30840;while(1){c=p[d>>2];h=p[b+4>>2];Eb(f,p[b>>2],c>>>0>=h>>>0|(c|0)==(h&-65536));b=b+8|0;if((b|0)!=31176){continue}break}break q}if(!j){break q}b=p[d>>2];if(b>>>0>=19267584){break q}Eb(f,8,b>>>0>18285313);b=31192;while(1){Eb(f,p[b>>2],s[d>>2]>=s[b+4>>2]);b=b+8|0;if((b|0)!=31424){continue}break}}s:{if(p[a+480180>>2]&16777248){b=31424;while(1){c=p[d>>2];h=p[b+4>>2];g=h&-65536;if(!(c>>>0<=g>>>0|c>>>0>=h>>>0?c>>>0>=g>>>0:0)){Ag(f,p[b>>2])}b=b+8|0;if((b|0)!=31472){continue}break}break s}if(p[a+480180>>2]==4){b=31472;while(1){if(s[d>>2]<s[b+4>>2]){Ag(f,p[b>>2])}b=b+8|0;if((b|0)!=31528){continue}break}break s}if(p[a+480180>>2]!=2){break s}b=31536;while(1){if(s[d>>2]<s[b+4>>2]){Ag(f,p[b>>2])}b=b+8|0;if((b|0)!=31616){continue}break}}if(!(p[a+480180>>2]!=4|s[d>>2]>=18415616)){Eb(f,98,1)}if(!(s[d>>2]<19333159|s[d>>2]>=19333193)){b=0;while(1){c=b+77|0;vb(e+32|0,f,c);Eb(f,b+86|0,tb(e+32|0));Ag(f,c);b=b+1|0;if((b|0)!=5){continue}break}}t:{if(s[d>>2]<18284544){Eb(f,8,1);break t}if(s[d>>2]<18284544|s[d>>2]>18874627|p[d>>2]==18874368){break t}Eb(f,6,1)}u:{if(s[d>>2]<19136512){Ag(f,7);break u}if(!(p[a+480180>>2]&16777248)|(s[d>>2]<19136512|s[d>>2]>=19267584)){break u}Eb(f,7,1)}vb(e+32|0,f,31);v:{if(!tb(e+32|0)|s[d>>2]<19071234|(!r[a+480192>>1]|s[d>>2]>=19398723)){break v}b=1;while(1){w:{c=p[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break w}h=q[c+65|0];if(!(q[c+60|0]&4)|(h|0)==255|h>>>0<=q[c- -64|0]){break w}Eb(f,97,1);break v}b=b+1|0;if((b&65535)>>>0<=r[a+480192>>1]){continue}break}}x:{if(!r[a+480192>>1]|p[a+480180>>2]!=16777216|(s[d>>2]<19398688|s[d>>2]>19485952)){break x}if(!r[a+480190>>1]){break x}b=1;while(1){if(!(q[(v(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if((b&65535)>>>0<=r[a+480190>>1]){continue}break x}break}Eb(f,109,1)}fb=e+48|0;return}a=I()|0;H()|0;pb(e+32|0);break j}a=I()|0;H()|0;pb(e+16|0)}L(a|0);E()}function iCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-224|0;fb=d;Ac(b);a:{b:{c:{d:{e:{f:{g:{if(!gt(b,d+208|0)){break g}if(!NO(d+208|0)){break g}h=Hh(d+192|0);i=Xc(d+176|0);Jb(d+112|0,0,64);p[114610]=0;f=J(890,b|0,d+104|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}h:{if(!f){break h}f=d+104|4;g=q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24);g=(g<<8&16711680|g<<24|(g>>>8&65280|g>>>24))+ -4|0;g=g<<24|g<<8&16711680|(g>>>8&65280|g>>>24);n[f|0]=g;n[f+1|0]=g>>>8;n[f+2|0]=g>>>16;n[f+3|0]=g>>>24;g=0;i:{j:{k:{while(1){e=q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24);e=(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))+ -8|0;e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);n[f|0]=e;n[f+1|0]=e>>>8;n[f+2|0]=e>>>16;n[f+3|0]=e>>>24;l:{if(c){break l}e=d+104|0;if((q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))!=1413764176){break l}g=1;break h}e=q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24);p[114610]=0;N(341,d+24|0,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));e=p[114610];p[114610]=0;if((e|0)==1){break k}p[114610]=0;e=M(337,d+24|0)|0;j=p[114610];p[114610]=0;m:{n:{o:{p:{q:{if((j|0)==1){break q}if(!e){break p}e=d+104|0;e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if((e|0)<=1347699795){if((e|0)==1129139796){break o}if((e|0)!=1229866575){break n}p[114610]=0;k=J(891,d+24|0,d+112|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break q}break n}if((e|0)!=1347699796){if((e|0)!=1447383635){break n}p[114610]=0;J(338,d+24|0,4)|0;e=p[114610];p[114610]=0;if((e|0)==1){break q}p[114610]=0;e=J(892,d+24|0,16070)|0;j=p[114610];p[114610]=0;if((j|0)==1){break q}if(!e){break n}e=q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0<7){break n}e=q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24);p[114610]=0;U(893,d+24|0,i|0,2,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))+ -6|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break q}break n}p[114610]=0;g=P(894,a|0,d+24|0,c|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break n}}a=I()|0;H()|0;sb(d+24|0);break a}sb(d+24|0);break m}LO(h,d+24|0)}sb(d+24|0);p[114610]=0;e=J(890,b|0,d+104|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break b}if(e){continue}}break}if(Pc(i)){p[114610]=0;b=J(2,d+24|0,16073)|0;c=p[114610];p[114610]=0;if((c|0)==1){break j}xb(i,b);pb(b)}if(!(g&k&1)){break i}b=d+154|0;b=q[b|0]|q[b+1|0]<<8;p[114610]=0;f=b&1;P(478,a+1074308|0,5,!f|0)|0;b=p[114610];p[114610]=0;r:{s:{t:{if((b|0)!=1){b=d+150|0;if(q[b|0]|q[b+1|0]<<8){o[d+24>>1]=64;b=q[b|0]|q[b+1|0]<<8;p[114610]=0;o[d+88>>1]=(b<<8&16711680|b<<24)>>>16;b=J(477,d+24|0,d+88|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break t}p[a+480228>>2]=r[b>>1]}b=d+152|0;if(!(!f|!(q[b|0]|q[b+1|0]<<8))){b=q[b|0]|q[b+1|0]<<8;p[a+480204>>2]=v((b<<24|b<<8&16711680)>>>16|0,1e4)}if(q[d+112|0]){p[114610]=0;N(748,d+88|0,2,d+112|0);b=p[114610];p[114610]=0;if((b|0)==1){break s}p[114610]=0;K(415,d+24|0,d+88|0);b=p[114610];p[114610]=0;if((b|0)==1){break s}xb(a+1304400|0,d+24|0);pb(d+24|0)}b=r[d+158>>1];o[d+86>>1]=b;o[d+22>>1]=b;if(!dp(d+22|0,1,12)){break i}b=r[d+156>>1];o[d+84>>1]=b;o[d+20>>1]=b;if(!dp(d+20|0,1,31)){break i}b=r[d+162>>1];o[d+82>>1]=b;o[d+18>>1]=b;if(!dp(d+18|0,0,23)){break i}b=r[d+164>>1];o[d+80>>1]=b;o[d+16>>1]=b;if(!dp(d+16|0,0,59)){break i}b=r[d+166>>1];o[d+78>>1]=b;o[d+14>>1]=b;if(dp(d+14|0,0,59)){break r}break i}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}b=wp(d+24|0);c=d+160|0;c=q[c|0]|q[c+1|0]<<8;p[b+20>>2]=(c<<24|c<<8&16711680)>>>16;c=d+158|0;c=q[c|0]|q[c+1|0]<<8;p[b+16>>2]=((c<<24|c<<8&16711680)>>>16|0)+ -1;c=d+156|0;c=q[c|0]|q[c+1|0]<<8;p[b+12>>2]=(c<<24|c<<8&16711680)>>>16;c=d+162|0;c=q[c|0]|q[c+1|0]<<8;p[b+8>>2]=(c<<24|c<<8&16711680)>>>16;c=d+164|0;c=q[c|0]|q[c+1|0]<<8;p[b+4>>2]=(c<<24|c<<8&16711680)>>>16;c=d+166|0;c=q[c|0]|q[c+1|0]<<8;p[b>>2]=(c<<24|c<<8&16711680)>>>16;p[114610]=0;K(666,a+1304500|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break i}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}if(g&1){p[114610]=0;b=M(337,h|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break c}if(b){b=Lb(d+24|0);p[114610]=0;P(481,h|0,b|0,32)|0;c=p[114610];p[114610]=0;if((c|0)==1){break d}if(tz(b,16077)){p[114610]=0;N(13,d+88|0,2,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break d}xb(a+1304412|0,d+88|0);pb(d+88|0)}p[114610]=0;c=M(895,h|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}if(!c){p[114610]=0;c=M(548,h|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}p[114610]=0;Z(549,a+1304424|0,h|0,c|0,40,0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break d}}pb(b)}p[114610]=0;b=J(2,d+88|0,16092)|0;c=p[114610];p[114610]=0;if((c|0)==1){break f}p[114610]=0;N(723,d+24|0,b|0,i|0);c=p[114610];p[114610]=0;if((c|0)==1){break e}xb(a+1304460|0,d+24|0);pb(d+24|0);pb(b)}p[a+480208>>2]=p[a+480208>>2]|2097152;p[114610]=0;a=a+1074308|0;P(478,a|0,84,1)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}p[114610]=0;P(478,a|0,83,1)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}p[114610]=0;P(478,a|0,85,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}}pb(i);sb(h)}fb=d+224|0;return g&1}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(b);break a}a=I()|0;H()|0;pb(b);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0}pb(i);sb(h);L(a|0);E()}function BG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-448|0;fb=e;a:{if(Yi(b)){break a}g=q[Mj(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Xj(e+184|0,b,p[b+4>>2]+ -1|0);f=p[e+188>>2];p[b>>2]=p[e+184>>2];p[b+4>>2]=f}ud(e+184|0);f=p[e+184>>2];ud(e+416|0);h=Lj(f,p[e+420>>2],b);ud(e+184|0);f=p[b>>2];g=p[b+4>>2];c:{d:{e:{f:{if((h|0)==p[e+188>>2]){p[e+440>>2]=f;p[e+444>>2]=g;a=ic(e+432|0,38139);f=p[e+444>>2];p[e+16>>2]=p[e+440>>2];p[e+20>>2]=f;f=p[a+4>>2];p[e+8>>2]=p[a>>2];p[e+12>>2]=f;if(xc(e+16|0,e+8|0)){a=W(8)|0;p[114610]=0;d=J(2142,e+416|0,c|0)|0;b=p[114610];p[114610]=0;g:{h:{i:{if((b|0)!=1){p[114610]=0;N(2119,e+184|0,39211,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break i}dc(a,e+184|0);c=0;p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break c}b=I()|0;H()|0;pb(e+184|0);break h}b=I()|0;H()|0;break g}c=1;b=I()|0;H()|0}pb(d);if(!c){break d}}X(a|0);break d}if(!d){break f}d=W(8)|0;p[114610]=0;f=J(2142,e+384|0,b|0)|0;b=p[114610];p[114610]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){p[114610]=0;N(2119,e+400|0,39090,f|0);a=p[114610];p[114610]=0;if((a|0)==1){break r}p[114610]=0;N(2137,e+416|0,e+400|0,39226);b=p[114610];p[114610]=0;a=1;if((b|0)==1){break q}p[114610]=0;c=J(2142,e+368|0,c|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break p}p[114610]=0;N(138,e+184|0,e+416|0,c|0);b=p[114610];p[114610]=0;a=1;if((b|0)==1){break o}dc(d,e+184|0);p[114610]=0;N(2009,d|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(e+184|0);a=0;break n}b=I()|0;H()|0;break j}a=1;b=I()|0;H()|0;break k}b=I()|0;H()|0;break l}a=1;b=I()|0;H()|0;break m}b=I()|0;H()|0}pb(c)}pb(e+416|0)}pb(e+400|0)}pb(f)}if(!a){break d}X(d|0);break d}p[e+360>>2]=f;p[e+364>>2]=g;d=ic(e+352|0,38139);f=p[e+364>>2];p[e+176>>2]=p[e+360>>2];p[e+180>>2]=f;f=p[d+4>>2];p[e+168>>2]=p[d>>2];p[e+172>>2]=f;if(xc(e+176|0,e+168|0)){a=W(8)|0;p[114610]=0;d=J(2142,e+416|0,c|0)|0;b=p[114610];p[114610]=0;s:{t:{u:{if((b|0)!=1){p[114610]=0;N(2119,e+184|0,39211,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break u}dc(a,e+184|0);c=0;p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break c}b=I()|0;H()|0;pb(e+184|0);break t}b=I()|0;H()|0;break s}c=1;b=I()|0;H()|0}pb(d);if(!c){break d}}X(a|0);break d}d=p[b+4>>2];p[e+344>>2]=p[b>>2];p[e+348>>2]=d;d=ic(e+336|0,38969);f=p[e+348>>2];p[e+160>>2]=p[e+344>>2];p[e+164>>2]=f;f=p[d+4>>2];p[e+152>>2]=p[d>>2];p[e+156>>2]=f;if(xc(e+160|0,e+152|0)){b=p[c+4>>2];p[e+328>>2]=p[c>>2];p[e+332>>2]=b;b=ic(e+320|0,39162);d=p[e+332>>2];p[e+64>>2]=p[e+328>>2];p[e+68>>2]=d;d=p[b+4>>2];p[e+56>>2]=p[b>>2];p[e+60>>2]=d;if(xc(e- -64|0,e+56|0)){p[a+52>>2]=0;break f}b=p[c+4>>2];p[e+312>>2]=p[c>>2];p[e+316>>2]=b;b=ic(e+304|0,39170);d=p[e+316>>2];p[e+48>>2]=p[e+312>>2];p[e+52>>2]=d;d=p[b+4>>2];p[e+40>>2]=p[b>>2];p[e+44>>2]=d;if(xc(e+48|0,e+40|0)){p[a+52>>2]=1;break f}b=p[c+4>>2];p[e+296>>2]=p[c>>2];p[e+300>>2]=b;b=ic(e+288|0,39179);d=p[e+300>>2];p[e+32>>2]=p[e+296>>2];p[e+36>>2]=d;d=p[b+4>>2];p[e+24>>2]=p[b>>2];p[e+28>>2]=d;if(xc(e+32|0,e+24|0)){p[a+52>>2]=2;break f}a=W(8)|0;p[114610]=0;d=J(2142,e+416|0,c|0)|0;b=p[114610];p[114610]=0;v:{w:{x:{if((b|0)!=1){p[114610]=0;N(2119,e+184|0,39273,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break x}dc(a,e+184|0);c=0;p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break c}b=I()|0;H()|0;pb(e+184|0);break w}b=I()|0;H()|0;break v}c=1;b=I()|0;H()|0}pb(d);if(!c){break d}}X(a|0);break d}d=p[b+4>>2];p[e+280>>2]=p[b>>2];p[e+284>>2]=d;b=ic(e+272|0,39012);d=p[e+284>>2];p[e+144>>2]=p[e+280>>2];p[e+148>>2]=d;d=p[b+4>>2];p[e+136>>2]=p[b>>2];p[e+140>>2]=d;if(!xc(e+144|0,e+136|0)){break f}b=p[c+4>>2];p[e+264>>2]=p[c>>2];p[e+268>>2]=b;b=ic(e+256|0,39184);d=p[e+268>>2];p[e+128>>2]=p[e+264>>2];p[e+132>>2]=d;d=p[b+4>>2];p[e+120>>2]=p[b>>2];p[e+124>>2]=d;b=0;y:{if(xc(e+128|0,e+120|0)){break y}b=p[c+4>>2];p[e+248>>2]=p[c>>2];p[e+252>>2]=b;b=ic(e+240|0,39189);d=p[e+252>>2];p[e+112>>2]=p[e+248>>2];p[e+116>>2]=d;d=p[b+4>>2];p[e+104>>2]=p[b>>2];p[e+108>>2]=d;b=1;if(xc(e+112|0,e+104|0)){break y}b=p[c+4>>2];p[e+232>>2]=p[c>>2];p[e+236>>2]=b;b=ic(e+224|0,39195);d=p[e+236>>2];p[e+96>>2]=p[e+232>>2];p[e+100>>2]=d;d=p[b+4>>2];p[e+88>>2]=p[b>>2];p[e+92>>2]=d;b=2;if(xc(e+96|0,e+88|0)){break y}b=p[c+4>>2];p[e+216>>2]=p[c>>2];p[e+220>>2]=b;b=ic(e+208|0,39206);c=p[e+220>>2];p[e+80>>2]=p[e+216>>2];p[e+84>>2]=c;c=p[b+4>>2];p[e+72>>2]=p[b>>2];p[e+76>>2]=c;b=3;if(xc(e+80|0,e+72|0)){break y}a=W(8)|0;p[114610]=0;c=J(85,e+184|0,39298)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(c);break d}p[a+56>>2]=b;b=a+24|0;if(!p[p[b>>2]+24668>>2]){break f}c=p[b>>2];d=c+24664|0;f=p[d+4>>2];p[e+200>>2]=p[d>>2];p[e+204>>2]=f;d=c+24656|0;f=p[d+4>>2];p[e+192>>2]=p[d>>2];p[e+196>>2]=f;d=p[c+24652>>2];p[e+184>>2]=p[c+24648>>2];p[e+188>>2]=d;i=e,j=hG(p[a+56>>2]),p[i+204>>2]=j;if(!lw(e+184|0,p[b>>2]+24648|0)){break f}gx(p[b>>2],e+184|0)}fb=e+448|0;return}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function qCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0;d=fb-1824|0;fb=d;Ac(b);f=d+1224|0;e=TBa(b,f);if(!e){GO(f)}a:{if(!e){break a}if(!OO(d+1224|0)){break a}if(!pCa(b)){break a}p[d+1216>>2]=p[d+1240>>2];f=p[d+1228>>2];p[d+1200>>2]=p[d+1224>>2];p[d+1204>>2]=f;f=d+1232|0;e=p[f+4>>2];p[d+1208>>2]=p[f>>2];p[d+1212>>2]=e;xd(a,1);f=a+1074308|0;Ag(f,83);Eb(f,84,1);Eb(f,85,1);o[a+480188>>1]=4;p[d+1196>>2]=0;o[a+480190>>1]=15;Jc(b,20);k=a+480188|0;g=1;h=1;f=0;while(1){j=v(g,104)+a|0;m=j+484380|0;e=((g<<5)+a|0)+946300|0;Jy(b,d+16|0,m,e,1);i=p[m>>2];b:{if(!q[Yb(e,0)|0]){break b}c:{if(hd(e,15681,3)){if(hd(e,15685,3)){break c}}if(q[Yb(e,5)|0]==58){break b}}h=0}e=q[d+44|0]|q[d+45|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0>=2){e=q[d+42|0]|q[d+43|0]<<8;p[j+484384>>2]=(e<<24|e<<8&16711680)>>>16;e=q[d+44|0]|q[d+45|0]<<8;l=(e<<24|e<<8&16711680)>>>15|0;e=q[d+42|0]|q[d+43|0]<<8;p[j+484388>>2]=l+((e<<8&16711680|e<<24)>>>16|0);Ym(m)}e=q[d+38|0]|q[d+39|0]<<8;d:{if((e<<24|e<<8&16711680)>>>16>>>0<=4999){e=q[d+42|0]|q[d+43|0]<<8;if((e<<24|e<<8&16711680)>>>16>>>0<1e4){break d}}p[d+1064>>2]=5;z=d,A=p[Gf(d+1196|0,d+1064|0)>>2],p[z+1196>>2]=A}f=f+i|0;g=g+1|0;if((g|0)!=16){continue}break}Iy(b,d+1064|0);s=a+484360|0;qn(Ob(s),d+1064|2,128,65535,65535);g=0;m=TO(b,Ob(s),q[d+1064|0],f,k,0);e=d+1064|1;if(q[d+1064|0]?0:!(q[e|0]|m>>>0>1)){break a}if(pf(b)+65536>>>0<(m<<10)+f>>>0){break a}if(!c){g=1;break a}if(!q[e|0]){n[e|0]=120}if(!hd(d+1200|0,15689,6)){n[e|0]=120}p[a+480204>>2]=125e4;e:{if(q[e|0]==120){break e}f=a;w=145364549.18032786/+(240-q[e|0]|0);f:{if(w<4294967296&w>=0){e=~~w>>>0;break f}e=0}p[f+480204>>2]=e;if(p[d+1196>>2]>=2){p[d+16>>2]=h&1?4:5;z=d,A=p[Gf(d+1196|0,d+16|0)>>2],p[z+1196>>2]=A;break e}p[d+16>>2]=h&1?1:2;z=d,A=p[Gf(d+1196|0,d+16|0)>>2],p[z+1196>>2]=A}p[a+480260>>2]=452;p[a+480264>>2]=3424;p[a+480228>>2]=64;p[a+480208>>2]=p[a+480208>>2]|2097152;pn(d+1048|0,3,d+1200|0);zc(d+16|0,d+1048|0);xb(a+1304400|0,d+16|0);pb(d+16|0);k=0;Xi(a,0);x=p[b+8>>2];o[d+1046>>1]=0;g:{if(m){y=h&1;h=0;while(1){z=d,A=Fy(Ub(Ob(s)),Vb(Ob(s)),d+1046|0),p[z+16>>2]=A;z=d,A=Vb(Ob(s)),p[z+1048>>2]=A;f=Ab(d+16|0,d+1048|0);Ey(b,d+16|0);if(f){h=Gy(d+16|0)+h|0;if(h>>>0>512){break g}}t=0;f=0;j=0;while(1){g=0;while(1){e=f;i=((d+16|0)+(t<<4)|0)+(g<<2)|0;u=q[Yb(i,2)|0]&15;l=q[Yb(i,3)|0];f=0;h:{if(!(e&255)|(q[i|0]|q[i+1|0]<<8|(q[i+2|0]<<16|q[i+3|0]<<24))){break h}f=e+1|0;if((f&255)>>>0<33){break h}p[d+1196>>2]=6}i:{j:{k:{switch(u+ -1|0){case 0:case 1:e=p[d+1196>>2];if((e|0)==1?l>>>0>=32:0){break j}i=(u|0)!=1;if(!(i|(l+ -1&255)>>>0>1)){p[d+1048>>2]=2;z=d,A=p[Gf(d+1196|0,d+1048|0)>>2],p[z+1196>>2]=A;break i}if(i|((l|0)!=55?(l|0)!=71:0)){break i}if((e|0)<=2){break j}break i;case 10:p[d+1196>>2]=6;break i;case 11:case 12:case 13:p[d+1048>>2]=2;z=d,A=p[Gf(d+1196|0,d+1048|0)>>2],p[z+1196>>2]=A;if((u|0)!=13){break i}j=((l|t)!=0)+j|0;f=1;break i;case 14:break k;default:break i}}p[d+1048>>2]=3;z=d,A=p[Gf(d+1196|0,d+1048|0)>>2],p[z+1196>>2]=A;break i}p[d+1196>>2]=y}g=g+1|0;if((g|0)!=4){continue}break}t=t+1|0;if((t|0)!=64){continue}break}if((j+ -1&255)>>>0<2){p[d+1196>>2]=6}k=(j&255)+k|0;f=r[d+1046>>1]+1|0;o[d+1046>>1]=f;if((f&65535)>>>0<m>>>0){continue}break}}if(!(p[d+1196>>2]!=6|k>>>0<=m+32>>>0)){p[d+1196>>2]=5}Jc(b,x);u=c&1;if(u){Pf(a+484344|0,m)}if(m){t=a+484344|0;l=0;while(1){Ey(b,d+16|0);l:{if(!u){break l}if(!ag(t,l&65535,64)){break l}p[d+1048>>2]=0;j=0;while(1){x=_e(Rb(t,l),j,0);h=0;while(1){f=p[((d+16|0)+(j<<4)|0)+(h<<2)>>2];p[d+8>>2]=f;p[d+12>>2]=f;e=x+v(h,6)|0;Ms(d+8|0,e);m:{n:{o:{p:{f=q[e+5|0];q:{if(f){i=e+3|0;k=(d+1048|0)+h|0;g=q[e+3|0];if((g|0)!=14){break p}n[k|0]=0;g=14;break q}k=(d+1048|0)+h|0;n[k|0]=0;g=q[e+3|0];if(!g){break n}i=e+3|0}k=(d+1048|0)+h|0;break o}s=q[k|0];if(!s){break o}if(s>>>0>=16){n[e+2|0]=3;n[e+4|0]=s>>>4;break o}n[e+2|0]=4;n[e+4|0]=s}r:{s:{t:{switch(g+ -12|0){case 1:if(p[d+1196>>2]!=6){g=10;n[i|0]=10;break s}f=0;n[e+5|0]=0;g=13;break s;case 0:f=f&127;n[e+5|0]=f;g=12;break s;case 2:if(p[d+1196>>2]>3?f>>>0<=1:0){break r}g=10;n[i|0]=10;n[k|0]=f;break s;case 3:break t;default:break s}}g=15;f=f&15;n[e+5|0]=f}if(p[d+1196>>2]>1){break r}u:{v:{w:{switch(g|0){case 0:if(f>>>0>2){break v}break;case 2:break u;case 1:break v;default:break w}}n[i|0]=0;break m}n[i|0]=1;break m}g=f&15;if(g){n[i|0]=2;n[e+5|0]=g;break m}if(!(f&240)){break m}n[i|0]=3;n[e+5|0]=f>>>4;break m}fj(e);break m}n[k|0]=0}h=h+1|0;if((h|0)!=4){continue}break}j=j+1|0;if((j|0)!=64){continue}break}}l=l+1|0;if((m|0)!=(l|0)){continue}break}}e=p[d+1196>>2];f=15695;x:{if(e>>>0>=7){break x}f=p[(e<<2)+77448>>2]}e=Mb(d+16|0,15960);xb(a+1304436|0,e);pb(e);e=Mb(d+16|0,15973);xb(a+1304448|0,e);pb(e);Ec(a+1304460|0,f);p[a+1304496>>2]=2;g=1;if(!(c&2)){break a}h=1;while(1){c=v(h,104)+a|0;f=c+484384|0;Sb(b,p[f>>2]);e=p[f>>2];p[f>>2]=0;f=c+484380|0;p[f>>2]=p[f>>2]-e;c=c+484388|0;p[c>>2]=p[c>>2]-e;Tc(d+16|0,8,1,1,0);fg(d+16|0,f,b);h=h+1|0;if((h|0)!=16){continue}break}break a}g=0}fb=d+1824|0;return g|0}function eza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0;d=fb-352|0;fb=d;Jc(b,60);e=15;a:{if(!Dh(b,17148)){Jc(b,124);e=31;if(!Dh(b,17153)){break a}}xd(a,536870912);o[a+480190>>1]=e;Ac(b);b:{if(r[a+480190>>1]){while(1){e=Pz(b);p[(d+224|0)+(f<<2)>>2]=e;if(e>>>0>131072){break b}f=f+1|0;if(f>>>0<r[a+480190>>1]){continue}break}}p[a+480260>>2]=56;p[a+480264>>2]=13696;p[a+480196>>2]=6;f=0;o[a+480192>>1]=0;o[a+480188>>1]=4;p[a+480228>>2]=64;Xi(a,1);Sb(b,4);e=zp(b);if(e>>>0<178){break a}f=a;m=177693e5/+(e>>>0);c:{if(m<4294967296&m>=0){e=~~m>>>0;break c}e=0}p[f+480204>>2]=e;Sb(b,14);d:{e:{f:{if(r[a+480190>>1]){l=d+78|0;h=1;e=0;i=1;while(1){PO(b,d+56|0);dza(d+56|0,(v(h,104)+a|0)+484380|0,p[((h<<2)+d|0)+220>>2]);f=d+56|0;while(1){if((q[f|0]+ -1&255)>>>0<=30){n[f|0]=32;e=e+1|0}f=f+1|0;if((l|0)!=(f|0)){continue}break}if(e>>>0>127){break b}xn(d+192|0,3,d+56|0);zc(d+208|0,d+192|0);p[114610]=0;J(369,((h<<5)+a|0)+946300|0,d+208|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break f}pb(d+208|0);i=i+1|0;h=i&65535;if(h>>>0<=r[a+480190>>1]){continue}break}}e=Mb(d+56|0,17158);p[114610]=0;f=a+946332|0;h=J(1004,f|0,e|0)|0;i=p[114610];p[114610]=0;l=1;g:{h:{i:{j:{if((i|0)!=1){if(!h){p[114610]=0;h=J(85,d+208|0,17169)|0;i=p[114610];p[114610]=0;if((i|0)==1){break j}p[114610]=0;l=J(1004,f|0,h|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break i}pb(h)}pb(e);f=0;if(!Iy(b,d+56|0)){break a}if(!vN(d+56|0)){break a}if(c){break g}break d}f=I()|0;H()|0;break h}f=I()|0;H()|0;break h}f=I()|0;H()|0;pb(h)}pb(e);break e}o[d+54>>1]=0;if(q[d+56|0]){while(1){o[d+208>>1]=q[(d+f|0)+58|0]+1;w=d,x=r[Bi(d+54|0,d+208|0)>>1],o[w+54>>1]=x;f=f+1|0;if(f>>>0<q[d+56|0]){continue}break}}f=d+56|1;e=q[f|0];h=q[d+56|0];i=a+484360|0;Pe(Ob(i),e>>>0<h>>>0?q[f|0]:0);qn(Ob(i),d+56|2,q[d+56|0],65535,65535);if(r[a+480190>>1]==31){Sb(b,4)}p[d+48>>2]=0;p[d+44>>2]=0;p[d+40>>2]=0;n[d+39|0]=0;s=c&1;if(s){Pf(a+484344|0,r[d+54>>1])}if(r[d+54>>1]){t=a+484344|0;h=0;while(1){k:{l:{if(s){i=0;if(ag(t,h&65535,64)){break l}}Sb(b,1024);break k}while(1){u=_e(Rb(t,h),i,0);f=0;while(1){Dl(d+208|0,b);e=v(f,6)+u|0;m:{n:{if(q[Yb(d+208|0,0)|0]!=255){break n}n[(d+48|0)+f|0]=0;n[(d+40|0)+f|0]=0;o:{if(!l){break o}if(q[Yb(d+208|0,1)|0]!=252){break o}w=Yb(d+208|0,1),x=254,n[w|0]=x}p:{switch(q[Yb(d+208|0,1)|0]+ -252|0){case 2:n[e+3|0]=13;break m;case 1:break m;case 0:break p;default:break n}}n[e+3|0]=14;n[d+39|0]=9;break m}g=p[d+208>>2];p[d+32>>2]=g;p[d+12>>2]=g;Ms(d+12|0,e);g=q[e|0];q:{if(!g){break q}n[(d+40|0)+f|0]=0;n[(d+48|0)+f|0]=g;if(g>>>0>48){break q}n[d+192|0]=8;w=d,x=q[dh(d+39|0,d+192|0)|0],n[w+39|0]=x}r:{s:{t:{u:{v:{switch(q[e+3|0]){case 0:if(q[e+5|0]){break s}break r;case 1:n[e+3|0]=1;break m;case 2:g=q[e+5|0];if(g&240){n[e+3|0]=3;n[e+5|0]=g>>>4;break m}g=g&15;if(g){n[e+3|0]=2;n[e+5|0]=g;break m}n[e+5|0]=0;break s;case 3:if(q[(d+40|0)+f|0]){break t}n[e+3|0]=19;n[e+5|0]=0;break m;case 4:if(q[(d+40|0)+f|0]){break t}n[e+3|0]=19;n[e+5|0]=1;break m;case 5:if(!q[e+1|0]){break t}n[e+3|0]=13;n[d+192|0]=63;n[d+31|0]=q[e+5|0]+(r[(v(q[e+1|0],104)+a|0)+484410>>1]>>>2|0);g=q[hc(d+192|0,d+31|0)|0];n[e+5|0]=g;if(!q[(d+40|0)+f|0]){break u}n[e+4|0]=g;n[e+2|0]=1;n[e+5|0]=0;break s;case 6:g=q[e+1|0];if(!g){break t}n[e+3|0]=13;g=r[(v(g,104)+a|0)+484410>>1]>>>2|0;j=q[e+5|0];g=g>>>0<j>>>0?0:g-j|0;n[e+5|0]=g;if(!q[(d+40|0)+f|0]){break u}n[e+4|0]=g;n[e+2|0]=1;n[e+5|0]=0;break s;case 8:j=q[(d+48|0)+f|0];g=q[e+5|0];k=j+(g>>>4|0)|0;n[(d+44|0)+f|0]=k;n[e+3|0]=2;g=g&15;n[(d+40|0)+f|0]=g;w=e,x=uN(g,j,k&255),n[w+5|0]=x;break u;case 9:n[d+192|0]=8;w=d,x=q[dh(d+39|0,d+192|0)|0],n[w+39|0]=x;break s;case 7:break v;default:break s}}g=q[(d+48|0)+f|0];j=q[e+5|0];k=g-(j>>>4|0)|0;n[(d+44|0)+f|0]=k;n[e+3|0]=3;j=j&15;n[(d+40|0)+f|0]=j;w=e,x=uN(j,k&255,g),n[w+5|0]=x}if(q[e+3|0]){break m}break r}n[e+5|0]=0}n[e+3|0]=0}j=q[(d+40|0)+f|0];if(!j){break m}k=(d+44|0)+f|0;g=q[k|0];if(g){n[(d+48|0)+f|0]=g;n[e|0]=g;n[e+5|0]=j;n[k|0]=0}n[e+3|0]=4}f=f+1|0;if((f|0)!=4){continue}break}i=i+1|0;if((i|0)!=64){continue}break}}h=h+1|0;if(h>>>0<r[d+54>>1]){continue}break}}e=r[a+480190>>1];w:{x:{y:{z:{A:{B:{if(c&2){if(!(e&65535)){break B}f=1;while(1){c=(v(f&65535,104)+a|0)+484380|0;if(p[c>>2]){fg(Tc(d+208|0,8,1,0,0),c,b);e=r[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(e&65535)>>>0){continue}break}}if((e&65535)==15){break A}}f=0;p[114610]=0;J(2,d+208|0,17191)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break z}f=I()|0;H()|0;break e}b=Mb(d+16|0,17178);p[114610]=0;K(219,d+192|0,b|0);c=p[114610];p[114610]=0;f=1;if((c|0)==1){break x}p[114610]=0;N(537,d+208|0,d+192|0,d+39|0);c=p[114610];p[114610]=0;if((c|0)==1){break y}}xb(a+1304436|0,d+208|0);pb(d+208|0);if(f){yb(d+192|0);pb(d+16|0)}Ec(a+1304448|0,r[a+480190>>1]==15?17222:17226);p[a+1304496>>2]=2;break d}f=I()|0;H()|0;yb(d+192|0);break w}f=I()|0;H()|0}pb(b);break e}f=I()|0;H()|0;pb(d+208|0)}L(f|0);E()}f=1;break a}f=0}fb=d+352|0;return f|0}function qna(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0;g=fb-16|0;fb=g;c=a+1074392|0;b=p[c>>2]+1|0;p[c>>2]=b;a:{b:{c:{if(b>>>0<il(a)>>>0){break c}u=a+1074984|0;j=a+1074308|0;i=a+1304360|0;h=a+484344|0;d=a+484360|0;f=a+1074438|0;l=a+1074424|0;m=a+480210|0;while(1){k=0;d:{if(!p[a+1074396>>2]){break d}k=0;if(!(q[m|0]&8)){break d}k=p[a+480180>>2]==1}e:{if(p[a+480180>>2]!=2|(q[m|0]&8?0:p[a+1074428>>2])){break e}b=0;if(!r[a+480188>>1]){break e}while(1){p[(v(b,896)+a|0)+1075788>>2]=0;b=b+1|0;if(b>>>0<r[a+480188>>1]){continue}break}}p[a+1074400>>2]=0;p[a+1074392>>2]=0;p[a+1074396>>2]=0;p[a+1074424>>2]=p[a+1074428>>2];b=r[a+1074440>>1];o[a+1074438>>1]=b;if(!(q[a+480208|0]&32)){c=a;f:{if(fc(Ob(d))>>>0>b>>>0){b=r[kc(Ob(d),r[f>>1])>>1];break f}b=65535}o[c+1074436>>1]=b;g:{if((b&65535)>>>0>=ke(h)>>>0){break g}if(Ch(Rb(h,r[a+1074436>>1]))){break g}o[a+1074436>>1]=65534}if(r[a+1074436>>1]>=ke(h)>>>0){while(1){h:{i:{j:{k:{l:{if(r[a+1074436>>1]!=65535){c=r[f>>1];if(fc(Ob(d))>>>0>c>>>0){break l}}m:{b=r[Ob(d)+28>>1];if(!b){c=r[f>>1];if(fc(Ob(d))>>>0<c>>>0){break k}c=r[f>>1];if(!c){break k}while(1){b=c;c=b+ -1|0;e=c&65535;if(!e){break m}if(r[kc(Ob(d),e)>>1]!=65535){continue}break}}c=p[a+480208>>2]|524288;break i}c=p[a+480208>>2]|524288;break j}b=r[f>>1]+1|0;o[f>>1]=b;break h}c=p[a+480208>>2]|524288}b=0}o[a+1074438>>1]=b;p[a+480208>>2]=c&-524289;n:{if(fc(Ob(d))>>>0<=(b&65535)>>>0){break n}while(1){if(r[kc(Ob(d),r[f>>1])>>1]!=65534){break n}c=r[f>>1]+1|0;o[f>>1]=c;if(fc(Ob(d))>>>0>(c&65535)>>>0){continue}break}}c=r[f>>1];o:{if(fc(Ob(d))>>>0<=c>>>0){break o}if(!Vo(Ob(d),r[f>>1])){break o}b=r[f>>1];break h}$i(i,1);break b}c=a;p:{if(fc(Ob(d))>>>0>(b&65535)>>>0){b=r[kc(Ob(d),r[f>>1])>>1];break p}b=65535}o[c+1074436>>1]=b;q:{if((b&65535)>>>0>=ke(h)>>>0){break q}if(Ch(Rb(h,r[a+1074436>>1]))){break q}o[a+1074436>>1]=65534}if(r[a+1074436>>1]>=ke(h)>>>0){continue}break}}o[a+1074440>>1]=r[a+1074438>>1]}if(!Cg(h,r[a+1074436>>1])){break b}if(s[a+1074424>>2]>=s[Rb(h,r[a+1074436>>1])+12>>2]){p[l>>2]=0}if(p[a+480272>>2]==-1){c=0}else{c=(q[a+480208|0]&32)>>>5|0}if(k){b=i+12|0;if(cd(b)){b=-1}else{b=p[_i(b)>>2]}b=(b|0)==p[l>>2]}else{b=1}r:{if(c|b^1){break r}if(!vL(i,r[f>>1],p[l>>2],1)){break r}c=p[a+480272>>2];if(c){if((c|0)>=1){p[a+480272>>2]=c+ -1}$i(i,1);tJ(i,r[f>>1],p[l>>2]);break r}s:{if(q[m|0]&64){if(uL(i,f,l,1)){break s}o[a+1074438>>1]=0;o[a+1074440>>1]=0;p[a+1074424>>2]=0;p[a+1074428>>2]=0;c=q[d+16|0];if((Ah(d)+ -1|0)<=(c|0)){Uo(d,0);$i(i,1);a=0;break a}Uo(d,q[d+16|0]+1&255);$i(i,1);break s}$i(i,1);break b}b=0;while(1){_m((v(b,896)+a|0)+1074984|0,a,b&65535);b=b+1|0;if((b|0)!=256){continue}break}QJ(a);p[a+1074416>>2]=p[a+480196>>2];p[a+1074420>>2]=p[a+480204>>2];p[a+1074444>>2]=p[a+480200>>2];o[a+1074440>>1]=r[a+1074438>>1];p[a+1074428>>2]=p[a+1074424>>2];b=i;t=fc(Ob(d));c=r[a+1074438>>1];if(t>>>0>c>>>0){w=a,x=r[kc(Ob(d),r[a+1074438>>1])>>1],o[w+1074436>>1]=x;c=r[a+1074438>>1]}tJ(b,c&65535,p[a+1074424>>2]);if(!Cg(h,r[a+1074436>>1])){break b}}c=p[a+1074424>>2]+1|0;p[a+1074428>>2]=c;t:{if(c>>>0<s[Rb(h,r[a+1074436>>1])+12>>2]){break t}if(!(q[a+480208|0]&32)){o[a+1074440>>1]=r[a+1074438>>1]+1}p[a+1074428>>2]=0;vb(g+8|0,j,63);if(!tb(g+8|0)){break t}c=p[a+1074432>>2];p[a+1074432>>2]=0;p[a+1074428>>2]=c}c=_e(Rb(h,r[a+1074436>>1]),p[a+1074424>>2],0);b=r[a+480188>>1];if(b){t=(v(b,896)+a|0)+1074984|0;b=u;while(1){vb(g+8|0,j,82);u:{if(!tb(g+8|0)|q[b+827|0]!=1){break u}e=q[c+3|0];if((e|0)!=3?(e|0)!=2:0){break u}w=b,x=dg(a,q[b+822|0],p[b+768>>2],p[b+704>>2]),p[w+700>>2]=x}vb(g+8|0,j,91);v:{if(!tb(g+8|0)){break v}if(Sf(c)){break v}if(!Sf(b+810|0)|q[b+813|0]!=19){break v}e=q[b+815|0];if((e&240)!=208|(e&15)>>>0<s[a+1074416>>2]){break v}w=b,x=dg(a,q[b+810|0],p[b+768>>2],0),p[w+700>>2]=x}vb(g+8|0,j,92);w:{if(!tb(g+8|0)){break w}vb(g,j,5);if(tb(g)|p[a+1074416>>2]!=1|q[b+813|0]!=17){break w}p[a+1074420>>2]=v(q[b+815|0],1e4)}e=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);n[b+810|0]=e;n[b+811|0]=e>>>8;n[b+812|0]=e>>>16;n[b+813|0]=e>>>24;e=q[c+4|0]|q[c+5|0]<<8;n[b+814|0]=e;n[b+815|0]=e>>>8;e=p[b+676>>2];p[b+20>>2]=p[b+672>>2];p[b+24>>2]=e;p[b+88>>2]=p[b+88>>2]&-393217;vb(g+8|0,j,21);if(!tb(g+8|0)){n[b+851|0]=0}p[b+884>>2]=0;n[b+827|0]=0;c=c+6|0;b=b+896|0;if((t|0)!=(b|0)){continue}break}}ypa(a);if(!k){break c}c=p[a+1074416>>2]+1|0;p[a+1074392>>2]=c;if(c>>>0>=il(a)>>>0){continue}break}}if(!p[a+1074416>>2]){p[a+1074416>>2]=1}c=p[a+480208>>2];x:{if(p[a+1074392>>2]){p[a+480208>>2]=c&-4097;if(p[a+480180>>2]&1048580|(q[a+480210|0]&32?0:p[a+480180>>2]==1)){break x}if(s[a+1074392>>2]>=il(a)>>>0|s[a+1074392>>2]%(p[a+1074400>>2]+p[a+1074416>>2]>>>0)){break x}p[a+480208>>2]=p[a+480208>>2]|4096;break x}p[a+480208>>2]=c&-528385|4096}a=Npa(a);break a}a=0}fb=g+16|0;return a}function Dv(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;h=fb-80|0;fb=h;p[h+76>>2]=b;C=h+55|0;z=h+56|0;b=0;a:{b:while(1){c:{if((x|0)<0){break c}if((b|0)>(2147483647-x|0)){p[114584]=61;x=-1;break c}x=b+x|0}d:{e:{f:{k=p[h+76>>2];b=k;i=q[b|0];if(i){while(1){g:{i=i&255;h:{if(!i){i=b;break h}if((i|0)!=37){break g}i=b;while(1){if(q[b+1|0]!=37){break h}j=b+2|0;p[h+76>>2]=j;i=i+1|0;l=q[b+2|0];b=j;if((l|0)==37){continue}break}}b=i-k|0;if(a){Fe(a,k,b)}if(b){continue b}i=h;j=!Sg(n[p[h+76>>2]+1|0]);b=p[h+76>>2];i:{if(!(j|q[b+2|0]!=36)){y=n[b+1|0]+ -48|0;A=1;b=b+3|0;break i}y=-1;b=b+1|0}p[i+76>>2]=b;r=0;s=n[b|0];j=s+ -32|0;j:{if(j>>>0>31){i=b;break j}i=b;j=1<<j;if(!(j&75913)){break j}while(1){i=b+1|0;p[h+76>>2]=i;r=j|r;s=n[b+1|0];j=s+ -32|0;if(j>>>0>=32){break j}b=i;j=1<<j;if(j&75913){continue}break}}k:{if((s|0)==42){j=h;l:{m:{if(!Sg(n[i+1|0])){break m}b=p[h+76>>2];if(q[b+2|0]!=36){break m}p[((n[b+1|0]<<2)+e|0)+ -192>>2]=10;t=p[((n[b+1|0]<<3)+d|0)+ -384>>2];A=1;b=b+3|0;break l}if(A){break f}A=0;t=0;if(a){b=p[c>>2];p[c>>2]=b+4;t=p[b>>2]}b=p[h+76>>2]+1|0}p[j+76>>2]=b;if((t|0)>-1){break k}t=0-t|0;r=r|8192;break k}t=NE(h+76|0);if((t|0)<0){break f}b=p[h+76>>2]}l=-1;n:{if(q[b|0]!=46){break n}if(q[b+1|0]==42){o:{if(!Sg(n[b+2|0])){break o}b=p[h+76>>2];if(q[b+3|0]!=36){break o}p[((n[b+2|0]<<2)+e|0)+ -192>>2]=10;l=p[((n[b+2|0]<<3)+d|0)+ -384>>2];b=b+4|0;p[h+76>>2]=b;break n}if(A){break f}if(a){b=p[c>>2];p[c>>2]=b+4;b=p[b>>2]}else{b=0}l=b;b=p[h+76>>2]+2|0;p[h+76>>2]=b;break n}p[h+76>>2]=b+1;l=NE(h+76|0);b=p[h+76>>2]}i=0;while(1){B=i;w=-1;if(n[b|0]+ -65>>>0>57){break a}s=b+1|0;p[h+76>>2]=s;i=n[b|0];b=s;i=q[(i+v(B,58)|0)+55023|0];if(i+ -1>>>0<8){continue}break}p:{q:{if((i|0)!=19){if(!i){break a}if((y|0)>=0){p[(y<<2)+e>>2]=i;b=(y<<3)+d|0;i=p[b+4>>2];p[h+64>>2]=p[b>>2];p[h+68>>2]=i;break q}if(!a){break d}ME(h- -64|0,i,c,g);s=p[h+76>>2];break p}if((y|0)>-1){break a}}b=0;if(!a){continue b}}j=r&-65537;i=r&8192?j:r;w=0;y=55056;r=z;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{b=n[s+ -1|0];b=B?(b&15)==3?b&-33:b:b;switch(b+ -88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break e;default:break G}}H:{switch(b+ -65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break e;default:break H}}if((b|0)==83){break w}break e}b=p[h+64>>2];k=p[h+68>>2];j=55056;break z}b=0;I:{switch(B&255){case 0:p[p[h+64>>2]>>2]=x;continue b;case 1:p[p[h+64>>2]>>2]=x;continue b;case 2:i=p[h+64>>2];p[i>>2]=x;p[i+4>>2]=x>>31;continue b;case 3:o[p[h+64>>2]>>1]=x;continue b;case 4:n[p[h+64>>2]]=x;continue b;case 6:p[p[h+64>>2]>>2]=x;continue b;case 7:break I;default:continue b}}i=p[h+64>>2];p[i>>2]=x;p[i+4>>2]=x>>31;continue b}l=l>>>0>8?l:8;i=i|8;b=120}k=E5(p[h+64>>2],p[h+68>>2],z,b&32);if(!(i&8)|!(p[h+64>>2]|p[h+68>>2])){break y}y=(b>>>4|0)+55056|0;w=2;break y}k=D5(p[h+64>>2],p[h+68>>2],z);if(!(i&8)){break y}b=z-k|0;l=(l|0)>(b|0)?l:b+1|0;break y}j=p[h+68>>2];k=j;b=p[h+64>>2];if((j|0)<-1?1:(j|0)<=-1){k=0-(k+(0<b>>>0)|0)|0;b=0-b|0;p[h+64>>2]=b;p[h+68>>2]=k;w=1;j=55056;break z}if(i&2048){w=1;j=55057;break z}w=i&1;j=w?55058:55056}y=j;k=pm(b,k,z)}i=(l|0)>-1?i&-65537:i;b=p[h+68>>2];j=b;s=p[h+64>>2];if(!(!!(b|s)|l)){l=0;k=z;break e}b=!(j|s)+(z-k|0)|0;l=(l|0)>(b|0)?l:b;break e}b=p[h+64>>2];k=b?b:55066;b=$q(k,0,l);r=b?b:l+k|0;i=j;l=b?b-k|0:l;break e}j=p[h+64>>2];if(l){break u}b=0;vf(a,32,t,0,i);break t}p[h+12>>2]=0;p[h+8>>2]=p[h+64>>2];p[h+64>>2]=h+8;l=-1;j=h+8|0}b=0;J:{while(1){k=p[j>>2];if(!k){break J}k=QE(h+4|0,k);r=(k|0)<0;if(!(r|k>>>0>l-b>>>0)){j=j+4|0;b=b+k|0;if(l>>>0>b>>>0){continue}break J}break}w=-1;if(r){break a}}vf(a,32,t,b,i);if(!b){b=0;break t}s=0;j=p[h+64>>2];while(1){k=p[j>>2];if(!k){break t}k=QE(h+4|0,k);s=k+s|0;if((s|0)>(b|0)){break t}Fe(a,h+4|0,k);j=j+4|0;if(s>>>0<b>>>0){continue}break}}vf(a,32,t,b,i^8192);b=(t|0)>(b|0)?t:b;continue b}b=m[f|0](a,u[h+64>>3],t,l,i,b)|0;continue b}n[h+55|0]=p[h+64>>2];l=1;k=C;i=j;break e}j=b+1|0;p[h+76>>2]=j;i=q[b+1|0];b=j;continue}}w=x;if(a){break a}if(!A){break d}b=1;while(1){a=p[(b<<2)+e>>2];if(a){ME((b<<3)+d|0,a,c,g);w=1;b=b+1|0;if((b|0)!=10){continue}break a}break}w=1;if(b>>>0>=10){break a}while(1){if(p[(b<<2)+e>>2]){break f}b=b+1|0;if((b|0)!=10){continue}break}break a}w=-1;break a}r=r-k|0;l=(l|0)<(r|0)?r:l;j=l+w|0;b=(t|0)<(j|0)?j:t;vf(a,32,b,j,i);Fe(a,y,w);vf(a,48,b,j,i^65536);vf(a,48,l,r,0);Fe(a,k,r);vf(a,32,b,j,i^8192);continue}break}w=0}fb=h+80|0;return w}function eIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0;d=fb-1328|0;fb=d;Ac(b);g=d+752|0;h=YHa(b,g);if(!h){PQ(g)}a:{b:{c:{if(!h){break c}if(!SQ(d+752|0)){break c}if(!Hb(b,dd(RQ(d+752|0),ib))){break c}if(!c){e=1;break c}u=ct(d+744|0);w=1;d:{while(1){g=(e<<5)+a|0;h=g+480280|0;Fg(h);i=(d+752|0)+(e<<4)|0;o[g+480284>>1]=((q[i+78|0]<<8&65280)>>>0)/255;mk(d+480|0,1,i- -64|0);zc(d+96|0,d+480|0);p[114610]=0;J(378,g+480289|0,d+96|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}pb(d+96|0);e:{f:{switch(q[i+79|0]){case 0:j=e+1|0;break e;case 1:p[h>>2]=1024;j=f+1|0;break e;case 2:break f;default:break d}}p[h>>2]=1024;uj(d+96|0,u,e);Zd(d+96|0,1)}w=e>>>0<31;f=f+1|0;e=e+1|0;if((e|0)!=32){continue}break}xd(a,33554432);o[a+480188>>1]=j&255;e=Mb(d+96|0,13326);xb(a+1304436|0,e);pb(e);e=Mb(d+96|0,13340);xb(a+1304448|0,e);pb(e);p[a+1304496>>2]=4;g:{if(q[d+831|0]){break g}h=1;while(1){if(q[((h<<4)+d|0)+831|0]!=1){break g}e=1;h=h+1|0;if((h|0)!=16){continue}break}while(1){f=((e<<5)+a|0)+480280|0;p[f>>2]=p[f>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}Eg(d+480|0,1,d+752|0);zc(d+96|0,d+480|0);xb(a+1304400|0,d+96|0);pb(d+96|0);p[a+480208>>2]=p[a+480208>>2]&-17|(q[d+790|0]|q[d+791|0]<<8)<<4&16;p[a+480196>>2]=q[d+800|0];p[a+480204>>2]=v(q[d+801|0],1e4);A=a,B=sd(q[d+802|0],0,64)<<2,p[A+480200>>2]=B;A=a,B=sd(q[d+803|0],4,127),p[A+480228>>2]=B;e=q[d+788|0]|q[d+789|0]<<8;o[a+480190>>1]=0;o[a+480192>>1]=e;hA(b,d+480|0);Et(Ob(a+484360|0),d+480|0,q[d+784|0]|q[d+785|0]<<8,65535,255);x=c&1;if(x){Pf(a+484344|0,q[d+786|0]|q[d+787|0]<<8)}if(q[d+786|0]|q[d+787|0]<<8){y=a+484344|0;j=0;while(1){e=kg(b);s=kg(b);ld(d+96|0,b,e+ -4|0);h:{if(!x){break h}p[114610]=0;e=P(402,y|0,j&65535,s|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){i:{if(!e){break h}l=0;m=jj(d+16|0);if(!s){break h}while(1){j:{p[114610]=0;g=M(387,d+96|0)|0;e=p[114610];p[114610]=0;k:{l:{if((e|0)!=1){if(g){break l}l=l+1|0;break k}break i}e=m;t=g&31;if(r[a+480188>>1]>t>>>0){e=Rb(y,j);p[114610]=0;e=P(471,e|0,l|0,t|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break i}}m:{if(!(g&32)){break m}p[114610]=0;K(472,d+32|0,d+96|0);f=p[114610];p[114610]=0;if((f|0)!=1){f=Zc(d+32|0);h=q[d+32|0];n[e|0]=h;n[e+1|0]=q[f|0];f=e;i=255;n:{if((h|0)==160){break n}if((h|0)!=255){n[e|0]=(v(h>>>4|0,12)+(h&15)|0)+13;p[114610]=0;h=M(618,e|0)|0;i=p[114610];p[114610]=0;if((i|0)!=1){i=0;if(!h){break n}break m}break i}i=0}n[f|0]=i;break m}break i}f=g&192;o:{if(!f){break o}if((f|0)==192){p[114610]=0;K(598,d+32|0,d+96|0);f=p[114610];p[114610]=0;p:{q:{r:{if((f|0)!=1){i=Zc(d+32|0);h=Tf(d+32|0);f=vi(d+32|0);k=d+32|0;z=q[k|0];if((z|0)!=12){break r}p[114610]=0;n[d+8|0]=64;g=J(391,i|0,d+8|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break i}n[e+4|0]=q[g|0];g=1;break q}break i}g=q[h|0];s:{if((g|0)==12){p[114610]=0;n[d+8|0]=64;f=J(391,f|0,d+8|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){n[e+4|0]=q[f|0];g=1;break s}break i}if((z|0)==10){n[e+4|0]=(q[i|0]<<6>>>0)/255;g=2;break q}if((g|0)!=10){break p}n[e+4|0]=(q[f|0]<<6>>>0)/255;g=2}h=k;f=i}n[e+2|0]=g;g=q[h|0]}n[e+3|0]=g;n[e+5|0]=q[f|0];break o}p[114610]=0;K(472,d+32|0,d+96|0);f=p[114610];p[114610]=0;if((f|0)==1){break j}f=Zc(d+32|0);n[e+3|0]=q[d+32|0];n[e+5|0]=q[f|0]}if(q[e+3|0]){p[114610]=0;S(619,e|0);f=p[114610];p[114610]=0;if((f|0)==1){break i}}uj(d+32|0,u,t);if(!tb(d+32|0)){break k}p[114610]=0;f=M(620,e|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break j}if(!f){break k}n[e+3|0]=0}if(l>>>0<s>>>0){continue}break h}break}}}e=I()|0;H()|0;sb(d+96|0);break a}sb(d+96|0);j=j+1|0;if(j>>>0<(q[d+786|0]|q[d+787|0]<<8)>>>0){continue}break}}if(!r[a+480192>>1]){break d}i=c&2;g=0;f=1;while(1){g=g+1|0;m=g&65535;c=JJ(a,m,0);if(!(!c|!_Ha(b,d+96|0))){bIa(d+96|0,c,f&65535);e=0;t:{if(!(q[d+474|0]|q[d+475|0]<<8)){break t}while(1){u:{sp(b,d+32|0);v:{if((q[d+92|0]|q[d+93|0]<<8|(q[d+94|0]<<16|q[d+95|0]<<24))!=808538953){break v}h=e+f|0;c=h&65535;if(c>>>0>3999){break v}o[a+480190>>1]=h;h=v(c,104)+a|0;k=h+484380|0;aIa(d+32|0,k);wA(d+16|0,h+484423|0);p[114610]=0;J(369,((c<<5)+a|0)+946300|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break u}pb(d+16|0);if(!(q[d+48|0]|q[d+49|0]<<8|(q[d+50|0]<<16|q[d+51|0]<<24))){break v}ld(d+16|0,b,q[d+48|0]|q[d+49|0]<<8|(q[d+50|0]<<16|q[d+51|0]<<24));w:{if(!i){break w}c=Tc(d+8|0,o[h+484414>>1]&1?16:8,1,0,0);p[114610]=0;P(400,c|0,k|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break w}e=I()|0;H()|0;sb(d+16|0);break a}sb(d+16|0)}e=e+1|0;if(e>>>0<(q[d+474|0]|q[d+475|0]<<8)>>>0){continue}break t}break}e=I()|0;H()|0;pb(d+16|0);break a}f=(q[d+474|0]|q[d+475|0]<<8)+f|0}if(m>>>0<r[a+480192>>1]){continue}break}}e=w^1}fb=d+1328|0;return e&1}e=I()|0;H()|0;pb(d+96|0)}L(e|0);E()}function jd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;n=fb-96|0;fb=n;w=c;k=g;v=(k&131071)<<15|f>>>17;j=i&65535;r=j;o=h;k=h;B=k<<15|g>>>17;q=(e^i)&-2147483648;k=e&65535;m=k;u=d;E=k;k=j;C=(k&131071)<<15|h>>>17;F=i>>>16&32767;N=e>>>16&32767;a:{b:{if(N+ -1>>>0<=32765){j=0;if(F+ -1>>>0<32766){break b}}l=e&2147483647;j=l;k=d;if(!(!d&(j|0)==2147418112?!(b|c):(j|0)==2147418112&d>>>0<0|j>>>0<2147418112)){x=d;q=e|32768;break a}l=i&2147483647;e=l;d=h;if(!(!d&(e|0)==2147418112?!(f|g):(e|0)==2147418112&d>>>0<0|e>>>0<2147418112)){x=h;q=i|32768;b=f;c=g;break a}if(!(b|k|(j^2147418112|c))){if(!(d|f|(e|g))){q=2147450880;b=0;c=0;break a}q=q|2147418112;b=0;c=0;break a}if(!(d|f|(e^2147418112|g))){d=b|k;e=c|j;b=0;c=0;if(!(d|e)){q=2147450880;break a}q=q|2147418112;break a}if(!(b|k|(c|j))){b=0;c=0;break a}if(!(d|f|(e|g))){b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;j=c;d=!(m|u);h=d<<6;k=y(d?b:u)+32|0;b=y(d?c:m);b=h+((b|0)==32?k:b)|0;ef(n+80|0,i,j,u,m,b+ -15|0);u=p[n+88>>2];w=p[n+84>>2];E=p[n+92>>2];s=16-b|0;b=p[n+80>>2]}j=s;if(e>>>0>65535){break b}c=!(o|r);d=c<<6;e=y(c?f:o)+32|0;c=y(c?g:r);c=d+((c|0)==32?e:c)|0;h=c;ef(n- -64|0,f,g,o,r,c+ -15|0);f=p[n+76>>2];c=f;i=p[n+68>>2];g=i;e=p[n+72>>2];d=e;B=d<<15|g>>>17;d=g;f=p[n+64>>2];v=(d&131071)<<15|f>>>17;C=(c&131071)<<15|e>>>17;j=(s-h|0)+16|0}s=j;d=v;r=0;i=NNa(d,0,b,r);c=ib;D=c;z=f<<15&-32768;o=w;f=NNa(z,0,o,0);e=f+i|0;l=ib+c|0;l=e>>>0<f>>>0?l+1|0:l;c=e;f=0;g=NNa(b,r,z,G);e=f+g|0;j=ib+c|0;j=e>>>0<g>>>0?j+1|0:j;v=e;g=j;W=(c|0)==(j|0)&e>>>0<f>>>0|j>>>0<c>>>0;P=NNa(d,A,o,O);J=ib;w=u;f=NNa(z,G,u,0);e=f+P|0;m=ib+J|0;m=e>>>0<f>>>0?m+1|0:m;Q=e;h=NNa(B,0,b,r);e=e+h|0;f=ib+m|0;K=e;f=e>>>0<h>>>0?f+1|0:f;u=f;h=f;f=(l|0)==(D|0)&c>>>0<i>>>0|l>>>0<D>>>0;e=l;c=e+K|0;j=f+h|0;D=c;j=c>>>0<e>>>0?j+1|0:j;e=j;h=c;S=NNa(d,A,w,R);L=ib;c=z;H=E|65536;z=t;f=NNa(c,G,H,t);c=f+S|0;j=ib+L|0;j=c>>>0<f>>>0?j+1|0:j;T=c;k=NNa(o,O,B,U);c=c+k|0;t=j;f=j+ib|0;f=c>>>0<k>>>0?f+1|0:f;M=c;I=C&2147483647|-2147483648;c=NNa(b,r,I,0);b=M+c|0;r=f;k=f+ib|0;G=b;c=b>>>0<c>>>0?k+1|0:k;j=e+b|0;f=0;b=f+h|0;if(b>>>0<f>>>0){j=j+1|0}E=b;C=j;f=j;h=b+W|0;if(h>>>0<b>>>0){f=f+1|0}i=f;s=(s+(F+N|0)|0)+ -16383|0;f=NNa(w,R,B,U);b=ib;l=0;k=NNa(d,A,H,z);d=k+f|0;j=ib+b|0;j=d>>>0<k>>>0?j+1|0:j;A=d;k=d;d=j;j=(b|0)==(d|0)&k>>>0<f>>>0|d>>>0<b>>>0;f=NNa(I,V,o,O);b=f+k|0;k=ib+d|0;k=b>>>0<f>>>0?k+1|0:k;o=b;f=b;b=k;d=(d|0)==(b|0)&f>>>0<A>>>0|b>>>0<d>>>0;f=j+d|0;if(f>>>0<d>>>0){l=1}k=f;d=b;f=l;F=k;j=0;k=(m|0)==(u|0)&K>>>0<Q>>>0|u>>>0<m>>>0;m=k+((m|0)==(J|0)&Q>>>0<P>>>0|m>>>0<J>>>0)|0;if(m>>>0<k>>>0){j=1}l=m;m=m+o|0;k=d+j|0;A=m;j=m;k=j>>>0<l>>>0?k+1|0:k;d=k;b=(b|0)==(d|0)&j>>>0<o>>>0|d>>>0<b>>>0;k=F+b|0;if(k>>>0<b>>>0){f=f+1|0}b=k;k=NNa(I,V,H,z);b=b+k|0;j=ib+f|0;j=b>>>0<k>>>0?j+1|0:j;l=b;m=NNa(I,V,w,R);f=ib;o=NNa(B,U,H,z);b=o+m|0;k=ib+f|0;k=b>>>0<o>>>0?k+1|0:k;o=b;b=k;k=(f|0)==(b|0)&o>>>0<m>>>0|b>>>0<f>>>0;f=b+l|0;l=j+k|0;k=f>>>0<b>>>0?l+1|0:l;w=f;j=d+o|0;l=0;b=l+A|0;if(b>>>0<l>>>0){j=j+1|0}m=b;f=b;b=j;d=(d|0)==(b|0)&f>>>0<A>>>0|b>>>0<d>>>0;f=w+d|0;if(f>>>0<d>>>0){k=k+1|0}o=f;l=b;j=0;f=(t|0)==(r|0)&M>>>0<T>>>0|r>>>0<t>>>0;t=f+((t|0)==(L|0)&T>>>0<S>>>0|t>>>0<L>>>0)|0;if(t>>>0<f>>>0){j=1}f=t+((c|0)==(r|0)&G>>>0<M>>>0|c>>>0<r>>>0)|0;d=c;c=d+m|0;l=f+l|0;l=c>>>0<d>>>0?l+1|0:l;t=c;d=c;c=l;b=(b|0)==(c|0)&d>>>0<m>>>0|c>>>0<b>>>0;d=b+o|0;if(d>>>0<b>>>0){k=k+1|0}b=c;j=k;k=d;f=0;d=(e|0)==(C|0)&E>>>0<D>>>0|C>>>0<e>>>0;e=d+((e|0)==(u|0)&D>>>0<K>>>0|e>>>0<u>>>0)|0;if(e>>>0<d>>>0){f=1}d=e+t|0;l=b+f|0;l=d>>>0<e>>>0?l+1|0:l;b=d;e=l;b=(c|0)==(e|0)&b>>>0<t>>>0|e>>>0<c>>>0;c=k+b|0;if(c>>>0<b>>>0){j=j+1|0}b=c;c=j;c:{if(c&65536){s=s+1|0;break c}m=g>>>31|0;j=c<<1|b>>>31;b=b<<1|e>>>31;c=j;j=e<<1|d>>>31;d=d<<1|i>>>31;e=j;k=v;j=g<<1|k>>>31;v=k<<1;g=j;k=i<<1|h>>>31;h=h<<1|m;i=k}if((s|0)>=32767){q=q|2147418112;b=0;c=0;break a}d:{if((s|0)<=0){f=1-s|0;if(f>>>0>=128){b=0;c=0;break a}k=s+127|0;ef(n+48|0,v,g,h,i,k);ef(n+32|0,d,e,b,c,k);om(n+16|0,v,g,h,i,f);om(n,d,e,b,c,f);v=(p[n+48>>2]|p[n+56>>2])!=0|(p[n+52>>2]|p[n+60>>2])!=0|(p[n+32>>2]|p[n+16>>2]);g=p[n+36>>2]|p[n+20>>2];h=p[n+40>>2]|p[n+24>>2];i=p[n+44>>2]|p[n+28>>2];d=p[n>>2];e=p[n+4>>2];c=p[n+12>>2];b=p[n+8>>2];break d}c=c&65535|s<<16}x=b|x;q=c|q;if(!(!h&(i|0)==-2147483648?!(g|v):(i|0)>-1)){l=q;m=e;b=d+1|0;if(b>>>0<1){m=m+1|0}c=m;d=(e|0)==(c|0)&b>>>0<d>>>0|c>>>0<e>>>0;e=d+x|0;if(e>>>0<d>>>0){l=l+1|0}x=e;q=l;break a}if(h|v|(i^-2147483648|g)){b=d;c=e;break a}m=q;j=e;b=d&1;c=b+d|0;if(c>>>0<b>>>0){j=j+1|0}b=c;c=j;d=(e|0)==(c|0)&b>>>0<d>>>0|c>>>0<e>>>0;e=d+x|0;if(e>>>0<d>>>0){m=m+1|0}x=e;q=m}p[a>>2]=b;p[a+4>>2]=c;p[a+8>>2]=x;p[a+12>>2]=q;fb=n+96|0}function rza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;d=fb-768|0;fb=d;Ac(b);e=d+160|0;f=mza(b,e);if(!f){AN(e)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}if(!CN(d+160|0)){break n}if(!Hb(b,dd(BN(d+160|0),ib))){break n}if(!c){t=1;break n}xd(a,262144);ft(d+104|0,2,d+160|0);zc(d+24|0,d+104|0);xb(a+1304400|0,d+24|0);pb(d+24|0);e=Mb(d+24|0,16928);xb(a+1304436|0,e);pb(e);e=Mb(d+24|0,16940);xb(a+1304448|0,e);pb(e);f=Mb(d+144|0,16944);p[114610]=0;K(219,d+104|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}n[d+8|0]=q[d+190|0];e=q[d+189|0];p[114610]=0;n[d+127|0]=e;K(995,d+128|0,d+127|0);e=p[114610];p[114610]=0;if((e|0)==1){break e}e=0;p[114610]=0;Q(451,d+24|0,d+104|0,d+8|0,d+128|0);g=p[114610];p[114610]=0;if((g|0)==1){break f}xb(a+1304460|0,d+24|0);pb(d+24|0);pb(d+128|0);yb(d+104|0);pb(f);p[a+480208>>2]=12;p[a+1304496>>2]=4;o[a+480188>>1]=q[d+198|0]|q[d+199|0]<<8;o[d+24>>1]=q[d+194|0]|q[d+195|0]<<8;o[d+104>>1]=3999;B=a,C=r[rf(d+24|0,d+104|0)>>1],o[B+480190>>1]=C;vz(Ob(a+484360|0),d+256|0,q[d+192|0]|q[d+193|0]<<8,255,254);if(r[a+480188>>1]){while(1){f=(e<<5)+a|0;Fg(f+480280|0);o[f+480284>>1]=(q[(d+e|0)+224|0]<<4|4)&244;e=e+1|0;if(e>>>0<r[a+480188>>1]){continue}break}}ld(d+104|0,b,v(q[d+194|0]|q[d+195|0]<<8,80));if(r[a+480190>>1]){g=c&2;j=d+72|0;e=0;while(1){p[114610]=0;J(996,d+104|0,d+24|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break m}p[114610]=0;N(580,d+8|0,2,j|0);f=p[114610];p[114610]=0;o:{p:{q:{if((f|0)==1){break q}p[114610]=0;K(415,d+128|0,d+8|0);f=p[114610];p[114610]=0;if((f|0)==1){break q}p[114610]=0;e=e+1|0;J(369,((e<<5)+a|0)+946300|0,d+128|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break p}pb(d+128|0);p[114610]=0;f=(v(e,104)+a|0)+484380|0;N(997,d+128|0,d+24|0,f|0);h=p[114610];p[114610]=0;r:{if((h|0)==1){break r}if(!g|!p[f>>2]){break o}h=q[d+42|0]|q[d+43|0]<<8|(q[d+44|0]<<16|q[d+45|0]<<24);p[114610]=0;h=J(256,b|0,h|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break r}if(!h){break o}p[114610]=0;P(400,d+128|0,f|0,b|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){break o}}a=I()|0;H()|0;break g}a=I()|0;H()|0;break g}a=I()|0;H()|0;pb(d+128|0);break g}if(e>>>0<r[a+480190>>1]){continue}break}}t=1;s:{if(!(c&1)){break s}c=q[d+196|0]|q[d+197|0]<<8;p[114610]=0;k=a+484344|0;K(401,k|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break l}if(!(q[d+196|0]|q[d+197|0]<<8)){break s}u=d+24|4;w=d+24|2;x=d+24|5;y=d+24|3;z=d+24|1;j=0;while(1){p[114610]=0;c=P(402,k|0,j&65535,64)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}t:{if(!c){break t}c=(j<<1)+d|0;e=c+512|0;if(!(q[e|0]|q[e+1|0]<<8)){break t}c=q[c+512|0]|q[c+513|0]<<8;p[114610]=0;c=J(256,b|0,c<<4)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}if(!c){break t}l=0;c=Rb(k,j);p[114610]=0;m=P(471,c|0,0,0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break h}while(1){p[114610]=0;c=J(258,b|0,1)|0;e=p[114610];p[114610]=0;u:{v:{w:{if((e|0)!=1){if(!c){break t}p[114610]=0;h=M(387,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break w}if(h){break v}l=l+1|0;m=v(r[a+480188>>1],6)+m|0;break u}a=I()|0;H()|0;break g}a=I()|0;H()|0;break g}o[d+28>>1]=0;p[d+24>>2]=0;c=h&31;f=v(c,6)+m|0;s=jj(d+24|0);g=r[a+480188>>1]>c>>>0;x:{y:{z:{A:{B:{C:{D:{if(!(h&32)){break D}p[114610]=0;K(472,d+128|0,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break C}e=Zc(d+128|0);i=g?f:d+24|0;c=q[d+128|0];n[i|0]=c;n[(g?f+1|0:z)|0]=q[e|0];E:{if(c){if((c|0)==254){break E}if(c>>>0<121){break D}}c=0}n[i|0]=c}if(!(h&64)){break x}p[114610]=0;K(472,d+128|0,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break j}A=Zc(d+128|0);c=g?f+3|0:y;e=q[d+128|0];n[c|0]=e;i=g?f+5|0:x;n[i|0]=q[A|0];if(e>>>0>15){break B}p[114610]=0;S(577,(g?f:s)|0);e=p[114610];p[114610]=0;if((e|0)!=1){break A}a=I()|0;H()|0;break g}a=I()|0;H()|0;break g}if(e>>>0>23){break y}s=c;c=q[e+16946|0];n[s|0]=c;break z}c=q[c|0]}c=c&255;if((c|0)!=23){if((c|0)!=9){break x}c=q[i|0];F:{G:{if(c>>>0>=136){e=c&127;break G}e=128;if(c>>>0<129){break F}}n[i|0]=e;c=e}n[i|0]=(v(c&127,255)>>>0)/127;break x}p[114610]=0;n[d+8|0]=64;c=J(391,i|0,d+8|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){n[i|0]=q[c|0]<<1;break x}a=I()|0;H()|0;break g}n[c|0]=0}if(!(h&128)){break u}n[(g?f+2|0:w)|0]=1;p[114610]=0;c=M(387,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}n[(g?f+4|0:u)|0]=c}if(l>>>0<64){continue}break}}j=j+1|0;if(j>>>0<(q[d+196|0]|q[d+197|0]<<8)>>>0){continue}break}}sb(d+104|0)}fb=d+768|0;return t|0}a=I()|0;H()|0;break g}a=I()|0;H()|0;break g}a=I()|0;H()|0;break g}a=I()|0;H()|0;break g}a=I()|0;H()|0;break g}a=I()|0;H()|0}sb(d+104|0);break a}a=I()|0;H()|0;pb(d+128|0);break d}a=I()|0;H()|0}yb(d+104|0);break b}a=I()|0;H()|0}pb(f)}L(a|0);E()}function lMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-128|0;fb=e;Ac(b);a:{if(!ES(b,12168)){break a}if(!cA(b,e+112|0)){break a}if(!GS(e+112|0)){break a}if(!Hb(b,dd(FS(e+112|0),ib))){break a}if(!Sb(b,q[e+121|0]|q[e+122|0]<<8)){break a}b:{if(!c){break b}xd(a,4096);p[a+480208>>2]=12;o[a+480188>>1]=(q[e+112|2]&31)+1;f=e+112|3;o[a+480190>>1]=q[f|0];Xi(a,1);d=Mb(e+56|0,12176);xb(a+1304436|0,d);pb(d);d=Mb(e+56|0,12194);xb(a+1304448|0,d);pb(d);d=Mb(e+80|0,12198);p[114610]=0;K(219,e+96|0,d|0);g=p[114610];p[114610]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((g|0)!=1){p[114610]=0;Q(427,e+56|0,e+96|0,e+112|1,e+112|0);g=p[114610];p[114610]=0;if((g|0)==1){break o}xb(a+1304460|0,e+56|0);pb(e+56|0);yb(e+96|0);pb(d);p[a+1304496>>2]=4;k=jMa(e+96|0,q[f|0]);if(r[a+480190>>1]){f=1;d=1;while(1){p[114610]=0;J(428,b|0,e+56|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break k}p[114610]=0;K(429,e+56|0,(v(f,104)+a|0)+484380|0);g=p[114610];p[114610]=0;if((g|0)==1){break k}g=q[e+72|0];Wd(e+40|0,k,f+ -1|0);Zd(e+40|0,(g&3)!=0);d=d+1|0;f=d&65535;if(f>>>0<=r[a+480190>>1]){continue}break}}p[114610]=0;P(430,b|0,a+1304400|0,-1)|0;f=p[114610];p[114610]=0;d=1;if((f|0)!=1){if(r[a+480190>>1]){while(1){p[114610]=0;P(431,b|0,(((d&65535)<<5)+a|0)+946300|0,-1)|0;f=p[114610];p[114610]=0;if((f|0)==1){break m}d=d+1|0;if((d&65535)>>>0<=r[a+480190>>1]){continue}break}}if(r[a+480188>>1]){d=0;while(1){p[114610]=0;f=(d<<5)+a|0;S(432,f+480280|0);g=p[114610];p[114610]=0;if((g|0)==1){break e}p[114610]=0;P(433,b|0,f+480289|0,-1)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}d=d+1|0;if(d>>>0<r[a+480188>>1]){continue}break}}f=e+112|4;d=q[f|0]|q[f+1|0]<<8;p[114610]=0;j=a+484344|0;K(401,j|0,d|0);d=p[114610];p[114610]=0;if((d|0)!=1){break l}}b=I()|0;H()|0;break d}b=I()|0;H()|0;break n}b=I()|0;H()|0;yb(e+96|0)}pb(d);break c}b=I()|0;H()|0;break d}if(q[f|0]|q[f+1|0]<<8){d=0;while(1){p[114610]=0;P(434,b|0,e+56|0,-1)|0;g=p[114610];p[114610]=0;p:{q:{if((g|0)==1){break q}p[114610]=0;g=P(402,j|0,d&65535,64)|0;h=p[114610];p[114610]=0;if((h|0)==1){break q}if(!g){break p}g=Rb(j,d);p[114610]=0;J(435,g|0,e+56|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break p}}b=I()|0;H()|0;break d}d=d+1|0;if(d>>>0<(q[f|0]|q[f+1|0]<<8)>>>0){continue}break}}p[114610]=0;h=M(357,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}r:{if(!h){break r}p[114610]=0;d=J(258,b|0,h|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break f}if(!d){break r}g=Yt(e+56|0);p[114610]=0;P(436,b|0,g|0,h|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break h}d=Lb(e+40|0);p[114610]=0;K(111,d|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break i}l=e,m=Ub(g),p[l>>2]=m;l=e,m=Vb(g),p[l+32>>2]=m;if(Ab(e,e+32|0)){while(1){s:{h=q[p[e>>2]];if(h&128){l=e,m=jf(d),p[l+16>>2]=m;Ld(e+24|0,e+16|0);p[114610]=0;U(437,d|0,p[e+24>>2],h&127,32)|0;h=p[114610];p[114610]=0;if((h|0)!=1){break s}break i}p[114610]=0;K(110,d|0,h<<24>>24);h=p[114610];p[114610]=0;if((h|0)!=1){break s}break i}bg(e);if(Ab(e,e+32|0)){continue}break}}p[114610]=0;Q(438,e|0,4,5,d|0);h=p[114610];p[114610]=0;if((h|0)==1){break i}xb(d,e);pb(e);h=Ib(d);p[114610]=0;h=M(439,h|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break i}i=wb(d);p[114610]=0;Z(440,a+1304424|0,h|0,i|0,76,0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break i}pb(d);Xd(g)}d=Ob(a+484360|0);g=e+112|6;g=q[g|0]|q[g+1|0]<<8;p[114610]=0;Z(441,d|0,b|0,g|0,65535,65535)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}t:{u:{v:{w:{if(!(q[f|0]|q[f+1|0]<<8)){break w}g=c&1;d=0;while(1){p[114610]=0;h=J(258,b|0,4)|0;i=p[114610];p[114610]=0;x:{if((i|0)!=1){if(h){break x}break w}b=I()|0;H()|0;break d}p[114610]=0;h=M(390,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break u}p[114610]=0;N(341,e+56|0,b|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break t}y:{if(!g){break y}p[114610]=0;h=J(442,j|0,d&65535)|0;i=p[114610];p[114610]=0;if((i|0)==1){break v}if(!h){break y}h=Rb(j,d);p[114610]=0;N(443,h|0,0,e+56|0);h=p[114610];p[114610]=0;if((h|0)==1){break v}}sb(e+56|0);d=d+1|0;if(d>>>0<(q[f|0]|q[f+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!r[a+480190>>1])){f=1;d=1;while(1){c=v(f,104)+a|0;g=r[c+484414>>1];Wd(e+56|0,k,f+ -1|0);f=Tc(e+40|0,g&1?16:8,1,0,tb(e+56|0)?6:0);p[114610]=0;P(400,f|0,c+484380|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break j}d=d+1|0;f=d&65535;if(f>>>0<=r[a+480190>>1]){continue}break}}ce(k);break b}b=I()|0;H()|0;sb(e+56|0);break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;pb(d);break g}b=I()|0;H()|0}Xd(g);break d}b=I()|0;H()|0;break d}b=I()|0;H()|0}ce(k)}L(b|0);E()}f=1}fb=e+128|0;return f|0}function t6(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,s=0,u=0,x=0,y=0,z=0,A=w(0),B=0,C=0,D=0,F=0,G=w(0),H=0,I=0,J=0,K=w(0),L=0,M=0,N=0,O=0,P=0;m=fb-2368|0;fb=m;z=p[a+404>>2];C=q[c+1|0];H=z+v(C,40)|0;I=p[((q[c|0]<<2)+a|0)+104>>2];a:{l=p[a+4>>2];b:{if((l|0)>=1){while(1){i=q[(p[H+4>>2]+v(B,3)|0)+2|0];J=(m+1344|0)+(B<<2)|0;p[J>>2]=0;h=q[(i+H|0)+9|0];if(!r[((h<<1)+a|0)+132>>1]){Wb(a,21);a=0;break b}k=p[a+260>>2];c:{d:{if(bc(a,1)){i=2;u=p[((B<<2)+a|0)+996>>2];l=k+v(h,1596)|0;L=p[(q[l+1588|0]<<2)+50588>>2];h=_k(L)+ -1|0;O=u,P=bc(a,h),o[O>>1]=P;O=u,P=bc(a,h),o[O+2>>1]=P;x=0;if(q[l|0]){while(1){M=q[(l+x|0)+1|0];h=l+M|0;y=q[h+33|0];k=0;D=q[h+49|0];e:{if(!D){break e}h=p[a+124>>2]+v(q[h+65|0],2096)|0;if(p[a+1396>>2]<=9){Kj(a)}j=p[a+1392>>2];k=o[(h+((j&1023)<<1)|0)+36>>1];f:{if((k|0)>=0){s=j;j=q[k+p[h+8>>2]|0];p[a+1392>>2]=s>>>j;s=p[a+1396>>2]-j|0;j=(s|0)<0;p[a+1396>>2]=j?0:s;k=j?-1:k;break f}k=Zk(a,h)}if(!q[h+23|0]){break e}k=p[p[h+2088>>2]+(k<<2)>>2]}if(y){N=-1<<D^-1;y=i+y|0;while(1){h=0;j=o[((l+(M<<4)|0)+((k&N)<<1)|0)+82>>1];g:{if((j|0)<0){break g}j=p[a+124>>2]+v(j&65535,2096)|0;if(p[a+1396>>2]<=9){Kj(a)}s=p[a+1392>>2];h=o[(j+((s&1023)<<1)|0)+36>>1];h:{if((h|0)>=0){F=s;s=q[h+p[j+8>>2]|0];p[a+1392>>2]=F>>>s;F=p[a+1396>>2]-s|0;s=(F|0)<0;p[a+1396>>2]=s?0:F;h=s?-1:h;break h}h=Zk(a,j)}if(!q[j+23|0]){break g}h=p[p[j+2088>>2]+(h<<2)>>2]}k=k>>D;o[u+(i<<1)>>1]=h;i=i+1|0;if((y|0)!=(i|0)){continue}break}i=y}x=x+1|0;if(x>>>0<q[l|0]){continue}break}}if(p[a+1396>>2]!=-1){break d}}p[J>>2]=1;break c}o[m+320>>1]=257;y=l+1592|0;i=p[l+1592>>2];if((i|0)>=3){k=2;while(1){i=k<<1;x=i+l|0;D=q[x+1088|0];h=D<<1;j=l+338|0;F=r[i+j>>1];J=r[h+j>>1];s=j;x=q[x+1089|0];j=x<<1;h=e6(F,J,r[s+j>>1],o[h+u>>1],o[j+u>>1]);s=i+u|0;j=r[s>>1];i:{j:{if(j){n[x+(m+320|0)|0]=1;n[D+(m+320|0)|0]=1;n[(m+320|0)+k|0]=1;x=L-h|0;i=j<<16>>16;if(((x|0)<(h|0)?x:h)<<1<=(i|0)){if((x|0)>(h|0)){break i}h=(j^-1)+L|0;break j}if(i&1){h=h-(i+1>>>1|0)|0;break j}h=(i>>1)+h|0;break j}n[(m+320|0)+k|0]=0}o[s>>1]=h}k=k+1|0;i=p[y>>2];if((k|0)<(i|0)){continue}break}}h=0;if((i|0)<=0){break c}while(1){if(!q[(m+320|0)+h|0]){o[u+(h<<1)>>1]=65535;i=p[y>>2]}h=h+1|0;if((h|0)<(i|0)){continue}break}}B=B+1|0;l=p[a+4>>2];if((B|0)<(l|0)){continue}break}}k:{l:{i=p[a+80>>2];if(!(p[a+84>>2]!=p[a+92>>2]?i:0)){ac(m+320|0,m+1344|0,l<<2);h=r[H>>1];if(h){y=h>>>0>1?h:1;u=p[(z+v(C,40)|0)+4>>2];h=0;while(1){j=u+v(h,3)|0;k=q[j+1|0];j=(m+1344|0)+(q[j|0]<<2)|0;if(!(p[(m+1344|0)+(k<<2)>>2]?p[j>>2]:0)){p[(m+1344|0)+(k<<2)>>2]=0;p[j>>2]=0}h=h+1|0;if((y|0)!=(h|0)){continue}break}}y=I>>1;u=z+v(C,40)|0;if(q[u+8|0]){i=0;while(1){k=0;if((l|0)>=1){B=p[u+4>>2];h=0;while(1){if(q[(B+v(h,3)|0)+2|0]==(i|0)){s=k+m|0;j=h<<2;m:{if(p[j+(m+1344|0)>>2]){p[(m+256|0)+(k<<2)>>2]=0;j=1;break m}p[(m+256|0)+(k<<2)>>2]=p[(a+j|0)+800>>2];j=0}n[s|0]=j;k=k+1|0}h=h+1|0;if((h|0)<(l|0)){continue}break}}d6(a,m+256|0,k,y,q[(i+u|0)+24|0],m);i=i+1|0;if(i>>>0<q[u+8|0]){l=p[a+4>>2];continue}break}i=p[a+80>>2]}if(!(p[a+84>>2]!=p[a+92>>2]?i:0)){i=r[H>>1];if(i){u=(y|0)>1?y:1;j=z+v(C,40)|0;l=a+800|0;while(1){k=i;i=i+ -1|0;if((I|0)>=2){h=p[j+4>>2]+v(i,3)|0;B=p[l+(q[h+1|0]<<2)>>2];C=p[l+(q[h|0]<<2)>>2];h=0;while(1){z=h<<2;x=z+B|0;G=t[x>>2];z=z+C|0;A=t[z>>2];n:{if(!(A<=w(0))){if(!(G<=w(0))){K=w(A-G);break n}K=A;A=w(G+A);break n}if(!(G<=w(0))){K=w(G+A);break n}K=A;A=w(A-G)}t[z>>2]=A;t[x>>2]=K;h=h+1|0;if((u|0)!=(h|0)){continue}break}}if((k|0)>1){continue}break}}if(p[a+4>>2]<1){break k}k=y<<2;h=0;while(1){l=h<<2;u=l+a|0;i=u;o:{if(p[l+(m+320|0)>>2]){Jb(p[i+800>>2],0,k);break o}c6(a,H,h,I,p[i+800>>2],p[u+996>>2])}h=h+1|0;i=p[a+4>>2];if((h|0)<(i|0)){continue}break}break l}aa(50360,50416,3319,50608);E()}aa(50360,50416,3286,50608);E()}h=0;if((i|0)<=0){break k}while(1){b6(p[((h<<2)+a|0)+800>>2],I,a,q[c|0]);h=h+1|0;if((h|0)<p[a+4>>2]){continue}break}}eF(a);p:{if(q[a+1377|0]){p[a+1060>>2]=0-y;n[a+1377|0]=0;p[a+1064>>2]=1;p[a+1412>>2]=I-f;break p}c=p[a+1412>>2];if(!c){break p}i=e-d|0;if((c|0)>=(i|0)){p[a+1412>>2]=c-i;p[g>>2]=e;d=e;break p}d=c+d|0;p[g>>2]=d;p[a+1412>>2]=0}c=p[a+1064>>2];q:{r:{s:{if(p[a+1388>>2]==p[a+1404>>2]){t:{if(!c|!(q[a+1375|0]&4)){break t}c=p[a+1408>>2];g=p[a+1060>>2];if(c>>>0>=g+(f-d|0)>>>0){break t}e=b;b=c-g|0;b=(b>>>0>c>>>0?0:b)+d|0;b=(b|0)>(f|0)?f:b;p[e>>2]=b;p[a+1060>>2]=b+p[a+1060>>2];break q}p[a+1064>>2]=1;p[a+1060>>2]=p[a+1408>>2]+(d-y|0);break s}if(!c){break r}}p[a+1060>>2]=p[a+1060>>2]+(e-d|0)}if(p[a+84>>2]!=p[a+92>>2]?p[a+80>>2]:0){break a}p[b>>2]=f}a=1}fb=m+2368|0;return a}aa(50360,50416,3435,50608);E()}function yoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-208|0;fb=f;o[a+480212>>1]=0;p[a+480240>>2]=65536;p[a+480244>>2]=65536;cK(a+900380|0);bK(a+946300|0);d=eK(f+48|0);p[114610]=0;e=a+906300|0;N(1408,e|0,e+4e4|0,d|0);e=p[114610];p[114610]=0;a:{b:{c:{d:{if((e|0)!=1){Im(d);e:{if(Zp(b)){e=0;i=f+48|0;soa(i);f:{g:{h:{if(c&16){break h}p[114610]=0;g=(c|0)!=0;h=P(1409,i|0,b|0,g|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}d=4;i:{if(h){break i}p[114610]=0;h=P(1410,i|0,b|0,g|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}d=5;if(h){break i}p[114610]=0;h=P(1411,i|0,b|0,g|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}d=6;if(h){break i}h=0;p[114610]=0;g=P(1412,i|0,b|0,g|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}d=3;if(!g){break h}}if(!c){e=1;break b}if(!cd(i)){LO(b,lA(i,0)+12|0)}h=d}if(c&32){break b}d=77888;j:{k:{while(1){g=p[d+8>>2];j=(g>>1)+a|0;e=p[d+4>>2];e=g&1?p[p[j>>2]+e>>2]:e;p[114610]=0;e=P(e|0,j|0,b|0,c|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){if(e){break j}d=d+12|0;if((d|0)==78344){break k}continue}break}a=O(71348)|0;break f}p[a+480180>>2]=0;p[a+480184>>2]=0}if(!c){break b}if(!(p[a+480184>>2]|!h)){p[a+480184>>2]=h}ox(i);break e}a=O(71348)|0}b=H()|0;ox(i);if(($(71348)|0)!=(b|0)){break c}T(a|0)|0;p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)==1){a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break c}a=O(0)|0;H()|0;rb(a)}E()}xd(a,0);p[a+1074300>>2]=19464961}d=0;while(1){b=(d<<5)+a|0;Lg(b+480286|0,64);b=b+480284|0;if(r[b>>1]>=257){o[b>>1]=128}_m((v(d,896)+a|0)+1074984|0,a,d&65535);d=d+1|0;if((d|0)!=127){continue}break}if(r[a+480190>>1]){h=a+1304392|0;d=1;while(1){g=v(d&65535,104)+a|0;j=g+484380|0;l:{if(ue(j)){$x(j,a,0);break l}e=g+484414|0;b=r[e>>1];if(b&16384){break l}p[j>>2]=0;p[j+4>>2]=0;p[j+16>>2]=0;p[j+8>>2]=0;p[j+12>>2]=0;o[e>>1]=b&65505}b=g+484412|0;if(r[b>>1]>=65){o[b>>1]=64}m:{if(!(q[g+484415|0]&2)){break m}if(!aj(h)){break m}woa(a)}d=d+1|0;if((d&65535)>>>0<=r[a+480190>>1]){continue}break}}d=0;e=0;while(1){b=p[(((d&65535)<<2)+a|0)+900380>>2];if(b){Oua(b,p[a+480180>>2]);e=d}d=d+1|0;if((d&65535)>>>0<=r[a+480192>>1]){continue}break}o[a+480192>>1]=e;d=p[a+480204>>2];if(d>>>0<1e4){p[a+480204>>2]=125e4;d=125e4}h=p[a+480196>>2];if(!h){p[a+480196>>2]=6;h=6}e=p[a+480220>>2];b=p[a+480216>>2];if(e>>>0<b>>>0){p[a+480220>>2]=b;e=b}p[a+1074420>>2]=d;d=a+1074416|0;p[d>>2]=h;p[a+1074412>>2]=e;p[a+1074408>>2]=b;p[a+1074444>>2]=p[a+480200>>2];Ex(a+1074376|0);p[a+1074440>>2]=-65536;b=a+1074384|0;p[b>>2]=0;p[b+4>>2]=0;p[a+1074380>>2]=0;b=a+1074424|0;p[b>>2]=0;p[b+4>>2]=0;b=a+1074432|0;p[b>>2]=0;p[b+4>>2]=0;b=a+1074396|0;p[b>>2]=0;p[b+4>>2]=0;o[a+480276>>1]=0;p[a+1074392>>2]=p[d>>2];zo(a);$i(a+1304360|0,1);b=a+484360|0;k=f,l=Ub(b),p[k+48>>2]=l;k=f,l=Vb(b),p[k+32>>2]=l;if(!Ab(f+48|0,f+32|0)){break d}while(1){e=p[f+48>>2];ig(e,bj(e));b=r[e+28>>1];if(fc(e)>>>0<=b>>>0){Pe(e,0)}Zx(f+48|0);if(Ab(f+48|0,f+32|0)){continue}break}break d}a=I()|0;H()|0;Im(d);break c}g=f+48|0;qoa(g);n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c&12)==12){d=0;while(1){c=v(d,160)+a|0;h=c+906300|0;b=h+16|0;e=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);b=h+20|0;w:{if(!(e|(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24)))){break w}p[114610]=0;J(1413,h|0,a|0)|0;b=p[114610];p[114610]=0;x:{if((b|0)!=1){e=p[h>>2];if(!e){break x}c=p[c+906448>>2];b=p[p[e>>2]+56>>2];p[114610]=0;K(b|0,e|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){break w}}a=I()|0;H()|0;break n}k=f,l=uoa(Ub(g),Vb(g),h),p[k+32>>2]=l;k=f,l=Vb(g),p[k+16>>2]=l;if(Ab(f+32|0,f+16|0)){break w}p[114610]=0;p[f+32>>2]=c+906316;K(1414,g|0,f+32|0);b=p[114610];p[114610]=0;if((b|0)==1){break o}p[114610]=0;c=J(2,f+16|0,20462)|0;b=p[114610];p[114610]=0;if((b|0)==1){break v}b=VJ(h);p[114610]=0;K(1415,f|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break u}p[114610]=0;N(3,f+32|0,c|0,f|0);b=p[114610];p[114610]=0;if((b|0)==1){break t}p[114610]=0;N(650,a|0,2,f+32|0);b=p[114610];p[114610]=0;if((b|0)==1){break s}pb(f+32|0);pb(f);pb(c)}d=d+1|0;if((d|0)!=250){continue}break}}b=p[a+1074368>>2];p[114610]=0;K(1416,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break p}b=p[a+480180>>2];y:{if(!b){break y}Rr(a+8|0,Bo(a));if(!p[a+1074304>>2]){break y}p[114610]=0;S(1417,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break p}}TJ(g);e=(b|0)!=0;break a}a=I()|0;H()|0;break n}a=I()|0;H()|0;break q}a=I()|0;H()|0;break r}a=I()|0;H()|0;pb(f+32|0)}pb(f)}pb(c);break n}a=I()|0;H()|0;break n}a=I()|0;H()|0}TJ(g)}L(a|0);E()}ox(i)}fb=f+208|0;return e|0}function FW(a,b){var c=0,d=0,e=0,f=0;c=fb-176|0;fb=c;f=Hv(c+160|0);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{d=p[b>>2];if(d&1){p[114610]=0;p[c+144>>2]=19464961;K(242,c+96|0,c+144|0);d=p[114610];p[114610]=0;if((d|0)==1){break o}p[114610]=0;K(201,f|0,c+96|0);d=p[114610];p[114610]=0;if((d|0)==1){break n}pb(c+96|0);d=p[b>>2]}if(!(d&4)){break l}p[114610]=0;d=Y(243)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}if(!d){break m}break l}b=I()|0;H()|0;break a}b=I()|0;H()|0;pb(c+96|0);break a}p[114610]=0;S(244,c+96|0);d=p[114610];p[114610]=0;p:{if((d|0)!=1){p[114610]=0;K(201,f|0,c+96|0);d=p[114610];p[114610]=0;if((d|0)==1){break p}pb(c+96|0);break l}b=I()|0;H()|0;break a}b=I()|0;H()|0;pb(c+96|0);break a}q:{d=p[b>>2];if(!(d&8)){break q}p[114610]=0;d=J(2,c+128|0,7142)|0;e=p[114610];p[114610]=0;r:{s:{t:{u:{v:{if((e|0)!=1){p[114610]=0;K(219,c+144|0,d|0);e=p[114610];p[114610]=0;if((e|0)==1){break v}p[114610]=0;N(245,c+96|0,c+144|0,7152);e=p[114610];p[114610]=0;if((e|0)==1){break u}p[114610]=0;K(201,f|0,c+96|0);e=p[114610];p[114610]=0;if((e|0)==1){break t}pb(c+96|0);yb(c+144|0);pb(d);d=p[b>>2];break q}b=I()|0;H()|0;break a}b=I()|0;H()|0;break r}b=I()|0;H()|0;break s}b=I()|0;H()|0;pb(c+96|0)}yb(c+144|0)}pb(d);break a}w:{if(!(d&16)){break w}p[114610]=0;S(236,c+96|0);d=p[114610];p[114610]=0;x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if((d|0)!=1){p[114610]=0;K(246,c+144|0,c+96|0);d=p[114610];p[114610]=0;if((d|0)==1){break y}d=Pc(c+144|0);pb(c+144|0);if(!d){p[114610]=0;d=J(2,c- -64|0,7156)|0;e=p[114610];p[114610]=0;if((e|0)==1){break V}p[114610]=0;K(219,c+80|0,d|0);e=p[114610];p[114610]=0;if((e|0)==1){break U}p[114610]=0;K(246,c+48|0,c+96|0);e=p[114610];p[114610]=0;if((e|0)==1){break T}p[114610]=0;N(247,c+144|0,c+80|0,c+48|0);e=p[114610];p[114610]=0;if((e|0)==1){break S}p[114610]=0;K(201,f|0,c+144|0);e=p[114610];p[114610]=0;if((e|0)==1){break R}pb(c+144|0);pb(c+48|0);yb(c+80|0);pb(d)}if(!Pc(Ig(c+96|0))){p[114610]=0;d=J(2,c+32|0,7160)|0;e=p[114610];p[114610]=0;if((e|0)==1){break N}p[114610]=0;K(219,c+80|0,d|0);e=p[114610];p[114610]=0;if((e|0)==1){break M}e=Ig(c+96|0);p[114610]=0;N(247,c+144|0,c+80|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break L}p[114610]=0;K(201,f|0,c+144|0);e=p[114610];p[114610]=0;if((e|0)==1){break K}pb(c+144|0);yb(c+80|0);pb(d)}p[114610]=0;K(248,c+144|0,c+96|0);d=p[114610];p[114610]=0;if((d|0)==1){break H}d=Pc(c+144|0);pb(c+144|0);if(!d){p[114610]=0;d=J(2,c+16|0,7156)|0;e=p[114610];p[114610]=0;if((e|0)==1){break G}p[114610]=0;K(219,c+80|0,d|0);e=p[114610];p[114610]=0;if((e|0)==1){break F}p[114610]=0;K(248,c+48|0,c+96|0);e=p[114610];p[114610]=0;if((e|0)==1){break E}p[114610]=0;N(247,c+144|0,c+80|0,c+48|0);e=p[114610];p[114610]=0;if((e|0)==1){break D}p[114610]=0;K(201,f|0,c+144|0);e=p[114610];p[114610]=0;if((e|0)==1){break C}pb(c+144|0);pb(c+48|0);yb(c+80|0);pb(d)}Se(c+96|0);d=p[b>>2];break w}b=I()|0;H()|0;break a}b=I()|0;H()|0;break x}b=I()|0;H()|0;break O}b=I()|0;H()|0;break P}b=I()|0;H()|0;break Q}b=I()|0;H()|0;pb(c+144|0)}pb(c+48|0)}yb(c+80|0)}pb(d);break x}b=I()|0;H()|0;break x}b=I()|0;H()|0;break I}b=I()|0;H()|0;break J}b=I()|0;H()|0;pb(c+144|0)}yb(c+80|0)}pb(d);break x}b=I()|0;H()|0;break x}b=I()|0;H()|0;break x}b=I()|0;H()|0;break z}b=I()|0;H()|0;break A}b=I()|0;H()|0;break B}b=I()|0;H()|0;pb(c+144|0)}pb(c+48|0)}yb(c+80|0)}pb(d);break x}b=I()|0;H()|0}Se(c+96|0);break a}W:{if(!(d&32)){break W}p[114610]=0;d=Y(243)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}if(d){break W}Xc(c+96|0);p[114610]=0;K(201,f|0,c+96|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}pb(c+96|0)}if(q[b|0]&64){p[114610]=0;S(249,c+96|0);b=p[114610];p[114610]=0;if((b|0)==1){break j}p[114610]=0;K(201,f|0,c+96|0);b=p[114610];p[114610]=0;if((b|0)==1){break i}pb(c+96|0)}p[114610]=0;d=J(2,c+96|0,7166)|0;b=p[114610];p[114610]=0;if((b|0)==1){break h}p[114610]=0;N(250,c|0,f|0,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;e=J(2,c+144|0,10991)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;N(251,a|0,c|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break e}pb(e);pb(c);pb(d);Xk(f);fb=c+176|0;return}b=I()|0;H()|0;break a}b=I()|0;H()|0;break a}b=I()|0;H()|0;pb(c+96|0);break a}b=I()|0;H()|0;break a}b=I()|0;H()|0;break c}b=I()|0;H()|0;break d}b=I()|0;H()|0;pb(e)}pb(c)}pb(d);break a}b=I()|0;H()|0;pb(c+96|0)}Xk(f);L(b|0);E()}function L3(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,r=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=fb-432|0;fb=g;h=p[b+4>>2];a:{if(h>>>0<s[b+104>>2]){p[b+4>>2]=h+1;i=q[h|0];break a}i=Sc(b)}b:{c:{while(1){if((i|0)!=48){d:{if((i|0)!=46){break b}h=p[b+4>>2];if(h>>>0>=s[b+104>>2]){break d}p[b+4>>2]=h+1;i=q[h|0];break c}}else{h=p[b+4>>2];if(h>>>0<s[b+104>>2]){z=1;p[b+4>>2]=h+1;i=q[h|0]}else{z=1;i=Sc(b)}continue}break}i=Sc(b)}y=1;if((i|0)!=48){break b}while(1){o=o+ -1|0;h=v+ -1|0;if((h|0)!=-1){o=o+1|0}v=h;h=p[b+4>>2];e:{if(h>>>0<s[b+104>>2]){p[b+4>>2]=h+1;i=q[h|0];break e}i=Sc(b)}if((i|0)==48){continue}break}z=1}h=1073676288;while(1){f:{A=i|32;g:{h:{B=i+ -48|0;if(B>>>0<10){break h}if(A+ -97>>>0>5?(i|0)!=46:0){break f}if((i|0)!=46){break h}if(y){break f}y=1;v=m;o=j;break g}i=(i|0)>57?A+ -87|0:B;i:{if((j|0)<0?1:(j|0)<=0?m>>>0<=7:0){r=i+(r<<4)|0;break i}if((j|0)<0?1:(j|0)<=0?m>>>0<=28:0){$f(g+48|0,i);jd(g+32|0,w,x,n,h,0,0,0,1073414144);w=p[g+32>>2];x=p[g+36>>2];n=p[g+40>>2];h=p[g+44>>2];jd(g+16|0,w,x,n,h,p[g+48>>2],p[g+52>>2],p[g+56>>2],p[g+60>>2]);Of(g,k,l,t,u,p[g+16>>2],p[g+20>>2],p[g+24>>2],p[g+28>>2]);t=p[g+8>>2];u=p[g+12>>2];k=p[g>>2];l=p[g+4>>2];break i}if(!i|E){break i}jd(g+80|0,w,x,n,h,0,0,0,1073610752);Of(g- -64|0,k,l,t,u,p[g+80>>2],p[g+84>>2],p[g+88>>2],p[g+92>>2]);t=p[g+72>>2];u=p[g+76>>2];E=1;k=p[g+64>>2];l=p[g+68>>2]}m=m+1|0;if(m>>>0<1){j=j+1|0}z=1}i=p[b+4>>2];if(i>>>0<s[b+104>>2]){p[b+4>>2]=i+1;i=q[i|0]}else{i=Sc(b)}continue}break}j:{k:{l:{if(!z){if(!p[b+104>>2]){if(f){break k}break l}c=p[b+4>>2];p[b+4>>2]=c+ -1;if(!f){break l}p[b+4>>2]=c+ -2;if(!y){break k}p[b+4>>2]=c+ -3;break k}if((j|0)<0?1:(j|0)<=0?m>>>0<=7:0){n=m;h=j;while(1){r=r<<4;n=n+1|0;if(n>>>0<1){h=h+1|0}if((n|0)!=8|h){continue}break}}m:{if((i&-33)==80){n=QD(b,f);i=ib;h=i;if(n|(h|0)!=-2147483648){break m}if(f){n=0;h=0;if(!p[b+104>>2]){break m}p[b+4>>2]=p[b+4>>2]+ -1;break m}k=0;l=0;Rg(b,0,0);c=0;b=0;break j}n=0;h=0;if(!p[b+104>>2]){break m}p[b+4>>2]=p[b+4>>2]+ -1}if(!r){Qh(g+112|0,+(e|0)*0);k=p[g+112>>2];l=p[g+116>>2];c=p[g+120>>2];b=p[g+124>>2];break j}f=y?v:m;o=(y?o:j)<<2|f>>>30;b=n+(f<<2)|0;f=h+o|0;f=b>>>0<n>>>0?f+1|0:f;b=b+ -32|0;h=f+ -1|0;m=b;j=b>>>0<4294967264?h+1|0:h;if((j|0)>0?1:(j|0)>=0?b>>>0>0-d>>>0:0){p[114584]=68;$f(g+160|0,e);jd(g+144|0,p[g+160>>2],p[g+164>>2],p[g+168>>2],p[g+172>>2],-1,-1,-1,2147418111);jd(g+128|0,p[g+144>>2],p[g+148>>2],p[g+152>>2],p[g+156>>2],-1,-1,-1,2147418111);k=p[g+128>>2];l=p[g+132>>2];c=p[g+136>>2];b=p[g+140>>2];break j}b=d+ -226|0;f=m>>>0>=b>>>0;b=b>>31;if((j|0)>(b|0)?1:(j|0)>=(b|0)?f:0){if((r|0)>-1){while(1){Of(g+416|0,k,l,t,u,0,0,0,-1073807360);h=HE(k,l,t,u,1073610752);f=(h|0)<0;b=f;Of(g+400|0,k,l,t,u,b?k:p[g+416>>2],b?l:p[g+420>>2],b?t:p[g+424>>2],b?u:p[g+428>>2]);j=j+ -1|0;b=m+ -1|0;if((b|0)!=-1){j=j+1|0}m=b;t=p[g+408>>2];u=p[g+412>>2];k=p[g+400>>2];l=p[g+404>>2];r=r<<1|(h|0)>-1;if((r|0)>-1){continue}break}}f=m;b=d;h=(f-b|0)+32|0;f=j-((b>>31)+(f>>>0<b>>>0)|0)|0;b=h;f=b>>>0<32?f+1|0:f;c=((f|0)<0?1:(f|0)<=0?b>>>0<c>>>0:0)?(b|0)>0?b:0:c;n:{if((c|0)>=113){$f(g+384|0,e);v=p[g+392>>2];o=p[g+396>>2];w=p[g+384>>2];x=p[g+388>>2];d=0;b=0;break n}Qh(g+352|0,Jh(1,144-c|0));$f(g+336|0,e);w=p[g+336>>2];x=p[g+340>>2];v=p[g+344>>2];o=p[g+348>>2];UD(g+368|0,p[g+352>>2],p[g+356>>2],p[g+360>>2],p[g+364>>2],w,x,v,o);C=p[g+376>>2];D=p[g+380>>2];d=p[g+372>>2];b=p[g+368>>2]}c=!(r&1)&((Wk(k,l,t,u,0,0,0,0)|0)!=0&(c|0)<32);hm(g+320|0,c+r|0);jd(g+304|0,w,x,v,o,p[g+320>>2],p[g+324>>2],p[g+328>>2],p[g+332>>2]);Of(g+272|0,p[g+304>>2],p[g+308>>2],p[g+312>>2],p[g+316>>2],b,d,C,D);jd(g+288|0,c?0:k,c?0:l,c?0:t,c?0:u,w,x,v,o);Of(g+256|0,p[g+288>>2],p[g+292>>2],p[g+296>>2],p[g+300>>2],p[g+272>>2],p[g+276>>2],p[g+280>>2],p[g+284>>2]);iv(g+240|0,p[g+256>>2],p[g+260>>2],p[g+264>>2],p[g+268>>2],b,d,C,D);e=p[g+240>>2];d=p[g+244>>2];c=p[g+248>>2];b=p[g+252>>2];if(!Wk(e,d,c,b,0,0,0,0)){p[114584]=68}TD(g+224|0,e,d,c,b,m);k=p[g+224>>2];l=p[g+228>>2];c=p[g+232>>2];b=p[g+236>>2];break j}p[114584]=68;$f(g+208|0,e);jd(g+192|0,p[g+208>>2],p[g+212>>2],p[g+216>>2],p[g+220>>2],0,0,0,65536);jd(g+176|0,p[g+192>>2],p[g+196>>2],p[g+200>>2],p[g+204>>2],0,0,0,65536);k=p[g+176>>2];l=p[g+180>>2];c=p[g+184>>2];b=p[g+188>>2];break j}Rg(b,0,0)}Qh(g+96|0,+(e|0)*0);k=p[g+96>>2];l=p[g+100>>2];c=p[g+104>>2];b=p[g+108>>2]}p[a>>2]=k;p[a+4>>2]=l;p[a+8>>2]=c;p[a+12>>2]=b;fb=g+432|0}function WAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,s=0,t=0;e=fb-80|0;fb=e;Ac(b);a:{b:{c:{d:{if(lO(b,16578)){g=qp(e- -64|0);h=qp(e+48|0);l=Hs(e+32|0);p[114610]=0;K(447,a|0,32768);d=p[114610];p[114610]=0;if((d|0)==1){break b}p[114610]=0;d=J(2,e+8|0,16587)|0;i=p[114610];p[114610]=0;e:{f:{g:{if((i|0)!=1){xb(a+1304436|0,d);pb(d);p[114610]=0;d=J(2,e+8|0,16597)|0;i=p[114610];p[114610]=0;if((i|0)==1){break c}xb(a+1304448|0,d);pb(d);p[a+1304496>>2]=2;j=a+484360|0;i=e+24|4;h:{while(1){p[114610]=0;d=J(258,b|0,8)|0;f=p[114610];p[114610]=0;i:{j:{k:{if((f|0)!=1){l:{if(!d){break l}p[114610]=0;d=J(928,b|0,e+24|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break k}if(!d){break l}d=i;d=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);p[114610]=0;N(341,e+8|0,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));d=p[114610];p[114610]=0;if((d|0)==1){break j}p[114610]=0;d=M(337,e+8|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}if(d){break i}sb(e+8|0)}if(r[a+480188>>1]){break h}d=0;break e}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}m:{n:{o:{p:{q:{r:{d=e+24|0;d=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if((d|0)<=1347175757){if((d|0)==1129140036){break r}if((d|0)==1346458708){break p}if((d|0)!=1346522948){break n}if(gd(g)>>>0>255){break n}p[114610]=0;K(604,g|0,e+8|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}break n}if((d|0)<=1396854595){if((d|0)==1347175758){break q}if(r[a+480190>>1]|(d|0)!=1396788560){break n}p[114610]=0;N(929,e+8|0,l|0,a|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}break n}if((d|0)==1396854596){break o}if((d|0)!=1397769541){break n}p[114610]=0;d=M(255,e+8|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}if(d>>>0<2){break n}p[114610]=0;d=M(484,e+8|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}s=a,t=sd(d,1,255),p[s+480196>>2]=t;break n}if(r[a+480188>>1]){break n}p[114610]=0;d=M(255,e+8|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}f=0;if(d>>>0<8){break n}while(1){p[114610]=0;k=M(387,e+8|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break m}p[114610]=0;m=M(387,e+8|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break d}d=r[a+480188>>1];if(k|m){p[114610]=0;S(432,((d<<5)+a|0)+480280|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}k=r[a+480188>>1];d=k+1|0;o[a+480188>>1]=d;o[((k<<5)+a|0)+480284>>1]=f+ -1>>>0<2?192:64}p[114610]=0;S(432,(((d&65535)<<5)+a|0)+480280|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}d=r[a+480188>>1];o[a+480188>>1]=d+1;o[((d<<5)+a|0)+480284>>1]=f+ -1>>>0<2?192:64;f=f+1|0;if((f|0)!=4){continue}break}if(c){break n}sb(e+8|0);break f}p[114610]=0;d=M(255,e+8|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}if(d>>>0<2){break n}p[114610]=0;n=M(484,e+8|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break d}break n}d=Ob(j);p[114610]=0;f=M(255,e+8|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break d}p[114610]=0;Z(584,d|0,e+8|0,f|0,255,254)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break n}break d}if(gd(h)>>>0>3998){break n}p[114610]=0;d=M(255,e+8|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}if(!d){break n}p[114610]=0;K(604,h|0,e+8|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}}sb(e+8|0);continue}break}break d}p[a+480200>>2]=256;p[a+480204>>2]=125e4;p[a+480260>>2]=452;p[a+480264>>2]=3424;p[a+480228>>2]=48;p[a+480232>>2]=48;b=Ob(j);p[114610]=0;K(930,b|0,n&65535);b=p[114610];p[114610]=0;if((b|0)==1){break b}s:{if(!(c&1)){break s}d=0;b=gd(g);p[114610]=0;K(401,a+484344|0,b&65535);b=p[114610];p[114610]=0;if((b|0)==1){break b}if(!gd(g)){break s}b=0;while(1){d=jc(g,d);p[114610]=0;N(931,d|0,b&65535,a|0);d=p[114610];p[114610]=0;if((d|0)==1){break g}b=b+1|0;d=b&65535;if(gd(g)>>>0>d>>>0){continue}break}}d=1;if(r[a+480190>>1]<2){break e}i=c&2;f=1;b=0;t:{while(1){if(!i|b>>>0>=gd(h)>>>0){break f}u:{c=(v(f,104)+a|0)+484380|0;if(p[c>>2]){d=jc(h,b);p[114610]=0;d=M(255,d|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break u}vc(c,d);Wd(e+8|0,l,f+ -1|0);d=Tc(e+24|0,8,1,1,tb(e+8|0)?10:0);j=jc(h,b);p[114610]=0;P(400,d|0,c|0,j|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break t}b=b+1|0}d=1;f=f+1|0;if(f>>>0<r[a+480190>>1]){continue}break e}break}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}d=1}ce(l);$c(h);$c(g)}fb=e+80|0;return d|0}a=I()|0;H()|0;sb(e+8|0);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0}ce(l);$c(h);$c(g);L(a|0);E()}function tLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,r=0,s=0,t=0;e=fb-3040|0;fb=e;Ac(b);h=e+1080|0;f=qLa(b,h);if(!f){kS(h)}a:{if(!f){break a}if(!oS(e+1080|0)){break a}if(!c){d=1;break a}if(!Hb(b,dd(1024,0))){break a}nS(b,e+560|0);nS(b,e+48|0);while(1){h=g<<2;f=h+(e+560|0)|0;if((q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24))>>>0>16777215){break a}h=h+(e+48|0)|0;if((q[h|0]|q[h+1|0]<<8|(q[h+2|0]<<16|q[h+3|0]<<24))>>>0<3|(q[h|0]|q[h+1|0]<<8|(q[h+2|0]<<16|q[h+3|0]<<24))>>>0>4096){break a}if(!mS(b,((q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24))+(q[h|0]|q[h+1|0]<<8|(q[h+2|0]<<16|q[h+3|0]<<24))|0)+2978|0)){break a}g=g+1|0;if((g|0)!=128){continue}break}xd(a,2);ei(a);d=Mb(e+16|0,12301);xb(a+1304436|0,d);pb(d);d=Mb(e+16|0,12306);xb(a+1304448|0,d);pb(d);d=Mb(e+16|0,12310);xb(a+1304460|0,d);pb(d);p[a+1304496>>2]=4;d=q[e+1080|0];p[a+480204>>2]=143e4;p[a+480196>>2]=d;i=a+484360|0;Pe(Ob(i),q[e+1081|0]);p[a+480188>>2]=4194317;Eb(a+1074308|0,95,1);d=0;while(1){o[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){g=d+1|0;h=v(g,104)+a|0;f=h+484380|0;vd(f,2);yi(e+32|0,1,(v(d,13)+e|0)+1082|0);zc(e+16|0,e+32|0);p[114610]=0;J(369,((g<<5)+a|0)+946300|0,e+16|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break e}pb(e+16|0);m=f;d=(e+1080|0)+(d<<4)|0;f=d+422|0;p[m>>2]=q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24);if((q[d+430|0]|q[d+431|0]<<8|(q[d+432|0]<<16|q[d+433|0]<<24))>>>0<=(q[d+422|0]|q[d+423|0]<<8|(q[d+424|0]<<16|q[d+425|0]<<24))>>>0){p[h+484384>>2]=q[d+426|0]|q[d+427|0]<<8|(q[d+428|0]<<16|q[d+429|0]<<24);d=q[d+430|0]|q[d+431|0]<<8|(q[d+432|0]<<16|q[d+433|0]<<24);o[h+484414>>1]=2;p[h+484388>>2]=d}p[h+484404>>2]=8287;d=g;if((d|0)!=32){continue}break}g=0;while(1){d=g+33|0;h=(v(d,104)+a|0)+484380|0;vd(h,2);yi(e+32|0,1,(v(g,13)+e|0)+2010|0);zc(e+16|0,e+32|0);p[114610]=0;J(369,((d<<5)+a|0)+946300|0,e+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break d}pb(e+16|0);p[e+24>>2]=0;p[e+16>>2]=0;p[e+20>>2]=0;d=(e+1080|0)+v(g,11)|0;f=q[d+1347|0];s=Yb(e+16|0,0),t=f,n[s|0]=t;f=q[d+1352|0];s=Yb(e+16|0,1),t=f,n[s|0]=t;f=q[d+1348|0];s=Yb(e+16|0,2),t=f,n[s|0]=t;f=q[d+1353|0];s=Yb(e+16|0,3),t=f,n[s|0]=t;f=q[d+1349|0];s=Yb(e+16|0,4),t=f,n[s|0]=t;f=q[d+1354|0];s=Yb(e+16|0,5),t=f,n[s|0]=t;f=q[d+1350|0];s=Yb(e+16|0,6),t=f,n[s|0]=t;f=q[d+1355|0];s=Yb(e+16|0,7),t=f,n[s|0]=t;f=q[d+1351|0];s=Yb(e+16|0,8),t=f,n[s|0]=t;f=q[d+1356|0];s=Yb(e+16|0,9),t=f,n[s|0]=t;d=q[d+1346|0];s=Yb(e+16|0,10),t=d,n[s|0]=t;p[e+8>>2]=p[e+24>>2];d=p[e+20>>2];p[e>>2]=p[e+16>>2];p[e+4>>2]=d;Xo(h,1,e);g=g+1|0;if((g|0)!=32){continue}break}Et(Ob(i),e+2778|0,256,255,65535);k=a+484344|0;Pf(k,128);m=c&1;h=0;f:{while(1){g=h<<2;d=g+(e+560|0)|0;Jc(b,(q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24))+2978|0);d=g+(e+48|0)|0;ld(e+16|0,b,q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24));g:{if(!m){break g}p[114610]=0;d=P(402,k|0,h&65535,64)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!d){break g}d=0;f=Rb(k,h);while(1){p[114610]=0;g=J(258,e+16|0,1)|0;i=p[114610];p[114610]=0;h:{i:{if((i|0)!=1){if(!g){break g}p[114610]=0;g=M(387,e+16|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break c}if(g>>>0>12){break i}p[114610]=0;i=P(471,f|0,d|0,g|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break c}p[114610]=0;K(472,e+32|0,e+16|0);j=p[114610];p[114610]=0;if((j|0)==1){break c}j=Zc(e+32|0);l=e+32|0;r=q[l|0];g=g>>>0>3;n[i|0]=((r&15)+(g?13:37)|0)+v(r>>>4&7,12);n[i+1|0]=((q[j|0]>>>4|0)+(g?33:1)|0)+(q[l|0]>>>3&16);lS(i,q[j|0],g);break h}break c}i=g+ -32|0;if((i&255)>>>0<=12){p[114610]=0;i=P(471,f|0,d|0,i&65535)|0;j=p[114610];p[114610]=0;if((j|0)==1){break c}p[114610]=0;j=M(387,e+16|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break c}lS(i,j,g>>>0>35);break h}if((g|0)!=64){if((g|0)!=96){break f}if(!d){break g}p[114610]=0;d=P(471,f|0,d+ -1|0,0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}n[d+3|0]=14;break g}p[114610]=0;g=M(387,e+16|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break c}d=d+g|0}if(d>>>0<64){continue}break}}sb(e+16|0);h=h+1|0;if((h|0)!=128){continue}break}d=1;if(!(c&2)){break a}g=1;while(1){fg(Tc(e+16|0,8,1,0,1),(v(g,104)+a|0)+484380|0,b);g=g+1|0;if((g|0)!=33){continue}break}break a}sb(e+16|0);d=0;break a}d=I()|0;H()|0;pb(e+16|0);break b}d=I()|0;H()|0;pb(e+16|0);break b}d=I()|0;H()|0;sb(e+16|0)}L(d|0);E()}fb=e+3040|0;return d|0}function EG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-416|0;fb=e;n[e+415|0]=c;a:{if(Yi(b)){break a}f=q[Mj(b)|0];c=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}c=0}d=c;Xj(e+160|0,b,p[b+4>>2]+ -1|0);c=p[e+164>>2];p[b>>2]=p[e+160>>2];p[b+4>>2]=c}ud(e+160|0);c=p[e+160>>2];ud(e+376|0);g=Lj(c,p[e+380>>2],b);ud(e+160|0);c=p[b>>2];f=p[b+4>>2];c:{d:{e:{f:{if((g|0)==p[e+164>>2]){p[e+400>>2]=c;p[e+404>>2]=f;a=ic(e+392|0,38139);c=p[e+404>>2];p[e+8>>2]=p[e+400>>2];p[e+12>>2]=c;c=p[a+4>>2];p[e>>2]=p[a>>2];p[e+4>>2]=c;if(xc(e+8|0,e)){a=W(8)|0;p[114610]=0;K(2141,e+376|0,e+415|0);b=p[114610];p[114610]=0;g:{h:{i:{if((b|0)!=1){p[114610]=0;N(2119,e+160|0,39211,e+376|0);b=p[114610];p[114610]=0;if((b|0)==1){break i}dc(a,e+160|0);d=0;p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break e}b=I()|0;H()|0;pb(e+160|0);break h}b=I()|0;H()|0;break g}d=1;b=I()|0;H()|0}pb(e+376|0);if(!d){break f}}X(a|0);break f}if(!d){break c}a=W(8)|0;p[114610]=0;d=J(2142,e+344|0,b|0)|0;b=p[114610];p[114610]=0;c=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){p[114610]=0;N(2119,e+360|0,39090,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break r}p[114610]=0;N(2137,e+376|0,e+360|0,39226);b=p[114610];p[114610]=0;if((b|0)==1){break q}p[114610]=0;K(2141,e+328|0,e+415|0);b=p[114610];p[114610]=0;if((b|0)==1){break p}p[114610]=0;N(138,e+160|0,e+376|0,e+328|0);b=p[114610];p[114610]=0;if((b|0)==1){break o}dc(a,e+160|0);p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break e}b=I()|0;H()|0;pb(e+160|0);c=0;break n}b=I()|0;H()|0;break j}b=I()|0;H()|0;break k}b=I()|0;H()|0;break l}b=I()|0;H()|0;break m}b=I()|0;H()|0}pb(e+328|0)}pb(e+376|0)}pb(e+360|0)}pb(d)}if(!c){break f}X(a|0);break f}p[e+320>>2]=c;p[e+324>>2]=f;c=ic(e+312|0,38139);d=p[e+324>>2];p[e+152>>2]=p[e+320>>2];p[e+156>>2]=d;d=p[c+4>>2];p[e+144>>2]=p[c>>2];p[e+148>>2]=d;if(!xc(e+152|0,e+144|0)){break d}a=W(8)|0;p[114610]=0;K(2141,e+376|0,e+415|0);b=p[114610];p[114610]=0;s:{t:{u:{if((b|0)!=1){p[114610]=0;N(2119,e+160|0,39211,e+376|0);b=p[114610];p[114610]=0;if((b|0)==1){break u}dc(a,e+160|0);d=0;p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break e}b=I()|0;H()|0;pb(e+160|0);break t}b=I()|0;H()|0;break s}d=1;b=I()|0;H()|0}pb(e+376|0);if(!d){break f}}X(a|0)}L(b|0)}E()}c=p[b+4>>2];p[e+304>>2]=p[b>>2];p[e+308>>2]=c;c=ic(e+296|0,38828);d=p[e+308>>2];p[e+136>>2]=p[e+304>>2];p[e+140>>2]=d;d=p[c+4>>2];p[e+128>>2]=p[c>>2];p[e+132>>2]=d;v:{if(!xc(e+136|0,e+128|0)){c=p[b+4>>2];p[e+288>>2]=p[b>>2];p[e+292>>2]=c;c=ic(e+280|0,39125);d=p[e+292>>2];p[e+120>>2]=p[e+288>>2];p[e+124>>2]=d;d=p[c+4>>2];p[e+112>>2]=p[c>>2];p[e+116>>2]=d;if(!xc(e+120|0,e+112|0)){break v}}n[a+60|0]=q[e+415|0];break c}c=p[b+4>>2];p[e+272>>2]=p[b>>2];p[e+276>>2]=c;c=ic(e+264|0,38846);d=p[e+276>>2];p[e+104>>2]=p[e+272>>2];p[e+108>>2]=d;d=p[c+4>>2];p[e+96>>2]=p[c>>2];p[e+100>>2]=d;w:{if(!xc(e+104|0,e+96|0)){c=p[b+4>>2];p[e+256>>2]=p[b>>2];p[e+260>>2]=c;c=ic(e+248|0,39143);d=p[e+260>>2];p[e+88>>2]=p[e+256>>2];p[e+92>>2]=d;d=p[c+4>>2];p[e+80>>2]=p[c>>2];p[e+84>>2]=d;if(!xc(e+88|0,e+80|0)){break w}}n[a+61|0]=q[e+415|0];break c}c=p[b+4>>2];p[e+240>>2]=p[b>>2];p[e+244>>2]=c;c=ic(e+232|0,38865);d=p[e+244>>2];p[e+72>>2]=p[e+240>>2];p[e+76>>2]=d;d=p[c+4>>2];p[e+64>>2]=p[c>>2];p[e+68>>2]=d;if(xc(e+72|0,e- -64|0)){n[a+62|0]=q[e+415|0];break c}c=p[b+4>>2];p[e+224>>2]=p[b>>2];p[e+228>>2]=c;c=ic(e+216|0,38883);d=p[e+228>>2];p[e+56>>2]=p[e+224>>2];p[e+60>>2]=d;d=p[c+4>>2];p[e+48>>2]=p[c>>2];p[e+52>>2]=d;if(xc(e+56|0,e+48|0)){n[a+63|0]=q[e+415|0];break c}c=p[b+4>>2];p[e+208>>2]=p[b>>2];p[e+212>>2]=c;c=ic(e+200|0,38907);d=p[e+212>>2];p[e+40>>2]=p[e+208>>2];p[e+44>>2]=d;d=p[c+4>>2];p[e+32>>2]=p[c>>2];p[e+36>>2]=d;if(xc(e+40|0,e+32|0)){n[a+64|0]=q[e+415|0];break c}c=p[b+4>>2];p[e+192>>2]=p[b>>2];p[e+196>>2]=c;b=ic(e+184|0,38981);c=p[e+196>>2];p[e+24>>2]=p[e+192>>2];p[e+28>>2]=c;c=p[b+4>>2];p[e+16>>2]=p[b>>2];p[e+20>>2]=c;if(!xc(e+24|0,e+16|0)){break c}c=a+24|0;b=p[c>>2];d=b+24664|0;f=p[d+4>>2];p[e+176>>2]=p[d>>2];p[e+180>>2]=f;d=b+24656|0;f=p[d+4>>2];p[e+168>>2]=p[d>>2];p[e+172>>2]=f;d=p[b+24652>>2];p[e+160>>2]=p[b+24648>>2];p[e+164>>2]=d;b=e;if(q[e+415|0]){a=hG(p[a+56>>2])}else{a=0}p[b+180>>2]=a;if(!lw(e+160|0,p[c>>2]+24648|0)){break c}gx(p[c>>2],e+160|0)}fb=e+416|0}function uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-48|0;fb=d;e=Mb(d+32|0,38630);f=hf(c,e);pb(e);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){Vi(a,0,p[b+24>>2]+1304448|0);break k}e=Mb(d+32|0,38635);f=hf(c,e);pb(e);if(f){Vi(a,0,p[b+24>>2]+1304436|0);break k}e=Mb(d+32|0,38645);f=hf(c,e);pb(e);if(f){Vi(a,0,p[b+24>>2]+1304484|0);break k}e=Mb(d+32|0,38658);f=hf(c,e);pb(e);if(f){Vi(a,0,p[b+24>>2]+1304472|0);break k}e=Mb(d+32|0,38676);f=hf(c,e);pb(e);if(f){Sma(d+32|0,p[p[b+24>>2]+480184>>2]);p[114610]=0;N(9,a|0,0,d+32|0);a=p[114610];p[114610]=0;if((a|0)==1){break j}pb(d+32|0);break k}e=Mb(d+32|0,38686);f=hf(c,e);pb(e);if(f){Rma(d+32|0,p[p[b+24>>2]+480184>>2]);p[114610]=0;N(9,a|0,0,d+32|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(d+32|0);break k}c=I()|0;H()|0;pb(d+32|0);break a}e=Mb(d+32|0,38701);f=hf(c,e);pb(e);if(f){Vi(a,0,p[b+24>>2]+1304460|0);break k}e=Mb(d+32|0,38709);f=hf(c,e);pb(e);if(f){Vi(a,0,p[b+24>>2]+1304412|0);break k}e=Mb(d+32|0,38716);f=hf(c,e);pb(e);if(f){Uf(d+32|0,p[b+24>>2]+1304400|0);p[114610]=0;N(2185,a|0,b|0,d+32|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(d+32|0);break k}c=I()|0;H()|0;pb(d+32|0);break a}e=Mb(d+32|0,38722);f=hf(c,e);pb(e);if(f){l:{b=b+24|0;if(!cd(cw(p[b>>2]))){if(p[oG(cw(p[b>>2]))+12>>2]){break l}}Lb(a);break k}Woa(d+32|0,oG(cw(p[b>>2])));p[114610]=0;N(9,a|0,0,d+32|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(d+32|0);break k}c=I()|0;H()|0;pb(d+32|0);break a}e=Mb(d+32|0,38727);f=hf(c,e);pb(e);if(f){c=b+24|0;OM(d+32|0,p[c>>2]+1304424|0);m:{n:{o:{if(!Pc(d+32|0)){break o}c=p[c>>2];p[114610]=0;c=M(2186,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break m}p:{switch(c|0){case 0:p[114610]=0;K(2187,d+16|0,b|0);c=p[114610];p[114610]=0;if((c|0)!=1){xb(d+32|0,d+16|0);pb(d+16|0);break o}c=I()|0;H()|0;break b;case 1:p[114610]=0;K(2188,d+16|0,b|0);c=p[114610];p[114610]=0;if((c|0)!=1){xb(d+32|0,d+16|0);pb(d+16|0);break o}c=I()|0;H()|0;break b;case 2:if(Pc(d+32|0)){p[114610]=0;K(2187,d+16|0,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}xb(d+32|0,d+16|0);pb(d+16|0)}if(!Pc(d+32|0)){break o}p[114610]=0;K(2188,d+16|0,b|0);c=p[114610];p[114610]=0;if((c|0)!=1){xb(d+32|0,d+16|0);pb(d+16|0);break o}c=I()|0;H()|0;break b;case 3:if(Pc(d+32|0)){p[114610]=0;K(2188,d+16|0,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break h}xb(d+32|0,d+16|0);pb(d+16|0)}if(!Pc(d+32|0)){break o}p[114610]=0;K(2187,d+16|0,b|0);c=p[114610];p[114610]=0;if((c|0)!=1){xb(d+32|0,d+16|0);pb(d+16|0);break o}c=I()|0;H()|0;break b;case 4:p[114610]=0;K(2187,d+16|0,b|0);c=p[114610];p[114610]=0;q:{r:{if((c|0)!=1){p[114610]=0;K(2188,d|0,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break q}if(Pc(d+16|0)){break r}p[114610]=0;J(1251,d+32|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break r}break d}c=I()|0;H()|0;break b}if(!Pc(d)){p[114610]=0;J(1251,d+32|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break d}}pb(d);pb(d+16|0);break o}c=I()|0;H()|0;break c;case 5:break p;default:break o}}p[114610]=0;K(2187,d+16|0,b|0);c=p[114610];p[114610]=0;s:{if((c|0)!=1){p[114610]=0;K(2188,d|0,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break n}if(Pc(d)){break s}p[114610]=0;J(1251,d+32|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break s}break f}c=I()|0;H()|0;break b}if(!Pc(d+16|0)){p[114610]=0;J(1251,d+32|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break f}}pb(d);pb(d+16|0)}p[114610]=0;N(2185,a|0,b|0,d+32|0);a=p[114610];p[114610]=0;if((a|0)==1){break m}pb(d+32|0);break k}c=I()|0;H()|0;break e}c=I()|0;H()|0;break b}e=Mb(d+32|0,38735);f=hf(c,e);pb(e);if(f){OM(d+32|0,p[b+24>>2]+1304424|0);p[114610]=0;N(2185,a|0,b|0,d+32|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(d+32|0);break k}c=I()|0;H()|0;pb(d+32|0);break a}e=c;c=Mb(d+32|0,38747);e=hf(e,c);pb(c);if(e){a=Lb(a);b=b+68|0;g=d,h=Ub(b),p[g+32>>2]=h;g=d,h=Vb(b),p[g+16>>2]=h;if(!Ab(d+32|0,d+16|0)){break k}c=1;while(1){b=p[d+32>>2];if(!(c&1)){p[114610]=0;J(1995,a|0,38756)|0;c=p[114610];p[114610]=0;if((c|0)==1){break g}}p[114610]=0;J(1251,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}kn(d+32|0);c=0;if(Ab(d+32|0,d+16|0)){continue}break}break k}Mb(a,38139)}fb=d+48|0;return}c=I()|0;H()|0;pb(d+32|0);break a}c=I()|0;H()|0;break b}c=I()|0;H()|0;break b}c=I()|0;H()|0;pb(a);break a}c=I()|0;H()|0;pb(d)}pb(d+16|0);break b}c=I()|0;H()|0;pb(d)}pb(d+16|0)}pb(d+32|0)}L(c|0);E()}function kJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0;d=fb-336|0;fb=d;Ac(b);a:{if(!gt(b,d+320|0)){break a}if(!lR(d+320|0)){break a}if(p[d+320>>2]==1179472708){Sb(b,4)}if(!bf(b,d+312|0)|p[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}i=d+312|4;g=i;xS(b,d+120|0,q[g|0]|q[g+1|0]<<8|(q[g+2|0]<<16|q[g+3|0]<<24));if((q[d+156|0]|q[d+157|0]<<8)>>>0>128|(q[d+162|0]|q[d+163|0]<<8)>>>0>16|((q[d+160|0]|q[d+161|0]<<8)>>>0>256|(q[d+154|0]|q[d+155|0]<<8)>>>0>128)){break a}xd(a,8192);e=Mb(d+40|0,12774);xb(a+1304436|0,e);pb(e);e=Mb(d+40|0,12786);xb(a+1304448|0,e);pb(e);p[a+1304496>>2]=4;ft(d+104|0,2,d+120|0);zc(d+40|0,d+104|0);xb(a+1304400|0,d+40|0);pb(d+40|0);o[d+40>>1]=q[d+162|0]|q[d+163|0]<<8;o[d+104>>1]=1;u=a,w=r[Bi(d+40|0,d+104|0)>>1],o[u+480188>>1]=w;p[a+480196>>2]=q[d+166|0];p[a+480204>>2]=v(q[d+167|0],1e4);n[d+40|0]=q[d+164|0];n[d+104|0]=64;e=q[hc(d+40|0,d+104|0)|0];p[a+480200>>2]=e<<2;if(!e){p[a+480200>>2]=256}e=a;b:{if(q[d+165|0]==128){p[d+40>>2]=256/r[a+480188>>1];p[d+104>>2]=128;g=p[Cb(d+40|0,d+104|0)>>2];break b}g=q[d+165|0]&127}p[e+480228>>2]=g;e=0;while(1){g=(e<<5)+a|0;Fg(g+480280|0);f=d+e|0;if(q[f+168|0]<=128){o[g+480284>>1]=q[f+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}e=a+484360|0;qn(Ob(e),d+184|0,q[d+156|0]|q[d+157|0]<<8,255,254);if((q[d+154|0]|q[d+155|0]<<8)>>>0<(q[d+156|0]|q[d+157|0]<<8)>>>0){Pe(Ob(e),q[d+154|0]|q[d+155|0]<<8)}e=1;if(!bf(b,d+312|0)){break a}m=c&2;j=a+484344|0;s=c&1;t=d+76|0;while(1){c=i;ld(d+104|0,b,q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24));c:{d:{e:{if(!(!s|p[d+312>>2]!=1414807888)){p[114610]=0;l=k&65535;c=P(402,j|0,l|0,64)|0;e=p[114610];p[114610]=0;if((e|0)==1){break e}if(!c){break c}p[114610]=0;J(338,d+104|0,2)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}ch(d+40|0);g=0;f:{while(1){p[114610]=0;c=J(258,d+104|0,1)|0;e=p[114610];p[114610]=0;g:{h:{if((e|0)!=1){if(c^1|g>>>0>63){break f}p[114610]=0;e=M(387,d+104|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break h}if(e){break g}g=g+1|0;continue}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}c=d+40|0;i:{j:{k:{f=e&15;l:{if(r[a+480188>>1]>f>>>0){c=Rb(j,l);p[114610]=0;c=P(471,c|0,g|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break l}}m:{if(!(e&128)){break m}p[114610]=0;f=M(387,d+104|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break k}if(!f){break m}n[c|0]=f>>>0<109?f+12|0:f}if(!(e&64)){break i}p[114610]=0;f=M(387,d+104|0)|0;h=p[114610];p[114610]=0;if((h|0)!=1){break j}}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}n[c+1|0]=f}n:{o:{p:{q:{r:{s:{t:{u:{if(e&32){n[c+2|0]=1;p[114610]=0;f=M(387,d+104|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break u}p[114610]=0;n[d+24|0]=f;n[d+8|0]=64;f=J(391,d+24|0,d+8|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break t}n[c+4|0]=q[f|0]}if(!(e&16)){continue}p[114610]=0;K(472,d+24|0,d+104|0);e=p[114610];p[114610]=0;if((e|0)==1){break s}h=Zc(d+24|0);f=d+24|0;e=q[f|0];switch(e+ -17|0){case 2:break q;case 0:case 1:break r;default:break p}}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}e=e&15;break o}n[f|0]=33;n[h|0]=145;e=q[f|0];break n}if(e>>>0<17){break n}e=(e&240)==32?9:-1}n[f|0]=e}n[c+3|0]=e;n[c+5|0]=q[h|0];p[114610]=0;S(577,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}b=I()|0;H()|0;break d}k=k+1|0;break c}if(p[d+312>>2]!=1414745673|r[a+480190>>1]>3998){break c}c=r[a+480190>>1]+1|0;o[a+480190>>1]=c;p[114610]=0;J(578,d+104|0,d+40|0)|0;e=p[114610];p[114610]=0;v:{w:{x:{if((e|0)==1){break x}p[114610]=0;c=(v(c&65535,104)+a|0)+484380|0;K(579,d+40|0,c|0);e=p[114610];p[114610]=0;if((e|0)==1){break x}p[114610]=0;N(580,d+8|0,2,t|0);e=p[114610];p[114610]=0;if((e|0)==1){break w}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break w}e=r[a+480190>>1];p[114610]=0;J(369,((e<<5)+a|0)+946300|0,d+24|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break v}pb(d+24|0);if(!m){break c}p[114610]=0;K(581,d+24|0,d+40|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;P(400,d+24|0,c|0,d+104|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break c}}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;pb(d+24|0);break d}b=I()|0;H()|0}sb(d+104|0);L(b|0);E()}sb(d+104|0);e=1;if(bf(b,d+312|0)){continue}break}}fb=d+336|0;return e|0}function UE(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,w=0,y=0,z=0,A=0,C=0,D=0;h=fb-560|0;fb=h;g=c;c=(c+ -3|0)/24|0;t=(c|0)>0?c:0;l=g+v(t,-24)|0;n=p[(e<<2)+52208>>2];j=d+ -1|0;if((n+j|0)>=0){g=d+n|0;c=t-j|0;while(1){u[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+p[(c<<2)+52224>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}q=l+ -24|0;g=0;i=(n|0)>0?n:0;m=(d|0)<1;while(1){a:{if(m){f=0;break a}k=g+j|0;c=0;f=0;while(1){f=f+u[(c<<3)+a>>3]*u[(h+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}u[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}C=47-l|0;w=48-l|0;D=l+ -25|0;g=n;b:{while(1){f=u[(g<<3)+h>>3];c=0;i=g;k=(g|0)<1;if(!k){while(1){m=(h+480|0)+(c<<2)|0;o=f;f=f*5.960464477539063e-8;c:{if(x(f)<2147483648){j=~~f;break c}j=-2147483648}f=+(j|0);o=o+f*-16777216;d:{if(x(o)<2147483648){j=~~o;break d}j=-2147483648}p[m>>2]=j;i=i+ -1|0;f=u[(i<<3)+h>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Jh(f,q);f=f+B(f*.125)*-8;e:{if(x(f)<2147483648){m=~~f;break e}m=-2147483648}f=f- +(m|0);f:{g:{h:{y=(q|0)<1;i:{if(!y){i=(g<<2)+h|0;j=p[i+476>>2];c=j>>w;s=i;i=j-(c<<w)|0;p[s+476>>2]=i;m=c+m|0;j=i>>C;break i}if(q){break h}j=p[((g<<2)+h|0)+476>>2]>>23}if((j|0)<1){break f}break g}j=2;if(!(f>=.5^1)){break g}j=0;break f}c=0;i=0;if(!k){while(1){s=(h+480|0)+(c<<2)|0;z=p[s>>2];k=16777215;j:{k:{if(i){break k}k=16777216;if(z){break k}i=0;break j}p[s>>2]=k-z;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(y){break l}m:{switch(D|0){case 0:c=(g<<2)+h|0;p[c+476>>2]=p[c+476>>2]&8388607;break l;case 1:break m;default:break l}}c=(g<<2)+h|0;p[c+476>>2]=p[c+476>>2]&4194303}m=m+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!i){break f}f=f-Jh(1,q)}if(f==0){i=0;n:{c=g;if((c|0)<=(n|0)){break n}while(1){c=c+ -1|0;i=p[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(n|0)){continue}break}if(!i){break n}l=q;while(1){l=l+ -24|0;g=g+ -1|0;if(!p[(h+480|0)+(g<<2)>>2]){continue}break}break b}c=1;while(1){i=c;c=c+1|0;if(!p[(h+480|0)+(n-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;u[(h+320|0)+(j<<3)>>3]=p[(t+g<<2)+52224>>2];c=0;f=0;if((d|0)>=1){while(1){f=f+u[(c<<3)+a>>3]*u[(h+320|0)+(j-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}u[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}break}f=Jh(f,0-q|0);o:{if(!(f>=16777216^1)){d=(h+480|0)+(g<<2)|0;o=f;f=f*5.960464477539063e-8;p:{if(x(f)<2147483648){c=~~f;break p}c=-2147483648}f=o+ +(c|0)*-16777216;q:{if(x(f)<2147483648){a=~~f;break q}a=-2147483648}p[d>>2]=a;g=g+1|0;break o}if(x(f)<2147483648){c=~~f}else{c=-2147483648}l=q}p[(h+480|0)+(g<<2)>>2]=c}f=Jh(1,l);r:{if((g|0)<=-1){break r}c=g;while(1){u[(c<<3)+h>>3]=f*+p[(h+480|0)+(c<<2)>>2];f=f*5.960464477539063e-8;a=(c|0)>0;c=c+ -1|0;if(a){continue}break}k=0;if((g|0)<0){break r}a=(n|0)>0?n:0;i=g;while(1){d=a>>>0<k>>>0?a:k;l=g-i|0;c=0;f=0;while(1){f=f+u[(c<<3)+54992>>3]*u[(c+i<<3)+h>>3];q=(c|0)!=(d|0);c=c+1|0;if(q){continue}break}u[(h+160|0)+(l<<3)>>3]=f;i=i+ -1|0;c=(g|0)!=(k|0);k=k+1|0;if(c){continue}break}}s:{t:{u:{switch(e|0){case 3:v:{if((g|0)<1){break v}f=u[(h+160|0)+(g<<3)>>3];c=g;while(1){o=f;a=c+ -1|0;d=(h+160|0)+(a<<3)|0;A=u[d>>3];f=A+f;u[(h+160|0)+(c<<3)>>3]=o+(A-f);u[d>>3]=f;d=(c|0)>1;c=a;if(d){continue}break}if((g|0)<2){break v}f=u[(h+160|0)+(g<<3)>>3];c=g;while(1){o=f;a=c+ -1|0;d=(h+160|0)+(a<<3)|0;r=u[d>>3];f=r+f;u[(h+160|0)+(c<<3)>>3]=o+(r-f);u[d>>3]=f;d=(c|0)>2;c=a;if(d){continue}break}r=0;if((g|0)<=1){break v}while(1){r=r+u[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g+ -1|0;if(a){continue}break}}if(j){break t}a=p[h+164>>2];p[b>>2]=p[h+160>>2];p[b+4>>2]=a;a=p[h+172>>2];c=p[h+168>>2];u[b+16>>3]=r;p[b+8>>2]=c;p[b+12>>2]=a;break s;case 0:f=0;if((g|0)>=0){while(1){f=f+u[(h+160|0)+(g<<3)>>3];a=(g|0)>0;g=g+ -1|0;if(a){continue}break}}u[b>>3]=j?-f:f;break s;case 1:case 2:break u;default:break s}}f=0;if((g|0)>=0){c=g;while(1){f=f+u[(h+160|0)+(c<<3)>>3];a=(c|0)>0;c=c+ -1|0;if(a){continue}break}}u[b>>3]=j?-f:f;f=u[h+160>>3]-f;c=1;if((g|0)>=1){while(1){f=f+u[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}u[b+8>>3]=j?-f:f;break s}u[b>>3]=-u[h+160>>3];f=u[h+168>>3];u[b+16>>3]=-r;u[b+8>>3]=-f}fb=h+560|0;return m&7}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-144|0;fb=e;d=-1;a:{b:{c:{if(!wt(p[p[b>>2]+ -12>>2]+b|0)){b=Pk(e+40|0,b);p[114610]=0;d=J(686,e+24|0,32348)|0;f=p[114610];p[114610]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((f|0)!=1){p[114610]=0;p[e+16>>2]=83886084;p[e+20>>2]=0;N(687,b|0,d|0,e+16|0);f=p[114610];p[114610]=0;if((f|0)==1){break F}yb(d);p[114610]=0;n[e+15|0]=0;d=J(686,e+24|0,32358)|0;f=p[114610];p[114610]=0;if((f|0)==1){break E}p[114610]=0;P(688,b|0,e+15|0,d|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break D}yb(d);p[114610]=0;f=q[e+15|0];d=J(686,e+24|0,32363)|0;g=p[114610];p[114610]=0;if((g|0)==1){break C}p[114610]=0;f=f?0:c;Q(1605,b|0,a+40|0,d|0,f|0);c=p[114610];p[114610]=0;if((c|0)==1){break B}yb(d);p[114610]=0;o[e+12>>1]=65535;c=J(686,e+24|0,32365)|0;d=p[114610];p[114610]=0;if((d|0)==1){break A}p[114610]=0;P(1184,b|0,e+12|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break z}yb(c);p[114610]=0;o[e+10>>1]=0;c=J(686,e+24|0,32367)|0;d=p[114610];p[114610]=0;if((d|0)==1){break y}p[114610]=0;P(1184,b|0,e+10|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break x}yb(c);o[a>>1]=r[e+10>>1];p[114610]=0;c=J(686,e+24|0,32369)|0;d=p[114610];p[114610]=0;if((d|0)==1){break w}p[114610]=0;Q(1606,b|0,a+52|0,c|0,f|0);d=p[114610];p[114610]=0;if((d|0)==1){break v}yb(c);p[114610]=0;c=J(686,e+24|0,32371)|0;d=p[114610];p[114610]=0;if((d|0)==1){break u}p[114610]=0;P(1571,b|0,a+36|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break t}yb(c);p[114610]=0;c=J(686,e+24|0,32373)|0;d=p[114610];p[114610]=0;if((d|0)==1){break s}p[114610]=0;f=a+4|0;U(1607,b|0,f|0,c|0,1608)|0;d=p[114610];p[114610]=0;if((d|0)==1){break r}yb(c);p[114610]=0;c=J(686,e+24|0,32378)|0;d=p[114610];p[114610]=0;if((d|0)==1){break q}p[114610]=0;g=a+28|0;P(1609,b|0,g|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break p}yb(c);p[114610]=0;c=J(686,e+24|0,32383)|0;d=p[114610];p[114610]=0;if((d|0)==1){break o}p[114610]=0;P(1609,b|0,a+30|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break n}yb(c);p[114610]=0;c=J(686,e+24|0,32388)|0;d=p[114610];p[114610]=0;if((d|0)==1){break m}p[114610]=0;P(1610,b|0,a+32|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break l}yb(c);p[114610]=0;o[e+8>>1]=0;c=J(686,e+24|0,32393)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}p[114610]=0;P(1184,b|0,e+8|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break k}yb(c);d=-1;if(p[b>>2]&1073741824|(r[g>>1]+300&65535)>>>0>=601){break d}c=r[a>>1];if(c>>>0>3|(c|0)==2|o[a+30>>1]<0){break d}c=p[a+36>>2];p[114610]=0;c=M(864,c|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break j}p[114610]=0;p[e+24>>2]=c;p[e+16>>2]=0;c=P(1241,e+24|0,e+16|0,32344)|0;h=p[114610];p[114610]=0;if((h|0)==1){break i}p[a+36>>2]=p[c>>2];if(Bb(f)>>>0>32767){break d}switch(r[a>>1]+ -1|0){case 0:break g;case 2:break h;default:break f}}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(d);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(d);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(d);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(c);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(c);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(c);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(c);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(c);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(c);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(c);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(c);break a}a=I()|0;H()|0;yb(c);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}if(o[e+8>>1]<1){break d}o[e+6>>1]=r[a+30>>1];t[e+24>>2]=t[a+32>>2];c=r[a+28>>1];p[114610]=0;o[e+16>>1]=c;o[e+18>>1]=(c+r[e+8>>1]|0)+ -1;a=U(1611,a|0,e+6|0,e+24|0,e+16|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){if(a){break e}break d}a=I()|0;H()|0;break a}if(o[e+8>>1]<1){break d}t[e+24>>2]=t[a+32>>2];c=r[a+28>>1];p[114610]=0;o[e+16>>1]=c;o[e+18>>1]=(c+r[e+8>>1]|0)+ -1;a=Z(1612,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){if(a){break e}break d}a=I()|0;H()|0;break a}p[114610]=0;S(1613,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}}d=1}hg(b)}fb=e+144|0;return d|0}a=I()|0;H()|0;break a}a=I()|0;H()|0}hg(b);L(a|0);E()}function NK(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;a:{if(!Ud(d&255)){break a}j=(v(b,896)+a|0)+1074984|0;b:{c:{if(e?0:!(!(p[a+480180>>2]&17825824)|!r[a+480192>>1])){break c}if(Zi(j)){break c}d=v(b,896)+a|0;e=d+1075060|0;if(!p[e>>2]|q[d+1075073|0]&4){break a}c=v(b,896)+a|0;g=c+1075004|0;f=c+1075008|0;if(!(p[g>>2]|p[f>>2])){break a}c=PK(a,b);if((c|0)==65535){break a}i=a+1074984|0;c=i+v(c,896)|0;Yr(c,j);n[c+851|0]=0;n[c+827|0]=0;o[c+808>>1]=b+1;p[c+88>>2]=p[c+88>>2]&-918529;Gs(c+810|0);p[c+696>>2]=0;p[c+88>>2]=p[c+88>>2]|2101248;p[e>>2]=0;p[j>>2]=0;p[j+4>>2]=0;c=i+v(b,896)|0;p[c+92>>2]=0;p[c+96>>2]=0;p[g>>2]=0;p[f>>2]=0;if(!(q[d+1075073|0]&2)){break b}a=a+1304392|0;if(!kd(a)){break b}ii(p[a>>2],b,1);break b}e=v(b,896)+a|0;k=p[e+1075088>>2];c=r[a+480192>>1]<c>>>0?0:c;g=p[(c?((c<<2)+a|0)+900380|0:e+1075640|0)>>2];d:{if(!g){break d}i=d+ -1|0;c=r[Yc(g+236|0,i)>>1];f=a+1074308|0;vb(h+8|0,f,104);e:{if(tb(h+8|0)){vb(h,f,34);if(tb(h)){break e}}d=q[Yb(g+108|0,i)|0]}if((c+ -1&65535)>>>0<=3998){k=(v(c,104)+a|0)+484380|0;break d}vb(h+8|0,f,43);if(!tb(h+8|0)){break d}if(!gi(g)){break a}}if(q[e+1075073|0]&4){break a}if(b>>>0<=255){i=a+1304392|0;t=a+1074308|0;x=b+1|0;c=b;while(1){f=(b|0)==(c|0);f:{if(c>>>0<r[a+480188>>1]?!f:0){break f}e=v(c,896)+a|0;if(r[e+1075792>>1]!=(x|0)?!f:0){break f}w=e+1075640|0;f=p[w>>2];if(!f){break f}l=e+1074984|0;g:{h:{i:{j:{k:{l:{m:{switch(q[f+17|0]+ -1|0){case 0:if(!d){break f}s=(f|0)==(g|0)&q[e+1075803|0]==(d|0);u=s;if(!g){break l}if(s){break i}break f;case 1:if(!k|p[e+1075088>>2]!=(k|0)){break f}if((f|0)==(g|0)){break g}vb(h+8|0,t,104);if(!tb(h+8|0)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(g){break j}u=(f|0)==(g|0)}if(u){break g}break f}if(!g){break f}s=q[g+34|0];if(!s){break f}if((s|0)==q[f+34|0]){break h}break f}if((f|0)!=(g|0)){break f}}if(!q[g+34|0]){break g}}if(!q[e+1075803|0]|q[f+18|0]>2){break g}vb(h+8|0,t,34);Tj(a,c&65535,HM(l,tb(h+8|0))+255|0,0);n[e+1075806|0]=0}n:{o:{switch(q[p[w>>2]+18|0]){case 0:Nm(a,l);p[e+1075672>>2]=0;if(!(q[e+1075073|0]&2)){break n}if(!kd(i)){break n}ii(p[i>>2],c&65535,1);break n;case 1:Nm(a,l);if(!(q[e+1075073|0]&2)){break n}if(!kd(i)){break n}_j(p[i>>2],c&65535);break n;case 2:break o;default:break n}}l=e+1075072|0;f=p[l>>2];p[l>>2]=f|4096;if(!(f&512)){break n}if(!kd(i)){break n}vb(h+8|0,t,105);if(tb(h+8|0)){break n}_j(p[i>>2],c&65535)}if(p[e+1075672>>2]){break f}p[e+1075680>>2]=0;e=e+1075072|0;p[e>>2]=p[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}e=0;g=0;p:{if(!Zi(j)){break p}if(!Ud(q[(v(b,896)+a|0)+1075803|0])){break p}q:{c=Km(a,b,2,1);if(c+ -251>>>0<5){break q}if(!c){break p}g=p[(v(c,160)+a|0)+906140>>2];if(!g){break q}vb(h+8|0,a+1074308|0,34);e=(z=g,A=HM(j,tb(h+8|0)),B=b,y=p[p[g>>2]+96>>2],m[y](z|0,A|0,B|0)|0);break p}g=0}if(yh(j)?0:!e){break a}d=PK(a,b);if((d|0)==65535){break a}f=v(d,896)+a|0;c=f+1075072|0;i=f+1074984|0;r:{if(!(q[f+1075073|0]&2)){break r}k=a+1304392|0;if(!kd(k)){break r}ii(p[k>>2],d,1)}Yr(i,j);p[c>>2]=p[c>>2]&-917505;n[f+1075835|0]=0;k=r[a+480188>>1];n[f+1075811|0]=0;o[f+1075792>>1]=k>>>0>b>>>0?b+1|0:0;s:{if(!g|e^1){break s}e=q[(v(b,896)+a|0)+1075804|0];if(e>>>0>3|(e|0)==1){break s}Tj(a,b,255,0);n[(v(b,896)+a|0)+1075806|0]=0}t:{u:{switch(q[(v(b,896)+a|0)+1075804|0]){case 2:Nm(a,i);if(!(q[c+1|0]&2)){break t}e=a+1304392|0;if(!kd(e)){break t}_j(p[e>>2],b);vb(h+8|0,a+1074308|0,105);if(!tb(h+8|0)){break t}Vx(p[e>>2],b,d);break t;case 0:p[(v(d,896)+a|0)+1075680>>2]=0;e=p[c>>2];p[c>>2]=e|4096;if(!(e&512)){break t}e=a+1304392|0;if(!kd(e)){break t}ii(p[e>>2],b,1);break t;case 3:e=p[c>>2];p[c>>2]=e|4096;if(!(e&512)){break t}e=a+1304392|0;if(!kd(e)){break t}vb(h+8|0,a+1074308|0,105);g=tb(h+8|0);e=p[e>>2];if(g){Vx(e,b,d);break t}_j(e,b);break t;case 1:break u;default:break t}}if(!(q[c+1|0]&2)){break t}e=a+1304392|0;if(!kd(e)){break t}Vx(p[e>>2],b,d)}if(!p[(v(d,896)+a|0)+1075672>>2]){p[(v(d,896)+a|0)+1075680>>2]=0;p[c>>2]=p[c>>2]|2101248}a=v(b,896)+a|0;p[a+1075060>>2]=0;p[j>>2]=0;p[j+4>>2]=0;a=a+1075076|0;p[a>>2]=0;p[a+4>>2]=0}}fb=h+16|0}function Gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=w(0),l=0,m=0;d=fb-128|0;fb=d;h=-1;a:{b:{c:{d:{if(!tf(p[p[b>>2]+ -12>>2]+b|0)){break d}df(d+112|0,b);e=p[d+120>>2];f=p[d+124>>2];Ll(d+104|0);Hj(b,d+104|0,8);if((q[d+104|0]|q[d+105|0]<<8|(q[d+106|0]<<16|q[d+107|0]<<24))!=1414681667|(q[d+108|0]|q[d+109|0]<<8|(q[d+110|0]<<16|q[d+111|0]<<24))!=776101705){a=Bg(d+88|0,e,f);c=p[a+12>>2];p[d+16>>2]=p[a+8>>2];p[d+20>>2]=c;c=p[a+4>>2];p[d+8>>2]=p[a>>2];p[d+12>>2]=c;Ni(b,d+8|0);break d}o[d+86>>1]=0;mf(b,d+86|0);if((r[d+86>>1]&65534)!=2){break d}Ll(d+78|0);Hj(b,d+78|0,8);if((q[d+78|0]|q[d+79|0]<<8|(q[d+80|0]<<16|q[d+81|0]<<24))!=1933333571|(q[d+82|0]|q[d+83|0]<<8|(q[d+84|0]<<16|q[d+85|0]<<24))!=1111389030){break d}o[d+76>>1]=0;mf(b,d+76|0);e=o[d+76>>1];if((e+ -3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if((e|0)<=3){e=Lb(d+112|0);p[114610]=0;f=P(724,b|0,e|0,65535)|0;i=p[114610];p[114610]=0;if((i|0)==1){break b}if(!f){break j}p[114610]=0;N(13,d- -64|0,c|0,e|0);f=p[114610];p[114610]=0;if((f|0)!=1){break k}break b}e=Lb(d+112|0);p[114610]=0;f=P(726,b|0,e|0,255)|0;i=p[114610];p[114610]=0;if((i|0)==1){break c}if(!f){break i}p[114610]=0;N(13,d- -64|0,c|0,e|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}}xb(a+40|0,d- -64|0);pb(d- -64|0);pb(e);o[d+62>>1]=0;mf(b,d+62|0);o[d+60>>1]=0;mf(b,d+60|0);o[a>>1]=r[d+60>>1];o[d+58>>1]=0;l:{if(o[d+76>>1]<=3){p[d+112>>2]=0;ni(b,d+112|0);e=p[d+112>>2];if(e>>>0>65535){break d}e=Gz(e);o[d+58>>1]=e;break l}mf(b,d+58|0);e=r[d+58>>1]}m:{n:{o:{p:{if(e&65535){i=a+52|0;f=0;while(1){e=Lb(d+112|0);p[114610]=0;o[d+40>>1]=0;J(1616,b|0,d+40|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break g}q:{if(o[d+76>>1]<=3){p[114610]=0;g=P(724,b|0,e|0,65535)|0;j=p[114610];p[114610]=0;if((j|0)==1){break g}if(g){break q}break e}p[114610]=0;g=P(726,b|0,e|0,255)|0;j=p[114610];p[114610]=0;if((j|0)==1){break g}if(!g){break e}}p[114610]=0;N(13,d- -64|0,c|0,e|0);g=p[114610];p[114610]=0;if((g|0)==1){break p}p[114610]=0;g=J(1617,i|0,d+40|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break o}xb(g,d- -64|0);pb(d- -64|0);pb(e);f=f+1|0;if((f&65535)>>>0<r[d+58>>1]){continue}break}}Ll(d- -64|0);Hj(b,d- -64|0,8);if((q[d+64|0]|q[d+65|0]<<8|(q[d+66|0]<<16|q[d+67|0]<<24))!=1933333571|(q[d+68|0]|q[d+69|0]<<8|(q[d+70|0]<<16|q[d+71|0]<<24))!=1161720678){break d}c=r[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(o[d+86>>1]>2){break n}if(oI(b,c)){break m}break d}b=I()|0;H()|0;break f}b=I()|0;H()|0;pb(d- -64|0);break f}if(!nI(b,c)){break d}}c=a+16|0;r:{if(o[d+86>>1]<=2){if(oI(b,c)){break r}break d}if(!nI(b,c)){break d}}l=a,m=Bb(a+16|0),p[l+36>>2]=m;o[d+56>>1]=0;mf(b,d+56|0);c=r[d+56>>1];o[a+28>>1]=c;if((c+200&65535)>>>0>400){break d}o[d+54>>1]=0;mf(b,d+54|0);c=o[d+54>>1];o[a+30>>1]=c;if((c|0)<0){break d}p[d+48>>2]=0;po(b,d+48|0);k=t[d+48>>2];t[a+32>>2]=k;if(k<w(0)){break d}Ll(d+40|0);Hj(b,d+40|0,8);if((q[d+40|0]|q[d+41|0]<<8|(q[d+42|0]<<16|q[d+43|0]<<24))!=1414681667|(q[d+44|0]|q[d+45|0]<<8|(q[d+46|0]<<16|q[d+47|0]<<24))!=776298313){break d}c=a+4|0;if(Bb(c)>>>0>32767){break d}f=a+32|0;s:{if(!(t[f>>2]>w(0)?o[a+30>>1]>=1:0)){if(!r[a>>1]){break s}break d}t:{switch(r[a>>1]+ -1|0){case 0:case 2:break t;default:break s}}if(Bb(c)>>>0<o[a+30>>1]>>>0){break d}}b=0;e=p[a+36>>2];if(e){b=e+ -1|0;p[a+36>>2]=b}l=d,m=Os(b),p[l+112>>2]=m;p[d+32>>2]=0;l=a,m=p[Mx(d+112|0,d+32|0,32344)>>2],p[l+36>>2]=m;qo(a);h=1;if(r[a>>1]!=3){break d}b=sI(Bb(c));if((o[a+30>>1]-o[a+28>>1]|0)>(b|0)){break d}e=Pj(d+112|0);h=0;if(o[a+30>>1]>0){while(1){b=Fb(c,h-o[a+28>>1]|0);p[114610]=0;K(1618,e|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break h}h=h+1|0;if((h|0)<o[a+30>>1]){continue}break}}b=r[a+28>>1];o[d+32>>1]=b;c=Bb(c);p[114610]=0;o[d+34>>1]=(b+c|0)+ -1;o[d+30>>1]=0;Z(1612,a|0,e|0,f|0,d+32|0,d+30|0)|0;a=p[114610];p[114610]=0;h=1;if((a|0)!=1){Ef(e);break d}break h}pb(e);break d}pb(e);break d}b=I()|0;H()|0;Ef(e);break a}b=I()|0;H()|0}pb(e);break a}pb(e)}fb=d+128|0;return h|0}b=I()|0;H()|0;pb(e);break a}b=I()|0;H()|0;pb(e)}L(b|0);E()}function jG(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-48|0;fb=g;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(kr(c)){h=b+24|0;if(Cg(p[h>>2]+484344|0,c&65535)){break j}}c=a;a=Lb(g+32|0);b=Lb(g+16|0);sh(c,a,b);pb(b);pb(a);break i}b=Rb(p[h>>2]+484344|0,c);if(!(p[b+12>>2]>(d|0)?(d|0)>=0:0)){c=a;a=Lb(g+32|0);b=Lb(g+16|0);sh(c,a,b);pb(b);pb(a);break i}if(!(r[p[h>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){c=a;a=Lb(g+32|0);b=Lb(g+16|0);sh(c,a,b);pb(b);pb(a);break i}if(f>>>0>=6){c=a;a=Lb(g+32|0);b=Lb(g+16|0);sh(c,a,b);pb(b);pb(a);break i}b=_e(b,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{if(!Sf(b)){if(!Mr(b)){break n}}MJ(g+16|0,p[h>>2],q[b|0],q[b+1|0]);p[114610]=0;N(9,g+32|0,0,g+16|0);c=p[114610];p[114610]=0;d=1;if((c|0)!=1){break m}c=I()|0;H()|0;break b}d=0;p[114610]=0;J(85,g+32|0,38780)|0;c=p[114610];p[114610]=0;if((c|0)==1){break l}}p[114610]=0;c=M(556,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}o:{if(c){p[114610]=0;J(85,g|0,38784)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}break o}if(Mr(b)){p[114610]=0;J(85,g|0,38788)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break o}break c}p[114610]=0;J(85,g|0,38780)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}}sh(a,g+32|0,g);pb(g);pb(g+32|0);if(!d){break i}pb(g+16|0);break i}c=I()|0;H()|0;break a;case 1:c=b+1|0;p:{if(q[b+1|0]){Ps(g+32|0,c);break p}Mb(g+32|0,38792)}q:{if(q[c|0]){p[114610]=0;J(85,g+16|0,38795)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break q}break d}p[114610]=0;J(85,g+16|0,38792)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}}sh(a,g+32|0,g+16|0);pb(g+16|0);pb(g+32|0);break i;case 2:r:{if(Pm(b)){Mb(g+32|0,38798);break r}if(q[b+2|0]){nj(g+32|0,1,QI(p[p[h>>2]+8>>2],q[b+2|0]));break r}Mb(g+32|0,38798)}p[114610]=0;c=M(1342,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}s:{if(c){p[114610]=0;J(85,g+16|0,38798)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}break s}if(q[b+2|0]){p[114610]=0;J(85,g+16|0,38800)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break s}break e}p[114610]=0;J(85,g+16|0,38798)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}}sh(a,g+32|0,g+16|0);pb(g+16|0);pb(g+32|0);break i;case 4:t:{if(Pm(b)){i=g,j=Gx(b)&255,p[i>>2]=j;Ny(g+32|0,g);break t}if(q[b+2|0]){Ps(g+32|0,b+4|0);break t}Mb(g+32|0,38792)}p[114610]=0;c=M(1342,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}u:{if(c){p[114610]=0;J(85,g+16|0,38802)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}break u}if(q[b+2|0]){p[114610]=0;J(85,g+16|0,38802)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break u}break f}p[114610]=0;J(85,g+16|0,38792)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}}sh(a,g+32|0,g+16|0);pb(g+16|0);pb(g+32|0);break i;case 3:v:{if(Pm(b)){i=g,j=(cs(b)&3840)!=0,n[i|0]=j;X9(g+32|0,g);break v}if(q[b+3|0]){nj(g+32|0,1,PI(p[p[h>>2]+8>>2],q[b+3|0]));break v}Mb(g+32|0,38805)}p[114610]=0;c=M(1342,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}w:{if(c){p[114610]=0;J(85,g+16|0,38807)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}break w}if(q[b+3|0]){p[114610]=0;J(85,g+16|0,38807)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break w}break g}p[114610]=0;J(85,g+16|0,38805)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}}sh(a,g+32|0,g+16|0);pb(g+16|0);pb(g+32|0);break i;case 5:x:{if(Pm(b)){i=g,j=cs(b)&255,p[i>>2]=j;Ny(g+32|0,g);break x}if(q[b+3|0]){Ps(g+32|0,b+5|0);break x}Mb(g+32|0,38792)}p[114610]=0;c=M(1342,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break h}y:{if(c){p[114610]=0;J(85,g+16|0,38809)|0;b=p[114610];p[114610]=0;if((b|0)==1){break h}break y}if(q[b+3|0]){p[114610]=0;J(85,g+16|0,38809)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break y}break h}p[114610]=0;J(85,g+16|0,38792)|0;b=p[114610];p[114610]=0;if((b|0)==1){break h}}sh(a,g+32|0,g+16|0);pb(g+16|0);pb(g+32|0);break i;default:break k}}c=a;a=Lb(g+32|0);b=Lb(g+16|0);sh(c,a,b);pb(b);pb(a)}fb=g+48|0;return}c=I()|0;H()|0;pb(g+32|0);break a}c=I()|0;H()|0;pb(g+32|0);break a}c=I()|0;H()|0;pb(g+32|0);break a}c=I()|0;H()|0;pb(g+32|0);break a}c=I()|0;H()|0;pb(g+32|0);break a}c=I()|0;H()|0;pb(g+32|0);if(!d){break a}}pb(g+16|0)}L(c|0);E()}function Xya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0;d=fb-192|0;fb=d;Ac(b);a:{if(!uz(b,d+144|0)){break a}if(!rN(d+144|0)){break a}if(!Hb(b,dd(qN(d+144|0),ib))){break a}b:{if(!c){break b}xd(a,256);pn(d+16|0,2,d+144|0);zc(d+48|0,d+16|0);xb(a+1304400|0,d+48|0);pb(d+48|0);e=Mb(d+48|0,17231);xb(a+1304436|0,e);pb(e);e=Mb(d+48|0,17248);xb(a+1304448|0,e);pb(e);g=Mb(d+128|0,17252);p[114610]=0;K(219,d+16|0,g|0);e=p[114610];p[114610]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){p[114610]=0;K(450,d+112|0,d+175|0);e=p[114610];p[114610]=0;if((e|0)==1){break i}p[114610]=0;Q(451,d+48|0,d+16|0,d+174|0,d+112|0);e=p[114610];p[114610]=0;if((e|0)==1){break h}xb(a+1304460|0,d+48|0);pb(d+48|0);pb(d+112|0);yb(d+16|0);pb(g);p[a+1304496>>2]=4;p[a+480260>>2]=64;p[a+480264>>2]=32767;p[a+480188>>2]=2031620;f=q[d+176|0];if(q[d+175|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-v(e,10)}g=(f&255?f:96)&255;e=SK(g);p[a+480196>>2]=g>>>4;p[a+480204>>2]=e;if(q[d+175|0]>10){break e}break d}f=I()|0;H()|0;break f}f=I()|0;H()|0;break g}f=I()|0;H()|0;pb(d+112|0)}yb(d+16|0)}pb(g);break c}n[d+48|0]=64;u=a,w=q[hc(d+178|0,d+48|0)|0]<<2,p[u+480200>>2]=w}f=0;while(1){e=(f<<5)+a|0;Fg(e+480280|0);o[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;j:{k:{while(1){Js(b,d+16|0);if(q[d+28|0]!=46?q[d+28|0]:0){break k}Wya(d+16|0,(v(f,104)+a|0)+484380|0);mk(d,2,d+16|0);zc(d+112|0,d);p[114610]=0;J(369,((f<<5)+a|0)+946300|0,d+112|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break j}pb(d+112|0);o[((f<<1)+d|0)+46>>1]=q[d+30|0]|q[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;rp(Ob(e),b,q[d+175|0]?128:64,65535,65535);e=Ob(e);u=d,w=Ub(e),p[u+16>>2]=w;u=d,w=Vb(e),p[u+112>>2]=w;if(Ab(d+16|0,d+112|0)){while(1){e=p[d+16>>2];g=r[e>>1];l:{if(!((g|0)!=99?(g|0)!=255:0)){o[e>>1]=65535;break l}if(g>>>0>63){break k}}te(d+16|0);if(Ab(d+16|0,d+112|0)){continue}break}}s=c&1;if(s){Pf(a+484344|0,q[d+177|0])}if(q[d+177|0]){l=a+484344|0;while(1){m:{n:{if(s){if(ag(l,j&65535,64)){break n}}f=0;while(1){if((td(b)+5&255)>>>0>=3){Sb(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break m}u=d,w=Ub(Rb(l,j)),p[u+112>>2]=w;p[d>>2]=63;i=65535;k=0;while(1){f=0;while(1){g=f;h=0;f=0;m=0;t=0;o:{p:{q:{r:{s:{t:{e=td(b);switch(e+ -251|0){case 1:break o;case 0:break r;case 2:break t;default:break s}}n[p[d+112>>2]]=254;break o}It(d+16|0,b);f=q[Yb(d+16|0,0)|0];m=q[Yb(d+16|0,1)|0];t=q[Yb(d+16|0,2)|0];h=254;if((e|0)==254){break q}h=e;if(e>>>0>95){break p}}h=(v(h>>>4|0,12)+(h&15)|0)+37|0}e=h;n[p[d+112>>2]]=e}n[p[d+112>>2]+1|0]=(f&248)>>>3;if(q[p[d+112>>2]+1|0]>=32){n[p[d+112>>2]+1|0]=0}e=m>>>1&120|f&7;if(e>>>0<=64){n[p[d+112>>2]+2|0]=1;n[p[d+112>>2]+4|0]=e}n[p[d+112>>2]+3|0]=q[(m&15)+17280|0];n[p[d+112>>2]+5|0]=t;u:{switch(q[p[d+112>>2]+3|0]+ -11|0){case 0:h=p[d+112>>2];e=q[h+5|0];if(q[p[d+112>>2]+5|0]&15){n[h+5|0]=e&15;break o}n[h+5|0]=e&240;break o;case 3:n[p[d+112>>2]+5|0]=v(q[p[d+112>>2]+5|0]&240,10)|q[p[d+112>>2]+5|0]&15;v:{if((i|0)!=65535){if(q[p[d+112>>2]+5|0]){break v}n[p[d+112>>2]+3|0]=12;n[p[d+112>>2]+5|0]=i}i=65535}vc(d,k);break o;case 1:i=q[p[d+112>>2]+5|0];p[d>>2]=63;n[p[d+112>>2]+3|0]=0;break o;case 5:if(q[d+175|0]<=20){n[p[d+112>>2]+5|0]=q[p[d+112>>2]+5|0]%10|q[p[d+112>>2]+5|0]/10<<4}if(q[p[d+112>>2]+5|0]){break o}n[p[d+112>>2]+3|0]=0;break o;case 7:break o;default:break u}}if(q[p[d+112>>2]+5|0]){break o}n[p[d+112>>2]+3|0]=0}uk(d+112|0);f=g+1|0;if((g&65535)>>>0<3){continue}break}k=k+1|0;if((k|0)!=64){continue}break}if((i|0)==65535){break m}el(Rb(l,j),on(Oe(Ip(d+16|0,12,i&255),p[d>>2])))}j=j+1|0;if(j>>>0<q[d+177|0]){continue}break}}f=1;if(!(c&2)){break a}g=Tc(d+16|0,8,1,0,0);while(1){c=v(f,104)+a|0;e=c+484380|0;w:{if(!p[e>>2]|!r[c+484410>>1]){break w}c=r[((f<<1)+d|0)+46>>1];if(c>>>0<4){break w}if(!Jc(b,c<<4)){break w}fg(g,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=I()|0;H()|0;pb(d+112|0)}L(f|0);E()}f=1}fb=d+192|0;return f|0}function r0(){var a=0,b=0,c=0,d=0,e=0;Bd(463392);p[115848]=62400;p[114610]=0;b=J(2515,463408,28)|0;a=p[114610];p[114610]=0;a:{b:{c:{d:{if((a|0)!=1){p[114610]=0;c=J(85,463568,62389)|0;a=p[114610];p[114610]=0;if((a|0)==1){break d}Bb(b);RC(b);QC(b);Bd(463072);p[115768]=64016;p[114610]=0;K(2516,463392,463072);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463080);p[115770]=64048;p[114610]=0;K(2517,463392,463080);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463088);n[463100]=0;p[115774]=0;p[115772]=62420;d=463096,e=Vn(),p[d>>2]=e;p[114610]=0;K(2518,463392,463088);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463104);p[115776]=63004;p[114610]=0;K(2519,463392,463104);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463112);p[115778]=63152;p[114610]=0;K(2520,463392,463112);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;R(2521);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(2522,463392,463120);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463136);p[115784]=63300;p[114610]=0;K(2523,463392,463136);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;wq(463144);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(2525,463392,463144);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463152);o[231580]=11310;p[115788]=62520;Lb(463164);p[114610]=0;K(2526,463392,463152);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463184);p[115798]=46;p[115799]=44;p[115796]=62560;Lb(463200);p[114610]=0;K(2527,463392,463184);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463216);p[115804]=64080;p[114610]=0;K(2528,463392,463216);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463224);p[115806]=64324;p[114610]=0;K(2529,463392,463224);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463232);p[115808]=64536;p[114610]=0;K(2530,463392,463232);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463240);p[115810]=64768;p[114610]=0;K(2531,463392,463240);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;PC();a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(2533,463392,463248);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463256);p[115814]=65900;p[114610]=0;K(2534,463392,463256);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463264);p[115816]=66016;p[114610]=0;K(2535,463392,463264);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463272);p[115818]=66132;p[114610]=0;K(2536,463392,463272);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;OC();a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(2538,463392,463280);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;NC();a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(2540,463392,463288);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;MC();a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(2542,463392,463296);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;LC();a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(2544,463392,463304);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463312);p[115830]=68292;p[115828]=64968;p[115830]=65016;p[114610]=0;K(2545,463392,463312);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463328);p[115834]=68328;p[115832]=65232;p[115834]=65280;p[114610]=0;K(2546,463392,463328);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;R(2547);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(2548,463392,463344);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;R(2549);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(2550,463392,463360);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;KC();a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(2552,463392,463376);a=p[114610];p[114610]=0;if((a|0)==1){break c}Bd(463384);p[115846]=67024;p[114610]=0;K(2553,463392,463384);a=p[114610];p[114610]=0;if((a|0)==1){break c}return}a=I()|0;H()|0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;pb(c)}UC(b)}L(a|0);E()}function TU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-160|0;fb=d;Ac(b);hq(a);a:{if(!au(b,d+120|0)){break a}if(!cJ(d+120|0)){break a}if(!wma(b,d+120|0)){break a}if(!c){f=1;break a}sma(d+104|0,b,d+120|0);c=d+152|0;c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[114610]=0;c=J(256,b|0,c|0)|0;g=p[114610];p[114610]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((g|0)!=1){if(!c){break b}g=d+88|0;OU(g);c=d+148|0;f=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[114610]=0;K(332,g|0,f|0);f=p[114610];p[114610]=0;if((f|0)==1){break h}if(!(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))){break i}f=d+120|4;while(1){j:{p[114610]=0;e=J(258,b|0,4)|0;k=p[114610];p[114610]=0;if((k|0)==1){break j}if(!e){break i}e=q[f|0]|q[f+1|0]<<8;p[114610]=0;e=J(333,b|0,e|0)|0;k=p[114610];p[114610]=0;k:{if((k|0)!=1){p[d+24>>2]=e;if(e>>>0>=nc(d+104|0)>>>0){break k}p[114610]=0;K(334,g|0,d+24|0);e=p[114610];p[114610]=0;if((e|0)!=1){break k}}b=I()|0;H()|0;break f}i=i+1|0;if(i>>>0<(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))>>>0){continue}break i}break}b=I()|0;H()|0;break f}b=I()|0;H()|0;break e}c=d+144|0;c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);f=0;p[114610]=0;c=J(256,b|0,c|0)|0;i=p[114610];p[114610]=0;if((i|0)!=1){break g}}b=I()|0;H()|0;break f}if(!c){break c}f=d+140|0;if(!(q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24))){break d}k=d+36|0;c=d+120|4;i=0;l:{m:{n:{o:{p:{q:{while(1){p[114610]=0;e=J(258,b|0,4)|0;h=p[114610];p[114610]=0;r:{if((h|0)!=1){if(e){break r}break d}b=I()|0;H()|0;break f}e=q[c|0]|q[c+1|0]<<8;p[114610]=0;fa(335,b|0,d+84|0,d+80|0,d+76|0,d+72|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break o}s:{t:{if(p[d+76>>2]<1){break t}e=p[d+84>>2];if((e|0)>-1){break t}e=e^-1;p[d+84>>2]=e;if(Bb(g)>>>0<=e>>>0){break t}if(!Md(id(d+104|0,p[Fb(g,p[d+84>>2])>>2]),11555)){break t}p[114610]=0;Q(336,d+56|0,b|0,p[d+80>>2],p[d+76>>2]);e=p[114610];p[114610]=0;if((e|0)==1){break n}p[114610]=0;e=M(337,d+56|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break m}if(e){if((q[c|0]|q[c+1|0]<<8)>>>0<=39){p[114610]=0;J(338,d+56|0,8)|0;e=p[114610];p[114610]=0;if((e|0)==1){break m}}if((q[c|0]|q[c+1|0]<<8)>>>0<=59){p[114610]=0;J(338,d+56|0,16)|0;e=p[114610];p[114610]=0;if((e|0)==1){break m}}p[114610]=0;M(339,d+56|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break m}u:{if((q[c|0]|q[c+1|0]<<8)>>>0>=120){p[114610]=0;M(339,d+56|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break m}p[114610]=0;J(338,d+56|0,8)|0;break u}if((q[c|0]|q[c+1|0]<<8)>>>0>=100){p[114610]=0;J(338,d+56|0,4)|0;e=p[114610];p[114610]=0;if((e|0)==1){break m}p[114610]=0;M(339,d+56|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break m}p[114610]=0;J(338,d+56|0,4)|0;break u}if((q[c|0]|q[c+1|0]<<8)>>>0>=62){p[114610]=0;M(339,d+56|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break m}p[114610]=0;J(338,d+56|0,4)|0;break u}p[114610]=0;M(339,d+56|0)|0}e=p[114610];p[114610]=0;if((e|0)==1){break m}p[114610]=0;h=M(339,d+56|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break p}p[114610]=0;e=M(340,d+24|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break s}j=p[d+72>>2];v:{if((j|0)<0){break v}if(j>>>0>=nc(d+104|0)>>>0){break v}j=id(d+104|0,p[d+72>>2]);p[114610]=0;N(13,d+8|0,2,j|0);j=p[114610];p[114610]=0;if((j|0)==1){break q}xb(d+24|0,d+8|0);pb(d+8|0)}p[114610]=0;N(341,d+8|0,d+56|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break q}Nd(k,d+8|0);sb(d+8|0);p[114610]=0;K(342,a|0,e|0);h=p[114610];p[114610]=0;if((h|0)==1){break q}ju(e)}sb(d+56|0)}i=i+1|0;if(i>>>0<(q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24))>>>0){continue}break d}break}b=I()|0;H()|0;break l}b=I()|0;H()|0;ju(e);break l}b=I()|0;H()|0;break l}b=I()|0;H()|0;break f}b=I()|0;H()|0;break f}b=I()|0;H()|0}sb(d+56|0)}VA(g)}bd(d+104|0);L(b|0);E()}f=cd(a)^1}VA(g)}bd(d+104|0)}fb=d+160|0;return f|0}function b6(a,b,c,d){var e=0,f=0,g=0,h=w(0),i=0,j=w(0),k=0,l=w(0),m=w(0),n=0,o=w(0),q=0,s=0,u=0,x=0,y=0,z=0,A=0,B=w(0),C=w(0),D=w(0),E=w(0),F=0,G=0,H=0,I=0,J=0,K=0;s=b>>1;f=s<<2;J=p[c+92>>2];a:{if(p[c+80>>2]){q=rm(c,f);break a}q=fd(f)}f=s<<2;u=f+a|0;f=(f+q|0)+ -8|0;i=p[((d<<2)+c|0)+1068>>2];b:{if(!s){e=i;break b}g=a;e=i;while(1){t[f+4>>2]=w(t[e>>2]*t[g>>2])-w(t[e+4>>2]*t[g+8>>2]);t[f>>2]=w(t[e>>2]*t[g+8>>2])+w(t[e+4>>2]*t[g>>2]);e=e+8|0;f=f+ -8|0;g=g+16|0;if((u|0)!=(g|0)){continue}break}}if(f>>>0>=q>>>0){g=((s<<2)+a|0)+ -12|0;while(1){t[f+4>>2]=w(t[e+4>>2]*t[g>>2])-w(t[e>>2]*t[g+8>>2]);t[f>>2]=w(t[e>>2]*w(-t[g>>2]))-w(t[e+4>>2]*t[g+8>>2]);g=g+ -16|0;e=e+8|0;f=f+ -8|0;if(f>>>0>=q>>>0){continue}break}}H=b>>2;if((b|0)>=16){g=H<<2;f=g+q|0;k=a+g|0;e=(i+(s<<2)|0)+ -32|0;n=a;g=q;while(1){m=t[g>>2];l=t[f>>2];j=t[g+4>>2];h=t[f+4>>2];t[k+4>>2]=j+h;t[k>>2]=t[g>>2]+t[f>>2];j=w(h-j);h=w(l-m);t[n+4>>2]=w(t[e+16>>2]*j)-w(t[e+20>>2]*h);t[n>>2]=w(t[e+20>>2]*j)+w(t[e+16>>2]*h);m=t[g+8>>2];l=t[f+8>>2];j=t[g+12>>2];h=t[f+12>>2];t[k+12>>2]=j+h;t[k+8>>2]=t[g+8>>2]+t[f+8>>2];j=w(h-j);h=w(l-m);t[n+12>>2]=w(t[e>>2]*j)-w(t[e+4>>2]*h);t[n+8>>2]=w(t[e+4>>2]*j)+w(t[e>>2]*h);g=g+16|0;f=f+16|0;n=n+16|0;k=k+16|0;e=e+ -32|0;if(e>>>0>=i>>>0){continue}break}}y=_k(b);g=b>>4;k=s+ -1|0;e=b>>3;f=0-e|0;$E(g,a,k,f,i);$E(g,a,k-H|0,f,i);A=b>>5;f=0-g|0;io(A,a,k,f,i,16);io(A,a,k-e|0,f,i,16);io(A,a,k-(e<<1)|0,f,i,16);io(A,a,k+v(e,-3)|0,f,i,16);n=2;if((y|0)>=10){f=y+ -4>>1;n=(f|0)>3?f:3;f=2;while(1){g=f;f=f+1|0;F=2<<g;if((F|0)>=1){G=8<<g;e=0;x=b>>g+2;z=0-(x>>1)|0;g=b>>g+4;while(1){io(g,a,k-v(e,x)|0,z,i,G);e=e+1|0;if((F|0)!=(e|0)){continue}break}}if((f|0)!=(n|0)){continue}break}}I=y+ -7|0;if((n|0)<(I|0)){while(1){f=n;n=f+1|0;e=b>>f+6;if((e|0)>=1){K=2<<f;y=8<<f;F=y<<2;G=b>>f+2;x=0-(G>>1)|0;f=i;g=k;while(1){X5(K,a,g,x,f,y,G);g=g+ -8|0;f=(F<<2)+f|0;z=(e|0)>1;e=e+ -1|0;if(z){continue}break}}if((n|0)!=(I|0)){continue}break}}W5(A,a,k,i,b);x=s+ -4|0;e=((H<<2)+q|0)+ -16|0;if(e>>>0>=q>>>0){f=(x<<2)+q|0;g=p[((d<<2)+c|0)+1100>>2];while(1){i=(r[g>>1]<<2)+a|0;p[f+12>>2]=p[i>>2];p[f+8>>2]=p[i+4>>2];p[e+12>>2]=p[i+8>>2];p[e+8>>2]=p[i+12>>2];i=(r[g+2>>1]<<2)+a|0;p[f+4>>2]=p[i>>2];p[f>>2]=p[i+4>>2];p[e+4>>2]=p[i+8>>2];p[e>>2]=p[i+12>>2];g=g+4|0;f=f+ -16|0;e=e+ -16|0;if(e>>>0>=q>>>0){continue}break}}f=(s<<2)+q|0;i=f+ -16|0;if(i>>>0>q>>>0){g=p[((d<<2)+c|0)+1084>>2];k=f;e=q;while(1){B=t[g+4>>2];z=k+ -4|0;C=t[z>>2];l=t[e+4>>2];D=w(C+l);j=t[g>>2];E=t[e>>2];n=k+ -8|0;o=t[n>>2];h=w(E-o);m=w(w(B*D)-w(j*h));l=w(l-C);t[e+4>>2]=m+l;j=w(w(j*D)+w(B*h));h=w(o+E);t[e>>2]=j+h;t[z>>2]=m-l;t[n>>2]=h-j;B=t[g+12>>2];n=k+ -12|0;C=t[n>>2];l=t[e+12>>2];D=w(C+l);j=t[g+8>>2];E=t[e+8>>2];o=t[i>>2];h=w(E-o);m=w(w(B*D)-w(j*h));l=w(l-C);t[e+12>>2]=m+l;j=w(w(j*D)+w(B*h));h=w(o+E);t[e+8>>2]=j+h;t[i>>2]=h-j;t[n>>2]=m-l;g=g+16|0;e=e+16|0;k=i;i=i+ -16|0;if(e>>>0<i>>>0){continue}break}}i=f+ -32|0;if(i>>>0>=q>>>0){e=p[((d<<2)+c|0)+1076>>2]+(s<<2)|0;g=(x<<2)+a|0;k=((b<<2)+a|0)+ -16|0;while(1){o=t[e+ -4>>2];m=t[f+ -8>>2];l=t[e+ -8>>2];j=t[f+ -4>>2];h=w(w(o*m)-w(l*j));t[a>>2]=h;t[g+12>>2]=-h;h=w(w(l*w(-m))-w(j*o));t[u>>2]=h;t[k+12>>2]=h;o=t[e+ -12>>2];m=t[f+ -16>>2];l=t[e+ -16>>2];j=t[f+ -12>>2];h=w(w(o*m)-w(l*j));t[a+4>>2]=h;t[g+8>>2]=-h;h=w(w(l*w(-m))-w(j*o));t[u+4>>2]=h;t[k+8>>2]=h;o=t[e+ -20>>2];m=t[f+ -24>>2];l=t[e+ -24>>2];j=t[f+ -20>>2];h=w(w(o*m)-w(l*j));t[a+8>>2]=h;t[g+4>>2]=-h;h=w(w(l*w(-m))-w(j*o));t[u+8>>2]=h;t[k+4>>2]=h;o=t[e+ -28>>2];m=t[i>>2];e=e+ -32|0;l=t[e>>2];j=t[f+ -28>>2];h=w(w(o*m)-w(l*j));t[a+12>>2]=h;t[g>>2]=-h;h=w(w(l*w(-m))-w(j*o));t[u+12>>2]=h;t[k>>2]=h;k=k+ -16|0;g=g+ -16|0;u=u+16|0;a=a+16|0;f=i;i=f+ -32|0;if(i>>>0>=q>>>0){continue}break}}if(!p[c+80>>2]){Nb(q)}p[c+92>>2]=J}function CG(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=fb-256|0;fb=e;u[e+248>>3]=c;a:{if(Yi(b)){break a}g=q[Mj(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Xj(e+216|0,b,p[b+4>>2]+ -1|0);f=p[e+220>>2];p[b>>2]=p[e+216>>2];p[b+4>>2]=f}ud(e+216|0);f=p[e+216>>2];ud(e+200|0);h=Lj(f,p[e+204>>2],b);ud(e+216|0);f=p[b>>2];g=p[b+4>>2];c:{d:{e:{f:{if((h|0)==p[e+220>>2]){p[e+240>>2]=f;p[e+244>>2]=g;a=ic(e+232|0,38139);f=p[e+244>>2];p[e+16>>2]=p[e+240>>2];p[e+20>>2]=f;f=p[a+4>>2];p[e+8>>2]=p[a>>2];p[e+12>>2]=f;if(xc(e+16|0,e+8|0)){d=W(8)|0;p[114610]=0;K(2144,e+200|0,e+248|0);a=p[114610];p[114610]=0;g:{h:{i:{if((a|0)!=1){p[114610]=0;N(2119,e+216|0,39211,e+200|0);a=p[114610];p[114610]=0;if((a|0)==1){break i}dc(d,e+216|0);a=0;p[114610]=0;N(2009,d|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break c}b=I()|0;H()|0;pb(e+216|0);break h}b=I()|0;H()|0;break g}a=1;b=I()|0;H()|0}pb(e+200|0);if(!a){break d}}X(d|0);break d}if(!d){break f}d=W(8)|0;p[114610]=0;f=J(2142,e+168|0,b|0)|0;b=p[114610];p[114610]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){p[114610]=0;N(2119,e+184|0,39090,f|0);a=p[114610];p[114610]=0;if((a|0)==1){break r}p[114610]=0;N(2137,e+200|0,e+184|0,39226);b=p[114610];p[114610]=0;a=1;if((b|0)==1){break q}p[114610]=0;K(2144,e+152|0,e+248|0);a=p[114610];p[114610]=0;if((a|0)==1){break p}p[114610]=0;N(138,e+216|0,e+200|0,e+152|0);b=p[114610];p[114610]=0;a=1;if((b|0)==1){break o}dc(d,e+216|0);p[114610]=0;N(2009,d|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(e+216|0);a=0;break n}b=I()|0;H()|0;break j}a=1;b=I()|0;H()|0;break k}b=I()|0;H()|0;break l}a=1;b=I()|0;H()|0;break m}b=I()|0;H()|0}pb(e+152|0)}pb(e+200|0)}pb(e+184|0)}pb(f)}if(!a){break d}X(d|0);break d}p[e+144>>2]=f;p[e+148>>2]=g;d=ic(e+136|0,38139);f=p[e+148>>2];p[e+80>>2]=p[e+144>>2];p[e+84>>2]=f;f=p[d+4>>2];p[e+72>>2]=p[d>>2];p[e+76>>2]=f;if(xc(e+80|0,e+72|0)){d=W(8)|0;p[114610]=0;K(2144,e+200|0,e+248|0);a=p[114610];p[114610]=0;s:{t:{u:{if((a|0)!=1){p[114610]=0;N(2119,e+216|0,39211,e+200|0);a=p[114610];p[114610]=0;if((a|0)==1){break u}dc(d,e+216|0);a=0;p[114610]=0;N(2009,d|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break c}b=I()|0;H()|0;pb(e+216|0);break t}b=I()|0;H()|0;break s}a=1;b=I()|0;H()|0}pb(e+200|0);if(!a){break d}}X(d|0);break d}d=p[b+4>>2];p[e+128>>2]=p[b>>2];p[e+132>>2]=d;d=ic(e+120|0,38933);f=p[e+132>>2];p[e+64>>2]=p[e+128>>2];p[e+68>>2]=f;f=p[d+4>>2];p[e+56>>2]=p[d>>2];p[e+60>>2]=f;if(xc(e- -64|0,e+56|0)){if(!q[a+28|0]){break f}c=u[e+248>>3];if(!(c<=4?!(c<=0):0)){a=W(8)|0;p[114610]=0;d=J(85,e+216|0,39231)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}dc(a,d);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(d);break d}b=ek(65536/c);a=a+24|0;p[p[a>>2]+480244>>2]=b;zo(p[a>>2]);break f}d=p[b+4>>2];p[e+112>>2]=p[b>>2];p[e+116>>2]=d;d=ic(e+104|0,38951);f=p[e+116>>2];p[e+48>>2]=p[e+112>>2];p[e+52>>2]=f;f=p[d+4>>2];p[e+40>>2]=p[d>>2];p[e+44>>2]=f;if(xc(e+48|0,e+40|0)){if(!q[a+28|0]){break f}c=u[e+248>>3];if(!(c<=4?!(c<=0):0)){a=W(8)|0;p[114610]=0;d=J(85,e+216|0,39252)|0;b=p[114610];p[114610]=0;if((b|0)!=1){dc(a,d);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(d);break d}b=I()|0;H()|0;X(a|0);break d}b=ek(c*65536);a=a+24|0;p[p[a>>2]+480240>>2]=b;zo(p[a>>2]);break f}d=p[b+4>>2];p[e+96>>2]=p[b>>2];p[e+100>>2]=d;b=ic(e+88|0,39048);d=p[e+100>>2];p[e+32>>2]=p[e+96>>2];p[e+36>>2]=d;d=p[b+4>>2];p[e+24>>2]=p[b>>2];p[e+28>>2]=d;if(!xc(e+32|0,e+24|0)){break f}a=a+24|0;a;b=Xm(u[e+248>>3]*65536);p[p[a>>2]+480236>>2]=b}fb=e+256|0;return}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function d6(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;m=fb-16|0;fb=m;j=p[a+4>>2];h=p[a+396>>2];l=h+v(e,24)|0;k=p[l+4>>2];x=r[((e<<1)+a|0)+268>>1];g=d<<((x|0)==2);i=k>>>0<g>>>0?k:g;k=p[l>>2];k=(i-(k>>>0<g>>>0?k:g)>>>0)/s[l+8>>2]|0;n=k<<2;g=v(j,n+4|0);y=p[p[a+124>>2]+v(q[l+13|0],2096)>>2];C=p[a+92>>2];a:{if(p[a+80>>2]){g=rm(a,g);j=p[a+4>>2];break a}g=fd(g)}n=$5(g,j,n);b:{c:{d:{if((c|0)>=1){j=d<<2;g=0;while(1){if(!q[f+g|0]){Jb(p[(g<<2)+b>>2],0,j)}g=g+1|0;if((g|0)!=(c|0)){continue}break}if((c|0)==1|(x|0)!=2){break d}g=0;if((c|0)<1){break c}while(1){if(!q[f+g|0]){break c}g=g+1|0;if((g|0)!=(c|0)){continue}break}break b}g=0;if((x|0)==2){break c}}z=h+v(e,24)|0;A=z;B=(k|0)<1;d=0;while(1){if(!B){u=0;w=(c|0)<1;D=w|(d|0)!=0;j=0;while(1){g=0;if(!D){while(1){if(!q[f+g|0]){h=p[a+124>>2]+v(q[l+13|0],2096)|0;if(p[a+1396>>2]<=9){Kj(a)}i=p[a+1392>>2];e=o[(h+((i&1023)<<1)|0)+36>>1];e:{if((e|0)>=0){t=i;i=q[e+p[h+8>>2]|0];p[a+1392>>2]=t>>>i;t=p[a+1396>>2]-i|0;i=(t|0)<0;p[a+1396>>2]=i?0:t;e=i?-1:e;break e}e=Zk(a,h)}e=q[h+23|0]?p[p[h+2088>>2]+(e<<2)>>2]:e;if((e|0)==-1){break b}p[p[n+(g<<2)>>2]+(u<<2)>>2]=p[p[z+16>>2]+(e<<2)>>2]}g=g+1|0;if((g|0)!=(c|0)){continue}break}}f:{if((j|0)>=(k|0)){break f}e=0;if((y|0)<1){break f}while(1){g=0;if(!w){while(1){g:{if(q[f+g|0]){break g}h=g<<2;i=o[(p[A+20>>2]+(q[p[p[h+n>>2]+(u<<2)>>2]+e|0]<<4)|0)+(d<<1)>>1];if((i|0)<0){break g}t=p[b+h>>2];h=p[l+8>>2];if(!_5(a,p[a+124>>2]+v(i&65535,2096)|0,t,p[l>>2]+v(h,j)|0,h,x)){break b}}g=g+1|0;if((g|0)!=(c|0)){continue}break}}j=j+1|0;if((j|0)>=(k|0)){break f}e=e+1|0;if((e|0)<(y|0)){continue}break}}u=u+1|0;if((j|0)<(k|0)){continue}break}}d=d+1|0;if((d|0)!=8){continue}break}break b}if((c|0)==(g|0)){break b}z=(k|0)<1;A=z|(c|0)<3;u=h+v(e,24)|0;x=u;B=(c|0)!=2;e=0;while(1){h:{if(!B){if(z){break h}f=0;j=0;while(1){g=p[l>>2]+v(p[l+8>>2],f)|0;p[m+12>>2]=g&1;p[m+8>>2]=g>>1;if(!e){h=p[a+124>>2]+v(q[l+13|0],2096)|0;if(p[a+1396>>2]<=9){Kj(a)}i=p[a+1392>>2];g=o[(h+((i&1023)<<1)|0)+36>>1];i:{if((g|0)>=0){t=i;i=q[g+p[h+8>>2]|0];p[a+1392>>2]=t>>>i;w=p[a+1396>>2]-i|0;i=(w|0)<0;p[a+1396>>2]=i?0:w;g=i?-1:g;break i}g=Zk(a,h)}g=q[h+23|0]?p[p[h+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break b}p[p[n>>2]+(j<<2)>>2]=p[p[u+16>>2]+(g<<2)>>2]}j:{if((f|0)>=(k|0)){break j}g=0;if((y|0)<1){break j}while(1){h=p[l+8>>2];i=o[(p[x+20>>2]+(q[p[p[n>>2]+(j<<2)>>2]+g|0]<<4)|0)+(e<<1)>>1];k:{if((i|0)>=0){if(aF(a,p[a+124>>2]+v(i&65535,2096)|0,b,2,m+12|0,m+8|0,d,h)){break k}break b}h=p[l>>2]+(h+v(f,h)|0)|0;p[m+8>>2]=h>>1;p[m+12>>2]=h&1}f=f+1|0;if((f|0)>=(k|0)){break j}g=g+1|0;if((g|0)<(y|0)){continue}break}}j=j+1|0;if((f|0)<(k|0)){continue}break}break h}if(A){break h}f=0;j=0;while(1){h=p[l>>2]+v(p[l+8>>2],f)|0;g=(h|0)/(c|0)|0;p[m+12>>2]=h-v(c,g);p[m+8>>2]=g;if(!e){h=p[a+124>>2]+v(q[l+13|0],2096)|0;if(p[a+1396>>2]<=9){Kj(a)}i=p[a+1392>>2];g=o[(h+((i&1023)<<1)|0)+36>>1];l:{if((g|0)>=0){t=i;i=q[g+p[h+8>>2]|0];p[a+1392>>2]=t>>>i;w=p[a+1396>>2]-i|0;i=(w|0)<0;p[a+1396>>2]=i?0:w;g=i?-1:g;break l}g=Zk(a,h)}g=q[h+23|0]?p[p[h+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break b}p[p[n>>2]+(j<<2)>>2]=p[p[u+16>>2]+(g<<2)>>2]}m:{if((f|0)>=(k|0)){break m}g=0;if((y|0)<1){break m}while(1){h=p[l+8>>2];i=o[(p[x+20>>2]+(q[p[p[n>>2]+(j<<2)>>2]+g|0]<<4)|0)+(e<<1)>>1];n:{if((i|0)>=0){if(aF(a,p[a+124>>2]+v(i&65535,2096)|0,b,c,m+12|0,m+8|0,d,h)){break n}break b}h=p[l>>2]+(h+v(f,h)|0)|0;i=(h|0)/(c|0)|0;p[m+8>>2]=i;p[m+12>>2]=h-v(c,i)}f=f+1|0;if((f|0)>=(k|0)){break m}g=g+1|0;if((g|0)<(y|0)){continue}break}}j=j+1|0;if((f|0)<(k|0)){continue}break}}e=e+1|0;if((e|0)!=8){continue}break}}if(!p[a+80>>2]){Nb(n)}p[a+92>>2]=C;fb=m+16|0}function N5(a,b){var c=w(0),d=0,g=0,h=0,k=w(0),l=0,m=0,n=w(0),o=w(0),p=w(0),q=0,r=w(0),s=0,u=w(0),v=w(0),y=w(0),z=w(0);k=w(1);a:{b:{l=(i(a),e(2));c:{if((l|0)==1065353216){break c}m=(i(b),e(2));d=m&2147483647;if(!d){break c}g=l&2147483647;if(!(d>>>0<2139095041?g>>>0<=2139095040:0)){return w(a+b)}d:{e:{if((l|0)>-1){break e}q=2;if(d>>>0>1266679807){break d}if(d>>>0<1065353216){break e}h=150-(d>>>23|0)|0;s=d>>>h|0;q=0;if((d|0)!=s<<h){break d}q=2-(s&1)|0;break d}q=0}h=q;f:{if((d|0)!=1065353216){if((d|0)!=2139095040){break f}if((g|0)==1065353216){break c}if(g>>>0>=1065353217){return(m|0)>-1?b:w(0)}return(m|0)>-1?w(0):w(-b)}return(m|0)>-1?a:w(w(1)/a)}if((m|0)==1073741824){return w(a*a)}if(!((m|0)!=1056964608|(l|0)<0)){return w(D(a))}c=w(x(a));if(!(g?(l&1073741823)!=1065353216:0)){k=(m|0)<0?w(w(1)/c):c;if((l|0)>-1){break c}if(!(h|g+ -1065353216)){a=w(k-k);return w(a/a)}return(h|0)==1?w(-k):k}g:{if((l|0)>-1){break g}h:{switch(h|0){case 0:a=w(a-a);return w(a/a);case 1:break h;default:break g}}k=w(-1)}i:{if(d>>>0>=1291845633){if(g>>>0<=1065353207){return(m|0)<0?w(w(k*w(1.0000000150474662e+30))*w(1.0000000150474662e+30)):w(w(k*w(1.0000000031710769e-30))*w(1.0000000031710769e-30))}if(g>>>0>=1065353224){return(m|0)>0?w(w(k*w(1.0000000150474662e+30))*w(1.0000000150474662e+30)):w(w(k*w(1.0000000031710769e-30))*w(1.0000000031710769e-30))}a=w(c+w(-1));c=w(a*w(1.44268798828125));n=w(w(a*w(7052607543300837e-21))+w(w(w(a*a)*w(w(.5)-w(a*w(w(a*w(-.25))+w(.3333333432674408)))))*w(-1.4426950216293335)));a=(f(2,(i(w(c+n)),e(2))&-4096),j());r=w(a-c);break i}d=g>>>0<8388608;g=d?(i(w(c*w(16777216))),e(2)):g;l=g&8388607;h=l|1065353216;d=(g>>23)+(d?-151:-127)|0;g=0;j:{if(l>>>0<1885298){break j}if(l>>>0<6140887){g=1;break j}h=h+ -8388608|0;d=d+1|0}l=g<<2;r=t[l+52160>>2];n=(f(2,h),j());o=t[l+52144>>2];p=w(n-o);u=w(w(1)/w(o+n));c=w(p*u);a=(f(2,(i(c),e(2))&-4096),j());v=w(a*a);y=a;z=p;p=(f(2,((h>>1&-536875008|536870912)+(g<<21)|0)+4194304|0),j());n=w(u*w(w(z-w(a*p))-w(a*w(n-w(p-o)))));p=w(w(c+a)*n);a=w(c*c);o=w(p+w(w(a*a)*w(w(a*w(w(a*w(w(a*w(w(a*w(w(a*w(.20697501301765442))+w(.23066075146198273)))+w(.2727281153202057)))+w(.3333333432674408)))+w(.4285714328289032)))+w(.6000000238418579))));a=(f(2,(i(w(w(v+w(3))+o)),e(2))&-4096),j());p=w(y*a);c=w(w(n*a)+w(c*w(o-w(w(a+w(-3))-v))));a=(f(2,(i(w(p+c)),e(2))&-4096),j());o=w(a*w(.9619140625));n=w(t[l+52152>>2]+w(w(w(c-w(a-p))*w(.9617967009544373))+w(a*w(-.00011736857413779944))));c=w(d|0);a=(f(2,(i(w(w(r+w(o+n))+c)),e(2))&-4096),j());r=w(w(w(a-c)-r)-o)}o=(f(2,m&-4096),j());c=w(a*o);a=w(w(w(n-r)*b)+w(w(b-o)*a));b=w(c+a);h=(i(b),e(2));if((h|0)>=1124073473){break b}g=1124073472;k:{l:{if((h|0)==1124073472){if(w(a+w(4.299566569443414e-8))>w(b-c)^1){break l}break b}g=h&2147483647;if(!(a<=w(b-c)^1|(h|0)!=-1021968384)|g>>>0>=1125515265){break a}d=0;if(g>>>0<1056964609){break k}}m=(8388608>>>(g>>>23|0)+ -126|0)+h|0;g=m>>>23&255;d=(m&8388607|8388608)>>>150-g|0;d=(h|0)<0?0-d|0:d;c=w(c-(f(2,m&-8388608>>g+ -127),j()));h=(i(w(a+c)),e(2))}b=(f(2,h&-32768),j());n=w(b*w(.693145751953125));c=w(w(b*w(14286065379565116e-22))+w(w(a-w(b-c))*w(.6931471824645996)));a=w(n+c);b=w(a*a);b=w(a-w(b*w(w(b*w(w(b*w(w(b*w(w(b*w(4.138136944220605e-8))+w(-16533901998627698e-22)))+w(661375597701408e-19)))+w(-.0027777778450399637)))+w(.1666666716337204))));p=w(w(a*b)/w(b+w(-2)));b=w(c-w(a-n));a=w(w(a-w(p-w(b+w(a*b))))+w(1));h=(i(a),e(2))+(d<<23)|0;m:{if((h|0)<=8388607){a=WE(a,d);break m}a=(f(2,h),j())}k=w(k*a)}return k}return w(w(k*w(1.0000000150474662e+30))*w(1.0000000150474662e+30))}return w(w(k*w(1.0000000031710769e-30))*w(1.0000000031710769e-30))}function Tra(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,s=0,t=0;f=fb-11360|0;fb=f;Ac(c);a:{b:{if(!Hb(c,4)){break b}c:{while(1){d:{iT(c,f+16|0);e:{if(!hd(f+16|0,20185,3)){Rra(c,f+4648|0);h=3;d=0;while(1){g=q[(f+4648|0)+h|0];if(g&128){break c}d=g|d<<7;h=h+1|0;if((h|0)!=7){continue}break}Sb(c,d);break e}f:{if(hd(f+16|0,20189,3)){break f}if(!SO(c,20193)){break f}Sb(c,Lf(c)+16|0);break e}if(!hd(f+16|0,20199,3)){break e}if(!hd(f+16|0,20203,3)){break e}if(q[f+16|0]){break d}jg(c,2)}if(Hb(c,4)){continue}break b}break}if(QM(f+16|0)){break b}}h=0;break a}Ac(c);hz(f+11336|0,c);h=p[f+11336>>2];p[114610]=0;c=M(412,f+11336|0)|0;d=p[114610];p[114610]=0;g:{h:{if((d|0)!=1){p[114610]=0;c=M(859,c|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break h}}h=I()|0;H()|0;break g}j=f+11320|0;qU(j);Jb(f+4648|0,0,6668);p[114610]=0;S(1239,f+4648|0);d=p[114610];p[114610]=0;i:{j:{k:{if((d|0)!=1){d=f+4640|0;p[d>>2]=0;p[d+4>>2]=0;d=f+4632|0;p[d>>2]=0;p[d+4>>2]=0;p[f+4624>>2]=0;p[f+4628>>2]=0;g=0;d=0;l:{m:{n:{while(1){p[114610]=0;i=rg(458,h,l);k=p[114610];p[114610]=0;if((k|0)==1){break l}p[114610]=0;m=Z(1240,f+4648|0,c|0,i|0,f+16|0,f+4624|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break l}if((m|0)<0){break j}i=p[f+4624>>2];if((i|0)<0|!i&(m|0)>0|!(i|m)){break j}o:{if((i|0)>=1){k=p[f+4636>>2];if((k|0)!=(g|0)?g:0){break j}i=p[f+4632>>2];if((i|0)!=(d|0)?d:0){break j}if((k|0)<1|i+ -1>>>0>1){break k}p[114610]=0;p[f+8>>2]=0;d=rg(458,h,l);g=p[114610];p[114610]=0;if((g|0)==1){break o}p[114610]=0;p[f+4>>2]=d;d=P(1241,f+4624|0,f+8|0,f+4|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break o}d=p[d>>2];p[114610]=0;p[f+8>>2]=0;g=rg(458,h,l);n=p[114610];p[114610]=0;if((n|0)==1){break n}p[114610]=0;p[f+4>>2]=g;g=P(1241,f+4624|0,f+8|0,f+4|0)|0;n=p[114610];p[114610]=0;if((n|0)==1){break n}c=c+d|0;d=h;g=p[g>>2];h=d-g|0;l=l-((g>>31)+(d>>>0<g>>>0)|0)|0;if((m|0)>=1){s=f,t=Vb(j),p[s+8>>2]=t;Ld(f,f+8|0);p[114610]=0;U(1242,j|0,p[f>>2],f+16|0,(f+16|0)+(v(i,m)<<1)|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break m}}g=k;d=i}i=fc(j);if((l|0)<0?1:(l|0)<=0?h>>>0<1:0){break j}if((i>>>0)/(d>>>0)>>>0<268435457){continue}break j}break}h=I()|0;H()|0;break i}h=I()|0;H()|0;break i}h=O(71348)|0;if((H()|0)!=($(71348)|0)){break i}T(h|0)|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;g=k;d=i;if((c|0)!=1){break j}h=I()|0;H()|0;break i}h=I()|0;H()|0;break i}h=I()|0;H()|0;break i}g=k;d=i}h=0;p:{q:{r:{s:{t:{if(!d|!g){break t}if(cd(j)){break t}if((fc(j)>>>0)/(d>>>0)>>>0>268435456){break t}p[114610]=0;J(1243,a|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break p}if(!e){p[114610]=0;c=J(85,f+16|0,20207)|0;i=p[114610];p[114610]=0;if((i|0)==1){break s}p[114610]=0;J(369,((b<<5)+a|0)+946300|0,c|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break r}pb(c);p[114610]=0;c=v(b,104)+a|0;K(386,c+484380|0,0);i=p[114610];p[114610]=0;if((i|0)==1){break p}p[c+484404>>2]=g}g=v(b,104)+a|0;c=g+484380|0;s=c,t=(fc(j)>>>0)/(d>>>0)|0,p[s>>2]=t;i=g+484414|0;g=r[i>>1];o[i>>1]=(d|0)==2?g|65:g&65470|1;p[114610]=0;M(465,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break p}if(ue(c)){d=Ub(j);g=Vb(j);b=p[(v(b,104)+a|0)+484400>>2];p[114610]=0;P(1244,d|0,g|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break p}}if(!e){b=p[a+480180>>2];p[114610]=0;N(1245,c|0,32,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break q}p[114610]=0;N(1246,c|0,a|0,0);a=p[114610];p[114610]=0;if((a|0)==1){break p}}h=ue(c)}OA(j);uc(f+11336|0);break a}h=I()|0;H()|0;break i}h=I()|0;H()|0;pb(c);break i}h=I()|0;H()|0;break i}h=I()|0;H()|0}OA(j)}uc(f+11336|0);L(h|0);E()}fb=f+11360|0;return h|0}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-352|0;fb=d;a:{if(Yi(b)){break a}e=q[Mj(b)|0];f=1;b:{if((e|0)==33){break b}if((e|0)!=63){break a}f=0}c=f;Xj(d+320|0,b,p[b+4>>2]+ -1|0);e=p[d+324>>2];p[b>>2]=p[d+320>>2];p[b+4>>2]=e}ud(d+320|0);e=p[d+320>>2];ud(d+304|0);e=Lj(e,p[d+308>>2],b);ud(d+320|0);c:{d:{e:{f:{if((e|0)==p[d+324>>2]){a=p[b+4>>2];p[d+344>>2]=p[b>>2];p[d+348>>2]=a;a=ic(d+336|0,38139);e=p[d+348>>2];p[d+8>>2]=p[d+344>>2];p[d+12>>2]=e;e=p[a+4>>2];p[d>>2]=p[a>>2];p[d+4>>2]=e;if(xc(d+8|0,d)){a=W(8)|0;p[114610]=0;c=J(85,d+320|0,39080)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(c);break d}e=0;if(!c){break f}a=W(8)|0;p[114610]=0;c=J(2142,d+304|0,b|0)|0;b=p[114610];p[114610]=0;g:{h:{i:{if((b|0)!=1){p[114610]=0;N(2119,d+320|0,39090,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break i}dc(a,d+320|0);e=0;p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break c}b=I()|0;H()|0;pb(d+320|0);break h}b=I()|0;H()|0;break g}e=1;b=I()|0;H()|0}pb(c);if(!e){break d}}X(a|0);break d}if(p[e+4>>2]){a=W(8)|0;p[114610]=0;c=J(85,d+320|0,39104)|0;b=p[114610];p[114610]=0;if((b|0)!=1){dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(c);break d}b=I()|0;H()|0;X(a|0);break d}c=p[b+4>>2];p[d+296>>2]=p[b>>2];p[d+300>>2]=c;c=ic(d+288|0,38139);e=p[d+300>>2];p[d+152>>2]=p[d+296>>2];p[d+156>>2]=e;e=p[c+4>>2];p[d+144>>2]=p[c>>2];p[d+148>>2]=e;if(xc(d+152|0,d+144|0)){a=W(8)|0;p[114610]=0;c=J(85,d+320|0,39080)|0;b=p[114610];p[114610]=0;if((b|0)!=1){dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(c);break d}b=I()|0;H()|0;X(a|0);break d}c=p[b+4>>2];p[d+280>>2]=p[b>>2];p[d+284>>2]=c;c=ic(d+272|0,38828);e=p[d+284>>2];p[d+136>>2]=p[d+280>>2];p[d+140>>2]=e;e=p[c+4>>2];p[d+128>>2]=p[c>>2];p[d+132>>2]=e;j:{if(!xc(d+136|0,d+128|0)){c=p[b+4>>2];p[d+264>>2]=p[b>>2];p[d+268>>2]=c;c=ic(d+256|0,39125);e=p[d+268>>2];p[d+120>>2]=p[d+264>>2];p[d+124>>2]=e;e=p[c+4>>2];p[d+112>>2]=p[c>>2];p[d+116>>2]=e;if(!xc(d+120|0,d+112|0)){break j}}e=q[a+60|0]!=0;break f}c=p[b+4>>2];p[d+248>>2]=p[b>>2];p[d+252>>2]=c;c=ic(d+240|0,38846);e=p[d+252>>2];p[d+104>>2]=p[d+248>>2];p[d+108>>2]=e;e=p[c+4>>2];p[d+96>>2]=p[c>>2];p[d+100>>2]=e;k:{if(!xc(d+104|0,d+96|0)){c=p[b+4>>2];p[d+232>>2]=p[b>>2];p[d+236>>2]=c;c=ic(d+224|0,39143);e=p[d+236>>2];p[d+88>>2]=p[d+232>>2];p[d+92>>2]=e;e=p[c+4>>2];p[d+80>>2]=p[c>>2];p[d+84>>2]=e;if(!xc(d+88|0,d+80|0)){break k}}e=q[a+61|0]!=0;break f}c=p[b+4>>2];p[d+216>>2]=p[b>>2];p[d+220>>2]=c;c=ic(d+208|0,38865);e=p[d+220>>2];p[d+72>>2]=p[d+216>>2];p[d+76>>2]=e;e=p[c+4>>2];p[d+64>>2]=p[c>>2];p[d+68>>2]=e;if(xc(d+72|0,d- -64|0)){e=q[a+62|0]!=0;break f}c=p[b+4>>2];p[d+200>>2]=p[b>>2];p[d+204>>2]=c;c=ic(d+192|0,38883);e=p[d+204>>2];p[d+56>>2]=p[d+200>>2];p[d+60>>2]=e;e=p[c+4>>2];p[d+48>>2]=p[c>>2];p[d+52>>2]=e;if(xc(d+56|0,d+48|0)){e=q[a+63|0]!=0;break f}c=p[b+4>>2];p[d+184>>2]=p[b>>2];p[d+188>>2]=c;c=ic(d+176|0,38907);e=p[d+188>>2];p[d+40>>2]=p[d+184>>2];p[d+44>>2]=e;e=p[c+4>>2];p[d+32>>2]=p[c>>2];p[d+36>>2]=e;if(xc(d+40|0,d+32|0)){e=q[a+64|0]!=0;break f}c=p[b+4>>2];p[d+168>>2]=p[b>>2];p[d+172>>2]=c;b=ic(d+160|0,38981);c=p[d+172>>2];p[d+24>>2]=p[d+168>>2];p[d+28>>2]=c;c=p[b+4>>2];p[d+16>>2]=p[b>>2];p[d+20>>2]=c;e=0;if(!xc(d+24|0,d+16|0)){break f}e=p[p[a+24>>2]+24668>>2]!=0}fb=d+352|0;return e|0}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function d7(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-112|0;fb=c;f=Xc(c+96|0);p[114610]=0;g=J(2,c+80|0,6848)|0;d=p[114610];p[114610]=0;a:{b:{c:{if((d|0)!=1){d=p[b+20>>2];if(d){break c}Wc(a,f);break a}a=I()|0;H()|0;break b}p[114610]=0;p[c+48>>2]=d+1900;K(191,c- -64|0,c+48|0);d=p[114610];p[114610]=0;d:{e:{if((d|0)!=1){p[114610]=0;J(192,f|0,c- -64|0)|0;d=p[114610];p[114610]=0;f:{if((d|0)!=1){pb(c- -64|0);if(s[b+16>>2]<12){break f}Wc(a,f);break a}a=I()|0;H()|0;pb(c- -64|0);break d}p[114610]=0;d=J(2,c+48|0,6850)|0;e=p[114610];p[114610]=0;g:{h:{i:{j:{k:{l:{if((e|0)!=1){e=p[b+16>>2];p[114610]=0;p[c+16>>2]=e+1;K(193,c+32|0,c+16|0);e=p[114610];p[114610]=0;if((e|0)==1){break l}p[114610]=0;N(3,c- -64|0,d|0,c+32|0);e=p[114610];p[114610]=0;if((e|0)==1){break k}p[114610]=0;J(192,f|0,c- -64|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break j}pb(c- -64|0);pb(c+32|0);pb(d);if(p[b+12>>2]+ -1>>>0<31){break g}Wc(a,f);break a}a=I()|0;H()|0;break d}a=I()|0;H()|0;break h}a=I()|0;H()|0;break i}a=I()|0;H()|0;pb(c- -64|0)}pb(c+32|0)}pb(d);break d}p[114610]=0;d=J(2,c+48|0,6850)|0;e=p[114610];p[114610]=0;m:{n:{o:{p:{q:{r:{s:{if((e|0)!=1){p[114610]=0;K(193,c+32|0,b+12|0);e=p[114610];p[114610]=0;if((e|0)==1){break s}p[114610]=0;N(3,c- -64|0,d|0,c+32|0);e=p[114610];p[114610]=0;if((e|0)==1){break r}p[114610]=0;J(192,f|0,c- -64|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break q}pb(c- -64|0);pb(c+32|0);pb(d);d=p[b+8>>2];if(d){break n}if(p[b+4>>2]|p[b>>2]){break m}Wc(a,f);break a}a=I()|0;H()|0;break d}a=I()|0;H()|0;break o}a=I()|0;H()|0;break p}a=I()|0;H()|0;pb(c- -64|0)}pb(c+32|0)}pb(d);break d}if(d>>>0<24){break m}Wc(a,f);break a}if(s[b+4>>2]>=60){Wc(a,f);break a}p[114610]=0;d=J(2,c- -64|0,6852)|0;e=p[114610];p[114610]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((e|0)!=1){p[114610]=0;J(192,f|0,d|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break F}pb(d);if(p[b+32>>2]>=1){p[114610]=0;d=J(2,c- -64|0,6854)|0;e=p[114610];p[114610]=0;if((e|0)==1){break E}xb(g,d);pb(d)}p[114610]=0;K(193,c+32|0,b+8|0);d=p[114610];p[114610]=0;if((d|0)==1){break D}p[114610]=0;d=J(2,c+16|0,6861)|0;e=p[114610];p[114610]=0;if((e|0)==1){break C}p[114610]=0;N(3,c+48|0,c+32|0,d|0);e=p[114610];p[114610]=0;if((e|0)==1){break B}p[114610]=0;K(193,c|0,b+4|0);e=p[114610];p[114610]=0;if((e|0)==1){break A}p[114610]=0;N(3,c- -64|0,c+48|0,c|0);e=p[114610];p[114610]=0;if((e|0)==1){break z}p[114610]=0;J(192,f|0,c- -64|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break y}pb(c- -64|0);pb(c);pb(c+48|0);pb(d);pb(c+32|0);if(s[b>>2]<62){break t}p[114610]=0;N(194,a|0,f|0,g|0);a=p[114610];p[114610]=0;if((a|0)!=1){break a}break e}a=I()|0;H()|0;break d}a=I()|0;H()|0;pb(d);break d}a=I()|0;H()|0;break d}a=I()|0;H()|0;break d}a=I()|0;H()|0;break u}a=I()|0;H()|0;break v}a=I()|0;H()|0;break w}a=I()|0;H()|0;break x}a=I()|0;H()|0;pb(c- -64|0)}pb(c)}pb(c+48|0)}pb(d)}pb(c+32|0);break d}p[114610]=0;d=J(2,c+48|0,6861)|0;e=p[114610];p[114610]=0;G:{H:{I:{J:{K:{if((e|0)!=1){p[114610]=0;K(193,c+32|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break K}p[114610]=0;N(3,c- -64|0,d|0,c+32|0);b=p[114610];p[114610]=0;if((b|0)==1){break J}p[114610]=0;J(192,f|0,c- -64|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break I}pb(c- -64|0);pb(c+32|0);pb(d);p[114610]=0;J(192,f|0,g|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}Wc(a,f);break a}a=I()|0;H()|0;break d}a=I()|0;H()|0;break G}a=I()|0;H()|0;break H}a=I()|0;H()|0;pb(c- -64|0)}pb(c+32|0)}pb(d);break d}a=I()|0;H()|0;break d}a=I()|0;H()|0}pb(g)}pb(f);L(a|0);E()}pb(g);pb(f);fb=c+112|0}function Of(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;l=fb-112|0;fb=l;n=h;m=i&2147483647;k=c+ -1|0;j=b+ -1|0;if((j|0)!=-1){k=k+1|0}o=j;r=(j|0)==-1&(k|0)==-1;q=e&2147483647;j=q;s=d;k=(c|0)==(k|0)&o>>>0<b>>>0|k>>>0<c>>>0;o=d+k|0;if(o>>>0<k>>>0){j=j+1|0}k=o+ -1|0;j=j+ -1|0;j=(k|0)!=-1?j+1|0:j;a:{b:{if(!((k|0)==-1&(j|0)==2147418111?r:j>>>0>2147418111)){k=g+ -1|0;j=f+ -1|0;if((j|0)!=-1){k=k+1|0}o=j;r=(j|0)!=-1|(k|0)!=-1;j=m;k=(g|0)==(k|0)&o>>>0<f>>>0|k>>>0<g>>>0;o=k+n|0;if(o>>>0<k>>>0){j=j+1|0}k=o+ -1|0;j=j+ -1|0;j=(k|0)!=-1?j+1|0:j;if((k|0)==-1&(j|0)==2147418111?r:(j|0)==2147418111&(k|0)!=-1|j>>>0<2147418111){break b}}if(!(!s&(q|0)==2147418112?!(b|c):(q|0)==2147418112&s>>>0<0|q>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!n&(m|0)==2147418112?!(f|g):(m|0)==2147418112&n>>>0<0|m>>>0<2147418112)){i=i|32768;break a}if(!(b|s|(q^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|n|(m^2147418112|g))){break a}if(!(b|s|(c|q))){if(f|n|(g|m)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|n|(g|m)){break b}f=b;g=c;h=d;i=e;break a}j=(n|0)==(s|0)&(m|0)==(q|0)?(c|0)==(g|0)&f>>>0>b>>>0|g>>>0>c>>>0:(m|0)==(q|0)&n>>>0>s>>>0|m>>>0>q>>>0;q=j?f:b;k=j?g:c;n=j?i:e;s=n;o=j?h:d;n=n&65535;i=j?e:i;e=i;h=j?d:h;r=i>>>16&32767;m=s>>>16&32767;if(!m){d=!(n|o);i=d<<6;m=y(d?q:o)+32|0;d=y(d?k:n);d=i+((d|0)==32?m:d)|0;ef(l+96|0,q,k,o,n,d+ -15|0);o=p[l+104>>2];n=p[l+108>>2];q=p[l+96>>2];m=16-d|0;k=p[l+100>>2]}f=j?b:f;g=j?c:g;i=e&65535;if(!r){b=!(h|i);c=b<<6;d=y(b?f:h)+32|0;b=y(b?g:i);b=c+((b|0)==32?d:b)|0;ef(l+80|0,f,g,h,i,b+ -15|0);r=16-b|0;h=p[l+88>>2];i=p[l+92>>2];g=p[l+84>>2];f=p[l+80>>2]}b=h;j=i<<3|b>>>29;h=b<<3|g>>>29;i=j|524288;b=o;d=n<<3|b>>>29;n=b<<3|k>>>29;t=d;o=e^s;b=f;j=g<<3|b>>>29;b=b<<3;c=j;d=m-r|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;j=0;e=1;break c}ef(l- -64|0,b,c,h,i,128-d|0);om(l+48|0,b,c,h,i,d);h=p[l+56>>2];i=p[l+60>>2];j=p[l+52>>2];e=p[l+48>>2]|((p[l+64>>2]|p[l+72>>2])!=0|(p[l+68>>2]|p[l+76>>2])!=0)}f=j;d=n;r=t|524288;b=q;j=k<<3|b>>>29;c=b<<3;d:{if((o|0)<-1?1:(o|0)<=-1){k=e;b=c-k|0;n=h;q=d-h|0;e=(f|0)==(j|0)&c>>>0<k>>>0|j>>>0<f>>>0;h=q-e|0;c=j-((c>>>0<k>>>0)+f|0)|0;i=(r-((d>>>0<n>>>0)+i|0)|0)-(q>>>0<e>>>0)|0;if(!(b|h|(c|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}f=b;d=!(h|i);e=d<<6;g=y(d?b:h)+32|0;b=y(d?c:i);b=e+((b|0)==32?g:b)|0;b=b+ -12|0;ef(l+32|0,f,c,h,i,b);m=m-b|0;h=p[l+40>>2];i=p[l+44>>2];b=p[l+32>>2];c=p[l+36>>2];break d}j=f+j|0;b=c+e|0;if(b>>>0<c>>>0){j=j+1|0}c=j;g=(f|0)==(j|0)&b>>>0<e>>>0|j>>>0<f>>>0;k=i+r|0;e=d+h|0;if(e>>>0<d>>>0){k=k+1|0}f=e;e=g+f|0;d=k;h=e;i=h>>>0<f>>>0?d+1|0:d;if(!(i&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);c=h<<31|c>>>1;m=m+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}k=0;n=s&-2147483648;if((m|0)>=32767){h=k;i=n|2147418112;f=0;g=0;break a}e=0;e:{if((m|0)>0){e=m;break e}ef(l+16|0,b,c,h,i,m+127|0);om(l,b,c,h,i,1-m|0);b=p[l>>2]|((p[l+16>>2]|p[l+24>>2])!=0|(p[l+20>>2]|p[l+28>>2])!=0);c=p[l+4>>2];h=p[l+8>>2];i=p[l+12>>2]}m=b&7;g=m>>>0>4;b=(c&7)<<29|b>>>3;d=h<<29|c>>>3;j=d;f=b+g|0;if(f>>>0<b>>>0){j=j+1|0}c=f;g=j;b=(d|0)==(j|0)&c>>>0<b>>>0|j>>>0<d>>>0;j=n|i>>>3&65535|e<<16;c=(i&7)<<29|h>>>3|k;b=c+b|0;if(b>>>0<c>>>0){j=j+1|0}h=b;i=j;f:{if((m|0)==4){b=0;d=b+g|0;c=f&1;f=c+f|0;if(f>>>0<c>>>0){d=d+1|0}g=d;b=(b|0)==(d|0)&f>>>0<c>>>0|d>>>0<b>>>0;c=b+h|0;if(c>>>0<b>>>0){j=j+1|0}h=c;i=j;break f}if(!m){break a}}}p[a>>2]=f;p[a+4>>2]=g;p[a+8>>2]=h;p[a+12>>2]=i;fb=l+112|0}function $Aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0;d=fb-256|0;fb=d;Ac(b);a:{if(!Lz(b,d+184|0)){break a}if(!oO(d+184|0)){break a}if(!Hb(b,dd(mO(d+184|0),ib))){break a}b:{if(!c){break b}xd(a,16);pn(d,2,d+184|4);zc(d+16|0,d);xb(a+1304400|0,d+16|0);pb(d+16|0);o[a+480190>>1]=q[d+214|0];o[a+480188>>1]=q[d+217|0];e=Mb(d+16|0,16538);xb(a+1304436|0,e);pb(e);e=Mb(d+16|0,16551);xb(a+1304448|0,e);pb(e);f=Mb(d+168|0,16555);p[114610]=0;K(219,d|0,f|0);e=p[114610];p[114610]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=d+184|3;p[d+152>>2]=q[e|0]>>>4;e=q[e|0];p[114610]=0;p[d+164>>2]=e&15;Q(534,d+16|0,d|0,d+152|0,d+164|0);e=p[114610];p[114610]=0;if((e|0)==1){break i}xb(a+1304460|0,d+16|0);pb(d+16|0);yb(d);pb(f);p[a+1304496>>2]=4;if(r[a+480190>>1]){e=1;g=1;while(1){oT(b,d+16|0);_Aa(d+16|0,(v(e,104)+a|0)+484380|0);xn(d+152|0,2,d+16|0);zc(d,d+152|0);p[114610]=0;J(369,((e<<5)+a|0)+946300|0,d|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break e}pb(d);g=g+1|0;e=g&65535;if(e>>>0<=r[a+480190>>1]){continue}break}}if(r[a+480188>>1]){e=0;while(1){f=(e<<5)+a|0;Fg(f+480280|0);o[f+480284>>1]=(q[(d+e|0)+218|0]<<4|8)&248;e=e+1|0;if(e>>>0<r[a+480188>>1]){continue}break}}ZAa(b,d+16|0);yT(Ob(a+484360|0),d+16|0,q[d+211|0]+1|0);if(q[d+216|0]){break g}j=64;break f}e=I()|0;H()|0;break h}e=I()|0;H()|0;yb(d)}pb(f);break c}j=q[d+216|0]}ld(d,b,v(q[d+208|0]|q[d+209|0]<<8,192));j:{k:{if(!(c&1)){break k}e=q[d+210|0];p[114610]=0;m=a+484344|0;K(401,m|0,e+1|0);e=p[114610];p[114610]=0;if((e|0)==1){break d}while(1){p[114610]=0;f=P(402,m|0,k&65535,j|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break j}e=0;if(!f){break k}while(1){p[114610]=0;f=M(357,b|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break d}s=e;l:{if(!f|f>>>0>(q[d+208|0]|q[d+209|0]<<8)>>>0){break l}e=s&65535;if(e>>>0>=r[a+480188>>1]){break l}p[114610]=0;J(256,d|0,v(f,192)+ -192|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}f=Rb(m,k);p[114610]=0;e=P(471,f|0,0,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}t=0;if(!j){break l}while(1){p[114610]=0;K(810,d+152|0,d|0);f=p[114610];p[114610]=0;m:{if((f|0)!=1){g=Zc(d+152|0);l=Tf(d+152|0);h=e;i=d+152|0;f=q[i|0];if(f>>>0>=4){n[e|0]=(f>>>2|0)+37;f=q[i|0]}n[h+1|0]=f<<4&48|q[g|0]>>>4;f=q[l|0];h=0;l=0;n:{o:{p:{q:{r:{g=q[g|0]&15;switch(g+ -8|0){case 0:break o;case 6:break q;case 2:break r;default:break p}}f=f&240?f&-16:f&15;g=10;break n}g=14;i=(f+16&240)>>>4|0;if(i>>>0>8){break n}if(1<<i&435){break o}break n}h=g;l=f}f=l;g=h;if(!((f|g)&255)){break m}}n[e+5|0]=f;n[e+3|0]=g;p[114610]=0;S(577,e|0);f=p[114610];p[114610]=0;if((f|0)!=1){break m}break d}break d}e=v(r[a+480188>>1],6)+e|0;t=t+1|0;if((t|0)!=(j|0)){continue}break}}e=s+1|0;if((s&65535)>>>0<31){continue}break}e=k>>>0<q[d+210|0];k=k+1|0;if(e){continue}break}}if(q[d+212|0]|q[d+213|0]<<8){e=q[d+212|0]|q[d+213|0]<<8;p[114610]=0;Z(549,a+1304424|0,b|0,e|0,39,1)|0;e=p[114610];p[114610]=0;if((e|0)==1){break d}}if(!(!(c&2)|!r[a+480190>>1])){f=1;while(1){c=v(f&65535,104)+a|0;e=Tc(d+152|0,o[c+484414>>1]&1?16:8,1,0,1);p[114610]=0;P(400,e|0,c+484380|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break d}f=f+1|0;if((f&65535)>>>0<=r[a+480190>>1]){continue}break}}p[a+480260>>2]=64;p[a+480264>>2]=32767;sb(d);break b}break d}e=I()|0;H()|0;pb(d);break c}e=I()|0;H()|0;sb(d)}L(e|0);E()}e=1}fb=d+256|0;return e|0}function GK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;d=c&15;g=v(b,896)+a|0;e=g+1074984|0;a:{b:{switch((c&240)+ -16>>>4|0){case 0:a=g+1075072|0;p[a>>2]=p[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(q[a+480209|0]&16)){break a}if(p[a+480180>>2]!=64){b=v(b,896)+a|0;c=d<<28>>24;p[b+1075752>>2]=c;d=r[(d<<1)+21392>>1];p[b+1075688>>2]=d;e=b+1075684|0;if(!p[e>>2]){break a}k=e,l=dg(a,q[b+1075803|0],c,d),p[k>>2]=l;break a}a=v(b,896)+a|0;b=p[a+1075088>>2];if(!b){break a}p[a+1075688>>2]=p[b+24>>2]+v(d,80);break a;case 2:if(p[a+480180>>2]==2){n[(v(b,896)+a|0)+1075826|0]=c&3;break a}vb(f+8|0,a+1074308|0,21);if(tb(f+8|0)){n[(v(b,896)+a|0)+1075826|0]=d>>>0<4?d:0;break a}n[(v(b,896)+a|0)+1075826|0]=c&7;break a;case 3:if(p[a+480180>>2]==2){n[(v(b,896)+a|0)+1075829|0]=c&3;break a}vb(f+8|0,a+1074308|0,21);if(tb(f+8|0)){n[(v(b,896)+a|0)+1075829|0]=d>>>0<4?d:0;break a}n[(v(b,896)+a|0)+1075829|0]=c&7;break a;case 4:vb(f+8|0,a+1074308|0,21);if(tb(f+8|0)){a=v(b,896)+a|0;n[a+1075825|0]=0;n[a+1075832|0]=d>>>0<4?d:0;break a}n[(v(b,896)+a|0)+1075832|0]=c&7;break a;case 5:if(p[a+1074392>>2]|!(q[a+480209|0]&16)){break a}a=a+1074400|0;p[a>>2]=p[a>>2]+d;break a;case 6:if(!(q[a+480209|0]&16)){break a}c:{switch(d|0){case 0:case 1:case 2:d=r[a+480188>>1];if(d>>>0>255){break a}e=a+1304392|0;i=b+1|0;j=(c&15)+ -1|0;while(1){c=v(d,896)+a|0;d:{if(r[c+1075792>>1]!=(i|0)){break d}e:{f:{switch(j|0){case 0:Nm(a,c+1074984|0);if(!(q[c+1075073|0]&2)){break e}if(!kd(e)){break e}_j(p[e>>2],d&65535);break e;case 1:h=c+1075072|0;g=p[h>>2];p[h>>2]=g|4096;if(!(g&512)){break e}if(!kd(e)){break e}_j(p[e>>2],d&65535);break e;default:break f}}p[c+1075680>>2]=0;h=c+1075072|0;g=p[h>>2];p[h>>2]=g|4096;if(!(g&512)){break e}if(!kd(e)){break e}ii(p[e>>2],d&65535,1)}g=p[c+1075640>>2];if(!g){break d}h=q[g+34|0];if(!h){break d}h=p[(v(h,160)+a|0)+906140>>2];if(!h){break d}m[p[p[h>>2]+88>>2]](h,g,q[c+1075803|0]+255|0,0,b)}d=d+1|0;if((d&65535)!=256){continue}break}break a;case 3:n[(v(b,896)+a|0)+1075804|0]=0;break a;case 4:n[(v(b,896)+a|0)+1075804|0]=1;break a;case 5:n[(v(b,896)+a|0)+1075804|0]=2;break a;case 6:n[(v(b,896)+a|0)+1075804|0]=3;break a;case 7:a=(v(b,896)+a|0)+1075708|0;n[a|0]=q[a|0]&254;break a;case 8:a=(v(b,896)+a|0)+1075708|0;n[a|0]=q[a|0]|1;break a;case 9:a=(v(b,896)+a|0)+1075720|0;n[a|0]=q[a|0]&254;break a;case 10:a=(v(b,896)+a|0)+1075720|0;n[a|0]=q[a|0]|1;break a;case 11:a=(v(b,896)+a|0)+1075732|0;n[a|0]=q[a|0]&254;break a;case 12:a=(v(b,896)+a|0)+1075732|0;n[a|0]=q[a|0]|1;break a;case 13:case 14:break c;default:break a}}if(p[a+480180>>2]!=16777216){break a}b=(v(b,896)+a|0)+1075732|0;a=q[b|0];n[b|0]=(d|0)==13?a&238|1:a|17;break a;case 7:if(!(q[a+480209|0]&16)){break a}kl(a,e,d,4);break a;case 8:Dpa(a,e,d);break a;case 9:if(!(q[a+480209|0]&16)){break a}c=v(b,896)+a|0;n[c+1075840|0]=d;vb(f+8|0,a+1074308|0,35);if(tb(f+8|0)){break a}if(!Sf(c+1075794|0)){break a}c=d<<16;if(c>>>0>=s[(v(b,896)+a|0)+1075060>>2]){break a}p[e+4>>2]=c;break a;case 11:g:{if(d){break g}d=1;if(p[a+480180>>2]&16777248){break g}d=0;if(p[a+480180>>2]==2){break a}}vb(f+8|0,a+1074308|0,30);c=a;if(tb(f+8|0)){a=1}else{a=p[a+480180>>2]==2}Bx(c,b,d,a);break a;case 14:break b;default:break a}}if(p[a+480180>>2]==2){break a}n[(v(b,896)+a|0)+1075848|0]=d}fb=f+16|0}function hna(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0;h=fb-16|0;fb=h;j=v(b,896)+a|0;e=p[j+1075640>>2];a:{if(!e){break a}f=q[e+34|0];if(!f|q[e+15|0]&2|(!p[(v(f,160)+a|0)+906140>>2]|p[(v(b,896)+a|0)+1075072>>2]&134218752)){break a}f=v(b,896)+a|0;k=f+1075797|0;l=q[k|0];i=f+1075805|0;if(Ud(q[i|0])){g=q[Yb(e+108|0,q[i|0]+ -1|0)|0]}i=f+1075794|0;b:{c:{if((l|0)==1){e=0;d:{e:{switch((s[a+1074392>>2]%3|0)+ -1|0){case 0:e=q[(v(b,896)+a|0)+1075812|0]>>>4|0;break d;case 1:break e;default:break d}}e=q[(v(b,896)+a|0)+1075812|0]&15}f=v(b,896)+a|0;n[f+1075807|0]=g;if(q[f+1075806|0]==(e+g|0)){break b}if(!(q[a+480209|0]&16)){break c}if(!Sf(i)){break c}break b}e=0;if(q[i|0]|!q[(v(b,896)+a|0)+1075806|0]){break b}}f=v(b,896)+a|0;Tj(a,b,q[f+1075807|0]+e|0,r[f+1075672>>1])}f=(v(b,896)+a|0)+1075806|0;m=q[f|0];f:{if(m){Tj(a,b,m+255|0,0);break f}if(!(q[a+480209|0]&16)|(l|0)!=1){break f}if(Sf(i)){break f}if(!Ud(g)){break f}Tj(a,b,g+255|0,0)}n[f|0]=q[k|0]==1?q[(v(b,896)+a|0)+1075807|0]+e|0:0}g:{if(q[j+1075811|0]!=1){break g}if(dj(j+1074984|0)){g=0;h:{i:{j:{switch(s[a+1074392>>2]%3|0){case 1:g=q[(v(b,896)+a|0)+1075812|0]>>>4|0;break i;case 0:break i;case 2:break j;default:break h}}g=q[(v(b,896)+a|0)+1075812|0]&15}o[d>>1]=g}a=(v(b,896)+a|0)+1075856|0;n[a|0]=q[a|0]|12;break g}if(!(!(q[a+480209|0]&16)|p[a+480180>>2]!=1048576)){d=v(b,896)+a|0;e=dg(a,q[d+1075803|0],p[d+1075752>>2],p[d+1075688>>2]);p[c>>2]=e;p[d+1075684>>2]=e}g=a+1074308|0;vb(h+8|0,g,13);if(tb(h+8|0)){g=q[(v(b,896)+a|0)+1075812|0];if(!g){break g}b=65536;k:{switch(((s[a+1074392>>2]%(p[a+1074400>>2]+p[a+1074416>>2]>>>0)>>>0)%3|0)+ -1|0){case 1:g=g<<4;case 0:b=p[((g&240)<<2)+25248>>2];break;default:break k}}e=Go(a);a=p[c>>2];d=a;a=a>>31;l:{if(e){b=NNa(d,a,b,b>>31)+32768|0;a=ib;a=ONa(b,b>>>0<32768?a+1|0:a,65536,0);b=ib;break l}a=a<<16|d>>>16;e=(b|0)/2|0;f=d<<16;d=e+f|0;a=a+(e>>31)|0;a=ONa(d,d>>>0<f>>>0?a+1|0:a,b,b>>31);b=ib}t=c,u=rc(a,b),p[t>>2]=u;break g}vb(h+8|0,g,51);if(tb(h+8|0)){if(q[a+480209|0]&16){break g}m:{n:{d=p[a+1074416>>2];d=d-(s[a+1074392>>2]%(d>>>0)|0)|0;if((d|0)>16){break n}if((d|0)==16){break g}e=0;o:{switch((d|0)%3|0){case 0:break g;case 2:break n;case 1:break o;default:break m}}e=q[(v(b,896)+a|0)+1075812|0]>>>4|0;break m}e=q[(v(b,896)+a|0)+1075812|0]&15}b=v(b,896)+a|0;d=b+1075752|0;b=b+1075688|0;e=Xr(a,p[c>>2],p[d>>2],p[b>>2])+e|0;d=dg(a,e,p[d>>2],p[b>>2]);p[c>>2]=d;if(e>>>0<109){break g}p[h+8>>2]=d;t=h,u=dg(a,109,0,p[b>>2]),p[t+4>>2]=u;t=c,u=p[Uc(h+8|0,h+4|0)>>2],p[t>>2]=u;break g}d=p[a+1074392>>2];if(p[a+480180>>2]!=1){e=q[(v(b,896)+a|0)+1075803|0]}else{e=v(b,896)+a|0;e=Xr(a,p[c>>2],p[e+1075752>>2],p[e+1075688>>2])}p:{q:{switch((((p[a+480180>>2]&67633152?d+2|0:d)>>>0)%3|0)+ -1|0){case 0:e=(q[(v(b,896)+a|0)+1075812|0]>>>4|0)+e|0;break p;case 1:break q;default:break p}}e=(q[(v(b,896)+a|0)+1075812|0]&15)+e|0}if(!(p[a+480180>>2]&67633408|q[(v(b,896)+a|0)+1075803|0]!=(e&255))){vb(h+8|0,g,82);if(!tb(h+8|0)){break g}}f=c;j=a;if(q[a+480210|0]&32){i=e&255;if((i|0)==85){p[c>>2]=2147483647;break g}e=i>>>0>85?e+ -37|0:e}d=v(b,896)+a|0;t=f,u=dg(j,e&255,p[d+1075752>>2],p[d+1075688>>2]),p[t>>2]=u;if(p[a+480180>>2]&71827712){p[d+1075684>>2]=p[c>>2];break g}vb(h+8|0,g,82);if(!tb(h+8|0)){break g}n[(v(b,896)+a|0)+1075806|0]=e}fb=h+16|0}function PD(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0;l=fb-16|0;fb=l;a:{b:{c:{d:{e:{f:{if(b>>>0<=36){while(1){f=p[a+4>>2];g:{if(f>>>0<s[a+104>>2]){p[a+4>>2]=f+1;f=q[f|0];break g}f=Sc(a)}if(im(f)){continue}break}h:{i:{switch(f+ -43|0){case 0:case 2:break i;default:break h}}m=(f|0)==45?-1:0;f=p[a+4>>2];if(f>>>0<s[a+104>>2]){p[a+4>>2]=f+1;f=q[f|0];break h}f=Sc(a)}j:{if(!(b&-17|(f|0)!=48)){f=p[a+4>>2];k:{if(f>>>0<s[a+104>>2]){p[a+4>>2]=f+1;f=q[f|0];break k}f=Sc(a)}if((f&-33)==88){b=16;f=p[a+4>>2];l:{if(f>>>0<s[a+104>>2]){p[a+4>>2]=f+1;f=q[f|0];break l}f=Sc(a)}if(q[f+57361|0]<16){break e}if(!p[a+104>>2]){d=0;e=0;if(c){break a}break b}b=p[a+4>>2];p[a+4>>2]=b+ -1;if(!c){break b}p[a+4>>2]=b+ -2;d=0;e=0;break a}if(b){break j}b=8;break e}b=b?b:10;if(b>>>0>q[f+57361|0]){break j}if(p[a+104>>2]){p[a+4>>2]=p[a+4>>2]+ -1}d=0;e=0;Rg(a,0,0);p[114584]=28;break a}if((b|0)!=10){break e}c=f+ -48|0;if(c>>>0<=9){b=0;while(1){b=v(b,10)+c|0;c=p[a+4>>2];m:{if(c>>>0<s[a+104>>2]){p[a+4>>2]=c+1;f=q[c|0];break m}f=Sc(a)}c=f+ -48|0;if(b>>>0<429496729?c>>>0<=9:0){continue}break}g=b}if(c>>>0>9){break f}i=NNa(g,0,10,0);j=ib;b=c;while(1){c=p[a+4>>2];n:{if(c>>>0<s[a+104>>2]){p[a+4>>2]=c+1;f=q[c|0];break n}f=Sc(a)}c=f+ -48|0;k=c>>>0>9;h=j;g=b+i|0;if(g>>>0<b>>>0){h=h+1|0}if((h|0)==429496729&g>>>0>=2576980378|h>>>0>429496729|k){break f}i=NNa(g,h,10,0);j=ib;b=c;if((j|0)==-1&i>>>0<=(c^-1)>>>0|(j|0)!=-1){continue}break}b=10;break d}p[114584]=28;d=0;e=0;break a}b=10;if(c>>>0<=9){break d}break c}if(b+ -1&b){c=q[f+57361|0];if(b>>>0>c>>>0){while(1){j=v(b,j)+c|0;i=j>>>0<=119304646;g=b;f=p[a+4>>2];o:{if(f>>>0<s[a+104>>2]){p[a+4>>2]=f+1;f=q[f|0];break o}f=Sc(a)}c=q[f+57361|0];if(g>>>0>c>>>0?i:0){continue}break}g=j}if(b>>>0<=c>>>0){break d}j=b;while(1){k=NNa(g,h,j,0);i=ib;c=c&255;if((i|0)==-1&k>>>0>(c^-1)>>>0){break d}h=i;f=c+k|0;if(f>>>0<c>>>0){h=h+1|0}g=f;i=b;f=p[a+4>>2];p:{if(f>>>0<s[a+104>>2]){p[a+4>>2]=f+1;f=q[f|0];break p}f=Sc(a)}c=q[f+57361|0];if(i>>>0<=c>>>0){break d}oh(l,j,0,g,h);if(!(p[l+8>>2]|p[l+12>>2])){continue}break}break d}i=n[(v(b,23)>>>5&7)+57617|0];c=q[f+57361|0];if(b>>>0>c>>>0){while(1){j=j<<i|c;k=j>>>0<=134217727;g=b;f=p[a+4>>2];q:{if(f>>>0<s[a+104>>2]){p[a+4>>2]=f+1;f=q[f|0];break q}f=Sc(a)}c=q[f+57361|0];if(g>>>0>c>>>0?k:0){continue}break}g=j}j=i;k=j&31;if(32<=(j&63)>>>0){i=0;k=-1>>>k|0}else{i=-1>>>k|0;k=(1<<k)-1<<32-k|-1>>>k}if(!i&k>>>0<g>>>0|i>>>0<0|b>>>0<=c>>>0){break d}while(1){o=c&255;c=j;f=c&31;if(32<=(c&63)>>>0){h=g<<f;c=0}else{h=(1<<f)-1&g>>>32-f|h<<f;c=g<<f}g=o|c;c=p[a+4>>2];r:{if(c>>>0<s[a+104>>2]){p[a+4>>2]=c+1;f=q[c|0];break r}f=Sc(a)}if((h|0)==(i|0)&g>>>0>k>>>0|h>>>0>i>>>0){break d}c=q[f+57361|0];if(b>>>0>c>>>0){continue}break}}if(b>>>0<=q[f+57361|0]){break c}while(1){c=b;f=p[a+4>>2];s:{if(f>>>0<s[a+104>>2]){p[a+4>>2]=f+1;f=q[f|0];break s}f=Sc(a)}if(c>>>0>q[f+57361|0]){continue}break}p[114584]=68;m=d&1?0:m;g=d;h=e}if(p[a+104>>2]){p[a+4>>2]=p[a+4>>2]+ -1}t:{if((e|0)==(h|0)&g>>>0<d>>>0|h>>>0<e>>>0){break t}if(!(d&1|m)){p[114584]=68;e=e+ -1|0;a=d+ -1|0;if((a|0)!=-1){e=e+1|0}d=a;break a}if((e|0)==(h|0)&g>>>0<=d>>>0|h>>>0<e>>>0){break t}p[114584]=68;break a}a=m;b=a^g;d=b-a|0;c=a>>31;e=(c^h)-(c+(b>>>0<a>>>0)|0)|0;break a}d=0;e=0;Rg(a,0,0)}fb=l+16|0;ib=e;return d}function Nb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a+ -8|0;c=p[a+ -4>>2];a=c&-8;f=d+a|0;b:{if(c&1){break b}if(!(c&3)){break a}c=p[d>>2];d=d-c|0;if(d>>>0<s[115924]){break a}a=a+c|0;if(p[115925]!=(d|0)){if(c>>>0<=255){e=p[d+8>>2];c=c>>>3|0;b=p[d+12>>2];if((b|0)==(e|0)){i=463680,j=p[115920]&SNa(-2,c),p[i>>2]=j;break b}p[e+12>>2]=b;p[b+8>>2]=e;break b}h=p[d+24>>2];c=p[d+12>>2];c:{if((d|0)!=(c|0)){b=p[d+8>>2];p[b+12>>2]=c;p[c+8>>2]=b;break c}d:{e=d+20|0;b=p[e>>2];if(b){break d}e=d+16|0;b=p[e>>2];if(b){break d}c=0;break c}while(1){g=e;c=b;e=c+20|0;b=p[e>>2];if(b){continue}e=c+16|0;b=p[c+16>>2];if(b){continue}break}p[g>>2]=0}if(!h){break b}e=p[d+28>>2];b=(e<<2)+463984|0;e:{if(p[b>>2]==(d|0)){p[b>>2]=c;if(c){break e}i=463684,j=p[115921]&SNa(-2,e),p[i>>2]=j;break b}p[h+(p[h+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break b}}p[c+24>>2]=h;b=p[d+16>>2];if(b){p[c+16>>2]=b;p[b+24>>2]=c}b=p[d+20>>2];if(!b){break b}p[c+20>>2]=b;p[b+24>>2]=c;break b}c=p[f+4>>2];if((c&3)!=3){break b}p[115922]=a;p[f+4>>2]=c&-2;p[d+4>>2]=a|1;p[a+d>>2]=a;return}if(f>>>0<=d>>>0){break a}c=p[f+4>>2];if(!(c&1)){break a}f:{if(!(c&2)){if(p[115926]==(f|0)){p[115926]=d;a=p[115923]+a|0;p[115923]=a;p[d+4>>2]=a|1;if(p[115925]!=(d|0)){break a}p[115922]=0;p[115925]=0;return}if(p[115925]==(f|0)){p[115925]=d;a=p[115922]+a|0;p[115922]=a;p[d+4>>2]=a|1;p[a+d>>2]=a;return}a=(c&-8)+a|0;g:{if(c>>>0<=255){b=p[f+8>>2];c=c>>>3|0;e=p[f+12>>2];if((b|0)==(e|0)){i=463680,j=p[115920]&SNa(-2,c),p[i>>2]=j;break g}p[b+12>>2]=e;p[e+8>>2]=b;break g}h=p[f+24>>2];c=p[f+12>>2];h:{if((f|0)!=(c|0)){b=p[f+8>>2];p[b+12>>2]=c;p[c+8>>2]=b;break h}i:{e=f+20|0;b=p[e>>2];if(b){break i}e=f+16|0;b=p[e>>2];if(b){break i}c=0;break h}while(1){g=e;c=b;e=c+20|0;b=p[e>>2];if(b){continue}e=c+16|0;b=p[c+16>>2];if(b){continue}break}p[g>>2]=0}if(!h){break g}e=p[f+28>>2];b=(e<<2)+463984|0;j:{if(p[b>>2]==(f|0)){p[b>>2]=c;if(c){break j}i=463684,j=p[115921]&SNa(-2,e),p[i>>2]=j;break g}p[h+(p[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break g}}p[c+24>>2]=h;b=p[f+16>>2];if(b){p[c+16>>2]=b;p[b+24>>2]=c}b=p[f+20>>2];if(!b){break g}p[c+20>>2]=b;p[b+24>>2]=c}p[d+4>>2]=a|1;p[a+d>>2]=a;if(p[115925]!=(d|0)){break f}p[115922]=a;return}p[f+4>>2]=c&-2;p[d+4>>2]=a|1;p[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;c=(a<<3)+463720|0;b=p[115920];a=1<<a;k:{if(!(b&a)){p[115920]=a|b;a=c;break k}a=p[c+8>>2]}p[c+8>>2]=d;p[a+12>>2]=d;p[d+12>>2]=c;p[d+8>>2]=a;return}p[d+16>>2]=0;p[d+20>>2]=0;f=d;e=a>>>8|0;b=0;l:{if(!e){break l}b=31;if(a>>>0>16777215){break l}c=e;e=e+1048320>>>16&8;b=c<<e;h=b+520192>>>16&4;b=b<<h;g=b+245760>>>16&2;b=(b<<g>>>15|0)-(g|(e|h))|0;b=(b<<1|a>>>b+21&1)+28|0}p[f+28>>2]=b;g=(b<<2)+463984|0;m:{n:{e=p[115921];c=1<<b;o:{if(!(e&c)){p[115921]=c|e;p[g>>2]=d;p[d+24>>2]=g;break o}e=a<<((b|0)==31?0:25-(b>>>1|0)|0);c=p[g>>2];while(1){b=c;if((p[c+4>>2]&-8)==(a|0)){break n}c=e>>>29|0;e=e<<1;g=b+(c&4)|0;c=p[g+16>>2];if(c){continue}break}p[g+16>>2]=d;p[d+24>>2]=b}p[d+12>>2]=d;p[d+8>>2]=d;break m}a=p[b+8>>2];p[a+12>>2]=d;p[b+8>>2]=d;p[d+24>>2]=0;p[d+12>>2]=b;p[d+8>>2]=a}a=p[115928]+ -1|0;p[115928]=a;if(a){break a}d=464136;while(1){a=p[d>>2];d=a+8|0;if(a){continue}break}p[115928]=-1}}function rHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-272|0;fb=e;dHa(e+24|0,b);p[114610]=0;g=P(677,e+128|0,e+24|0,8)|0;b=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){pb(e+24|0);if(c>>>0<2189){break g}p[114610]=0;b=J(685,e+24|0,g|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break c}p[114610]=0;c=J(686,e+8|0,14349)|0;d=p[114610];p[114610]=0;if((d|0)==1){break z}p[114610]=0;p[e>>2]=19464961;p[e+4>>2]=0;N(687,b|0,c|0,e|0);d=p[114610];p[114610]=0;if((d|0)==1){break y}yb(c);p[114610]=0;n[e|0]=0;c=J(686,e+8|0,14357)|0;d=p[114610];p[114610]=0;if((d|0)==1){break i}d=0;p[114610]=0;P(688,b|0,e|0,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break x}yb(c);if(!q[e|0]){p[114610]=0;d=M(689,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break w}}f=p[a+4>>2];p[114610]=0;c=J(686,e+8|0,14368)|0;h=p[114610];p[114610]=0;if((h|0)==1){break v}p[114610]=0;Q(690,b|0,f|0,c|0,d|0);f=p[114610];p[114610]=0;if((f|0)==1){break u}yb(c);p[114610]=0;c=J(686,e+8|0,14370)|0;f=p[114610];p[114610]=0;if((f|0)==1){break t}p[114610]=0;Q(691,b|0,a|0,c|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break s}yb(c);p[114610]=0;c=J(686,e+8|0,14372)|0;d=p[114610];p[114610]=0;if((d|0)==1){break r}p[114610]=0;d=a+484360|0;U(692,b|0,d|0,c|0,693)|0;f=p[114610];p[114610]=0;if((f|0)==1){break q}yb(c);p[114610]=0;c=J(686,e+8|0,14374)|0;f=p[114610];p[114610]=0;if((f|0)==1){break p}p[114610]=0;U(694,b|0,a+484344|0,c|0,695)|0;f=p[114610];p[114610]=0;if((f|0)==1){break o}yb(c);p[114610]=0;f=M(689,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break n}p[114610]=0;c=J(686,e+8|0,14380)|0;h=p[114610];p[114610]=0;if((h|0)==1){break m}p[114610]=0;Q(696,b|0,d|0,c|0,f|0);d=p[114610];p[114610]=0;if((d|0)==1){break l}yb(c);if(p[b>>2]&1073741824){p[114610]=0;c=J(2,e+8|0,14388)|0;d=p[114610];p[114610]=0;if((d|0)==1){break k}p[114610]=0;N(650,a|0,1,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break j}pb(c)}hg(b);break f}a=I()|0;H()|0;pb(e+24|0);break a}a=I()|0;H()|0;break h}a=I()|0;H()|0;yb(c);break h}a=I()|0;H()|0;yb(c);break h}a=I()|0;H()|0;break h}a=I()|0;H()|0;break h}a=I()|0;H()|0;yb(c);break h}a=I()|0;H()|0;break h}a=I()|0;H()|0;yb(c);break h}a=I()|0;H()|0;break h}a=I()|0;H()|0;yb(c);break h}a=I()|0;H()|0;break h}a=I()|0;H()|0;yb(c);break h}a=I()|0;H()|0;break h}a=I()|0;H()|0;break h}a=I()|0;H()|0;yb(c);break h}a=I()|0;H()|0;break h}a=I()|0;H()|0;pb(c);break h}a=I()|0;H()|0}hg(b);break b}b=Xc(e+24|0);d=p[a+4>>2];p[114610]=0;f=M(689,a|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break e}p[114610]=0;d=U(697,d|0,g|0,b|0,f|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}A:{if((d|0)!=1){p[114610]=0;c=J(2,e+8|0,14437)|0;d=p[114610];p[114610]=0;B:{if((d|0)!=1){p[114610]=0;N(650,a|0,1,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break B}pb(c);break A}a=I()|0;H()|0;break d}a=I()|0;H()|0;pb(c);break d}p[114610]=0;d=M(689,a|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}p[114610]=0;Q(698,g|0,a|0,d|0,c>>>0<2188|0);a=p[114610];p[114610]=0;if((a|0)==1){break e}}pb(b)}ff(g);fb=e+272|0;return}a=I()|0;H()|0}pb(b);break b}a=I()|0;H()|0}ff(g)}L(a|0);E()}function oKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0;e=fb-720|0;fb=e;Ac(b);f=e+104|0;g=iKa(b,f);if(!g){KR(f)}a:{if(!g){break a}if(!MR(e+104|0)){break a}b:{if(!c){break b}xd(a,67108864);ei(a);d=q[e+129|0];o[a+480190>>1]=31;o[a+480188>>1]=d;p[a+480228>>2]=256/(d>>>0);d=Mb(e,12631);xb(a+1304436|0,d);pb(d);d=Mb(e,12643);xb(a+1304448|0,d);pb(d);f=Mb(e+88|0,12648);p[114610]=0;K(219,e- -64|0,f|0);d=p[114610];p[114610]=0;c:{d:{if((d|0)!=1){p[e+84>>2]=q[e+128|0]>>>4;d=q[e+128|0];p[114610]=0;p[e+80>>2]=d&15;Q(534,e|0,e- -64|0,e+84|0,e+80|0);d=p[114610];p[114610]=0;if((d|0)!=1){xb(a+1304460|0,e);pb(e);yb(e- -64|0);pb(f);p[a+1304496>>2]=2;qn(Ob(a+484360|0),e+152|0,q[e+151|0]+1|0,65535,65535);f=0;while(1){d=f+1|0;i=v(d,104)+a|0;j=i+484380|0;vd(j,1);g=(e+104|0)+(f<<2)|0;h=q[g+176|0]|q[g+177|0]<<8|(q[g+178|0]<<16|q[g+179|0]<<24);p[j>>2]=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);h=q[g+300|0]|q[g+301|0]<<8|(q[g+302|0]<<16|q[g+303|0]<<24);k=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);p[i+484384>>2]=k;h=q[g+424|0]|q[g+425|0]<<8|(q[g+426|0]<<16|q[g+427|0]<<24);p[i+484388>>2]=k+(h<<24|h<<8&16711680|(h>>>8&65280|h>>>24));if(q[g+424|0]|q[g+425|0]<<8|(q[g+426|0]<<16|q[g+427|0]<<24)){g=i+484414|0;o[g>>1]=r[g>>1]|2}Ym(j);f=(e+104|0)+f|0;n[e|0]=q[f+548|0];n[e+64|0]=64;t=i+484410|0,u=q[hc(e,e- -64|0)|0]<<2,o[t>>1]=u;n[i+484417|0]=q[f+579|0]<<4;f=d;if((d|0)!=31){continue}break}Sz(b,a+1304400|0,32);d=1;while(1){jT(b,((d<<5)+a|0)+946300|0,30);d=d+1|0;if((d|0)!=32){continue}break}k=c&1;if(k){Pf(a+484344|0,q[e+150|0]+1|0)}j=a+484344|0;d=0;while(1){g=d;i=Hh(e- -64|0);e:{f:{g:{if(q[e+130|0]){p[114610]=0;d=M(484,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break f}p[114610]=0;N(341,e|0,b|0,d|0);break g}d=r[a+480188>>1];p[114610]=0;N(341,e|0,b|0,d<<8)}d=p[114610];p[114610]=0;if((d|0)==1){break f}Nd(i,e);sb(e);if(!k){break e}p[114610]=0;d=P(402,j|0,g&65535,64)|0;f=p[114610];p[114610]=0;if((f|0)==1){break f}if(!d){break e}h:{if(!q[e+130|0]){d=0;if(!r[a+480188>>1]){break e}while(1){f=0;while(1){h=Rb(j,g);p[114610]=0;h=P(471,h|0,f|0,d&65535)|0;l=p[114610];p[114610]=0;if((l|0)==1){break h}p[114610]=0;K(535,i|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break h}f=f+1|0;if((f|0)!=64){continue}break}d=d+1|0;if((d&65535)>>>0<r[a+480188>>1]){continue}break}break e}h=0;p[114610]=0;J(536,i|0,e|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){while(1){d=Rb(j,g);p[114610]=0;l=J(497,d|0,h|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}if(r[a+480188>>1]){m=e+h|0;d=128;f=0;while(1){i:{if(!(q[m|0]&d)){break i}p[114610]=0;K(535,i|0,l+v(f,6)|0);s=p[114610];p[114610]=0;if((s|0)!=1){break i}break f}d=d>>>1|0;f=f+1|0;if(f>>>0<r[a+480188>>1]){continue}break}}h=h+1|0;if((h|0)!=64){continue}break e}}}}d=I()|0;H()|0;sb(i);break c}sb(i);d=g+1|0;if(g>>>0<q[e+150|0]){continue}break}d=1;if(!(c&2)){break a}c=Tc(e,8,1,1,0);while(1){fg(c,(v(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}d=I()|0;H()|0;yb(e- -64|0);break d}d=I()|0;H()|0}pb(f)}L(d|0);E()}d=1}fb=e+720|0;return d|0}function sIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;e=fb-976|0;fb=e;Ac(b);g=e+872|0;f=oIa(b,g);if(!f){_Q(g)}a:{if(!f){break a}if(!bR(e+872|0)){break a}if(!Hb(b,dd(aR(e+872|0),ib))){break a}b:{if(!c){break b}xd(a,512);p[a+480228>>2]=32;o[a+480188>>1]=16;p[a+480196>>2]=q[e+947|0];p[a+480200>>2]=256;p[a+480204>>2]=8e5;d=Mb(e+96|0,12920);xb(a+1304436|0,d);pb(d);d=Mb(e+96|0,12939);xb(a+1304448|0,d);pb(d);p[a+1304496>>2]=4;$Q(e+24|0,2,e+872|4);zc(e+96|0,e+24|0);xb(a+1304400|0,e+96|0);pb(e+96|0);d=0;while(1){g=(d<<5)+a|0;f=g+480280|0;Fg(f);h=f;f=(e+872|0)+d|0;p[h>>2]=!q[f+50|0]<<10;o[g+480284>>1]=(q[f+76|0]<<4|8)&248;d=d+1|0;if((d|0)!=16){continue}break}if(q[e+968|0]|q[e+969|0]<<8){ey(a+1304424|0,b,q[e+968|0]|q[e+969|0]<<8,132,0)}d=0;if(!qIa(b,e+96|0)){break a}d=a+484360|0;vz(Ob(d),e+96|0,q[e+353|0],255,254);Pe(Ob(d),q[e+354|0]);Jc(b,q[e+919|0]|q[e+920|0]<<8);m=a+484344|0;t=c&1;g=0;c:{d:{while(1){d=(g<<1)+e|0;f=d+355|0;if(q[f|0]|q[f+1|0]<<8){ld(e+24|0,b,q[d+355|0]|q[d+356|0]<<8);d=q[d+355|0]|q[d+356|0]<<8;k=(d+ -2|0)/64|0;e:{if(!t){break e}p[114610]=0;f=P(402,m|0,g&65535,k|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break d}if(!f){break e}p[114610]=0;j=M(387,e+24|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}p[114610]=0;J(338,e+24|0,1)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}if(d>>>0>=66){u=k>>>0>1?k:1;h=0;while(1){d=Rb(m,g);p[114610]=0;w=J(497,d|0,h|0)|0;d=p[114610];p[114610]=0;l=0;if((d|0)==1){break d}while(1){p[114610]=0;K(598,e+80|0,e+24|0);d=p[114610];p[114610]=0;f:{g:{if((d|0)!=1){d=v(l,6)+w|0;x=Zc(e+80|0);f=Tf(e+80|0);s=vi(e+80|0);i=q[e+80|0];if((i+ -1&255)>>>0<72){break g}i=q[d|0];break f}break d}i=i+36|0;n[d|0]=i;n[d+1|0]=q[x|0]+1}if(q[f|0]|i&255){n[d+2|0]=1;y=d,z=(sd(q[f|0],1,16)<<2)+ -4|0,n[y+4|0]=z}f=q[s|0]&15;n[d+5|0]=f;h:{i:{switch((q[s|0]>>>4|0)+ -3|0){case 0:n[d+5|0]=f<<2;break h;case 1:n[d+5|0]=(6/(f+1>>>0)|0)+1;break h;case 3:case 4:n[d+5|0]=f<<3;break h;case 7:n[d+4|0]=(f<<2)+4;n[d+2|0]=1;break h;case 8:n[d+5|0]=f|128;break h;case 9:break i;default:break h}}n[d+5|0]=(6/(f+1>>>0)|0)+1|13}n[d+3|0]=q[(q[s|0]>>>4|0)+12944|0];l=l+1|0;if((l|0)!=16){continue}break}h=h+1|0;if((u|0)!=(h|0)){continue}break}}d=Rb(m,g);p[114610]=0;f=P(498,e+80|0,14,0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break d}f=wi(Oe(f,j?k+ -2>>>0>j>>>0?j+1|0:-1:-1));p[114610]=0;J(499,d|0,f|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break d}}sb(e+24|0)}g=g+1|0;if((g|0)!=256){continue}break}d=1;if(!(c&2)){break a}_R(b,e+72|0);d=0;while(1){j:{k:{if(!(q[e+72+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;break k}if(!uz(b,e+24|0)){break b}d=d+1|0;o[a+480190>>1]=d;Eg(e+8|0,1,e+24|0);zc(e+80|0,e+8|0);c=r[a+480190>>1];p[114610]=0;J(369,((c<<5)+a|0)+946300|0,e+80|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break j}pb(e+80|0);c=(v(d,104)+a|0)+484380|0;rIa(e+24|0,c);Tc(e+80|0,n[e+70|0]&1?16:8,1,0,0);fg(e+80|0,c,b)}if((d|0)!=64){continue}break b}break}d=I()|0;H()|0;pb(e+80|0);break c}d=I()|0;H()|0;sb(e+24|0)}L(d|0);E()}d=1}fb=e+976|0;return d|0}function oca(a){var b=0,c=0,d=0,e=0;b=fb-96|0;fb=b;e=Lb(a);p[114610]=0;S(236,b- -64|0);a=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((a|0)!=1){p[114610]=0;p[b+32>>2]=0;K(2118,b+48|0,b+32|0);a=p[114610];p[114610]=0;if((a|0)==1){break k}p[114610]=0;J(1251,e|0,b+48|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break j}pb(b+48|0);p[114610]=0;J(1995,e|0,38805)|0;a=p[114610];p[114610]=0;l:{if((a|0)==1){break l}p[114610]=0;p[b+32>>2]=5;K(2118,b+48|0,b+32|0);a=p[114610];p[114610]=0;if((a|0)==1){break i}p[114610]=0;J(1251,e|0,b+48|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break h}pb(b+48|0);p[114610]=0;J(1995,e|0,38805)|0;a=p[114610];p[114610]=0;if((a|0)==1){break l}p[114610]=0;p[b+32>>2]=3;K(2118,b+48|0,b+32|0);a=p[114610];p[114610]=0;if((a|0)==1){break g}p[114610]=0;J(1251,e|0,b+48|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break f}pb(b+48|0);p[114610]=0;a=J(85,b+48|0,38245)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}d=wb(a);pb(a);if(!d){break d}p[114610]=0;J(1995,e|0,38245)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break d}}a=I()|0;H()|0;break c}a=I()|0;H()|0;break b}a=I()|0;H()|0;break c}a=I()|0;H()|0;pb(b+48|0);break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;pb(b+48|0);break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;pb(b+48|0);break c}a=I()|0;H()|0;break c}d=Xg(b+48|0);m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if(p[(b- -64|0)+12>>2]){a=p[(b- -64|0)+12>>2];p[114610]=0;p[b+12>>2]=a;K(2118,b+16|0,b+12|0);a=p[114610];p[114610]=0;if((a|0)==1){break y}p[114610]=0;N(2119,b+32|0,39389,b+16|0);a=p[114610];p[114610]=0;if((a|0)==1){break x}p[114610]=0;K(1534,d|0,b+32|0);a=p[114610];p[114610]=0;if((a|0)==1){break w}pb(b+32|0);pb(b+16|0)}if(!q[(b- -64|0)+16|0]){break s}p[114610]=0;c=J(85,b+32|0,39391)|0;a=p[114610];p[114610]=0;if((a|0)==1){break u}p[114610]=0;K(1534,d|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break t}pb(c);break r}a=I()|0;H()|0;break m}a=I()|0;H()|0;break v}a=I()|0;H()|0;pb(b+32|0)}pb(b+16|0);break m}a=I()|0;H()|0;break m}a=I()|0;H()|0;pb(c);break m}if(!q[(b- -64|0)+17|0]){break r}p[114610]=0;c=J(85,b+32|0,39400)|0;a=p[114610];p[114610]=0;if((a|0)==1){break q}p[114610]=0;K(1534,d|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break p}pb(c)}if(q[(b- -64|0)+18|0]){break o}break n}a=I()|0;H()|0;break m}a=I()|0;H()|0;pb(c);break m}p[114610]=0;c=J(85,b+32|0,39406)|0;a=p[114610];p[114610]=0;z:{if((a|0)!=1){p[114610]=0;K(1534,d|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break z}pb(c);break n}a=I()|0;H()|0;break m}a=I()|0;H()|0;pb(c);break m}if(cd(d)){break a}p[114610]=0;J(1995,e|0,39410)|0;a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;c=J(85,b+16|0,38805)|0;a=p[114610];p[114610]=0;A:{B:{C:{if((a|0)!=1){p[114610]=0;N(2120,b+32|0,d|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break C}p[114610]=0;J(1251,e|0,b+32|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break B}pb(b+32|0);pb(c);break a}a=I()|0;H()|0;break m}a=I()|0;H()|0;break A}a=I()|0;H()|0;pb(b+32|0)}pb(c);break m}a=I()|0;H()|0}bd(d)}Se(b- -64|0)}pb(e);L(a|0);E()}bd(d);Se(b- -64|0);fb=b+96|0}function zx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;i=v(b,896)+a|0;m=i+1075782|0;h=o[m>>1];l=a+1074308|0;vb(g+8|0,l,23);e=c&15;a:{b:{if(tb(g+8|0)){if(!(p[a+1074392>>2]|!q[(v(b,896)+a|0)+1075794|0])){o[m>>1]=e;break b}f=r[m>>1];if(f){j=f+ -1|0;o[m>>1]=j;f=0;if(j&65535){break b}}o[m>>1]=e;f=1;break b}vb(g+8|0,l,52);j=c&256;if(!(!j|!tb(g+8|0))){c:{if(!(q[a+480209|0]&16)){break c}f=v(b,896)+a|0;if(q[f+1075795|0]){h=QQ(f+1075794|0)?1:h}if(!q[(v(b,896)+a|0)+1075798|0]|q[f+1075796|0]!=1){break c}o[m>>1]=h;break a}f=0;if((e|0)>(h|0)){break b}if(q[a+480209|0]&16){if(Sf((v(b,896)+a|0)+1075794|0)){break b}}h=0;f=1;break b}if(p[a+480180>>2]&16777250){f=h?!((h|0)%((e?e:1)|0)|0):0;h=h+1|0;break b}if(p[a+480180>>2]==16){f=p[a+1074392>>2]==(e|0)&(e|0)!=0;break b}d:{e:{f:{g:{h:{if(j){f=v(b,896)+a|0;if(q[f+1075796|0]==1){e=(q[f+1075799|0]>15)+e|0}e=e?e:1;break h}if(p[a+480208>>2]&4096?!j:0){break e}e=e?e:1;if(p[a+1074416>>2]){break g}}f=0;break f}f=!(s[a+1074392>>2]%(e>>>0)|0)}h=h+1|0;break d}h=p[a+480180>>2]&1048580?0:h}if(!((e|0)>h<<16>>16|(q[(v(b,896)+a|0)+1075794|0]|!j?!p[a+1074392>>2]:0))){f=1}vb(g+8|0,l,52);if(!tb(g+8|0)|c){break b}f=!p[a+1074392>>2]}j=i+1074984|0;k=(v(b,896)+a|0)+1075060|0;i:{if(p[k>>2]){break i}vb(g+8|0,l,38);if(!tb(g+8|0)){break i}if(!Zi(j)){break a}}vb(g+8|0,l,106);if(A=0,B=tb(g+8|0),C=p[(v(b,896)+a|0)+1075680>>2],C?A:B){break a}if(f){e=v(b,896)+a|0;u=e+1075672|0;p[g+4>>2]=p[u>>2];f=c>>>4&15;j:{if(!f){e=p[e+1075072>>2];break j}vb(g+8|0,l,52);k:{if(A=tb(g+8|0),B=0,C=q[(v(b,896)+a|0)+1075796|0]==1,C?A:B){break k}e=n[f+21808|0];if(e){p[g+4>>2]=v(e,p[g+4>>2])>>4;break k}p[g+4>>2]=p[g+4>>2]+(n[f+21824|0]<<2)}Vd(g+4|0,0,256);f=(v(b,896)+a|0)+1075072|0;e=p[f>>2]|2097152;p[f>>2]=e}t=v(b,896)+a|0;w=t+1075684|0;x=p[w>>2];f=q[t+1075808|0];i=0;if(e&512){vb(g+8|0,l,108);i=tb(g+8|0)}if(!(!p[k>>2]|i^1|(f+ -1&255)>>>0>119)){NK(a,b,0,f,1)}l:{if(!(p[a+480180>>2]&1048580)){e=0;break l}e=(c|0)<256;if((c|0)>255){break l}k=q[(v(b,896)+a|0)+1075795|0];if(!k){break l}e=1;Mo(a,j,k,0,0,1)}t=t+1075072|0;m:{if(!i){break m}k=(v(b,896)+a|0)+1075088|0;if(!p[k>>2]){break m}i=a+1304392|0;if(!kd(i)){break m}ii(p[i>>2],b,1);Ux(p[i>>2],b,p[k>>2]+68|0)}i=v(b,896)+a|0;k=i+1075644|0;y=p[k>>2];z=p[t>>2];p[k>>2]=0;vb(g+8|0,l,23);bs(a,j,f,tb(g+8|0),e,0,b);if(!q[i+1075795|0]){p[k>>2]=y}if(!(!(z&4096)|p[a+480180>>2]!=4)){p[t>>2]=p[t>>2]|4096}e=i+1075794|0;p[u>>2]=p[g+4>>2];if(r[a+480192>>1]){n[e|0]=f;qJ(a,b)}if(!(q[e|0]|(!(p[a+480180>>2]&16777248)|!x))){p[w>>2]=x}f=p[a+480180>>2];vb(g+8|0,l,23);if(tb(g+8|0)){p[j>>2]=0;p[j+4>>2]=0}f=f&16777250;n:{if(d+ -1>>>0>9){break n}e=p[(v(b,896)+a|0)+1075088>>2];if(!e){break n}o:{if((d|0)==1){b=p[(v(b,896)+a|0)+1075648>>2];break o}i=(v(b,896)+a|0)+1075648|0;b=p[(e+(d<<2)|0)+60>>2];p[i>>2]=b}Lo(a,j,b)}h=f?h:0}vb(g+8|0,l,52);a=tb(g+8|0);vb(g+8|0,l,23);if(tb(g+8|0)){break a}o[m>>1]=(a&c>>>8)+h}fb=g+16|0}function L6(a,b,c,d){var e=0,f=0,g=0,h=0,i=w(0),j=w(0),k=w(0),l=w(0),m=0,n=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0;h=fb-32|0;fb=h;p[d+4080>>2]=p[a+1152>>2];s=c+ -1|0;u=v(s,2304)+a|0;p[d+4084>>2]=p[u+1152>>2];p[d+4088>>2]=p[a>>2];p[d+4092>>2]=p[u>>2];p[d+4336>>2]=p[a+1156>>2];p[d+4340>>2]=p[u+1156>>2];p[d+4344>>2]=p[a+4>>2];p[d+4348>>2]=p[u+4>>2];x=(s<<1)+b|0;cr(x,c,d+244|0);s=c<<6;cr(s+x|0,c,d+500|0);cr(b,c,d+240|0);cr(b+s|0,c,d+496|0);q=49056;y=d+3840|0;f=14;while(1){s=f;n=v(31-f|0,72);e=n+a|0;i=t[e>>2];m=f<<4;g=m+y|0;p[g>>2]=p[e>>2];p[(m|4)+y>>2]=p[n+u>>2];e=n|4;p[(m|8)+y>>2]=p[e+a>>2];p[(m|12)+y>>2]=p[e+u>>2];n=v(f,72);e=n+76|0;p[g+256>>2]=p[e+a>>2];p[g+260>>2]=p[e+u>>2];e=n+72|0;p[g+ -248>>2]=p[e+a>>2];p[g+ -244>>2]=p[e+u>>2];k=t[q>>2];n=d+m|0;j=t[n>>2];l=t[q+4>>2];t[h+16>>2]=w(k*i)-w(j*l);t[h>>2]=w(j*k)+w(l*i);e=f<<2;f=1;while(1){m=f<<2;i=t[m+g>>2];j=t[m+n>>2];t[m+(h+16|0)>>2]=w(i*k)-w(j*l);t[h+m>>2]=w(j*k)+w(i*l);f=f+1|0;if((f|0)!=4){continue}break}r=(e<<2)+y|0;m=r+ -3584|0;n=r+ -256|0;k=t[q+12>>2];l=t[q+8>>2];f=0;while(1){g=f<<2;e=g+h|0;i=t[g+m>>2];j=t[g+n>>2];t[e>>2]=w(w(i*l)+w(j*k))+t[e>>2];e=g+(h+16|0)|0;t[e>>2]=w(w(i*k)-w(j*l))+t[e>>2];f=f+1|0;if((f|0)!=4){continue}break}m=r+ -3328|0;n=r+ -512|0;k=t[q+20>>2];l=t[q+16>>2];f=0;while(1){g=f<<2;e=g+h|0;i=t[g+m>>2];j=t[g+n>>2];t[e>>2]=w(w(i*l)+w(j*k))+t[e>>2];e=g+(h+16|0)|0;t[e>>2]=w(w(j*l)-w(i*k))+t[e>>2];f=f+1|0;if((f|0)!=4){continue}break}m=r+ -3072|0;n=r+ -768|0;k=t[q+28>>2];l=t[q+24>>2];f=0;while(1){g=f<<2;e=g+h|0;i=t[g+m>>2];j=t[g+n>>2];t[e>>2]=w(w(i*l)+w(j*k))+t[e>>2];e=g+(h+16|0)|0;t[e>>2]=w(w(i*k)-w(j*l))+t[e>>2];f=f+1|0;if((f|0)!=4){continue}break}m=r+ -2816|0;n=r+ -1024|0;k=t[q+36>>2];l=t[q+32>>2];f=0;while(1){g=f<<2;e=g+h|0;i=t[g+m>>2];j=t[g+n>>2];t[e>>2]=w(w(i*l)+w(j*k))+t[e>>2];e=g+(h+16|0)|0;t[e>>2]=w(w(j*l)-w(i*k))+t[e>>2];f=f+1|0;if((f|0)!=4){continue}break}m=r+ -2560|0;n=r+ -1280|0;k=t[q+44>>2];l=t[q+40>>2];f=0;while(1){g=f<<2;e=g+h|0;i=t[g+m>>2];j=t[g+n>>2];t[e>>2]=w(w(i*l)+w(j*k))+t[e>>2];e=g+(h+16|0)|0;t[e>>2]=w(w(i*k)-w(j*l))+t[e>>2];f=f+1|0;if((f|0)!=4){continue}break}m=r+ -2304|0;n=r+ -1536|0;k=t[q+52>>2];l=t[q+48>>2];f=0;while(1){g=f<<2;e=g+h|0;i=t[g+m>>2];j=t[g+n>>2];t[e>>2]=w(w(i*l)+w(j*k))+t[e>>2];e=g+(h+16|0)|0;t[e>>2]=w(w(j*l)-w(i*k))+t[e>>2];f=f+1|0;if((f|0)!=4){continue}break}m=r+ -2048|0;n=r+ -1792|0;k=t[q+60>>2];l=t[q+56>>2];f=0;while(1){g=f<<2;e=g+h|0;i=t[g+m>>2];j=t[g+n>>2];t[e>>2]=w(w(i*l)+w(j*k))+t[e>>2];e=g+(h+16|0)|0;t[e>>2]=w(w(i*k)-w(j*l))+t[e>>2];f=f+1|0;if((f|0)!=4){continue}break}e=v(15-s|0,c)<<1;z=e+x|0,A=Wh(t[h+20>>2]),o[z>>1]=A;f=v(s+17|0,c)<<1;z=f+x|0,A=Wh(t[h+4>>2]),o[z>>1]=A;z=b+e|0,A=Wh(t[h+16>>2]),o[z>>1]=A;z=b+f|0,A=Wh(t[h>>2]),o[z>>1]=A;e=v(47-s|0,c)<<1;z=e+x|0,A=Wh(t[h+28>>2]),o[z>>1]=A;f=v(s+49|0,c)<<1;z=f+x|0,A=Wh(t[h+12>>2]),o[z>>1]=A;z=b+e|0,A=Wh(t[h+24>>2]),o[z>>1]=A;z=b+f|0,A=Wh(t[h+8>>2]),o[z>>1]=A;f=s+ -1|0;q=q- -64|0;if(s){continue}break}fb=h+32|0}function nq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;a:{b:{c=p[a+4>>2];if(c&1){break b}if(!(c&3)){break a}c=p[a>>2];b=c+b|0;a=a-c|0;if((a|0)!=p[115925]){if(c>>>0<=255){e=c>>>3|0;c=p[a+8>>2];d=p[a+12>>2];if((d|0)==(c|0)){i=463680,j=p[115920]&SNa(-2,e),p[i>>2]=j;break b}p[c+12>>2]=d;p[d+8>>2]=c;break b}h=p[a+24>>2];c=p[a+12>>2];c:{if((c|0)!=(a|0)){d=p[a+8>>2];p[d+12>>2]=c;p[c+8>>2]=d;break c}d:{d=a+20|0;e=p[d>>2];if(e){break d}d=a+16|0;e=p[d>>2];if(e){break d}c=0;break c}while(1){g=d;c=e;d=c+20|0;e=p[d>>2];if(e){continue}d=c+16|0;e=p[c+16>>2];if(e){continue}break}p[g>>2]=0}if(!h){break b}d=p[a+28>>2];e=(d<<2)+463984|0;e:{if(p[e>>2]==(a|0)){p[e>>2]=c;if(c){break e}i=463684,j=p[115921]&SNa(-2,d),p[i>>2]=j;break b}p[h+(p[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}p[c+24>>2]=h;d=p[a+16>>2];if(d){p[c+16>>2]=d;p[d+24>>2]=c}d=p[a+20>>2];if(!d){break b}p[c+20>>2]=d;p[d+24>>2]=c;break b}c=p[f+4>>2];if((c&3)!=3){break b}p[115922]=b;p[f+4>>2]=c&-2;p[a+4>>2]=b|1;p[f>>2]=b;return}c=p[f+4>>2];f:{if(!(c&2)){if(p[115926]==(f|0)){p[115926]=a;b=p[115923]+b|0;p[115923]=b;p[a+4>>2]=b|1;if(p[115925]!=(a|0)){break a}p[115922]=0;p[115925]=0;return}if(p[115925]==(f|0)){p[115925]=a;b=p[115922]+b|0;p[115922]=b;p[a+4>>2]=b|1;p[a+b>>2]=b;return}b=(c&-8)+b|0;g:{if(c>>>0<=255){e=c>>>3|0;c=p[f+8>>2];d=p[f+12>>2];if((d|0)==(c|0)){i=463680,j=p[115920]&SNa(-2,e),p[i>>2]=j;break g}p[c+12>>2]=d;p[d+8>>2]=c;break g}h=p[f+24>>2];c=p[f+12>>2];h:{if((f|0)!=(c|0)){d=p[f+8>>2];p[d+12>>2]=c;p[c+8>>2]=d;break h}i:{d=f+20|0;e=p[d>>2];if(e){break i}d=f+16|0;e=p[d>>2];if(e){break i}c=0;break h}while(1){g=d;c=e;d=c+20|0;e=p[d>>2];if(e){continue}d=c+16|0;e=p[c+16>>2];if(e){continue}break}p[g>>2]=0}if(!h){break g}d=p[f+28>>2];e=(d<<2)+463984|0;j:{if(p[e>>2]==(f|0)){p[e>>2]=c;if(c){break j}i=463684,j=p[115921]&SNa(-2,d),p[i>>2]=j;break g}p[h+(p[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break g}}p[c+24>>2]=h;d=p[f+16>>2];if(d){p[c+16>>2]=d;p[d+24>>2]=c}d=p[f+20>>2];if(!d){break g}p[c+20>>2]=d;p[d+24>>2]=c}p[a+4>>2]=b|1;p[a+b>>2]=b;if(p[115925]!=(a|0)){break f}p[115922]=b;return}p[f+4>>2]=c&-2;p[a+4>>2]=b|1;p[a+b>>2]=b}if(b>>>0<=255){c=b>>>3|0;b=(c<<3)+463720|0;d=p[115920];c=1<<c;k:{if(!(d&c)){p[115920]=c|d;c=b;break k}c=p[b+8>>2]}p[b+8>>2]=a;p[c+12>>2]=a;p[a+12>>2]=b;p[a+8>>2]=c;return}p[a+16>>2]=0;p[a+20>>2]=0;d=a;e=b>>>8|0;c=0;l:{if(!e){break l}c=31;if(b>>>0>16777215){break l}g=e+1048320>>>16&8;e=e<<g;c=e+520192>>>16&4;f=e<<c;e=f+245760>>>16&2;c=(f<<e>>>15|0)-(e|(c|g))|0;c=(c<<1|b>>>c+21&1)+28|0}p[d+28>>2]=c;e=(c<<2)+463984|0;m:{d=p[115921];g=1<<c;n:{if(!(d&g)){p[115921]=d|g;p[e>>2]=a;break n}d=b<<((c|0)==31?0:25-(c>>>1|0)|0);c=p[e>>2];while(1){e=c;if((p[c+4>>2]&-8)==(b|0)){break m}c=d>>>29|0;d=d<<1;g=e+(c&4)|0;c=p[g+16>>2];if(c){continue}break}p[g+16>>2]=a}p[a+24>>2]=e;p[a+12>>2]=a;p[a+8>>2]=a;return}b=p[e+8>>2];p[b+12>>2]=a;p[e+8>>2]=a;p[a+24>>2]=0;p[a+12>>2]=e;p[a+8>>2]=b}}function HB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=fb-144|0;fb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if(p[19092]>=(c|0)){ku(a+96|0,c);p[114610]=0;c=J(2,a+80|0,1024)|0;d=p[114610];p[114610]=0;if((d|0)==1){break E}p[114610]=0;N(3,a+112|0,a+96|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break D}p[114610]=0;d=J(4,a+48|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break C}p[114610]=0;e=J(2,a+32|0,1027)|0;f=p[114610];p[114610]=0;if((f|0)==1){break B}p[114610]=0;N(5,a- -64|0,d|0,e|0);f=p[114610];p[114610]=0;if((f|0)==1){break A}p[114610]=0;N(3,a+128|0,a+112|0,a- -64|0);f=p[114610];p[114610]=0;if((f|0)==1){break z}pb(a- -64|0);pb(e);pb(d);pb(a+112|0);pb(c);pb(a+96|0);if(p[b>>2]){c=p[b>>2]}else{c=1030}p[114610]=0;K(6,a+112|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break t}if(p[b+4>>2]){c=p[b+4>>2]}else{c=1030}p[114610]=0;K(6,a+96|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break s}b=p[b+8>>2];p[114610]=0;p[a+64>>2]=b;K(7,a+80|0,a- -64|0);b=p[114610];p[114610]=0;if((b|0)==1){break r}p[114610]=0;b=J(8,461048,1031)|0;c=p[114610];p[114610]=0;if((c|0)==1){break q}p[114610]=0;N(9,a- -64|0,0,a+112|0);c=p[114610];p[114610]=0;if((c|0)==1){break p}p[114610]=0;b=J(10,b|0,a- -64|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break o}p[114610]=0;b=J(8,b|0,1044)|0;c=p[114610];p[114610]=0;if((c|0)==1){break o}p[114610]=0;N(9,a+32|0,0,a+80|0);c=p[114610];p[114610]=0;if((c|0)==1){break n}p[114610]=0;b=J(10,b|0,a+32|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break m}p[114610]=0;b=J(8,b|0,1046)|0;c=p[114610];p[114610]=0;if((c|0)==1){break m}p[114610]=0;b=J(8,b|0,1024)|0;c=p[114610];p[114610]=0;if((c|0)==1){break m}p[114610]=0;N(9,a+16|0,0,a+128|0);c=p[114610];p[114610]=0;if((c|0)==1){break l}p[114610]=0;b=J(10,b|0,a+16|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break k}p[114610]=0;b=J(8,b|0,1048)|0;c=p[114610];p[114610]=0;if((c|0)==1){break k}p[114610]=0;N(9,a|0,0,a+96|0);c=p[114610];p[114610]=0;if((c|0)==1){break j}p[114610]=0;b=J(10,b|0,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break i}p[114610]=0;b=J(8,b|0,1051)|0;c=p[114610];p[114610]=0;if((c|0)==1){break i}p[114610]=0;J(11,b|0,12)|0;b=p[114610];p[114610]=0;if((b|0)==1){break i}pb(a);pb(a+16|0);pb(a+32|0);pb(a- -64|0);pb(a+80|0);pb(a+96|0);pb(a+112|0);pb(a+128|0)}fb=a+144|0;return}b=I()|0;H()|0;break u}b=I()|0;H()|0;break v}b=I()|0;H()|0;break w}b=I()|0;H()|0;break x}b=I()|0;H()|0;break y}b=I()|0;H()|0;pb(a- -64|0)}pb(e)}pb(d)}pb(a+112|0)}pb(c)}pb(a+96|0);break a}b=I()|0;H()|0;break b}b=I()|0;H()|0;break c}b=I()|0;H()|0;break d}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;break f}b=I()|0;H()|0;break f}b=I()|0;H()|0;break g}b=I()|0;H()|0;break g}b=I()|0;H()|0;break h}b=I()|0;H()|0;break h}b=I()|0;H()|0;pb(a)}pb(a+16|0)}pb(a+32|0)}pb(a- -64|0)}pb(a+80|0)}pb(a+96|0)}pb(a+112|0)}pb(a+128|0)}L(b|0);E()}function zQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-144|0;fb=e;j=XGa(e+128|0);a:{b:{c:{if(d){p[114610]=0;N(713,a|0,j|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){break c}break b}p[114610]=0;N(714,a|0,j|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}}d=Hv(e+112|0);d:{e:{if(r[b+480192>>1]){c=1;k=1;while(1){p[114610]=0;o[e+110>>1]=0;J(715,a|0,e+110|0)|0;i=p[114610];p[114610]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((i|0)!=1){p[114610]=0;i=J(716,j|0,e+110|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}p[e+104>>2]=i;i=((c<<2)+b|0)+900380|0;if(!p[i>>2]){break f}c=pi(j);p[114610]=0;p[e+88>>2]=c;c=J(717,e+104|0,e+88|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break u}if(!c){break g}p[114610]=0;c=M(718,e+104|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break t}p[114610]=0;c=J(4,e+88|0,c+4|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break t}p[114610]=0;f=J(2,e+72|0,14549)|0;g=p[114610];p[114610]=0;if((g|0)==1){break i}g=op(c,f);pb(f);if(!g){break s}p[p[i>>2]+44>>2]=0;break r}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}f=p[b+4>>2];p[114610]=0;f=J(719,f|0,c|0)|0;g=p[114610];p[114610]=0;v:{w:{x:{y:{z:{A:{if((g|0)!=1){p[p[i>>2]+44>>2]=f;if(p[p[i>>2]+44>>2]){break r}p[114610]=0;f=J(2,e+72|0,14569)|0;g=p[114610];p[114610]=0;if((g|0)==1){break A}B:{C:{if(op(c,f)){pb(f);break C}p[114610]=0;g=J(2,e+56|0,14595)|0;h=p[114610];p[114610]=0;if((h|0)==1){break z}h=op(c,g);pb(g);pb(f);if(!h){break B}}p[114610]=0;K(720,e+72|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break y}g=p[b+4>>2];f=np(e+48|0,e+72|0);p[114610]=0;g=J(721,g|0,f|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break x}Qf(f);Qf(e+72|0);if(g){break r}}l=e,m=SGa(Ub(d),Vb(d),c),p[l+72>>2]=m;l=e,m=Vb(d),p[l+56>>2]=m;if(!ll(e+72|0,e+56|0)){break v}p[114610]=0;K(722,d|0,c|0);f=p[114610];p[114610]=0;if((f|0)!=1){break w}}b=I()|0;H()|0;break h}b=I()|0;H()|0;break h}b=I()|0;H()|0;pb(f);break h}b=I()|0;H()|0;break h}b=I()|0;H()|0;Qf(f);Qf(e+72|0);break h}p[114610]=0;f=J(2,e+16|0,14601)|0;g=p[114610];p[114610]=0;if((g|0)==1){break q}p[114610]=0;N(723,e+32|0,f|0,c|0);g=p[114610];p[114610]=0;if((g|0)==1){break p}p[114610]=0;g=J(2,e|0,14610)|0;h=p[114610];p[114610]=0;if((h|0)==1){break o}p[114610]=0;N(3,e+56|0,e+32|0,g|0);h=p[114610];p[114610]=0;if((h|0)==1){break n}h=Cy(e+72|0,e+56|0);p[114610]=0;K(627,b|0,h|0);h=p[114610];p[114610]=0;if((h|0)==1){break m}pb(e+72|0);pb(e+56|0);pb(g);pb(e+32|0);pb(f)}p[p[i>>2]+44>>2]=0}pb(c);break f}b=I()|0;H()|0;break h}b=I()|0;H()|0;break j}b=I()|0;H()|0;break k}b=I()|0;H()|0;break l}b=I()|0;H()|0;pb(e+72|0);pb(e+56|0)}pb(g)}pb(e+32|0)}pb(f);break h}b=I()|0;H()|0}pb(c);break d}if(!p[i>>2]){break f}p[p[i>>2]+44>>2]=0}k=k+1|0;c=k&65535;if(c>>>0<=r[b+480192>>1]){continue}break}}Xk(d);tQ(j);fb=e+144|0;return}b=I()|0;H()|0}Xk(d);break a}b=I()|0;H()|0}tQ(j);L(b|0);E()}function DG(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-224|0;fb=f;p[f+216>>2]=c;p[f+220>>2]=d;a:{if(Yi(b)){break a}d=q[Mj(b)|0];c=1;b:{if((d|0)==33){break b}if((d|0)!=63){break a}c=0}e=c;Xj(f+184|0,b,p[b+4>>2]+ -1|0);c=p[f+188>>2];p[b>>2]=p[f+184>>2];p[b+4>>2]=c}ud(f+184|0);c=p[f+184>>2];ud(f+168|0);g=Lj(c,p[f+172>>2],b);ud(f+184|0);c=p[b>>2];d=p[b+4>>2];c:{d:{e:{f:{if((g|0)==p[f+188>>2]){p[f+208>>2]=c;p[f+212>>2]=d;a=ic(f+200|0,38139);c=p[f+212>>2];p[f+16>>2]=p[f+208>>2];p[f+20>>2]=c;c=p[a+4>>2];p[f+8>>2]=p[a>>2];p[f+12>>2]=c;if(xc(f+16|0,f+8|0)){a=W(8)|0;p[114610]=0;K(2143,f+168|0,f+216|0);b=p[114610];p[114610]=0;g:{h:{i:{if((b|0)!=1){p[114610]=0;N(2119,f+184|0,39211,f+168|0);b=p[114610];p[114610]=0;if((b|0)==1){break i}dc(a,f+184|0);e=0;p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break e}b=I()|0;H()|0;pb(f+184|0);break h}b=I()|0;H()|0;break g}e=1;b=I()|0;H()|0}pb(f+168|0);if(!e){break f}}X(a|0);break f}if(!e){break c}c=W(8)|0;p[114610]=0;d=J(2142,f+136|0,b|0)|0;b=p[114610];p[114610]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){p[114610]=0;N(2119,f+152|0,39090,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break r}p[114610]=0;N(2137,f+168|0,f+152|0,39226);b=p[114610];p[114610]=0;a=1;if((b|0)==1){break q}p[114610]=0;K(2143,f+120|0,f+216|0);a=p[114610];p[114610]=0;if((a|0)==1){break p}p[114610]=0;N(138,f+184|0,f+168|0,f+120|0);b=p[114610];p[114610]=0;a=1;if((b|0)==1){break o}dc(c,f+184|0);p[114610]=0;N(2009,c|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break e}b=I()|0;H()|0;pb(f+184|0);a=0;break n}b=I()|0;H()|0;break j}a=1;b=I()|0;H()|0;break k}b=I()|0;H()|0;break l}a=1;b=I()|0;H()|0;break m}b=I()|0;H()|0}pb(f+120|0)}pb(f+168|0)}pb(f+152|0)}pb(d)}if(!a){break f}X(c|0);break f}p[f+112>>2]=c;p[f+116>>2]=d;c=ic(f+104|0,38139);d=p[f+116>>2];p[f+64>>2]=p[f+112>>2];p[f+68>>2]=d;d=p[c+4>>2];p[f+56>>2]=p[c>>2];p[f+60>>2]=d;if(!xc(f- -64|0,f+56|0)){break d}a=W(8)|0;p[114610]=0;K(2143,f+168|0,f+216|0);b=p[114610];p[114610]=0;s:{t:{u:{if((b|0)!=1){p[114610]=0;N(2119,f+184|0,39211,f+168|0);b=p[114610];p[114610]=0;if((b|0)==1){break u}dc(a,f+184|0);e=0;p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break e}b=I()|0;H()|0;pb(f+184|0);break t}b=I()|0;H()|0;break s}e=1;b=I()|0;H()|0}pb(f+168|0);if(!e){break f}}X(a|0)}L(b|0)}E()}c=p[b+4>>2];p[f+96>>2]=p[b>>2];p[f+100>>2]=c;c=ic(f+88|0,38925);d=p[f+100>>2];p[f+48>>2]=p[f+96>>2];p[f+52>>2]=d;d=p[c+4>>2];p[f+40>>2]=p[c>>2];p[f+44>>2]=d;if(xc(f+48|0,f+40|0)){qG(a,rc(p[f+216>>2],p[f+220>>2]));break c}c=p[b+4>>2];p[f+80>>2]=p[b>>2];p[f+84>>2]=c;b=ic(f+72|0,39073);c=p[f+84>>2];p[f+32>>2]=p[f+80>>2];p[f+36>>2]=c;c=p[b+4>>2];p[f+24>>2]=p[b>>2];p[f+28>>2]=c;if(!xc(f+32|0,f+24|0)){break c}b=rc(p[f+216>>2],p[f+220>>2]);p[p[a+32>>2]+40>>2]=b>>>0>3?1:b}fb=f+224|0}function $ja(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-80|0;fb=d;g=o[b+28>>1];e=o[c>>1];f=b+4|0;Bb(f);a:{b:{if((g|0)<=(e|0)){if((r[b+28>>1]+Bb(f)<<16)+ -65536>>16>=(e|0)){break b}}Xc(a);break a}c:{e=o[b+30>>1];if(!e){b=b+52|0;h=d,i=Hw(b,c),p[h+56>>2]=i;h=d,i=pi(b),p[h+40>>2]=i;if(!oi(d+56|0,d+40|0)){break c}Uf(a,$g(d+56|0)+4|0);break a}f=d;g=o[c>>1];d:{if((g|0)>=0){g=(g|0)%(e|0)|0;break d}g=e+((g^-1)%(e|0)^-1)|0}o[f+78>>1]=g;e=Xc(a);p[114610]=0;g=b+52|0;f=J(1599,g|0,d+78|0)|0;a=p[114610];p[114610]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((a|0)==1){break u}p[d+72>>2]=f;a=pi(g);p[114610]=0;p[d+56>>2]=a;f=J(1600,d+72|0,d+56|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break f}if(f){p[114610]=0;f=M(1601,d+72|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break u}p[114610]=0;J(237,e|0,f+4|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break u}b=o[b+30>>1];a=o[c>>1];v:{if((a|0)>=0){a=(a|0)/(b|0)|0;break v}a=((a+1|0)/(b|0)|0)+ -1|0}p[114610]=0;p[d+40>>2]=a+5;K(234,d+56|0,d+40|0);a=p[114610];p[114610]=0;w:{if((a|0)!=1){p[114610]=0;J(192,e|0,d+56|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break w}pb(d+56|0);break a}b=I()|0;H()|0;break e}b=I()|0;H()|0;pb(d+56|0);break e}if(o[b+30>>1]>26){break r}p[114610]=0;f=P(803,d+40|0,1,(q[d+78|0]<<24)+1090519040>>24)|0;a=p[114610];p[114610]=0;if((a|0)==1){break t}p[114610]=0;N(13,d+56|0,0,f|0);a=p[114610];p[114610]=0;if((a|0)==1){break s}xb(e,d+56|0);pb(d+56|0);pb(f);p[114610]=0;J(235,e|0,32339)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break q}}b=I()|0;H()|0;break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;pb(f);break e}p[114610]=0;p[d+36>>2]=o[d+78>>1]%16;K(1602,d+40|0,d+36|0);a=p[114610];p[114610]=0;if((a|0)==1){break p}p[114610]=0;p[d+20>>2]=(o[d+78>>1]/16<<16>>16)%16;K(1602,d+24|0,d+20|0);a=p[114610];p[114610]=0;if((a|0)==1){break o}p[114610]=0;N(3,d+56|0,d+40|0,d+24|0);a=p[114610];p[114610]=0;if((a|0)==1){break n}xb(e,d+56|0);pb(d+56|0);pb(d+24|0);pb(d+40|0);if(o[d+78>>1]<256){break q}p[114610]=0;N(9,d+8|0,0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break l}p[114610]=0;K(1603,d+40|0,d+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break k}p[114610]=0;N(13,d+56|0,0,d+40|0);a=p[114610];p[114610]=0;if((a|0)==1){break j}xb(e,d+56|0);pb(d+56|0);pb(d+40|0);pb(d+8|0)}b=o[b+30>>1];a=o[c>>1];if((a|0)<0){break h}a=(a|0)/(b|0)|0;break g}b=I()|0;H()|0;break e}b=I()|0;H()|0;break m}b=I()|0;H()|0;pb(d+24|0)}pb(d+40|0);break e}b=I()|0;H()|0;break e}b=I()|0;H()|0;break i}b=I()|0;H()|0;pb(d+40|0)}pb(d+8|0);break e}a=((a+1|0)/(b|0)|0)+ -1|0}p[114610]=0;p[d+40>>2]=a+5;K(234,d+56|0,d+40|0);a=p[114610];p[114610]=0;x:{if((a|0)!=1){p[114610]=0;J(192,e|0,d+56|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break x}pb(d+56|0);break a}b=I()|0;H()|0;break e}b=I()|0;H()|0;pb(d+56|0);break e}b=I()|0;H()|0}pb(e);L(b|0);E()}b=fb-16|0;fb=b;iia(a,c);fb=b+16|0}fb=d+80|0}function uK(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=w(0),x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=w(0),K=w(0),L=0,M=0;g=fb-48|0;fb=g;l=r[a+480192>>1]?p[(v(b,896)+a|0)+1075640>>2]:l;x=a+1074308|0;f=v(b,896)+a|0;y=f+1075805|0;B=f+1075672|0;C=f+1075772|0;z=f+1075748|0;A=f+1075744|0;D=f+1075704|0;E=f+1075676|0;F=f+1075668|0;G=f+1075648|0;H=f+1075792|0;I=f+1075072|0;j=e&127;J=w(j>>>0);s=f+1075855|0;K=w(q[s|0]);h=1;while(1){e=q[d+i|0];if(e){a:{b:{c:{d:{f=e+ -48|0;e:{if((f&255)>>>0<10){break e}if((e+ -65&255)>>>0<=5){f=e+ -55|0;break e}f=k;f:{switch(e+ -97|0){case 13:f=0;if(!Ud(q[y|0])){break c}f=q[y|0]+ -1|0;break c;case 21:vb(g+8|0,x,28);g:{if(!tb(g+8|0)){vb(g,x,1);e=0;if(!tb(g)){break g}}e=o[C>>1]}f=v(p[z>>2],p[A>>2]);e=v(p[a+1074444>>2],e+p[B>>2]|0);f=Pb((rc(ONa(NNa(f,f>>31,e,e>>31),ib,1048576,0),ib)|0)/2|0,1,127);break c;case 23:p[g+8>>2]=p[E>>2]/2;p[g>>2]=127;f=p[Yd(g+8|0,g)>>2];break c;case 24:p[g+8>>2]=p[F>>2]/2;p[g>>2]=127;f=p[Yd(g+8|0,g)>>2];break c;case 0:f=0;if(!l){break c}e=r[l+28>>1];if(!e){break c}f=e+ -1>>>7&127;break c;case 1:f=0;if(!l){break c}e=r[l+28>>1];if(!e){break c}f=e+ -1&127;break c;case 14:f=p[G>>2]>>>8|0;break c;case 7:e=b;if(r[a+480188>>1]<=e>>>0){e=q[H|0]+ -1|0}f=e&127;break c;case 12:f=p[I>>2]>>>7&1;break c;case 15:f=0;if(!l){break c}e=q[l+30|0];if(!e){break c}f=e+ -1&127;break c;case 25:t=s;e=j;h:{if(!c){break h}e=j;if(n[s|0]<0){break h}i:{if(k>>>0<3){break i}m=(g+16|0)+k|0;if(q[m+ -3|0]!=240){break i}e=j;if(q[m+ -2|0]>239){break h}}u=Fo(a,K,J);if(u<w(4294967296)&u>=w(0)){e=~~u>>>0;break h}e=0}f=e;n[t|0]=f;break c;case 18:while(1){j:{if(!f){f=0;break j}f=f+ -1|0;if(q[f+(g+16|0)|0]!=240){continue}}break}if(q[(g+16|0)+f|0]!=240|k-f>>>0<5){break a}m=0;e=f+5|0;if((k|0)!=(e|0)){while(1){m=q[(g+16|0)+e|0]+m|0;e=e+1|0;if((k|0)!=(e|0)){continue}break}}f=0-m&127;break c;case 2:break f;case 20:break d;default:break a}}f=Bpa(a,b)}e=(g+16|0)+k|0;k:{if(h&1){n[e|0]=f;break k}n[e|0]=q[e|0]<<4|f;k=k+1|0}e=(h^-1)&1;break b}e=v(p[z>>2],p[A>>2]);f=e;t=e>>31;e=v(p[a+1074444>>2],p[D>>2]);f=Pb((rc(ONa(NNa(f,t,e,e>>31),ib,67108864,0),ib)|0)/2|0,1,127)}e=((h^-1)&1)+k|0;n[e+(g+16|0)|0]=f;k=e+1|0;e=1}h=(e|0)!=0}i=i+1|0;if((i|0)!=31){continue}}break}e=((h^-1)&1)+k|0;l:{if(!e){break l}f=0;h=0;while(1){d=(g+16|0)+h|0;j=n[d|0];m:{n:{o:{if((j|0)==-16){if(e-h>>>0>=4){i=4;if((q[(g+h|0)+17|0]&254)==240){break n}}i=h;p:{while(1){i=i+1|0;if(i>>>0>=e>>>0){break p}if(q[(g+16|0)+i|0]!=247){continue}break}j=i-h|0;i=j+1|0;if(i>>>0>=j>>>0){break n}}n[(g+16|0)+e|0]=247;e=e+1|0;i=e-h|0;break o}if((j|0)>=0){if(f&255){h=h+ -1|0;n[h+(g+16|0)|0]=f;break m}h=h+1|0;f=0;break m}L=g,M=UM(j&255),p[L+8>>2]=M;p[g>>2]=e-h;i=p[Cb(g+8|0,g)>>2]}if(!i){break l}j=q[d|0];f=j>>>0<240?j:f}d=Apa(a,b,c,d,i);h=(d?d:i)+h|0}if(e>>>0>h>>>0){continue}break}}fb=g+48|0}function rna(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;l=fb-16|0;fb=l;a:{b:{c:{if(!p[a+1074376>>2]){m=a+1074448|0;c=m;p[c>>2]=0;p[c+4>>2]=0;p[a+1074456>>2]=p[a+1074444>>2];break c}h=p[a+1074456>>2];c=p[a+1074444>>2];d:{if((h|0)==(c|0)){c=p[a+1074448>>2];break d}p[a+1074456>>2]=c;e=a+24604|0;d=a+1074448|0;e:{if((c|0)>(h|0)){c=KM(e);break e}c=JM(e)}p[d>>2]=c;p[a+1074452>>2]=c}m=a+1074448|0;if((c|0)>=1){break b}}break a}h=(p[a+1074456>>2]<<12)-p[a+1074460>>2]|0;k=(h|0)/(c|0)|0;if(p[a+1074368>>2]!=2){break a}p[l+12>>2]=50;p[l+8>>2]=1e4/(p[a+1074452>>2]+1|0);c=k>>31;g=p[Gf(l+12|0,l+8|0)>>2];if((c+k^c)<=(g|0)){break a}c=p[a+1074448>>2];f=p[a+1074452>>2];while(1){c=c+f|0;k=(h|0)/(c|0)|0;e=k>>31;if((e^e+k)>(g|0)){continue}break}p[m>>2]=c}f:{g:{switch(p[a+24624>>2]+ -1|0){case 0:if((b|0)<1){break f}e=p[a+1074444>>2];f=e<<12;c=a+12|0;h=e;d=e>>31;g=0;while(1){h:{if(p[m>>2]>=1){e=p[a+1074460>>2]+k|0;p[a+1074460>>2]=e;j=p[c>>2];o=c,q=rc(ONa(NNa(j,j>>31,e,e>>31),ib,1048576,0),ib),p[o>>2]=q;p[a+1074448>>2]=p[a+1074448>>2]+ -1;break h}e=p[c>>2];o=c,q=rc(ONa(NNa(e,e>>31,h,d),ib,256,0),ib),p[o>>2]=q;p[a+1074460>>2]=f}c=c+4|0;g=g+1|0;if((g|0)!=(b|0)){continue}break}break f;case 1:if((b|0)<1){break f}e=p[a+1074444>>2];d=e<<12;c=a+12|0;h=e;e=e>>31;g=0;while(1){i:{if(p[m>>2]>=1){f=p[a+1074460>>2]+k|0;p[a+1074460>>2]=f;j=p[c>>2];o=c,q=rc(ONa(NNa(j,j>>31,f,f>>31),ib,1048576,0),ib),p[o>>2]=q;f=p[a+1074460>>2];i=f;j=f>>31;f=p[c+4>>2];o=c,q=rc(ONa(NNa(i,j,f,f>>31),ib,1048576,0),ib),p[o+4>>2]=q;p[a+1074448>>2]=p[a+1074448>>2]+ -1;break i}f=p[c>>2];o=c,q=rc(ONa(NNa(f,f>>31,h,e),ib,256,0),ib),p[o>>2]=q;f=p[c+4>>2];o=c,q=rc(ONa(NNa(f,f>>31,h,e),ib,256,0),ib),p[o+4>>2]=q;p[a+1074460>>2]=d}c=c+8|0;g=g+1|0;if((g|0)!=(b|0)){continue}break}break f;case 3:break g;default:break f}}if((b|0)<1){break f}h=p[a+1074444>>2];j=h<<12;c=a+12|0;g=a+8204|0;e=h;h=e>>31;f=0;while(1){j:{if(p[m>>2]>=1){d=p[a+1074460>>2]+k|0;p[a+1074460>>2]=d;i=p[c>>2];o=c,q=rc(ONa(NNa(i,i>>31,d,d>>31),ib,1048576,0),ib),p[o>>2]=q;d=p[a+1074460>>2];i=d;n=d>>31;d=p[c+4>>2];o=c,q=rc(ONa(NNa(i,n,d,d>>31),ib,1048576,0),ib),p[o+4>>2]=q;d=p[a+1074460>>2];i=d;n=d>>31;d=p[g>>2];o=g,q=rc(ONa(NNa(i,n,d,d>>31),ib,1048576,0),ib),p[o>>2]=q;d=p[a+1074460>>2];i=d;n=d>>31;d=p[g+4>>2];o=g,q=rc(ONa(NNa(i,n,d,d>>31),ib,1048576,0),ib),p[o+4>>2]=q;p[a+1074448>>2]=p[a+1074448>>2]+ -1;break j}d=p[c>>2];o=c,q=rc(ONa(NNa(d,d>>31,e,h),ib,256,0),ib),p[o>>2]=q;d=p[c+4>>2];o=c,q=rc(ONa(NNa(d,d>>31,e,h),ib,256,0),ib),p[o+4>>2]=q;d=p[g>>2];o=g,q=rc(ONa(NNa(d,d>>31,e,h),ib,256,0),ib),p[o>>2]=q;d=p[g+4>>2];o=g,q=rc(ONa(NNa(d,d>>31,e,h),ib,256,0),ib),p[o+4>>2]=q;p[a+1074460>>2]=j}g=g+8|0;c=c+8|0;f=f+1|0;if((f|0)!=(b|0)){continue}break}}fb=l+16|0}function o1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb+ -64|0;fb=h;p[h+56>>2]=b;p[e>>2]=0;qc(h,d);p[114610]=0;i=M(2449,h|0)|0;j=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Gb(h);switch(g+ -65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=I()|0;H()|0;Gb(h);L(a|0);E()}oD(a,f+24|0,h+56|0,c,e,i);break b}nD(a,f+16|0,h+56|0,c,e,i);break b}b=m[p[p[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=Li(a,p[h+56>>2],c,d,e,f,Ib(b),Ib(b)+(wb(b)<<2)|0),p[k+56>>2]=l;break b}n1(f+12|0,h+56|0,c,e,i);break b}g=p[15551];p[h+24>>2]=p[15550];p[h+28>>2]=g;g=p[15549];p[h+16>>2]=p[15548];p[h+20>>2]=g;g=p[15547];p[h+8>>2]=p[15546];p[h+12>>2]=g;g=p[15545];p[h>>2]=p[15544];p[h+4>>2]=g;k=h,l=Li(a,b,c,d,e,f,h,h+32|0),p[k+56>>2]=l;break b}g=p[15559];p[h+24>>2]=p[15558];p[h+28>>2]=g;g=p[15557];p[h+16>>2]=p[15556];p[h+20>>2]=g;g=p[15555];p[h+8>>2]=p[15554];p[h+12>>2]=g;g=p[15553];p[h>>2]=p[15552];p[h+4>>2]=g;k=h,l=Li(a,b,c,d,e,f,h,h+32|0),p[k+56>>2]=l;break b}m1(f+8|0,h+56|0,c,e,i);break b}l1(f+8|0,h+56|0,c,e,i);break b}k1(f+28|0,h+56|0,c,e,i);break b}j1(f+16|0,h+56|0,c,e,i);break b}i1(f+4|0,h+56|0,c,e,i);break b}h1(h+56|0,c,e,i);break b}g1(a,f+8|0,h+56|0,c,e,i);break b}g=ac(h,62240,44);k=g,l=Li(a,b,c,d,e,f,g,g+44|0),p[k+56>>2]=l;break b}p[h+16>>2]=p[15576];g=p[15575];p[h+8>>2]=p[15574];p[h+12>>2]=g;g=p[15573];p[h>>2]=p[15572];p[h+4>>2]=g;k=h,l=Li(a,b,c,d,e,f,h,h+20|0),p[k+56>>2]=l;break b}f1(f,h+56|0,c,e,i);break b}g=p[15587];p[h+24>>2]=p[15586];p[h+28>>2]=g;g=p[15585];p[h+16>>2]=p[15584];p[h+20>>2]=g;g=p[15583];p[h+8>>2]=p[15582];p[h+12>>2]=g;g=p[15581];p[h>>2]=p[15580];p[h+4>>2]=g;k=h,l=Li(a,b,c,d,e,f,h,h+32|0),p[k+56>>2]=l;break b}e1(f+24|0,h+56|0,c,e,i);break b}a=m[p[p[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=m[p[p[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=Li(a,p[h+56>>2],c,d,e,f,Ib(b),Ib(b)+(wb(b)<<2)|0),p[k+56>>2]=l;break b}mD(f+20|0,h+56|0,c,e,i);break b}d1(f+20|0,h+56|0,c,e,i);break b}if((g|0)==37){break c}}p[e>>2]=p[e>>2]|4;break b}b1(h+56|0,c,e,i)}a=p[h+56>>2]}fb=h- -64|0;return a|0}function Voa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0;p[a+24588>>2]=0;p[a+24592>>2]=0;p[a+4>>2]=0;p[a>>2]=20704;p[a+8>>2]=p[19851];b=a+24596|0;p[b>>2]=0;p[b+4>>2]=0;_o(a+24604|0);fK(a+24648|0,0);mfa(a+393352|0);p[a+480224>>2]=0;o[a+480212>>1]=0;p[a+480204>>2]=0;p[a+480208>>2]=0;p[a+480180>>2]=0;p[a+480184>>2]=0;b=a+480186|0;o[b>>1]=0;o[b+2>>1]=0;o[b+4>>1]=0;o[b+6>>1]=0;p[a+480240>>2]=65536;p[a+480244>>2]=65536;k=ux(a+480248|0);p[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{while(1){p[114610]=0;b=M(1389,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break l}b=b+32|0;if((c|0)!=(b|0)){continue}break}e=a+484344|0;Nna(e);p[e+12>>2]=a;p[114610]=0;l=J(1390,a+484360|0,a|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break k}c=a+900380|0;b=a+484380|0;while(1){p[114610]=0;b=J(1014,b|0,0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break j}b=b+104|0;if((c|0)!=(b|0)){continue}break}p[114610]=0;M(1391,a+901404|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break i}f=a+946300|0;h=a+906300|0;c=0;while(1){p[114610]=0;d=(v(c,160)+a|0)+906300|0;M(1392,d|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break h}c=c+1|0;if((c|0)!=250){continue}break}c=a+1074300|0;d=a+946300|0;b=d;while(1){p[114610]=0;b=M(1163,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break g}b=b+32|0;if((c|0)!=(b|0)){continue}break}p[a+1074300>>2]=0;p[a+1074304>>2]=0;tx(a+1074308|0);p[114610]=0;b=Y(1393)|0;c=p[114610];p[114610]=0;if((c|0)==1){break f}p[114610]=0;b=M(1394,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break f}p[a+1074324>>2]=b;p[114610]=0;M(1395,a+1074328|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;M(1396,a+1074376|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;c=P(1334,a+1304360|0,a|0,255)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}g=Qoa(a+1304392|0);m=Poa(a+1304396|0);q=Lb(a+1304400|0);r=Xc(a+1304412|0);i=a+1304424|0;Lb(i);s=dK(a+1304436|0);j=a+1304500|0;Loa(j);n[a+1304512|0]=0;Ooa(a+1304520|0);p[a+1304560>>2]=0;Do(a+12|0);$o(a+8204|0);$o(a+12300|0);b=a+1074408|0;p[b>>2]=4;p[b+4>>2]=16;p[a+480216>>2]=4;p[a+480220>>2]=16;cK(a+900380|0);p[114610]=0;S(1397,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=M(1398,12)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}p[b>>2]=0;p[b+4>>2]=0;p[b+8>>2]=0;Lna(b);p[a+4>>2]=b;return a|0}b=I()|0;H()|0;break a}b=I()|0;H()|0;break b}b=I()|0;H()|0;break c}b=I()|0;H()|0;break c}b=I()|0;H()|0;if(!c){break c}while(1){d=Im(d+ -160|0);if((h|0)!=(d|0)){continue}break}break c}b=I()|0;H()|0;break d}b=I()|0;H()|0;break d}b=I()|0;H()|0;sx(j);Ur(s);pb(i);pb(r);pb(q);Tr(m);Sr(g);Io(c)}while(1){f=Im(f+ -160|0);if((h|0)!=(f|0)){continue}break}}ps(l)}rx(e)}be(k);L(b|0);E()}function sU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=w(0),l=0,o=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=w(0),F=0,G=0;h=b<<2;A=r[a+480214>>1]!=0;d=a+1074328|0;k=t[d>>2];E=t[d+4>>2];while(1){f=(v(e,160)+a|0)+906300|0;d=p[f>>2];a:{if(!d|!p[d+24>>2]){break a}if(!fh(d+44|0)){break a}g=p[f>>2];if(!(m[p[p[g>>2]+108>>2]](g)|0)){m[p[p[g>>2]+104>>2]](g,1);m[p[p[g>>2]+116>>2]](g)}d=g+44|0;x=Fd(d,0);j=Fd(d,1);b:{if(n[g+28|0]&1){cy(p[g+24>>2],x,j,b,k);break b}d=g+40|0;if(!(p[g+36>>2]?0:!p[d>>2])){an(p[g+24>>2],b,d,g+36|0);cy(p[g+24>>2],x,j,b,k);break b}Jb(x,0,h);Jb(j,0,h)}p[g+28>>2]=p[g+28>>2]&-2;if(Zt(f)){break a}A=!(q[g+28|0]&4)|A}e=e+1|0;if((e|0)!=250){continue}break}C=a+12|0;g=a+12300|0;x=a+14348|0;cy(C,g,x,b,k);d=a+1074464|0;F=q[d|0];n[d|0]=0;h=g;d=x;while(1){i=(v(u,160)+a|0)+906300|0;f=p[i>>2];c:{if(!f|!p[f+24>>2]){break c}if(!fh(f+44|0)){break c}y=p[i>>2];d:{if(Zt(i)){break d}f=p[i>>2];if(m[p[p[f>>2]+140>>2]](f)|q[p[i>>2]+28|0]&2){break d}e=0;if(!u){break c}while(1){if((mj((v(e,160)+a|0)+906300|0)|0)==(u|0)){break d}e=e+1|0;if((u|0)!=(e|0)){continue}break}break c}f=y+44|0;B=Fd(f,0);D=Fd(f,1);o=p[i>>2];l=(h|0)==(B|0);h=l?g:h;j=h;d=l?x:d;c=i+28|0;f=d;e:{if(!(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))){break e}j=h;c=mj(i);f=d;if(u>>>0>=c>>>0){break e}f=d;if((c|0)==255){break e}c=p[(v(c,160)+a|0)+906300>>2];f=d;if(!c){break e}if(!(q[o+28|0]&4)){m[p[p[c>>2]+144>>2]](c)}c=c+44|0;f=d;if(!fh(c)){break e}j=Fd(c,0);f=Fd(c,1)}f:{if(!Zt(i)){break f}g:{if(l){break g}e=0;if(!b){break g}while(1){z=e<<2;c=z+B|0;l=h+z|0;t[c>>2]=t[c>>2]+t[l>>2];c=z+D|0;G=c;k=t[c>>2];c=d+z|0;t[G>>2]=k+t[c>>2];p[l>>2]=0;p[c>>2]=0;e=e+1|0;if((e|0)!=(b|0)){continue}break}}d=f;h=j;if(!(A&1)){break f}h=p[i>>2];if(h){m[p[p[h>>2]+144>>2]](h)}h=j;e=mj(i);if(e>>>0>249|u>>>0>=e>>>0){break f}while(1){h=e&255;d=(v(h,160)+a|0)+906300|0;e=mj(d);d=p[d>>2];if(d){m[p[p[d>>2]+144>>2]](d)}if(e>>>0>h>>>0?e>>>0<=249:0){continue}break}d=f;h=j}h:{i:{if(!((q[i+24|0]&2)>>>1|0)){if(!PA(i)|!(q[o+28|0]&4)){break i}}e=0;if(!b){break h}while(1){l=e<<2;c=l+j|0;t[c>>2]=t[c>>2]+t[l+B>>2];c=f+l|0;t[c>>2]=t[c>>2]+t[l+D>>2];e=e+1|0;if((e|0)!=(b|0)){continue}break}break h}if(F){m[p[p[y>>2]+124>>2]](y)}m[p[p[y>>2]+60>>2]](y,j,f,b);p[o+32>>2]=p[o+32>>2]+b;if(!PA(i)){break h}if((m[p[p[y>>2]+152>>2]](y)|0)<1|s[o+32>>2]<p[a+24620>>2]<<2>>>0){break h}e=0;j:{if(!b){break j}while(1){k:{c=e<<2;k=t[c+j>>2];if(k>=w(1.1920928955078125e-7)|k<=w(-1.1920928955078125e-7)){break k}k=t[c+f>>2];if(k>=w(1.1920928955078125e-7)|!(k>w(-1.1920928955078125e-7))){break k}e=e+1|0;if((e|0)!=(b|0)){continue}break j}break}p[o+32>>2]=0;break h}p[o+28>>2]=p[o+28>>2]|4}p[o+28>>2]=p[o+28>>2]&-3}u=u+1|0;if((u|0)!=250){continue}break}iva(h,d,C,b,E)}function I9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-192|0;fb=d;a:{if(Yi(b)){break a}e=q[Mj(b)|0];g=1;b:{if((e|0)==33){break b}if((e|0)!=63){break a}g=0}c=g;Xj(d+160|0,b,p[b+4>>2]+ -1|0);e=p[d+164>>2];p[b>>2]=p[d+160>>2];p[b+4>>2]=e}ud(d+160|0);e=p[d+160>>2];ud(d+144|0);e=Lj(e,p[d+148>>2],b);ud(d+160|0);c:{d:{e:{f:{if((e|0)==p[d+164>>2]){a=p[b+4>>2];p[d+184>>2]=p[b>>2];p[d+188>>2]=a;a=ic(d+176|0,38139);e=p[d+188>>2];p[d+8>>2]=p[d+184>>2];p[d+12>>2]=e;e=p[a+4>>2];p[d>>2]=p[a>>2];p[d+4>>2]=e;if(xc(d+8|0,d)){a=W(8)|0;p[114610]=0;c=J(85,d+160|0,39080)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(c);break d}f=0;if(!c){break f}a=W(8)|0;p[114610]=0;e=J(2142,d+144|0,b|0)|0;b=p[114610];p[114610]=0;g:{h:{i:{if((b|0)!=1){p[114610]=0;N(2119,d+160|0,39090,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break i}dc(a,d+160|0);c=0;p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break c}b=I()|0;H()|0;pb(d+160|0);break h}b=I()|0;H()|0;break g}c=1;b=I()|0;H()|0}pb(e);if(!c){break d}}X(a|0);break d}if(p[e+4>>2]!=2){a=W(8)|0;p[114610]=0;c=J(85,d+160|0,39104)|0;b=p[114610];p[114610]=0;if((b|0)!=1){dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(c);break d}b=I()|0;H()|0;X(a|0);break d}c=p[b+4>>2];p[d+136>>2]=p[b>>2];p[d+140>>2]=c;c=ic(d+128|0,38139);e=p[d+140>>2];p[d+72>>2]=p[d+136>>2];p[d+76>>2]=e;e=p[c+4>>2];p[d+64>>2]=p[c>>2];p[d+68>>2]=e;if(xc(d+72|0,d- -64|0)){a=W(8)|0;p[114610]=0;c=J(85,d+160|0,39080)|0;b=p[114610];p[114610]=0;if((b|0)!=1){dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(c);break d}b=I()|0;H()|0;X(a|0);break d}c=p[b+4>>2];p[d+120>>2]=p[b>>2];p[d+124>>2]=c;c=ic(d+112|0,38933);e=p[d+124>>2];p[d+56>>2]=p[d+120>>2];p[d+60>>2]=e;e=p[c+4>>2];p[d+48>>2]=p[c>>2];p[d+52>>2]=e;if(xc(d+56|0,d+48|0)){f=1;if(!q[a+28|0]){break f}f=65536/+s[p[a+24>>2]+480244>>2];break f}c=p[b+4>>2];p[d+104>>2]=p[b>>2];p[d+108>>2]=c;c=ic(d+96|0,38951);e=p[d+108>>2];p[d+40>>2]=p[d+104>>2];p[d+44>>2]=e;e=p[c+4>>2];p[d+32>>2]=p[c>>2];p[d+36>>2]=e;if(xc(d+40|0,d+32|0)){f=1;if(!q[a+28|0]){break f}f=+s[p[a+24>>2]+480240>>2]*152587890625e-16;break f}c=p[b+4>>2];p[d+88>>2]=p[b>>2];p[d+92>>2]=c;b=ic(d+80|0,39048);c=p[d+92>>2];p[d+24>>2]=p[d+88>>2];p[d+28>>2]=c;c=p[b+4>>2];p[d+16>>2]=p[b>>2];p[d+20>>2]=c;f=0;if(!xc(d+24|0,d+16|0)){break f}a=a+24|0;a;f=+s[p[a>>2]+480236>>2]*152587890625e-16}fb=d+192|0;return+f}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function zNa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0;e=fb-576|0;fb=e;Ac(b);d=e+72|0;g=uNa(b,d);if(!g){wT(d)}a:{if(!g){break a}if(!CT(e+72|0)){break a}b:{if(!c){break b}if(!Hb(b,dd(BT(e+72|0),ib))){break a}xd(a,64);p[a+480260>>2]=112;p[a+480264>>2]=13696;p[a+480204>>2]=78e4;p[a+480196>>2]=4;o[a+480188>>1]=8;d=Mb(e+40|0,11897);xb(a+1304436|0,d);pb(d);d=Mb(e+40|0,11910);xb(a+1304448|0,d);pb(d);Ec(a+1304460|0,r[e+72>>1]==26217?11897:11914);p[a+1304496>>2]=4;d=q[e+182|0];o[a+480190>>1]=d;c:{d:{e:{f:{if(d){f=1;g=1;while(1){xNa(b,e+40|0);if((q[e+53|0]|q[e+54|0]<<8|(q[e+55|0]<<16|q[e+56|0]<<24))>>>0>67108863){break d}yNa(e+40|0,(v(f,104)+a|0)+484380|0);yi(e+8|0,2,e+40|0);zc(e+24|0,e+8|0);p[114610]=0;J(369,((f<<5)+a|0)+946300|0,e+24|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}pb(e+24|0);g=g+1|0;f=g&65535;if(f>>>0<=r[a+480190>>1]){continue}break}}d=e+72|2;zT(e+24|0,3,d,36);zc(e+40|0,e+24|0);xb(a+1304400|0,e+40|0);pb(e+40|0);f=0;PM(a+1304424|0,ub(d),108,36,0);d=a+484360|0;yT(Ob(d),e+185|0,128);if(r[kc(Ob(d),q[e+184|0])>>1]<q[e+183|0]){break e}break c}a=I()|0;H()|0;pb(e+24|0);L(a|0);E()}Pe(Ob(d),q[e+184|0]);break c}f=0;break a}while(1){d=(f<<5)+a|0;Fg(d+480280|0);o[d+480284>>1]=f&1?208:48;f=f+1|0;if((f|0)!=8){continue}break}k=a+484344|0;Pf(k,q[e+183|0]);if(q[e+183|0]){m=c&1;while(1){g:{h:{if(m){if(ag(k,i&65535,64)){break h}}Sb(b,1536);break g}p[e+24>>2]=-1;p[e+28>>2]=-1;l=0;while(1){f=Jp(Rb(k,i),l);g=0;while(1){It(e+40|0,b);d=Zc(e+40|0);s=Tf(e+40|0);h=q[d|0];j=e+40|0;d=q[j|0];if(d>>>0<=253){n[f|0]=(d>>>2|0)+37;n[f+1|0]=(d<<4&48|h>>>4)+1;n[(e+24|0)+g|0]=255;d=q[j|0]}if((d|0)!=255){n[f+2|0]=1;n[f+4|0]=(((h&15)<<6|8)>>>0)/15}j=(e+24|0)+g|0;i:{j:{d=q[s|0];k:{if((d|0)!=255){n[j|0]=d;if(d&15|(d|0)==48){break k}break j}d=q[j|0];if((d|0)==255){break i}}h=d&15;n[f+5|0]=h;l:{if(d<<24>>24<0){break l}d=d>>>4|0;n[f+3|0]=q[d+11923|0];m:{switch(d+ -3|0){case 0:n[f+5|0]=h|32;break j;case 1:n[f+5|0]=h|h<<4;break i;case 2:break j;case 3:break m;default:break i}}n:{switch(h|0){case 0:n[f+5|0]=79;break i;case 1:break n;default:break l}}n[f+5|0]=244;break i}n[f+3|0]=0;break i}n[j|0]=255}f=f+6|0;g=g+1|0;if((g|0)!=8){continue}break}l=l+1|0;if((l|0)!=64){continue}break}d=(e+72|0)+i|0;f=d;if(q[d+369|0]<63){el(Rb(k,i),wi(Oe(Ip(e+40|0,14,0),q[f+369|0])))}el(Rb(k,i),wi(Ip(e+40|0,16,q[d+241|0])))}i=i+1|0;if(i>>>0<q[e+183|0]){continue}break}}f=1;if(!(c&2)){break a}c=Tc(e+40|0,8,1,0,1);if(!r[a+480190>>1]){break b}while(1){fg(c,(v(f&65535,104)+a|0)+484380|0,b);f=f+1|0;if((f&65535)>>>0<=r[a+480190>>1]){continue}break}}f=1}fb=e+576|0;return f|0}function wba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-160|0;fb=d;g=d+144|0;AG(g);p[g>>2]=83720;B9(g+4|0);h=a+24|0;wm(p[h>>2],g);f=q[a+62|0];e=q[a+61|0];i=q[a+60|0];j=p[h>>2];b=Re(d+128|0,b);p[114610]=0;i=i?13:15;e=e?i&14:i;f=P(2145,j|0,b|0,(f?e&3:e)|0)|0;e=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){sb(b);if(!f){b=W(8)|0;p[114610]=0;c=J(85,d+112|0,38522)|0;a=p[114610];p[114610]=0;if((a|0)!=1){dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}a=I()|0;H()|0;X(b|0);break b}r:{if(q[a+63|0]){break r}p[114610]=0;K(2146,a|0,a+36|0);b=p[114610];p[114610]=0;if((b|0)!=1){break r}a=I()|0;H()|0;break b}n[a+28|0]=1;wm(p[h>>2],p[a+4>>2]);p[114610]=0;K(2147,d+112|0,g|0);b=p[114610];p[114610]=0;if((b|0)==1){break q}k=d,l=Ub(d+112|0),p[k+104>>2]=l;k=d,l=Vb(d+112|0),p[k+96>>2]=l;if(Ab(d+104|0,d+96|0)){h=a+68|0;while(1){b=p[d+104>>2];f=p[b>>2];p[114610]=0;e=f;f=b+4|0;N(2148,a|0,e|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break e}b=p[b>>2];p[114610]=0;K(2149,d+32|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;N(9,d+48|0,0,d+32|0);b=p[114610];p[114610]=0;if((b|0)==1){break h}p[114610]=0;b=J(85,d+16|0,38541)|0;e=p[114610];p[114610]=0;if((e|0)==1){break j}p[114610]=0;N(138,d- -64|0,d+48|0,b|0);e=p[114610];p[114610]=0;if((e|0)==1){break l}p[114610]=0;N(805,d+80|0,d- -64|0,f|0);f=p[114610];p[114610]=0;if((f|0)==1){break n}p[114610]=0;K(1534,h|0,d+80|0);f=p[114610];p[114610]=0;if((f|0)==1){break o}pb(d+80|0);pb(d- -64|0);pb(b);pb(d+48|0);pb(d+32|0);Ff(d+104|0);if(Ab(d+104|0,d+96|0)){continue}break}}k=d,l=fn(c),p[k+80>>2]=l;k=d,l=pi(c),p[k+64>>2]=l;s:{while(1){p[114610]=0;b=J(2150,d+80|0,d- -64|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break d}if(!b){break p}p[114610]=0;c=M(2151,d+80|0)|0;b=p[114610];p[114610]=0;t:{if((b|0)==1){break t}p[114610]=0;b=J(120,d|0,c|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break t}p[114610]=0;Q(2081,a|0,b|0,c+12|0,0);c=p[114610];p[114610]=0;if((c|0)==1){break s}pb(b);p[114610]=0;M(2152,d+80|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){continue}break d}break}a=I()|0;H()|0;break c}a=I()|0;H()|0;pb(b);break c}a=I()|0;H()|0;sb(b);break b}a=I()|0;H()|0;break b}hw(d+112|0);nr(g);fb=d+160|0;return}a=I()|0;H()|0;pb(d+80|0);break m}a=I()|0;H()|0}pb(d- -64|0);break k}a=I()|0;H()|0}pb(b);break i}a=I()|0;H()|0}pb(d+48|0);break g}a=I()|0;H()|0}pb(d+32|0);break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}a=I()|0;H()|0}hw(d+112|0)}nr(g);L(a|0)}E()}function H1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-32|0;fb=h;p[h+24>>2]=b;p[e>>2]=0;qc(h+8|0,d);p[114610]=0;i=M(21,h+8|0)|0;j=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Gb(h+8|0);switch(g+ -65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=I()|0;H()|0;Gb(h+8|0);L(a|0);E()}rD(a,f+24|0,h+24|0,c,e,i);break b}qD(a,f+16|0,h+24|0,c,e,i);break b}b=m[p[p[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=Mi(a,p[h+24>>2],c,d,e,f,Ib(b),Ib(b)+wb(b)|0),p[k+24>>2]=l;break b}G1(f+12|0,h+24|0,c,e,i);break b}p[h+8>>2]=623865125;p[h+12>>2]=2032480100;k=h,l=Mi(a,b,c,d,e,f,h+8|0,h+16|0),p[k+24>>2]=l;break b}p[h+8>>2]=623728933;p[h+12>>2]=1680158061;k=h,l=Mi(a,b,c,d,e,f,h+8|0,h+16|0),p[k+24>>2]=l;break b}F1(f+8|0,h+24|0,c,e,i);break b}E1(f+8|0,h+24|0,c,e,i);break b}D1(f+28|0,h+24|0,c,e,i);break b}C1(f+16|0,h+24|0,c,e,i);break b}B1(f+4|0,h+24|0,c,e,i);break b}A1(h+24|0,c,e,i);break b}z1(a,f+8|0,h+24|0,c,e,i);break b}g=q[62159]|q[62160]<<8|(q[62161]<<16|q[62162]<<24);n[h+15|0]=g;n[h+16|0]=g>>>8;n[h+17|0]=g>>>16;n[h+18|0]=g>>>24;g=q[62156]|q[62157]<<8|(q[62158]<<16|q[62159]<<24);p[h+8>>2]=q[62152]|q[62153]<<8|(q[62154]<<16|q[62155]<<24);p[h+12>>2]=g;k=h,l=Mi(a,b,c,d,e,f,h+8|0,h+19|0),p[k+24>>2]=l;break b}n[h+12|0]=q[62167];p[h+8>>2]=q[62163]|q[62164]<<8|(q[62165]<<16|q[62166]<<24);k=h,l=Mi(a,b,c,d,e,f,h+8|0,h+13|0),p[k+24>>2]=l;break b}y1(f,h+24|0,c,e,i);break b}p[h+8>>2]=624576549;p[h+12>>2]=1394948685;k=h,l=Mi(a,b,c,d,e,f,h+8|0,h+16|0),p[k+24>>2]=l;break b}x1(f+24|0,h+24|0,c,e,i);break b}a=m[p[p[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=m[p[p[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=Mi(a,p[h+24>>2],c,d,e,f,Ib(b),Ib(b)+wb(b)|0),p[k+24>>2]=l;break b}pD(f+20|0,h+24|0,c,e,i);break b}w1(f+20|0,h+24|0,c,e,i);break b}if((g|0)==37){break c}}p[e>>2]=p[e>>2]|4;break b}v1(h+24|0,c,e,i)}a=p[h+24>>2]}fb=h+32|0;return a|0}function iba(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=fb-96|0;fb=d;a:{b:{c:{if(!(b<.8)){p[114610]=0;S(2158,d+24|0);e=p[114610];p[114610]=0;d:{e:{f:{g:{h:{if((e|0)!=1){c=p[c>>2];p[114610]=0;K(2159,d+8|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break h}wm(p[d+24>>2],p[d+8>>2]);e=p[d+24>>2];c=Re(d+80|0,a);p[114610]=0;a=P(2145,e|0,c|0,15)|0;e=p[114610];p[114610]=0;if((e|0)==1){break g}sb(c);if(a){a=p[d+24>>2];p[114610]=0;M(1402,a|0)|0;a=p[114610];p[114610]=0;f=1;if((a|0)==1){break f}}Nc(d+8|0);th(d+24|0);break b}a=O(0)|0;H()|0;break c}a=O(0)|0;H()|0;break d}a=O(0)|0;H()|0;sb(c);break e}a=O(0)|0;H()|0}Nc(d+8|0)}th(d+24|0);break c}if(!(b<.6)){p[114610]=0;S(2158,d+24|0);e=p[114610];p[114610]=0;i:{j:{k:{l:{m:{if((e|0)!=1){c=p[c>>2];p[114610]=0;K(2159,d+8|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break m}wm(p[d+24>>2],p[d+8>>2]);e=p[d+24>>2];c=Re(d- -64|0,a);p[114610]=0;a=P(2145,e|0,c|0,2)|0;e=p[114610];p[114610]=0;if((e|0)==1){break l}sb(c);if(a){a=p[d+24>>2];p[114610]=0;M(1402,a|0)|0;a=p[114610];p[114610]=0;f=.8;if((a|0)==1){break k}}Nc(d+8|0);th(d+24|0);break b}a=O(0)|0;H()|0;break c}a=O(0)|0;H()|0;break i}a=O(0)|0;H()|0;sb(c);break j}a=O(0)|0;H()|0}Nc(d+8|0)}th(d+24|0);break c}f=.2;if(!(b<.2)){p[114610]=0;S(2158,d+24|0);e=p[114610];p[114610]=0;n:{o:{p:{q:{r:{if((e|0)!=1){c=p[c>>2];p[114610]=0;K(2159,d+8|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break r}wm(p[d+24>>2],p[d+8>>2]);e=p[d+24>>2];c=Re(d+48|0,a);p[114610]=0;a=P(2145,e|0,c|0,0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break q}sb(c);f=0;if(a){a=p[d+24>>2];p[114610]=0;M(1402,a|0)|0;a=p[114610];p[114610]=0;f=.6;if((a|0)==1){break p}}Nc(d+8|0);th(d+24|0);break b}a=O(0)|0;H()|0;break c}a=O(0)|0;H()|0;break n}a=O(0)|0;H()|0;sb(c);break o}a=O(0)|0;H()|0}Nc(d+8|0)}th(d+24|0);break c}if(b<.1){break b}p[114610]=0;N(858,d+24|0,a|0,2048);c=p[114610];p[114610]=0;s:{t:{u:{if((c|0)!=1){p[114610]=0;c=M(412,d+24|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break t}e=p[d+24>>2];p[114610]=0;a=M(255,a|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break t}p[114610]=0;a=VB(2160,3,0,c,e,a,0);c=p[114610];p[114610]=0;if((c|0)==1){break t}a=a+1|0;if(a>>>0>=3){break u}f=u[(a<<3)+40424>>3];uc(d+24|0);break b}a=O(0)|0;H()|0;break c}c=W(8)|0;p[114610]=0;e=J(85,d+8|0,38139)|0;a=p[114610];p[114610]=0;if((a|0)!=1){dc(c,e);p[114610]=0;N(2009,c|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=O(0)|0;H()|0;pb(e);break s}a=O(0)|0;H()|0;X(c|0);break s}a=O(0)|0;H()|0}uc(d+24|0)}T(a|0)|0;V();f=0}fb=d+96|0;return+f}E()}function T6(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=w(0),s=0,u=0,v=0,x=0,y=0,z=0,A=0,B=0,C=0,D=w(0),E=0,F=0;m=p[b+4>>2];h=p[b>>2]+((m|0)/8|0)|0;l=q[h|0]|q[h+1|0]<<8|(q[h+2|0]<<16|q[h+3|0]<<24);g=(l<<24|l<<8&16711680|(l>>>8&65280|l>>>24))<<(m&7);f=m|-8;s=h+4|0;m=p[c>>2];a:{u=r[c+6>>1];if(!u){u=0;break a}while(1){l=c+C|0;h=q[l+15|0];z=(o[(h<<1)+47888>>1]<<1)+43504|0;l=q[l+18|0];b:{if(h>>>0<16){k=m;v=l;while(1){x=q[k|0]>>>1|0;y=(u|0)>(x|0)?x:u;n=t[d>>2];while(1){i=o[(g>>>26&62)+z>>1];if((i|0)<=-1){j=5;while(1){f=f+j|0;g=g<<j;j=i&7;i=o[((g>>>32-j|0)-(i>>3)<<1)+z>>1];if((i|0)<0){continue}break}}h=i>>8;f=h+f|0;g=g<<h;j=1;while(1){h=i&15;t[a>>2]=t[((h|16)+(g>>31<<4)<<2)+47984>>2]*n;i=i>>4;a=a+4|0;h=(h|0)!=0;f=h+f|0;g=g<<h;h=j&1;j=0;if(h){continue}break}if((f|0)>-1){while(1){g=q[s|0]<<f|g;h=(f|0)>7;f=f+ -8|0;s=s+1|0;if(h){continue}break}}y=y+ -1|0;if(y){continue}break}d=d+4|0;k=k+1|0;u=u-x|0;if((u|0)<1){m=k;break a}h=(v|0)>0;v=v+ -1|0;if(h){continue}break}break b}A=q[h+47952|0];E=32-A|0;h=m;x=l;while(1){B=q[h|0]>>>1|0;v=(u|0)>(B|0)?B:u;n=t[d>>2];while(1){j=o[(g>>>26&62)+z>>1];if((j|0)<=-1){i=5;while(1){g=g<<i;f=f+i|0;k=j&7;i=k;j=o[((g>>>32-i|0)-(j>>3)<<1)+z>>1];if((j|0)<0){continue}break}}k=j>>8;f=k+f|0;g=g<<k;y=1;while(1){F=a;k=j&15;c:{if((k|0)==15){i=g<<A;k=(g>>>E|0)+15|0;f=f+A|0;if((f|0)>=0){while(1){i=q[s|0]<<f|i;g=(f|0)>7;f=f+ -8|0;s=s+1|0;if(g){continue}break}}D=w(w(n*w(((i|0)>-1?1:-1)|0))*G6(k));break c}i=g;D=w(t[((k|16)+(g>>31<<4)<<2)+47984>>2]*n)}t[F>>2]=D;j=j>>4;a=a+4|0;k=(k|0)!=0;f=k+f|0;g=i<<k;k=y&1;y=0;if(k){continue}break}if((f|0)>-1){while(1){g=q[s|0]<<f|g;k=(f|0)>7;f=f+ -8|0;s=s+1|0;if(k){continue}break}}v=v+ -1|0;if(v){continue}break}d=d+4|0;h=h+1|0;u=u-B|0;if((u|0)<1){m=h;break a}k=(x|0)>0;x=x+ -1|0;if(k){continue}break}}C=C+1|0;m=(l+m|0)+1|0;continue}}j=1-u|0;while(1){d:{l=q[c+26|0]?47872:47840;i=q[l+(g>>>28|0)|0];if(!(i&8)){i=q[l+((g<<4>>>32-(i&3))+(i>>>3)|0)|0]}h=i&7;f=h+f|0;if(((f+(s-p[b>>2]<<3)|0)+ -24|0)>(e|0)){break d}j=j+ -1|0;l=d;e:{if(j){break e}j=q[m|0]>>>1|0;if(!j){break d}m=m+1|0;n=t[d>>2];l=d+4|0}g=g<<h;if(i&128){t[a>>2]=(g|0)<0?w(-n):n;f=f+1|0;g=g<<1}if(i&64){t[a+4>>2]=(g|0)<0?w(-n):n;f=f+1|0;g=g<<1}j=j+ -1|0;d=l;f:{if(j){break f}j=q[m|0]>>>1|0;if(!j){break d}m=m+1|0;n=t[l>>2];d=l+4|0}if(i&32){t[a+8>>2]=(g|0)<0?w(-n):n;f=f+1|0;g=g<<1}if(i&16){t[a+12>>2]=(g|0)<0?w(-n):n;f=f+1|0;g=g<<1}if((f|0)>=0){while(1){g=q[s|0]<<f|g;l=(f|0)>7;f=f+ -8|0;s=s+1|0;if(l){continue}break}}a=a+16|0;continue}break}p[b+4>>2]=e}function ima(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=r[a+4>>1];c=h+1|0;o[a+4>>1]=c;if((c&65535)>>>0>=r[p[a>>2]+480188>>1]){o[a+4>>1]=0}a:{if(Pm(b)){break a}g=p[a>>2];c=p[g+1074304>>2];g=p[g+480180>>2];b:{if((g|0)==2){if(q[b+3|0]!=23|c>>>0>=18415616){break b}Ke(b+5|0,64);break b}if(g&16777248){c:{if(q[a+6|0]|c>>>0>=18874368?c>>>0>=18285314:0){break c}d:{switch(q[b+3|0]+ -20|0){case 3:Ke(b+5|0,128);break c;case 0:break d;default:break c}}e=q[b+5|0];if((e|0)!=208){if((e|0)!=192){break c}n[b|0]=254;n[b+3|0]=0;break c}n[b+3|0]=0}e:{if(c>>>0>=18350080){d=0;if(q[a+6|0]|c>>>0>=18874368){break e}}f=q[b+3|0]+ -6&255;d=0;if(f>>>0>23){break e}d=8388643>>>f&1}e=q[b+3|0];f:{if(((e|0)==24|(e|0)==22)&c>>>0<18874368?0:!d){break f}d=q[b+5|0];f=d&15;if(!f|(f|0)==15){break f}d=d&240;if(!d|(d|0)==240){break f}if((e|0)==24){n[b+5|0]=d;break f}n[b+5|0]=f}if(!r[p[a>>2]+480192>>1]|((c|0)==19005440|c>>>0>=19005700)|(q[a+6|0]|r[p[a>>2]+480192>>1]>=q[b+1|0])){break b}n[b+4|0]=0;n[b+2|0]=1;break b}if((g|0)!=4){break b}g:{if(q[b+3|0]!=23|c>>>0>=19137026|(c>>>0<18874368?!(q[a+6|0]?c>>>0>=18285314:0):0)){break g}if(q[b+5|0]<65){break g}n[b+3|0]=0}if(!(q[b+3|0]!=10|(q[a+6|0]|c>>>0>=18874368?c>>>0>=18415616:0)|q[b+2|0]!=11)){n[b+3|0]=0}h:{if(q[b+2|0]!=11|c>>>0>=18874640|q[b+3|0]!=4){break h}e=q[b+4|0];if(q[a+6|0]?0:!e){break h}f=q[b+5|0];if(!f){break h}n[b+2|0]=0;i=b,j=wP(f+(e<<4)|0),n[i+5|0]=j}if(q[b+5|0]|(q[b+3|0]!=16|c>>>0>=19007241)){break b}n[b+3|0]=0}i:{if(c>>>0>=18874368){break i}e=0;j:{k:{l:{f=q[b+3|0];d=q[b+5|0]&240;if(!((f|0)!=28|(d|0)!=96)){if(!q[a+6|0]|(g|0)!=4){break l}e=c>>>0<18350080}if(!h){break j}if((f|0)==20&(d|0)==96|e){break k}break j}if(!h){break j}}a=v(0-h|0,6)+b|0;while(1){if(!((q[a+3|0]|8)!=28|(q[a+5|0]&240)!=96)){n[a+3|0]=0}a=a+6|0;if(a>>>0<b>>>0){continue}break}}if(!h|(q[b+5|0]&240)!=224|q[b+3|0]!=20){break i}a=v(0-h|0,6)+b|0;while(1){if(!(q[a+3|0]!=20|(q[a+5|0]&240)!=224)){n[a+3|0]=0}a=a+6|0;if(a>>>0<b>>>0){continue}break}}m:{if(q[b+2|0]!=8|c>>>0>=19333175|(c|0)==19333120){break m}n:{o:{p:{q:{a=q[b+3|0];switch(a+ -5|0){case 1:break m;case 0:break o;case 2:break q;default:break p}}if(!q[b+4|0]){break n}n[b+3|0]=11;break m}if((a|0)!=26){break m}}c=q[b+5|0];if(!(c&15)){n[b+2|0]=1280;n[b+3|0]=5;n[b+5|0]=c|q[b+4|0]&15;break m}r:{switch(a+ -5|0){case 1:break m;case 0:case 2:break n;default:break r}}if((a|0)!=26){break m}}n[b+2|0]=0}if(q[b+3|0]|((g|0)==16777216|q[b+2|0]!=15)){break a}n[b+2|0]=2560;n[b+3|0]=10;n[b+5|0]=q[b+4|0]<<3}}function TE(a,b){var c=0,d=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=fb-48|0;fb=j;h(+a);k=e(1)|0;d=e(0)|0;a:{b:{i=k;k=i;l=i&2147483647;c:{if(l>>>0<=1074752122){if((k&1048575)==598523){break c}if(l>>>0<=1073928572){if((i|0)>0?1:(i|0)>=0?d>>>0>=0:0){a=a+ -1.5707963267341256;c=a+ -6.077100506506192e-11;u[b>>3]=c;u[b+8>>3]=a-c+ -6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;u[b>>3]=c;u[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((i|0)>0?1:(i|0)>=0?d>>>0>=0:0){a=a+ -3.1415926534682512;c=a+ -1.2154201013012384e-10;u[b>>3]=c;u[b+8>>3]=a-c+ -1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;u[b>>3]=c;u[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(l>>>0<=1075594811){if(l>>>0<=1075183036){if((l|0)==1074977148){break c}if((i|0)>0?1:(i|0)>=0?d>>>0>=0:0){a=a+ -4.712388980202377;c=a+ -1.8231301519518578e-10;u[b>>3]=c;u[b+8>>3]=a-c+ -1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;u[b>>3]=c;u[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((l|0)==1075388923){break c}if((i|0)>0?1:(i|0)>=0?d>>>0>=0:0){a=a+ -6.2831853069365025;c=a+ -2.430840202602477e-10;u[b>>3]=c;u[b+8>>3]=a-c+ -2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;u[b>>3]=c;u[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(l>>>0>1094263290){break b}}n=a*.6366197723675814+6755399441055744+ -6755399441055744;c=a+n*-1.5707963267341256;m=n*6.077100506506192e-11;a=c-m;u[b>>3]=a;h(+a);d=e(1)|0;e(0)|0;i=l>>>20|0;k=(i-(d>>>20&2047)|0)<17;if(x(n)<2147483648){d=~~n}else{d=-2147483648}d:{if(k){break d}m=c;a=n*6.077100506303966e-11;c=c-a;m=n*2.0222662487959506e-21-(m-c-a);a=c-m;u[b>>3]=a;k=i;h(+a);i=e(1)|0;e(0)|0;if((k-(i>>>20&2047)|0)<50){break d}m=c;a=n*2.0222662487111665e-21;c=c-a;m=n*8.4784276603689e-32-(m-c-a);a=c-m;u[b>>3]=a}u[b+8>>3]=c-a-m;break a}if(l>>>0>=2146435072){a=a-a;u[b>>3]=a;u[b+8>>3]=a;d=0;break a}f(0,d|0);f(1,i&1048575|1096810496);a=+g();d=0;k=1;while(1){o=(j+16|0)+(d<<3)|0;if(x(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);u[o>>3]=c;a=(a-c)*16777216;d=1;o=k&1;k=0;if(o){continue}break}u[j+32>>3]=a;e:{if(a!=0){d=2;break e}k=1;while(1){d=k;k=d+ -1|0;if(u[(j+16|0)+(d<<3)>>3]==0){continue}break}}d=UE(j+16|0,j,(l>>>20|0)+ -1046|0,d+1|0,1);if((i|0)<-1?1:(i|0)<=-1){u[b>>3]=-u[j>>3];u[b+8>>3]=-u[j+8>>3];d=0-d|0;break a}i=p[j+4>>2];p[b>>2]=p[j>>2];p[b+4>>2]=i;i=p[j+12>>2];p[b+8>>2]=p[j+8>>2];p[b+12>>2]=i}fb=j+48|0;return d}function bya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0;e=fb-208|0;fb=e;Ac(b);a:{if(!uz(b,e+160|0)){break a}if(!eN(e+160|0)){break a}if(!c){h=1;break a}if(!Hb(b,dd(dN(e+160|0),ib))){break a}xd(a,128);Eg(e+144|0,2,e+175|0);zc(e+72|0,e+144|0);xb(a+1304400|0,e+72|0);pb(e+72|0);d=Mb(e+72|0,17409);xb(a+1304436|0,d);pb(d);d=Mb(e+72|0,17422);xb(a+1304448|0,d);pb(d);f=Mb(e+144|0,17426);p[114610]=0;N(1028,e+72|0,f|0,p[(q[e+174|0]<<2)+77292>>2]);d=p[114610];p[114610]=0;b:{c:{if((d|0)!=1){xb(a+1304460|0,e+72|0);pb(e+72|0);pb(f);p[a+480208>>2]=12;p[a+1304496>>2]=4;ey(a+1304424|0,b,q[e+207|0]<<5,32,0);s=a,t=td(b),o[s+480190>>1]=t;if(r[a+480190>>1]>3999){break a}if(!r[a+480190>>1]){break c}j=e+136|0;g=e+134|0;d=1;f=1;while(1){d:{if(q[e+174|0]>=52){Lz(b,e+72|0);break d}Yxa(b,e+72|0);i=q[g|0]|q[g+1|0]<<8;n[j|0]=i;n[j+1|0]=i>>>8;n[g|0]=8363;n[g+1|0]=32}aya(e+72|0,(v(d,104)+a|0)+484380|0);Eg(e+56|0,2,e+72|0);zc(e+144|0,e+56|0);p[114610]=0;J(369,((d<<5)+a|0)+946300|0,e+144|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){pb(e+144|0);f=f+1|0;d=f&65535;if(d>>>0<=r[a+480190>>1]){continue}break c}break}d=I()|0;H()|0;pb(e+144|0);break b}d=I()|0;H()|0;pb(f);break b}rp(Ob(a+484360|0),b,256,255,254);s=a,t=td(b)+1|0,o[s+480188>>1]=t;f=td(b);if(r[a+480188>>1]>127){break a}if(r[a+480188>>1]){d=0;while(1){g=(d<<5)+a|0;Fg(g+480280|0);g=g+480284|0;e:{if(q[e+174|0]>=51){i=(td(b)<<4|8)&248;break e}i=d&1?192:64}o[g>>1]=i;d=d+1|0;if(d>>>0<r[a+480188>>1]){continue}break}}g=a+484344|0;l=f+1|0;Pf(g,l);d=0;while(1){j=d&65535;if(!ag(g,j,64)){break a}d=d+1|0;if(j>>>0<f>>>0){continue}break}if(r[a+480188>>1]){f=0;while(1){m=jj(e+72|0);j=0;while(1){if(Hb(b,5)){h=0;d=_e(Rb(g,j),0,f&65535);while(1){k=$xa(m,b,q[e+174|0]);i=k+h|0;h=i>>>0>64?64-h|0:k;if(h){while(1){k=p[e+72>>2];n[d|0]=k;n[d+1|0]=k>>>8;n[d+2|0]=k>>>16;n[d+3|0]=k>>>24;k=r[e+76>>1];n[d+4|0]=k;n[d+5|0]=k>>>8;d=v(r[a+480188>>1],6)+d|0;h=h+ -1|0;if(h){continue}break}h=i;i=i>>>0<64;h=i?h:64;if(i){continue}}break}j=j+1|0;if((l|0)!=(j|0)){continue}}break}f=f+1|0;if((f&65535)>>>0<r[a+480188>>1]){continue}break}}f=_xa(e+8|0,r[a+480188>>1]);p[114610]=0;N(1029,e+32|0,g|0,f|0);d=p[114610];p[114610]=0;h=1;if((d|0)!=1){ce(e+32|0);ce(f);if(!(c&2)|!r[a+480190>>1]){break a}d=1;while(1){c=v(d&65535,104)+a|0;fg(Tc(e+72|0,o[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);d=d+1|0;if((d&65535)>>>0<=r[a+480190>>1]){continue}break}break a}d=I()|0;H()|0;ce(f)}L(d|0);E()}fb=e+208|0;return h|0}function Xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-48|0;fb=c;if(Ch(b)){g=Qj(b);j=p[b+12>>2];f=_ka(c+32|0,g);a:{if(!j){break a}while(1){e=p[p[a>>2]+ -12>>2];p[114610]=0;e=M(1575,a+e|0)|0;d=p[114610];p[114610]=0;b:{if((d|0)!=1){c:{if(!e){break a}p[114610]=0;n[c+31|0]=0;J(1576,a|0,c+31|0)|0;e=p[114610];p[114610]=0;d:{if((e|0)!=1){e=n[c+31|0];if(e){break d}i=i+1|0;break b}break c}n[c+30|0]=0;e:{if((e|0)>-1){break e}p[114610]=0;J(1576,a|0,c+30|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break e}break c}n[c+29|0]=0;ch(c+16|0);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{e=e&127;e=e-((e|0)!=0)&65535;k=e>>>0>=g>>>0;A:{B:{if(!k){p[114610]=0;h=P(471,b|0,i|0,e|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}if(n[c+30|0]&1){break B}break y}h=c+16|0;d=q[c+30|0];if(!(d&1)){break A}}p[114610]=0;J(1576,a|0,c+29|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}if(e>>>0<g>>>0){break z}d=q[c+30|0]}if(d&2){break x}break w}d=q[c+29|0];l=Fc(f,e),m=d,n[l|0]=m}l=h,m=q[Fc(f,e)|0],n[l|0]=m;if(!(q[c+30|0]&2)){break u}}p[114610]=0;J(1576,a|0,c+29|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}if(e>>>0<g>>>0){break v}d=q[c+30|0]}if(d&4){break t}break s}d=q[c+29|0];l=Fc(f,e),m=d,n[l+1|0]=m}l=h,m=q[Fc(f,e)+1|0],n[l+1|0]=m;if(!(q[c+30|0]&4)){break q}}p[114610]=0;J(1576,a|0,c+29|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}if(e>>>0<g>>>0){break r}d=q[c+30|0]}if(d&8){break p}break o}d=q[c+29|0];l=Fc(f,e),m=d,n[l+2|0]=m}l=h,m=q[Fc(f,e)+2|0],n[l+2|0]=m;if(!(q[c+30|0]&8)){break m}}p[114610]=0;J(1576,a|0,c+29|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}if(e>>>0<g>>>0){break n}d=q[c+30|0]}if(d&16){break l}break k}d=q[c+29|0];l=Fc(f,e),m=d,n[l+4|0]=m}l=h,m=q[Fc(f,e)+4|0],n[l+4|0]=m;if(!(q[c+30|0]&16)){break i}}p[114610]=0;J(1576,a|0,c+29|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}if(e>>>0<g>>>0){break j}d=q[c+30|0]}if(d&32){break h}break f}d=q[c+29|0];l=Fc(f,e),m=d,n[l+3|0]=m}l=h,m=q[Fc(f,e)+3|0],n[l+3|0]=m;if(!(q[c+30|0]&32)){break g}}p[114610]=0;J(1576,a|0,c+29|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}if(k){break f}d=q[c+29|0];l=Fc(f,e),m=d,n[l+5|0]=m}l=h,m=q[Fc(f,e)+5|0],n[l+5|0]=m}if(!(q[c+30|0]&64)){break b}p[114610]=0;J(1576,a|0,c+15|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){e=q[c+15|0];p[114610]=0;P(1577,a|0,e|0,-1)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break b}}}}a=I()|0;H()|0;wl(f);L(a|0);E()}if(i>>>0<j>>>0){continue}break}}wl(f)}fb=c+48|0}function cqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,s=0,t=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=fb-32|0;fb=f;t=a+4|0;s=p[t>>2];o=a+20|0;y=p[Gc(o,b)+16>>2];a:{if(y+1>>>0<2){break a}h=(v(b,896)+s|0)+608|0;if(!yh(h)){if(!q[Gc(o,b)+20|0]){break a}}i=v(b,896)+s|0;if(!p[i+712>>2]){break a}D=p[(p[i+696>>2]&2?i+692|0:i+684|0)>>2];g=p[i+688>>2];j=p[i+692>>2];vb(f+24|0,p[a>>2]+1074308|0,31);z=tb(f+24|0);A=i+1356|0;k=q[A|0];B=i+616|0;e=$t(B,c);l=ib;m=l;p[f+24>>2]=e;p[f+28>>2]=l;if(q[i+696|0]&128){p[f+24>>2]=0-e;p[f+28>>2]=0-((0<e>>>0)+m|0)}l=j-g|0;E=l<<1;e=v(b,896)+s|0;C=e;F=e+1308|0;m=e+1480|0;G=(k&17)!=1;b:{while(1){c:{if(u>>>0<d>>>0){g=(q[A|0]&17)==1;break c}n[m|0]=q[m|0]&254;e=_e(Rb(p[a>>2]+484344|0,r[p[t>>2]+60>>1]),p[p[t>>2]+48>>2],b);j=q[e+3|0];if(q[e+2|0]==11){Fx(f+16|0,p[a>>2],e,0);k=_b(f+16|0);Lm(p[a>>2],h,p[f+16>>2]);g=1;if(q[k|0]){break c}}g=1;d:{switch(j+ -4|0){case 0:Lm(p[a>>2],h,q[e+5|0]);break c;case 2:break d;default:break c}}Lm(p[a>>2],h,0)}p[f+12>>2]=p[F>>2];if(z){Or(p[a>>2],h)}if(!G){wJ(p[a>>2],h,f+12|0);g=1}if(!z){Or(p[a>>2],h)}p[f+8>>2]=0;yJ(h,f+8|0);e:{if(!g){if(!q[Gc(o,b)+20|0]){break e}}if(q[m|0]&12){GM(h,w(1),0,p[a>>2]);e=q[m|0];n[m|0]=(e&8?-9:-5)&e}I=C,J=fx(p[a>>2],h,p[f+12>>2],0),p[I+616>>2]=J;p[C+620>>2]=ib;I=Gc(o,b),J=0,n[I+20|0]=J;e=$t(B,c);g=ib;j=g;p[f+24>>2]=e;p[f+28>>2]=g;if(!(q[i+696|0]&128)){break e}p[f+24>>2]=0-e;p[f+28>>2]=0-((0<e>>>0)+j|0)}Kb(h,f+24|0);e=p[h+4>>2];j=e;k=p[h>>2];f:{g=e;g:{if(D>>>0>e>>>0){break g}e=p[i+696>>2];if(!(e&2)){break f}if(e&4){H=k>>>0<0;x=p[i+688>>2];k=x;e=k;if((j|0)<(e|0)?1:(j|0)<=(e|0)?H:0){p[f+16>>2]=0;p[f+20>>2]=k<<1;I=h,J=Wf(f+16|0,h),p[I>>2]=J;p[h+4>>2]=ib;p[i+696>>2]=p[i+696>>2]^128;e=p[f+24>>2];g=0-(p[f+28>>2]+(0<e>>>0)|0)|0;p[f+24>>2]=0-e;p[f+28>>2]=g;x=p[i+688>>2];g=p[h+4>>2]}vb(f+16|0,p[a>>2]+1074308|0,33);e=(g-x>>>0)%(E-tb(f+16|0)>>>0)|0;j=l>>>0>e>>>0;h:{if(!j){p[h+4>>2]=p[i+692>>2]+(l-e|0);g=p[i+696>>2];if(!(j^(g&128)>>>7)){break h}break g}p[h+4>>2]=e+p[i+688>>2];g=p[i+696>>2];if(j^(g&128)>>>7){break g}}p[i+696>>2]=g^128;e=p[f+24>>2];g=0-(p[f+28>>2]+(0<e>>>0)|0)|0;p[f+24>>2]=0-e;p[f+28>>2]=g;break g}j=p[i+692>>2];if(j+l>>>0<=g>>>0){g=j+((g-j>>>0)%(l>>>0)|0)|0}while(1){e=g;g=e-l|0;if(e>>>0>=j>>>0){continue}break}p[h>>2]=k;p[h+4>>2]=e}u=u+1|0;if((y|0)!=(u|0)){continue}break b}break}IM(h);p[(v(b,896)+s|0)+1316>>2]=0}I=Gc(o,b),J=0,p[I+16>>2]=J}fb=f+32|0}function lCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;e=fb-560|0;fb=e;a:{if(!Jc(b,1464)){break a}if(!ln(b,e+556|0)){break a}xd(a,1);d=a+1074308|0;Ag(d,83);Eb(d,84,1);Eb(d,85,1);b:{if(Sd(e+556|0,15977)){d=Mb(e+32|0,15987);xb(a+1304436|0,d);pb(d);d=Mb(e+32|0,16010);xb(a+1304448|0,d);pb(d);d=Mb(e+32|0,16015);xb(a+1304460|0,d);break b}if(!Sd(e+556|0,15982)){break a}d=Mb(e+32|0,16032);xb(a+1304436|0,d);pb(d);d=Mb(e+32|0,16044);xb(a+1304448|0,d);pb(d);d=Mb(e+32|0,16048);xb(a+1304460|0,d)}pb(d);p[a+1304496>>2]=2;d=0;Jc(b,0);Zz(b,a+1304400|0,20);o[a+480190>>1]=31;f=1;while(1){d=Jy(b,e+32|0,(v(f,104)+a|0)+484380|0,((f<<5)+a|0)+946300|0,1)+d|0;f=f+1|0;if((f|0)!=32){continue}break}if(d>>>0>40){break a}Dt(e+552|0,b);m=Zc(e+552|0);i=e+552|0;if(q[i|0]>128){break a}kCa(b,e+32|0);d=e+544|0;f=e+32|0;g=q[m|0];c:{while(1){if(q[f|0]<=g>>>0){f=f+1|0;if((d|0)!=(f|0)){continue}break c}break}break a}s=1;if(!c){break a}p[a+480260>>2]=56;p[a+480264>>2]=13696;p[a+480204>>2]=125e4;p[a+480196>>2]=6;o[a+480192>>1]=0;o[a+480188>>1]=4;p[a+480228>>2]=64;p[a+480208>>2]=p[a+480208>>2]|2097152;Xi(a,0);r=a+484360|0;ig(Ob(r),q[i|0]);o[e+30>>1]=0;j=a+484344|0;Pf(j,q[i|0]);if(q[i|0]){g=0;while(1){x=kc(Ob(r),g),y=g,o[x>>1]=y;if(ag(j,g&65535,64)){t=g<<2;h=0;while(1){Jc(b,(q[e+32+(h+t)|0]<<8)+1468|0);f=_e(Rb(j,g),0,h&65535);d=0;while(1){Ns(b,f);d:{e:{l=q[f+3|0];f:{if((l|0)!=14){if(!l){if(q[f+5|0]){break e}break f}if((l+ -5&255)>>>0<5){break f}break e}if(q[f+5|0]<=15){break e}}n[f+3|0]=0;break d}fj(f)}f=f+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}x=e,y=Ub(Rb(j,g)),p[x+24>>2]=y;h=0;while(1){d=0;while(1){f=d;g:{if(q[p[e+24>>2]+3|0]!=17?q[p[e+24>>2]+3|0]!=16:0){break g}n[p[e+24>>2]+3|0]=16;k=0;if(q[p[e+24>>2]+5|0]<16){break g}if(!(!(q[p[e+24>>2]+5|0]&15)|(q[p[e+24>>2]+5|0]&15)==(q[p[e+24>>2]+5|0]>>>4|0))){u=q[p[e+24>>2]+5|0]>>>4|0;w=q[p[e+24>>2]+5|0]&15;k=1}d=p[e+24>>2];n[d+5|0]=q[d+5|0]>>>4}uk(e+24|0);d=f+1|0;if((f&65535)>>>0<3){continue}break}n[e+31|0]=w;n[e+30|0]=u;d=k&255;f=0;h:{if(!d){break h}el(Rb(j,g),Oe(Ip(e+8|0,16,q[(e+d|0)+29|0]),h));d=k+1|0;f=(d&255)==3?1:d}k=f;h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<q[i|0]){continue}break}}if(!(c&2)){break a}Jc(b,(q[m|0]<<8)+1468|0);f=1;while(1){c=(v(f,104)+a|0)+484380|0;if(p[c>>2]){fg(Tc(e+8|0,8,1,0,0),c,b)}f=f+1|0;if((f|0)!=32){continue}break}}fb=e+560|0;return s|0}function Lxa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb+ -64|0;fb=e;a:{if(!Hb(c,8)){break a}Sb(c,4);while(1){f=Ys(c);if(f){break a}if($sa(c)){continue}break}}n[d|0]=q[d|0]!=0|f;Ac(c);b:{c:{d:{e:{if(f){d=Lf(c);ld(e+48|0,c,pf(c));o[a+34>>1]=r[a+34>>1]&65534|q[b|0]>15;b=r[a+34>>1]&-65|(q[b+1|0]!=1)<<6;o[a+34>>1]=b;p[a>>2]=d>>>(b&1)>>>(b>>>6&1);p[114610]=0;p[e+44>>2]=0;p[e+40>>2]=0;K(862,e+16|0,e+48|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;c=M(412,e+16|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){d=p[e+16>>2];p[114610]=0;b=M(859,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;f=M(860,d|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break c}p[114610]=0;b=Z(861,b|0,f|0,e+44|0,e+40|0,0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;J(338,e+48|0,p[e+44>>2])|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}f:{if(!b){break f}h=p[e+44>>2];p[114610]=0;M(465,a|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}f=d-h|0;h=c+h|0;c=p[e+40>>2];d=0;g:{while(1){if(d>>>0>=s[a>>2]|(!f|(c|0)!=1?c:0)){break g}if(!ue(a)){break g}p[114610]=0;p[e+12>>2]=0;p[e+8>>2]=0;c=M(859,h|0)|0;i=p[114610];p[114610]=0;h:{if((i|0)==1){break h}p[114610]=0;i=M(860,f|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break h}p[114610]=0;c=da(863,b|0,c|0,i|0,e+12|0,e+4|0,e+8|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break h}p[114610]=0;p[e+44>>2]=c;J(338,e+48|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break h}c=p[a>>2];p[114610]=0;i=p[e+44>>2];c=M(864,c-d|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break h}fk(e+8|0,c);i:{if(p[e+8>>2]<1){break i}if(p[e+12>>2]!=(le(a)|0)){break i}c=0;if(p[e+12>>2]<=0){break i}while(1){j:{if(n[a+34|0]&1){g=p[a+20>>2];j=le(a);k=p[p[e+4>>2]+(c<<2)>>2];p[114610]=0;_(865,g+(v(d,j)<<1)|0,k|0,p[e+12>>2],p[e+8>>2],c|0);g=p[114610];p[114610]=0;if((g|0)!=1){break j}break c}g=p[a+20>>2];j=le(a);k=p[p[e+4>>2]+(c<<2)>>2];p[114610]=0;_(866,g+v(d,j)|0,k|0,p[e+12>>2],p[e+8>>2],c|0);g=p[114610];p[114610]=0;if((g|0)==1){break c}}c=c+1|0;if((c|0)<p[e+12>>2]){continue}break}}p[114610]=0;g=p[e+8>>2];c=M(867,b|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break h}f=f-i|0;h=h+i|0;p[e+40>>2]=c;d=d+g|0;continue}break}break c}p[114610]=0;S(868,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){break f}break c}uc(e+16|0);sb(e+48|0);a=(b|0)!=0;break e}break c}fg(b,a,c);a=1}fb=e- -64|0;return a|0}c=I()|0;H()|0;break b}c=I()|0;H()|0;uc(e+16|0)}sb(e+48|0);L(c|0);E()}function fEa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{g=q[a+3|0];switch(g+ -4|0){case 22:break j;case 21:break k;case 20:break l;case 18:break m;case 17:break n;case 16:break o;case 14:break p;case 13:break q;case 11:break r;case 10:break s;case 9:break t;case 8:break u;case 5:break v;case 4:break w;case 0:break x;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 23:break i;default:break b}}n[a+3|0]=5;n[f+15|0]=q[a+5|0]>>>3;n[f+14|0]=15;b=q[hc(f+15|0,f+14|0)|0];n[f+13|0]=q[a+5|0]<<1&30;n[f+12|0]=15;h=a,i=q[hc(f+13|0,f+12|0)|0]|b<<4,n[h+5|0]=i;break a}n[a+3|0]=0;break a}if((q[a+5|0]+ -1&255)>>>0<=19){n[a+3|0]=16;break a}n[a+3|0]=0;break a}n[a+3|0]=13;b=q[a+5|0];y:{if(!e){if(b>>>0>152){break y}n[a+5|0]=v((b&240)>>>4|0,10)+(b&15);break a}n[a+5|0]=(b&127)+1>>>1;break a}n[a+3|0]=0;break a}n[a+3|0]=11;break a}n[a+3|0]=0;break a}e=q[a+5|0];if(!e){n[a+3|0]=14;break a}if(e>>>0<=240){n[a+3|0]=17;h=a,i=Ss(+(yP(e,b,c,d)>>>0)*1e-4),n[h+5|0]=i;break a}n[a+3|0]=0;break a}n[a+3|0]=19;n[f+11|0]=15;h=a,i=q[hc(a+5|0,f+11|0)|0]|16,n[h+5|0]=i;break a}n[a+3|0]=19;n[f+10|0]=15;h=a,i=q[hc(a+5|0,f+10|0)|0]|32,n[h+5|0]=i;break a}n[a+3|0]=5;n[f+9|0]=(q[a+5|0]>>>4|0)+1;n[f+8|0]=15;b=hc(f+9|0,f+8|0);n[a+5|0]=q[a+5|0]&15|q[b|0]<<4;break a}n[a+3|0]=19;n[a+5|0]=q[a+5|0]&15|80;break a}n[a+3|0]=19;n[f+7|0]=15;h=a,i=q[hc(a+5|0,f+7|0)|0]|96,n[h+5|0]=i;break a}n[a+3|0]=19;n[f+6|0]=15;h=a,i=q[hc(a+5|0,f+6|0)|0]|192,n[h+5|0]=i;break a}n[a+3|0]=10;break a}n[a+3|0]=19;n[f+5|0]=15;h=a,i=q[hc(a+5|0,f+5|0)|0]|160,n[h+5|0]=i;break a}n[a+3|0]=19;n[f+4|0]=15;h=a,i=q[hc(a+5|0,f+4|0)|0]|176,n[h+5|0]=i;break a}n[a+3|0]=14;break a}n[a+3|0]=19;n[f+3|0]=15;h=a,i=q[hc(a+5|0,f+3|0)|0]|224,n[h+5|0]=i;break a}b=q[a+5|0];if(b&240){n[a+3|0]=19;n[a+5|0]=b>>>4|208;break a}if(b&15){n[a+3|0]=19;n[a+5|0]=b|144;break a}n[a+3|0]=0;break a}if(!(q[a+5|0]|q[a+4|0])){n[a+5|0]=159;n[a+3|0]=20;break a}n[a+3|0]=0;break a}b=q[a+4|0];if(b){n[a+3|0]=41;h=a,i=en(dd(((q[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),n[h+5|0]=i;break a}n[a+3|0]=0;break a}b=q[a+5|0];if((b+ -17&255)>>>0>=223){n[a+3|0]=9;h=a,i=kk(((b^128)<<3)+ -896|0),n[h+5|0]=i;break a}n[a+3|0]=0;break a}if(g>>>0<=15){fj(a);break a}n[a+3|0]=0}fb=f+16|0}function gna(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=fb-16|0;fb=k;g=p[b+104>>2];a:{if(!g|!q[g+40|0]){break a}m=dj(b);f=Go(a);vb(k+8|0,a+1074308|0,21);j=f?26272:25248;l=f?25248:26272;if(!(!tb(k+8|0)|m|p[a+480180>>2]==1048576)){if(!q[g+41|0]){break a}i=q[b+838|0];p[k+4>>2]=p[b+780>>2]+q[g+39|0];fk(k+4|0,q[g+40|0]<<8);d=p[k+4>>2];p[b+780>>2]=d;d=(d|0)/256|0;p[k+4>>2]=d;n[b+838|0]=q[b+838|0]+q[g+41|0];b:{c:{switch(q[g+38|0]+ -1|0){case 3:b=sJ(Mm(a))+ -64|0;d=p[k+4>>2];break b;case 2:b=64-(i+1>>>1|0)|0;break b;case 1:b=(i+1>>>1|0)+ -64|0;break b;case 0:b=(i>>>1^-1)&64;break b;default:break c}}b=n[i+21552|0]}fk(c,8388607);a=p[c>>2]<<8;p[c>>2]=a;i=v(b,d);d=(i|0)/64|0;b=d>>31;g=b^b+d;d=g>>>2|0;b=c;d:{if((i|0)<=-64){d=p[(d<<2)+j>>2];d=rc(ONa(NNa(d,d>>31,a,a>>31),ib,65536,0),ib);a=p[c>>2];j=d-a|0;d=j;l=g&3;if(!l){break d}d=p[(l<<2)+(f?25184:25120)>>2];d=rc(ONa(NNa(d,d>>31,a,a>>31),ib,65536,0),ib)+j|0;a=p[c>>2];d=d-a|0;break d}d=p[(d<<2)+l>>2];d=rc(ONa(NNa(d,d>>31,a,a>>31),ib,65536,0),ib);a=p[c>>2];j=d-a|0;d=j;l=g&3;if(!l){break d}d=p[(l<<2)+(f?25120:25184)>>2];d=rc(ONa(NNa(d,d>>31,a,a>>31),ib,65536,0),ib)+j|0;a=p[c>>2];d=d-a|0}p[b>>2]=(a+d|0)/256;p[e>>2]=d&255;break a}e:{if(!(q[g+39|0]|p[a+480180>>2]&16777248)){p[b+780>>2]=q[g+40|0]<<8;break e}f:{g:{if(p[a+480180>>2]&16777248){i=p[b+780>>2];h=b+780|0;f=q[g+39|0]<<1;break g}if(q[b+89|0]&8){break f}i=((q[g+40|0]<<8&65280)>>>0)/q[g+39|0]|0;h=b+780|0;f=p[b+780>>2]}p[h>>2]=f+i}fk(b+780|0,q[g+40|0]<<8)}f=q[b+838|0]+q[g+41|0]|0;n[b+838|0]=f;f=f<<24>>24;h:{i:{switch(q[g+38|0]+ -1|0){case 3:n[b+838|0]=f+1;h=n[(f&63)+21488|0];break h;case 2:h=(64-(f>>>1|0)&127)+ -64|0;break h;case 1:h=((f>>>1|0)- -64&127)+ -64|0;break h;case 0:h=(f|0)>-1?-64:64;break h;default:break i}}f=q[b+838|0];h=0-n[f+21552|0]|0;if(p[a+480180>>2]!=1048576){break h}h=(64-n[(f+ -64&255)+21552|0]|0)/2|0}f=h;h=v(f,p[b+780>>2]);i=(h|0)/256|0;if(m){t[d>>2]=w(w(w(f|0)*w(1220703143189894e-20))*w(q[g+40|0]))+t[d>>2];n[b+872|0]=q[b+872|0]|8;break a}if(p[a+480180>>2]!=4){j:{if((h|0)<=-256){i=0-i|0;b=0-h>>>16|0;a=(b<<2)+j|0;break j}j=l;b=(h|0)/65536|0;a=j+(b<<2)|0}d=p[c>>2];a=p[a>>2];a=((v(p[((b<<2)+j|0)+4>>2]-a|0,(i|0)/4&63)|0)/64|0)+a|0;a=rc(ONa(NNa(d,d>>31,a,a>>31),ib,256,0),ib);p[c>>2]=a;p[e>>2]=a&255;p[c>>2]=p[c>>2]/256;break a}p[c>>2]=p[c>>2]+((h|0)/16384|0)}fb=k+16|0}function T1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,o=0,r=0,s=0,t=0;k=fb-16|0;fb=k;m=sv(g);r=Yu(g);Zf(k,r);p[f>>2]=d;a:{b:{c:{i=a;g=q[i|0];switch(g+ -43|0){case 0:case 2:break c;default:break b}}p[114610]=0;g=J(2475,m|0,g<<24>>24)|0;i=p[114610];p[114610]=0;if((i|0)==1){break a}i=p[f>>2];p[f>>2]=i+4;p[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|q[g|0]!=48|(q[g+1|0]|32)!=120)){p[114610]=0;g=J(2475,m|0,48)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}h=p[f>>2];p[f>>2]=h+4;p[h>>2]=g;g=n[i+1|0];p[114610]=0;g=J(2475,m|0,g|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}h=p[f>>2];p[f>>2]=h+4;p[h>>2]=g;i=i+2|0;g=i;while(1){if(g>>>0>=c>>>0){break d}h=n[g|0];p[114610]=0;j=Y(2445)|0;l=p[114610];p[114610]=0;e:{if((l|0)==1){break e}p[114610]=0;h=gv(h,j);j=p[114610];p[114610]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(g>>>0>=c>>>0){break d}h=n[g|0];p[114610]=0;Y(2445)|0;j=p[114610];p[114610]=0;if((j|0)==1){break a}p[114610]=0;h=Sg(h);j=p[114610];p[114610]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Pc(k)){h=p[f>>2];p[114610]=0;U(2463,m|0,i|0,g|0,h|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}p[f>>2]=p[f>>2]+(g-i<<2);break f}l=0;p[114610]=0;Bj(i,g);h=p[114610];p[114610]=0;if((h|0)==1){break a}p[114610]=0;t=M(2460,r|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(h>>>0>=g>>>0){h=p[f>>2];p[114610]=0;Xn((i-a<<2)+d|0,h);i=p[114610];p[114610]=0;if((i|0)!=1){break f}break a}g:{if(n[cc(k,j)|0]<1){break g}if(n[cc(k,j)|0]!=(l|0)){break g}l=p[f>>2];p[f>>2]=l+4;p[l>>2]=t;j=(j>>>0<wb(k)+ -1>>>0)+j|0;l=0}s=n[h|0];p[114610]=0;s=J(2475,m|0,s|0)|0;o=p[114610];p[114610]=0;if((o|0)!=1){o=p[f>>2];p[f>>2]=o+4;p[o>>2]=s;h=h+1|0;l=l+1|0;continue}break}break a}h:{while(1){if(g>>>0<c>>>0){i=q[g|0];if((i|0)==46){p[114610]=0;i=M(2464,r|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}j=p[f>>2];h=j+4|0;p[f>>2]=h;p[j>>2]=i;g=g+1|0;break h}p[114610]=0;i=J(2475,m|0,i<<24>>24)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}h=p[f>>2];p[f>>2]=h+4;p[h>>2]=i;g=g+1|0;continue}break}h=p[f>>2]}p[114610]=0;U(2463,m|0,g|0,c|0,h|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break a}i=f;f=p[f>>2]+(c-g<<2)|0;p[i>>2]=f;p[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;pb(k);fb=k+16|0;return}a=I()|0;H()|0;pb(k);L(a|0);E()}function b2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,o=0,r=0,s=0,t=0;k=fb-16|0;fb=k;m=_t(g);r=$u(g);Zf(k,r);p[f>>2]=d;a:{b:{c:{i=a;g=q[i|0];switch(g+ -43|0){case 0:case 2:break c;default:break b}}p[114610]=0;g=J(22,m|0,g<<24>>24)|0;i=p[114610];p[114610]=0;if((i|0)==1){break a}i=p[f>>2];p[f>>2]=i+1;n[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|q[g|0]!=48|(q[g+1|0]|32)!=120)){p[114610]=0;g=J(22,m|0,48)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}h=p[f>>2];p[f>>2]=h+1;n[h|0]=g;g=n[i+1|0];p[114610]=0;g=J(22,m|0,g|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}h=p[f>>2];p[f>>2]=h+1;n[h|0]=g;i=i+2|0;g=i;while(1){if(g>>>0>=c>>>0){break d}h=n[g|0];p[114610]=0;j=Y(2445)|0;l=p[114610];p[114610]=0;e:{if((l|0)==1){break e}p[114610]=0;h=gv(h,j);j=p[114610];p[114610]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(g>>>0>=c>>>0){break d}h=n[g|0];p[114610]=0;Y(2445)|0;j=p[114610];p[114610]=0;if((j|0)==1){break a}p[114610]=0;h=Sg(h);j=p[114610];p[114610]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Pc(k)){h=p[f>>2];p[114610]=0;U(2440,m|0,i|0,g|0,h|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}p[f>>2]=p[f>>2]+(g-i|0);break f}l=0;p[114610]=0;Bj(i,g);h=p[114610];p[114610]=0;if((h|0)==1){break a}p[114610]=0;t=M(2431,r|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(h>>>0>=g>>>0){h=p[f>>2];p[114610]=0;Bj((i-a|0)+d|0,h);i=p[114610];p[114610]=0;if((i|0)!=1){break f}break a}g:{if(n[cc(k,j)|0]<1){break g}if(n[cc(k,j)|0]!=(l|0)){break g}l=p[f>>2];p[f>>2]=l+1;n[l|0]=t;j=(j>>>0<wb(k)+ -1>>>0)+j|0;l=0}s=n[h|0];p[114610]=0;s=J(22,m|0,s|0)|0;o=p[114610];p[114610]=0;if((o|0)!=1){o=p[f>>2];p[f>>2]=o+1;n[o|0]=s;h=h+1|0;l=l+1|0;continue}break}break a}while(1){h:{if(g>>>0<c>>>0){i=q[g|0];if((i|0)!=46){break h}p[114610]=0;i=M(2441,r|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}h=p[f>>2];p[f>>2]=h+1;n[h|0]=i;g=g+1|0}i=p[f>>2];p[114610]=0;U(2440,m|0,g|0,c|0,i|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break a}i=f;f=p[f>>2]+(c-g|0)|0;p[i>>2]=f;p[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;pb(k);fb=k+16|0;return}p[114610]=0;i=J(22,m|0,i<<24>>24)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}h=p[f>>2];p[f>>2]=h+1;n[h|0]=i;g=g+1|0;continue}}a=I()|0;H()|0;pb(k);L(a|0);E()}function L9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-160|0;fb=d;a:{if(Yi(b)){break a}f=q[Mj(b)|0];e=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}e=0}c=e;Xj(d+128|0,b,p[b+4>>2]+ -1|0);e=p[d+132>>2];p[b>>2]=p[d+128>>2];p[b+4>>2]=e}ud(d+128|0);e=p[d+128>>2];ud(d+112|0);e=Lj(e,p[d+116>>2],b);ud(d+128|0);c:{d:{e:{f:{if((e|0)==p[d+132>>2]){a=p[b+4>>2];p[d+152>>2]=p[b>>2];p[d+156>>2]=a;a=ic(d+144|0,38139);e=p[d+156>>2];p[d+8>>2]=p[d+152>>2];p[d+12>>2]=e;e=p[a+4>>2];p[d>>2]=p[a>>2];p[d+4>>2]=e;if(xc(d+8|0,d)){a=W(8)|0;p[114610]=0;c=J(85,d+128|0,39080)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(c);break d}e=0;f=0;if(!c){break f}a=W(8)|0;p[114610]=0;e=J(2142,d+112|0,b|0)|0;b=p[114610];p[114610]=0;g:{h:{i:{if((b|0)!=1){p[114610]=0;N(2119,d+128|0,39090,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break i}dc(a,d+128|0);c=0;p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break c}b=I()|0;H()|0;pb(d+128|0);break h}b=I()|0;H()|0;break g}c=1;b=I()|0;H()|0}pb(e);if(!c){break d}}X(a|0);break d}if(p[e+4>>2]!=1){a=W(8)|0;p[114610]=0;c=J(85,d+128|0,39104)|0;b=p[114610];p[114610]=0;if((b|0)!=1){dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(c);break d}b=I()|0;H()|0;X(a|0);break d}c=p[b+4>>2];p[d+104>>2]=p[b>>2];p[d+108>>2]=c;c=ic(d+96|0,38139);e=p[d+108>>2];p[d+56>>2]=p[d+104>>2];p[d+60>>2]=e;e=p[c+4>>2];p[d+48>>2]=p[c>>2];p[d+52>>2]=e;if(xc(d+56|0,d+48|0)){a=W(8)|0;p[114610]=0;c=J(85,d+128|0,39080)|0;b=p[114610];p[114610]=0;if((b|0)!=1){dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(c);break d}b=I()|0;H()|0;X(a|0);break d}c=p[b+4>>2];p[d+88>>2]=p[b>>2];p[d+92>>2]=c;c=ic(d+80|0,38925);e=p[d+92>>2];p[d+40>>2]=p[d+88>>2];p[d+44>>2]=e;e=p[c+4>>2];p[d+32>>2]=p[c>>2];p[d+36>>2]=e;if(xc(d+40|0,d+32|0)){a=p[a+8>>2];e=a;f=a>>31;break f}c=p[b+4>>2];p[d+72>>2]=p[b>>2];p[d+76>>2]=c;b=ic(d- -64|0,39073);c=p[d+76>>2];p[d+24>>2]=p[d+72>>2];p[d+28>>2]=c;c=p[b+4>>2];p[d+16>>2]=p[b>>2];p[d+20>>2]=c;e=0;f=0;if(!xc(d+24|0,d+16|0)){break f}a=p[p[a+32>>2]+40>>2];e=a;f=a>>31}fb=d+160|0;ib=f;return e|0}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function Ica(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Lb(a);p[114610]=0;R(81);c=p[114610];p[114610]=0;a:{b:{if((c|0)==1){c=Xa(83568,71348,71324,0)|0;d=H()|0;c:{d:{e:{if(($(83568)|0)==(d|0)){c=T(c|0)|0;p[114610]=0;J(1995,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;J(1995,a|0,37858)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;J(1995,a|0,37917)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}b=m[p[p[c>>2]+8>>2]](c)|0;p[114610]=0;J(1995,a|0,(b?b:34085)|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break b}b=I()|0;H()|0;break a}f:{if(($(71348)|0)==(d|0)){c=T(c|0)|0;p[114610]=0;J(1995,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;J(1995,a|0,37858)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;J(1995,a|0,37901)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}b=m[p[p[c>>2]+8>>2]](c)|0;p[114610]=0;J(1995,a|0,(b?b:34085)|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break b}b=I()|0;H()|0;break a}e=$(71324)|0;c=T(c|0)|0;g:{if((d|0)==(e|0)){p[114610]=0;J(1995,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;J(1995,a|0,37858)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;J(1995,a|0,37884)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}b=m[p[p[c>>2]+8>>2]](c)|0;p[114610]=0;J(1995,a|0,(b?b:34085)|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break b}b=I()|0;H()|0;break a}p[114610]=0;J(1995,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;J(1995,a|0,37858)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;J(1995,a|0,37861)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break b}b=I()|0;H()|0;break a}b=I()|0;H()|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;if((c|0)!=1){break a}break c}b=I()|0;H()|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;if((c|0)!=1){break a}break c}b=I()|0;H()|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;if((c|0)==1){break c}break a}b=I()|0;H()|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;if((c|0)!=1){break a}}a=O(0)|0;H()|0;rb(a)}E()}return}pb(a);L(b|0);E()}function G9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-160|0;fb=e;a:{if(Yi(c)){break a}g=q[Mj(c)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Xj(e+128|0,c,p[c+4>>2]+ -1|0);f=p[e+132>>2];p[c>>2]=p[e+128>>2];p[c+4>>2]=f}ud(e+128|0);f=p[e+128>>2];ud(e+112|0);h=Lj(f,p[e+116>>2],c);ud(e+128|0);f=p[c>>2];g=p[c+4>>2];c:{d:{e:{f:{if((h|0)==p[e+132>>2]){p[e+152>>2]=f;p[e+156>>2]=g;b=ic(e+144|0,38139);f=p[e+156>>2];p[e+8>>2]=p[e+152>>2];p[e+12>>2]=f;f=p[b+4>>2];p[e>>2]=p[b>>2];p[e+4>>2]=f;if(xc(e+8|0,e)){a=W(8)|0;p[114610]=0;b=J(85,e+128|0,39080)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}dc(a,b);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}c=I()|0;H()|0;pb(b);break d}if(d){b=W(8)|0;p[114610]=0;d=J(2142,e+112|0,c|0)|0;a=p[114610];p[114610]=0;g:{h:{i:{if((a|0)!=1){p[114610]=0;N(2119,e+128|0,39090,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break i}dc(b,e+128|0);a=0;p[114610]=0;N(2009,b|0,83568,2017);c=p[114610];p[114610]=0;if((c|0)!=1){break c}c=I()|0;H()|0;pb(e+128|0);break h}c=I()|0;H()|0;break g}a=1;c=I()|0;H()|0}pb(d);if(!a){break d}}X(b|0);break d}Lb(a);break f}p[e+104>>2]=f;p[e+108>>2]=g;d=ic(e+96|0,38139);f=p[e+108>>2];p[e+56>>2]=p[e+104>>2];p[e+60>>2]=f;f=p[d+4>>2];p[e+48>>2]=p[d>>2];p[e+52>>2]=f;if(xc(e+56|0,e+48|0)){a=W(8)|0;p[114610]=0;b=J(85,e+128|0,39080)|0;c=p[114610];p[114610]=0;if((c|0)!=1){dc(a,b);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}c=I()|0;H()|0;pb(b);break d}c=I()|0;H()|0;X(a|0);break d}d=p[c+4>>2];p[e+88>>2]=p[c>>2];p[e+92>>2]=d;d=ic(e+80|0,38969);f=p[e+92>>2];p[e+40>>2]=p[e+88>>2];p[e+44>>2]=f;f=p[d+4>>2];p[e+32>>2]=p[d>>2];p[e+36>>2]=f;if(xc(e+40|0,e+32|0)){j:{switch(p[b+52>>2]){case 0:Mb(a,39162);break f;case 1:Mb(a,39170);break f;case 2:Mb(a,39179);break f;default:break j}}Lb(a);break f}d=p[c+4>>2];p[e+72>>2]=p[c>>2];p[e+76>>2]=d;c=ic(e- -64|0,39012);d=p[e+76>>2];p[e+24>>2]=p[e+72>>2];p[e+28>>2]=d;d=p[c+4>>2];p[e+16>>2]=p[c>>2];p[e+20>>2]=d;if(xc(e+24|0,e+16|0)){k:{switch(p[b+56>>2]){case 0:Mb(a,39184);break f;case 1:Mb(a,39189);break f;case 2:Mb(a,39195);break f;case 3:Mb(a,39206);break f;default:break k}}Lb(a);break f}Lb(a)}fb=e+160|0;return}c=I()|0;H()|0;X(a|0)}L(c|0)}E()}function $La(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,r=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=fb-32|0;fb=e;j=jj(e+24|0);if(p[a+12>>2]){u=j+3|0;w=j+5|0;x=j+4|0;y=j+2|0;z=j+1|0;A=b^1;B=e+16|5;C=e+16|3;while(1){D=Jp(a,m);while(1){a:{if(!Hb(c,1)){break a}k=td(c);if((k|0)==255){break a}h=k&31;d=Qj(a)>>>0>h>>>0;h=v(h,6)+D|0;b:{if(!(k&64)){f=td(c);g=f<<24>>24;c:{d:{e:{f=f&127;switch(f|0){case 0:break c;case 1:break e;default:break d}}n[(d?h:e+24|0)|0]=255;break c}if(!(f>>>0>121|A)){n[(d?h:e+24|0)|0]=f+ -1;break c}if((f+ -12&255)>>>0>96|b){break c}n[(d?h:e+24|0)|0]=f+13}F=d?h+1|0:z,G=td(c),n[F|0]=G;if((g|0)>-1){break b}}t=d?h:j;g=d?h+3|0:u;f=d?h+5|0:w;r=d?h+4|0:x;l=d?h+2|0:y;h=d?h:e+24|0;while(1){d=h;p[e+16>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);o[e+20>>1]=q[d+4|0]|q[d+5|0]<<8;d=td(c);E=d&128;i=d&63;f:{if(d&64){n[l|0]=1;n[r|0]=i;break f}d=td(c);n[f|0]=d;g:{h:{if(i>>>0<=15){n[g|0]=i;fj(t);i:{j:{k:{d=q[g|0];switch(d+ -9|0){case 1:case 2:case 3:break g;case 4:break j;case 0:break k;default:break i}}n[g|0]=9;n[f|0]=v(q[f|0]&15,17);break g}n[g|0]=0;n[l|0]=1;p[e+12>>2]=q[f|0]+1>>>1;p[e+8>>2]=64;F=r,G=p[Yd(e+12|0,e+8|0)>>2],n[F|0]=G;break g}if((d|0)!=19){break g}if(q[f|0]==128){break h}Sw(t);break g}if(i>>>0>44){break g}i=i+ -16|0;n[g|0]=q[i+12272|0];l:{switch(i|0){case 0:if(d>>>0>1){break h}n[f|0]=d|158;break g;case 1:case 2:n[e+12|0]=15;F=f,G=q[hc(e+12|0,f)|0]|224,n[F|0]=G;break g;case 5:case 6:p[e+12>>2]=16;p[e+8>>2]=d+1;F=f,G=p[Yd(e+12|0,e+8|0)>>2]/2|240,n[F|0]=G;break g;case 14:m:{n:{o:{p:{q:{i=d>>>4|0;switch(i+ -1|0){case 1:break o;case 0:break p;default:break q}}switch(i+ -10|0){case 1:break m;case 0:break n;default:break h}}n[g|0]=2;n[f|0]=d|240;break g}n[g|0]=3;n[f|0]=d|240;break g}n[g|0]=11;n[f|0]=(d<<3&120)+8|15;break g}n[g|0]=11;n[f|0]=(d&15)+1>>>1|240;break g;case 12:break l;default:break g}}p[e+12>>2]=d+1>>>1;p[e+8>>2]=64;F=f,G=p[Yd(e+12|0,e+8|0)>>2],n[F|0]=G;break g}n[g|0]=0}Qw(g,f,C,B);if(Fm(q[e+19|0])>>>0<=Fm(q[g|0])>>>0){break f}r:{if(q[l|0]){break r}if(!Rw(g,f,1)){break r}n[l|0]=q[g|0];n[r|0]=q[f|0]}n[g|0]=q[e+19|0];n[f|0]=q[e+21|0]}if(E){continue}break}}if(!(k&128)){continue}}break}m=m+1|0;if(m>>>0<s[a+12>>2]){continue}break}}fb=e+32|0}function a$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-336|0;fb=d;t1(a);e=p[a+28>>2];a:{if(!tf(p[p[e>>2]+ -12>>2]+e|0)){vg(a,1073741825);break a}df(d- -64|0,p[a+28>>2]);e=d- -64|0;f=p[e+12>>2];p[a+8>>2]=p[e+8>>2];p[a+12>>2]=f;T_(Ic(d- -64|0,3),p[a+28>>2],d+24|0);if(hd(d+24|0,6931,3)){vg(a,1073741827);break a}n[d+335|0]=0;mh(p[a+28>>2],d+335|0);AC(d- -64|0);g=b;f=d+24|0;b=d- -64|0;e=q[d+335|0];if(e){Hj(p[a+28>>2],d- -64|0,e);e=q[d+335|0]}else{e=0}b=_l(f,b,e);e=Ru(g,b);yb(b);if(!e){vg(a,1073741830)}if(q[a+3|0]&64){break a}mh(p[a+28>>2],d+63|0);e=q[d+63|0];b=e&3;o[a+16>>1]=(b|0)==3?4:b;if(Kh(e,6)){tj(a,9,1)}p[d+56>>2]=0;xC(p[a+28>>2],d+56|0);b=p[d+56>>2];n[d+55|0]=0;if(b>>>0>=2){mh(p[a+28>>2],d+63|0);f=q[d+63|0];if(!f){mh(p[a+28>>2],d+55|0);f=q[d+63|0]}Tk(p[a+28>>2],b+(f?-1:-2)|0,-1)}p[d+40>>2]=0;p[d+44>>2]=0;b:{if(!Kh(e,4)){break b}sj(p[a+28>>2],d+40|0);b=p[d+44>>2];f=p[d+40>>2];p[a+56>>2]=f;p[a+60>>2]=b;g=p[c+4>>2];if((g|0)==(b|0)&f>>>0<=s[c>>2]|b>>>0<g>>>0){break b}vg(a,536871424)}if(Kh(e,5)){mh(p[a+28>>2],d+63|0);Tk(p[a+28>>2],q[d+63|0],-1)}c:{if(!Kh(q[d+55|0],0)){break c}mh(p[a+28>>2],d+63|0);b=q[d+63|0];b=b&1?-1:b>>>1|0;o[a+16>>1]=b;if(b){break c}vg(a,536871168)}p[a+4>>2]=0;b=1;if(Kh(q[d+55|0],1)){xC(p[a+28>>2],a+4|0)}tj(a,6,Kh(e,2));tj(a,7,Kh(e,3));tj(a,5,r[a+16>>1]!=0);tj(a,8,Kh(e,7));d:{if(od(a,5)){break d}if(od(a,6)){break d}if(od(a,7)){break d}b=od(a,8)}tj(a,11,b);od(a,11);b=q[d+55|0];if(Kh(b,2)){o[d+24>>1]=0;Pu(p[a+28>>2],d+24|0);Tk(p[a+28>>2],v(r[d+24>>1],od(a,9)?2:1),-1);b=q[d+55|0]}if(Kh(b&255,3)){Tk(p[a+28>>2],5,-1)}sj(p[a+28>>2],d+40|0);c=p[d+44>>2];b=p[d+40>>2];if(!c&b>>>0>=16001|c>>>0>0){vg(a,1073741831);break a}p[a+92>>2]=b;if(!b){vg(a,536871040)}e:{if(!od(a,11)){break e}sj(p[a+28>>2],d+40|0);b=p[d+44>>2];if((b|0)==2147483647|b>>>0<2147483647){break e}vg(a,1073741829);break a}df(d+8|0,p[a+28>>2]);VC(d+24|0,d+8|0,p[a+8>>2],p[a+12>>2]);b=p[d+36>>2];e=p[d+32>>2];if(!(!b|b>>>0<0?(b|0)>0?1:(b|0)>=0?e>>>0>=0:0:0)){vg(a,1073741832);break a}p[a+88>>2]=e;b=a;f:{if(od(a,11)){c=p[d+40>>2];break f}c=p[a+88>>2]}p[b+64>>2]=c;if(!od(a,11)){c=p[a+12>>2];e=p[a+88>>2];f=e+p[a+8>>2]|0;if(f>>>0<e>>>0){c=c+1|0}p[a+72>>2]=f;p[a+76>>2]=c}tj(a,10,1)}fb=d+336|0}function gda(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-80|0;fb=j;a:{b:{c:{k=Rn(1,32);d:{e:{if(!k){a=W(4)|0;Kk(a);p[114610]=0;N(2009,a|0,71348,2008);a=p[114610];p[114610]=0;if((a|0)!=1){break a}i=O(0)|0;H()|0;break e}p[k+16>>2]=0;p[k+20>>2]=0;p[k+12>>2]=f;p[k+8>>2]=e;p[k+4>>2]=d;p[k+24>>2]=0;p[k+28>>2]=0;p[k>>2]=c?c:1997;d=js(j- -64|0);f:{g:{if(!i){break g}c=p[i>>2];if(!c){break g}while(1){h:{e=p[i+4>>2];if(e){p[114610]=0;c=J(85,j+48|0,c|0)|0;f=p[114610];p[114610]=0;i:{if((f|0)!=1){p[114610]=0;f=J(2010,d|0,c|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break i}p[114610]=0;J(483,f|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}break h}i=O(0)|0;H()|0;break f}i=O(0)|0;H()|0;pb(c);break f}p[114610]=0;c=J(85,j+48|0,c|0)|0;e=p[114610];p[114610]=0;j:{if((e|0)!=1){p[114610]=0;J(2011,d|0,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break j}break h}i=O(0)|0;H()|0;break f}i=O(0)|0;H()|0;pb(c);break f}pb(c);c=p[i+8>>2];i=i+8|0;if(c){continue}break}}c=p[a+8>>2];e=p[a+4>>2];f=p[a>>2];p[114610]=0;a=M(1398,96)|0;i=p[114610];p[114610]=0;k:{l:{m:{if((i|0)!=1){p[114610]=0;p[j+44>>2]=c;p[j+40>>2]=e;p[j+36>>2]=f;p[j+32>>2]=b;N(2012,j+48|0,k|0,k+4|0);b=p[114610];p[114610]=0;if((b|0)==1){break m}b=oo(j+24|0,j+48|0);p[114610]=0;c=p[j+44>>2];p[j+16>>2]=p[j+40>>2];p[j+20>>2]=c;c=p[j+36>>2];p[j+8>>2]=p[j+32>>2];p[j+12>>2]=c;U(2086,a|0,j+8|0,b|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break l}p[k+28>>2]=a;Nc(b);Nc(j+48|0);a=p[k+28>>2];p[k+24>>2]=a?a+8|0:0;Yj(d);break d}i=O(0)|0;H()|0;break f}i=O(0)|0;H()|0;break k}i=O(0)|0;H()|0;Nc(b);Nc(j+48|0)}Nb(a)}Yj(d);T(i|0)|0;p[114610]=0;Q(1989,37133,k|0,g|0,h|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)!=1){a=p[k+28>>2];if(a){m[p[p[a>>2]+4>>2]](a)}p[k+24>>2]=0;p[k+28>>2]=0;a=p[k+20>>2];if(a){Nb(a)}Nb(k);k=0;break d}i=O(0)|0;H()|0;break e}i=O(0)|0;H()|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break b}}T(i|0)|0;k=0;p[114610]=0;Q(1989,37133,0,g|0,h|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}V()}fb=j+80|0;return k|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}a=O(0)|0;H()|0;rb(a)}E()}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-176|0;fb=e;df(e+160|0,b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{g=ija(a,b,c,d);if(!g){tn(p[p[b>>2]+ -12>>2]+b|0,0);g=p[e+172>>2];p[e+8>>2]=p[e+168>>2];p[e+12>>2]=g;g=p[e+164>>2];p[e>>2]=p[e+160>>2];p[e+4>>2]=g;Ni(b,e);b=Pk(e+56|0,b);p[114610]=0;g=J(686,e+40|0,32467)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}p[114610]=0;p[e+32>>2]=3;p[e+36>>2]=0;N(687,b|0,g|0,e+32|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}yb(g);p[114610]=0;n[e+31|0]=0;g=J(686,e+40|0,32470)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}p[114610]=0;P(688,b|0,e+31|0,g|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}yb(g);p[114610]=0;g=q[e+31|0];f=M(1624,b|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break f}p[114610]=0;h=M(1625,b|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break g}p[e+32>>2]=h;p[e+24>>2]=f;if(Ab(e+24|0,e+32|0)){g=g?0:d;while(1){p[114610]=0;o[e+22>>1]=65535;d=J(686,e+40|0,32475)|0;f=p[114610];p[114610]=0;if((f|0)==1){break j}p[114610]=0;f=P(1626,b|0,e+24|0,d|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break i}yb(d);m:{if(!f){p[114610]=0;Q(1627,b|0,e+24|0,c|0,g|0);d=p[114610];p[114610]=0;if((d|0)==1){break h}break m}p[114610]=0;d=J(686,e+40|0,32477)|0;f=p[114610];p[114610]=0;n:{o:{if((f|0)!=1){p[114610]=0;f=P(1626,b|0,e+24|0,d|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break o}yb(d);if(f){break n}p[114610]=0;P(1628,b|0,e+24|0,e+22|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break m}break h}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(d);break a}p[114610]=0;d=J(686,e+40|0,32479)|0;f=p[114610];p[114610]=0;if((f|0)==1){break l}p[114610]=0;f=P(1626,b|0,e+24|0,d|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break k}yb(d);if(f){break m}p[114610]=0;Q(1629,b|0,e+24|0,a|0,g|0);d=p[114610];p[114610]=0;if((d|0)==1){break h}}d=e+24|0;d;Ff(d);if(Ab(e+24|0,e+32|0)){continue}break}}a=p[b>>2];hg(b);g=a&1073741824?-1:1}fb=e+176|0;return g|0}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(d);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(d);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(g);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(g);break a}a=I()|0;H()|0}hg(b);L(a|0);E()}function lva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;e=fb-80|0;fb=e;w=p[a+16>>2];h=Df(e+48|0);p[h+8>>2]=a+112;p[h+16>>2]=p[a+128>>2];y=h,z=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[y+12>>2]=z;b=p[h+16>>2];if(b){y=h,z=Cf(a+8|0,b),p[y>>2]=z;p[h+4>>2]=ib}f=p[a+44>>2];p[e+32>>2]=f;m=p[a+48>>2];p[e+36>>2]=m;k=p[a+52>>2];p[e+40>>2]=k;l=p[a+56>>2];p[e+44>>2]=l;n=p[a+40>>2];q=p[a+36>>2];i=p[a+4>>2];g=p[a>>2];p[e+24>>2]=g;p[e+28>>2]=i;b=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=b;a:{if(!d){b=n>>12;j=q>>12;break a}while(1){b=0;f=b;j=g;p[e+72>>2]=g;p[e+76>>2]=b;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+w|0;b:{b=p[h+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;qd(p[h+8>>2],(o[(g<<1|2)+i>>1]+o[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);pd(p[h+8>>2],4);Kb(e+72|0,h);if((b|0)<2){break b}b=b+ -1|0;j=p[e+72>>2];f=p[e+76>>2];continue}}b=p[h+8>>2];Kb(b,b+8|0);b=p[h+8>>2];g=p[b+4>>2];if(g){f=b;b=(p[e+76>>2]&2147483647)<<1|p[e+72>>2]>>>31;qd(f,(o[(b<<1|2)+i>>1]+o[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);pd(p[h+8>>2],g);b=p[h+8>>2];g=p[b>>2];p[b>>2]=g;p[b+4>>2]=0}d=d+ -1|0;f=xf(b,p[h+12>>2]);p[e+12>>2]=f;p[e+8>>2]=f;j=0;m=1;while(1){k=p[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;r=p[i>>2];b=Pb(r,-16777216,16776704);u=p[a+64>>2];g=Pb(p[i+4>>2],-16777216,16776704);s=p[a+68>>2];x=s;s=s>>31;p[i+4>>2]=r;r=p[a+72>>2];t=k>>31;k=f<<8;f=k;f=NNa(l,t,f,f>>31);l=ib;t=(e+8|0)+(j<<2)|0;j=NNa(u,u>>31,b,b>>31);f=j+f|0;b=ib+l|0;b=f>>>0<j>>>0?b+1|0:b;l=f;f=NNa(x,s,g,g>>31);g=l+f|0;b=ib+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;p[t>>2]=(b|0)/256;p[i>>2]=b-(k&r);if(m){j=1;m=0;f=p[e+12>>2];continue}break}b=p[a+32>>2];q=p[a+28>>2]+q|0;j=q>>12;p[c>>2]=p[c>>2]+v(j,p[e+8>>2]);n=b+n|0;b=n>>12;p[c+4>>2]=p[c+4>>2]+v(b,p[e+12>>2]);Kb(e+24|0,e+16|0);if(d){c=c+8|0;g=p[e+24>>2];i=p[e+28>>2];continue}break}g=p[e+24>>2];i=p[e+28>>2];l=p[e+44>>2];k=p[e+40>>2];m=p[e+36>>2];f=p[e+32>>2]}p[a+40>>2]=n;p[a+20>>2]=j;p[a+36>>2]=q;p[a+56>>2]=l;p[a+52>>2]=k;p[a+48>>2]=m;p[a+44>>2]=f;p[a+24>>2]=b;p[a>>2]=g;p[a+4>>2]=i;fb=e+80|0}



function Apa(a,b,c,d,e){var f=0,g=0,h=0,i=w(0),j=0,k=0,l=0,o=w(0),s=0,u=0;g=fb-32|0;fb=g;p[g+28>>2]=e;a:{if(!e){break a}f=q[d|0];h=f+ -250|0;if(!(h>>>0>5|!(1<<h&37))){if(r[a+480188>>1]){f=0;while(1){h=(v(f,896)+a|0)+1075841|0;n[h|0]=127;n[h+1|0]=0;f=f+1|0;if(f>>>0<r[a+480188>>1]){continue}break}}f=q[d|0]}b:{if((f&255)!=240){break b}f=q[d+1|0];if((f&254)!=240){break b}if(e>>>0<4){break a}h=(v(b,896)+a|0)+1074984|0;e=n[d+3|0];k=(e|0)<0;d=q[d+2|0];if(!(k|(f|0)==241|d)){d=v(b,896)+a|0;f=d+1075841|0;j=f;if(c){e=tK(Fo(a,w(q[f|0]),w((e&255)>>>0)))}n[j|0]=e;n[d+1075802|0]=0;j=4;c=d+1075072|0;d=Oo(a,h,!(p[c>>2]&32768),256);if((d|0)<0|!(q[c+1|0]&2)){break a}a=a+1304392|0;if(!kd(a)){break a}To(p[a>>2],b,d>>>2&255,1);break a}if(!(k|(f|0)==241|(d|0)!=1)){b=v(b,896)+a|0;d=b+1075842|0;c:{if(!c){break c}i=Fo(a,w(q[d|0]),w((e&255)>>>0));if(i<w(4294967296)&i>=w(0)){e=~~i>>>0;break c}e=0}n[d|0]=e;n[b+1075801|0]=0;Oo(a,h,!(p[b+1075072>>2]&32768),256);j=4;break a}k=(f|0)==241;if(!(k|(d|0)!=2)){j=4;if((e&255)>>>0>31){break a}b=v(b,896)+a|0;n[b+1075849|0]=(e&240)>>>4;Oo(a,h,!(p[b+1075072>>2]&32768),256);break a}if(!(k|(d|0)!=3)){j=4;b=Km(a,b,3,0);if((e|0)<0|(b+5&255)>>>0<6){break a}b=(v(b,160)+a|0)+906284|0;i=w(w(((e^127)&255)>>>0)*w(.007874015718698502));if(!c){t[b>>2]=i;break a}l=b,o=Fo(a,t[b>>2],i),t[l>>2]=o;break a}if(d&128?0:(f|0)!=241){break a}j=4;b=Km(a,b,3,0);if((e|0)<0|(b+5&255)>>>0<6){break a}b=p[(v(b,160)+a|0)+906140>>2];if(!b){break a}d=(f|0)==241?d+128|0:d&127;i=w(w((e&255)>>>0)*w(.007874015718698502));if(!c){m[p[p[b>>2]+44>>2]](b,d,i);break a}s=b,u=d,o=Fo(a,w(m[p[p[b>>2]+48>>2]](b,d)),i),l=p[p[b>>2]+44>>2],m[l](s|0,u|0,w(o));break a}d:{e:{if(r[a+480188>>1]>b>>>0){f=b+1|0;break e}f=r[(v(b,896)+a|0)+1075792>>1];if(!f){break d}}if(q[(v(b,896)+a|0)+1075075|0]&4|(f&65535)>>>0>r[a+480188>>1]){break d}b=Km(a,b,3,0);if(!b|b+ -251>>>0<5){break d}a=p[(v(b,160)+a|0)+906140>>2];if(!a){break d}b=q[d|0];if((b|0)==240){Zb(g+16|0,ub(d),e);m[p[p[a>>2]+72>>2]](a,g+16|0)|0;break d}l=g,u=UM(b),p[l+12>>2]=u;b=p[Cb(g+12|0,g+28|0)>>2];p[g+12>>2]=0;ac(g+12|0,d,b);m[p[p[a>>2]+68>>2]](a,p[g+12>>2])|0}j=p[g+28>>2]}fb=g+32|0;return j}function rw(a){a=a|0;var b=0,c=0,d=w(0),e=0;Jb(a+4960|0,0,76);n[a+5044|0]=0;p[a+5036>>2]=0;p[a+5040>>2]=0;b=p[a+4292>>2];d=t[a+4268>>2];p[114610]=0;e=a+4504|0;if(d<w(4294967296)&d>=w(0)){c=~~d>>>0}else{c=0}_(1916,e|0,67,5,c|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}b=p[a+4296>>2];p[114610]=0;_(1916,a+4528|0,62,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4300>>2];p[114610]=0;_(1916,a+4552|0,53,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4304>>2];p[114610]=0;_(1916,a+4576|0,43,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4308>>2];p[114610]=0;_(1916,a+4600|0,32,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4312>>2];p[114610]=0;_(1916,a+4624|0,22,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4316>>2];p[114610]=0;_(1916,a+4648|0,75,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4320>>2];p[114610]=0;_(1916,a+4672|0,69,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4324>>2];p[114610]=0;_(1916,a+4696|0,60,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4328>>2];p[114610]=0;_(1916,a+4720|0,48,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4332>>2];p[114610]=0;_(1916,a+4744|0,36,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4336>>2];p[114610]=0;_(1916,a+4768|0,25,5,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;_(1916,a+4792|0,0,0,0,0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4344>>2];p[114610]=0;_(1916,a+4816|0,3,0,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[a+4348>>2];p[114610]=0;_(1916,a+4840|0,3,0,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;_(1916,a+4864|0,407,1,c|0,0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;_(1916,a+4888|0,400,1,c|0,0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;_(1916,a+4912|0,10,0,c|0,-1);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;_(1916,a+4936|0,10,0,c|0,-1);c=p[114610];p[114610]=0;if((c|0)==1){break a}n[a+5045|0]=1;return}c=O(71348)|0;if((H()|0)==($(71348)|0)){T(c|0)|0;n[a+5045|0]=0;V();return}L(c|0);E()}function RD(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;a:{if(c>>>0<=2){c=c<<2;h=p[c+57340>>2];k=p[c+57328>>2];while(1){c=p[b+4>>2];b:{if(c>>>0<s[b+104>>2]){p[b+4>>2]=c+1;c=q[c|0];break b}c=Sc(b)}if(im(c)){continue}break}g=1;c:{d:{switch(c+ -43|0){case 0:case 2:break d;default:break c}}g=(c|0)==45?-1:1;c=p[b+4>>2];if(c>>>0<s[b+104>>2]){p[b+4>>2]=c+1;c=q[c|0];break c}c=Sc(b)}e:{f:{while(1){if(n[e+57264|0]==(c|32)){g:{if(e>>>0>6){break g}c=p[b+4>>2];if(c>>>0<s[b+104>>2]){p[b+4>>2]=c+1;c=q[c|0];break g}c=Sc(b)}e=e+1|0;if((e|0)!=8){continue}break f}break}if((e|0)!=3){if((e|0)==8){break f}if(!d|e>>>0<4){break e}if((e|0)==8){break f}}c=p[b+104>>2];if(c){p[b+4>>2]=p[b+4>>2]+ -1}if(!d|e>>>0<4){break f}while(1){if(c){p[b+4>>2]=p[b+4>>2]+ -1}e=e+ -1|0;if(e>>>0>3){continue}break}}M3(f,w(w(g|0)*w(G)));g=p[f+8>>2];h=p[f+12>>2];i=p[f>>2];j=p[f+4>>2];break a}h:{i:{j:{if(e){break j}e=0;while(1){if(n[e+57273|0]!=(c|32)){break j}k:{if(e>>>0>1){break k}c=p[b+4>>2];if(c>>>0<s[b+104>>2]){p[b+4>>2]=c+1;c=q[c|0];break k}c=Sc(b)}e=e+1|0;if((e|0)!=3){continue}break}break i}l:{switch(e|0){case 0:m:{if((c|0)!=48){break m}e=p[b+4>>2];n:{if(e>>>0<s[b+104>>2]){p[b+4>>2]=e+1;e=q[e|0];break n}e=Sc(b)}if((e&-33)==88){L3(f+16|0,b,k,h,g,d);g=p[f+24>>2];h=p[f+28>>2];i=p[f+16>>2];j=p[f+20>>2];break a}if(!p[b+104>>2]){break m}p[b+4>>2]=p[b+4>>2]+ -1}K3(f+32|0,b,c,k,h,g,d);g=p[f+40>>2];h=p[f+44>>2];i=p[f+32>>2];j=p[f+36>>2];break a;case 3:break i;default:break l}}if(p[b+104>>2]){p[b+4>>2]=p[b+4>>2]+ -1}break h}o:{c=p[b+4>>2];p:{if(c>>>0<s[b+104>>2]){p[b+4>>2]=c+1;c=q[c|0];break p}c=Sc(b)}if((c|0)==40){e=1;break o}g=0;h=2147450880;if(!p[b+104>>2]){break a}p[b+4>>2]=p[b+4>>2]+ -1;break a}while(1){c=p[b+4>>2];q:{if(c>>>0<s[b+104>>2]){p[b+4>>2]=c+1;c=q[c|0];break q}c=Sc(b)}if(!(c+ -97>>>0>=26?!(c+ -48>>>0<10|c+ -65>>>0<26|(c|0)==95):0)){e=e+1|0;continue}break}g=0;h=2147450880;if((c|0)==41){break a}c=p[b+104>>2];if(c){p[b+4>>2]=p[b+4>>2]+ -1}if(d){if(!e){break a}while(1){e=e+ -1|0;if(c){p[b+4>>2]=p[b+4>>2]+ -1}if(e){continue}break}break a}}p[114584]=28;Rg(b,0,0)}g=0;h=0}p[a>>2]=i;p[a+4>>2]=j;p[a+8>>2]=g;p[a+12>>2]=h;fb=f+48|0}function QG(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-80|0;fb=j;a:{b:{c:{d:{e:{f:{k=Rn(1,28);if(!k){a=W(4)|0;Kk(a);p[114610]=0;N(2009,a|0,71348,2008);a=p[114610];p[114610]=0;if((a|0)!=1){break a}break f}p[k+24>>2]=0;p[k+16>>2]=0;p[k+20>>2]=0;p[k+12>>2]=f;p[k+8>>2]=e;p[k+4>>2]=d;p[k>>2]=c?c:1997;d=js(j- -64|0);g:{h:{if(!i){break h}c=p[i>>2];if(!c){break h}while(1){i:{e=p[i+4>>2];if(e){p[114610]=0;c=J(85,j+48|0,c|0)|0;f=p[114610];p[114610]=0;j:{if((f|0)!=1){p[114610]=0;f=J(2010,d|0,c|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break j}p[114610]=0;J(483,f|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break j}break i}i=O(0)|0;H()|0;break g}i=O(0)|0;H()|0;pb(c);break g}p[114610]=0;c=J(85,j+48|0,c|0)|0;e=p[114610];p[114610]=0;k:{if((e|0)!=1){p[114610]=0;J(2011,d|0,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}break i}i=O(0)|0;H()|0;break g}i=O(0)|0;H()|0;pb(c);break g}pb(c);c=p[i+8>>2];i=i+8|0;if(c){continue}break}}c=p[a+8>>2];e=p[a+4>>2];f=p[a>>2];p[114610]=0;a=M(1398,80)|0;i=p[114610];p[114610]=0;l:{m:{n:{if((i|0)!=1){p[114610]=0;p[j+44>>2]=c;p[j+40>>2]=e;p[j+36>>2]=f;p[j+32>>2]=b;N(2012,j+48|0,k|0,k+4|0);b=p[114610];p[114610]=0;if((b|0)==1){break n}b=oo(j+24|0,j+48|0);p[114610]=0;c=p[j+44>>2];p[j+16>>2]=p[j+40>>2];p[j+20>>2]=c;c=p[j+36>>2];p[j+8>>2]=p[j+32>>2];p[j+12>>2]=c;U(2013,a|0,j+8|0,b|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break m}p[k+24>>2]=a;Nc(b);Nc(j+48|0);Yj(d);c=k;break d}i=O(0)|0;H()|0;break g}i=O(0)|0;H()|0;break l}i=O(0)|0;H()|0;Nc(b);Nc(j+48|0)}Nb(a)}Yj(d);T(i|0)|0;p[114610]=0;Q(1989,34626,k|0,g|0,h|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break f}a=p[k+24>>2];if(a){Nb(mr(a))}c=0;p[k+24>>2]=0;a=p[k+20>>2];if(a){Nb(a)}Nb(k);break d}i=O(0)|0;H()|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)!=1){break e}break b}i=O(0)|0;H()|0}T(i|0)|0;c=0;p[114610]=0;Q(1989,34626,0,g|0,h|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}V()}fb=j+80|0;return c|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}a=O(0)|0;H()|0;rb(a)}E()}function el(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;a:{b:{if(cd(a)|s[b+4>>2]>=s[a+12>>2]){break b}c=r[b+8>>1]>=Qj(a)>>>0;i=r[b+8>>1];if((i|0)!=65535?c:0){break b}g=i;if((g&65535)==65535){i=Qj(a)+ -1|0;g=0}c=_e(a,p[b+4>>2],g&65535);c:{e=q[b+12|0];d:{if(e&2){break d}k=i&65535;if((g&65535)>>>0>k>>>0){break d}l=e&4;j=q[b+10|0];f=g;d=c;while(1){e:{if(!l){if((j|0)!=q[d+3|0]){break e}break c}if((j|0)==q[d+2|0]){break c}}d=d+6|0;f=f+1|0;if((f&65535)>>>0<=k>>>0){continue}break}}j=i&65535;if((g&65535)>>>0<=j>>>0){k=e&4;f=g;d=c;while(1){f:{if(!k){if(q[d+3|0]){break f}n[d+3|0]=q[b+10|0];n[d+5|0]=q[b+11|0];break c}if(q[d+2|0]){break f}n[d+2|0]=q[b+10|0];n[d+4|0]=q[b+11|0];break c}d=d+6|0;f=f+1|0;if((f&65535)>>>0<=j>>>0){continue}break}}g:{if(!(e&1)){break g}f=p[Em(a)+480180>>2]&2;e=q[b+12|0];h:{if(e&4){break h}i=i&65535;if((g&65535)>>>0>i>>>0){break h}while(1){i:{j:{switch(q[c+3|0]+ -9|0){case 4:if(!RI(p[Em(a)+8>>2],1)){break i}d=1;n[c+2|0]=1;n[c+4|0]=q[c+5|0];n[c+3|0]=q[b+10|0];n[c+5|0]=q[b+11|0];break a;case 0:break j;default:break i}}d=c;k:{if(f){e=q[c+5|0];if(e>>>0>128){break i}n[c+2|0]=2;n[c+3|0]=q[b+10|0];a=1;break k}n[c+2|0]=2;n[c+3|0]=q[b+10|0];e=q[c+5|0];a=2}n[d+4|0]=a+e>>>a;n[c+5|0]=q[b+11|0];break c}c=c+6|0;g=g+1|0;if((g&65535)>>>0<=i>>>0){continue}break}e=q[b+12|0]}l:{if(e&4){d=q[b+11|0];c=13;m:{switch(q[b+10|0]+ -1|0){case 1:d=en(v(f?2:4,d));e=q[b+12|0];c=9;break;case 0:break m;default:break l}}n[b+11|0]=d;n[b+10|0]=c;e=e&254;n[b+12|0]=e;break l}n[h+15|0]=0;c=q[b+11|0];n[h+14|0]=c;g=q[b+10|0];n:{o:{if(!(!f|(g|0)!=9)){if(c>>>0>128){break n}d=2;n[h+15|0]=2;f=c>>>1|0;n[h+14|0]=f;break o}n[h+15|0]=g;if(!Rw(h+15|0,h+14|0,1)){n[h+15|0]=0;break n}d=q[h+15|0];if(!d){break n}e=q[b+12|0];f=q[h+14|0]}n[b+11|0]=f;n[b+10|0]=d;n[b+12|0]=e&254}e=q[b+12|0]}d=1;if(e&1){break g}n[b+12|0]=e^4;if(el(a,b)){break a}}c=p[b>>2];p:{if((c|0)==1){if(p[b+4>>2]+1>>>0<s[a+12>>2]){p[b+4>>2]=p[b+4>>2]+1;break p}c=p[b>>2]}if((c|0)!=2){break b}d=0;c=p[b+4>>2];if(!c){break a}p[b+4>>2]=c+ -1}n[b+12|0]=q[b+12|0]|1;d=el(a,b);break a}d=1;break a}d=0}fb=h+16|0;return d|0}function Lm(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;p[b+88>>2]=p[b+88>>2]|524288;a:{b:{if(!(p[a+480208>>2]&8)){vb(f+8|0,a+1074308|0,15);if(tb(f+8|0)){break b}}if(p[a+480180>>2]!=268435456){break a}}c=c?c:q[b+831|0];n[b+832|0]=c;n[b+831|0]=c}c:{if(dj(b)){e=p[a+1074392>>2];i=p[b+880>>2];d:{if(c){p[b+776>>2]=c;break d}c=p[b+776>>2];if(!c){break c}}d=p[b+708>>2];e:{f:{if((d|0)>=1){if((c|0)<0){break f}break e}if(!d|(c|0)<1){break e}}c=0-c|0;p[b+776>>2]=c}g=b;h=(+(e>>>0)+1)*+(c|0)/+s[a+1074416>>2];g:{if(x(h)<2147483648){c=~~h;break g}c=-2147483648}p[g+880>>2]=c;if(q[b+90|0]&16){c=v(p[p[p[b+656>>2]+44>>2]+36>>2]+1|0,c);p[b+880>>2]=c}a=c-(e?i:0)|0;c=a>>31;e=d>>31;if((e+d^e)<=(c^a+c)){if(!d){break c}p[b+708>>2]=0;p[b+876>>2]=d+p[b+876>>2];n[b+872|0]=q[b+872|0]|8;break c}p[b+708>>2]=d-a;p[b+876>>2]=a+p[b+876>>2];n[b+872|0]=q[b+872|0]|8;break c}d=1;h:{if(!(n[b+872|0]&1)|p[a+480180>>2]&524352){break h}if(p[a+1074416>>2]==1){vb(f+8|0,a+1074308|0,6);if(tb(f+8|0)){break h}}d=0;if(p[a+480180>>2]!=8){break h}d=(q[a+480208|0]&2)>>>1|0}if(!(p[a+480180>>2]!=268435456|c>>>0<240)){d=n[b+872|0]&1;c=c+ -240|0}if(c){p[b+776>>2]=(p[a+480180>>2]==64?v(c,10):c)<<2}e=p[b+708>>2];c=p[b+700>>2];i:{if(!c){c=0;break i}if(!e|d^1){break i}g=b;j:{if((c|0)<(e|0)){d=p[b+776>>2];k:{if(!(q[a+480208|0]&16)){break k}if(p[a+480180>>2]==4){c=p[b+700>>2];break k}c=p[b+776>>2]/4|0;c=p[((c>>>0<255?c:255)<<2)+25248>>2];d=c;e=c>>31;c=p[b+700>>2];d=NNa(d,e,c,c>>31)+32768|0;c=ib;d=rc(ONa(d,d>>>0<32768?c+1|0:c,65536,0),ib);c=p[b+700>>2];d=d-c|0;d=(d|0)>1?d:1}e=p[b+708>>2];c=c+d|0;c=(c|0)>(e|0)?e:c;break j}if((c|0)<=(e|0)){break i}d=0-p[b+776>>2]|0;l:{if(!(q[a+480208|0]&16)){break l}if(p[a+480180>>2]==4){c=p[b+700>>2];break l}c=p[b+776>>2]/4|0;c=p[((c>>>0<255?c:255)<<2)+26272>>2];d=c;e=c>>31;c=p[b+700>>2];d=NNa(d,e,c,c>>31)+32768|0;c=ib;d=rc(ONa(d,d>>>0<32768?c+1|0:c,65536,0),ib);c=p[b+700>>2];d=d-c|0;d=(d|0)<-1?d:-1}e=p[b+708>>2];c=c+d|0;c=(c|0)<(e|0)?e:c}p[g+700>>2]=c}if((c|0)!=(e|0)){break c}vb(f+8|0,a+1074308|0,25);if(j=!tb(f+8|0),k=0,l=p[a+480180>>2]!=1,l?j:k){break c}p[b+708>>2]=0}fb=f+16|0}function Nu(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb-96|0;fb=c;g=a;i=a;a:{b:{c:{d:{e:{if(!(j=0,k=!od(a,11),l=p[a+4>>2],l?j:k)){d=p[a+28>>2];b=c+80|0;e=p[a+12>>2];f=p[a+64>>2];h=f+p[a+8>>2]|0;if(h>>>0<f>>>0){e=e+1|0}e=Bg(b,h,e);f=p[e+12>>2];p[c+32>>2]=p[e+8>>2];p[c+36>>2]=f;b=p[e+4>>2];p[c+24>>2]=p[e>>2];p[c+28>>2]=b;Ni(d,c+24|0);b=p[a+28>>2];if(wt(p[p[b>>2]+ -12>>2]+b|0)){vg(a,1073741826);break a}e=a+44|0;BZ(e,p[a+92>>2]);f=a+32|0;lD(f,p[a+92>>2]<<2);if(p[a+92>>2]){b=0;while(1){d=p[a+28>>2];if(wt(p[p[d>>2]+ -12>>2]+d|0)){vg(a,1073741828);break a}d=r[a+16>>1];o[c+78>>1]=d;if((d|0)==65535){Pu(p[a+28>>2],c+78|0)}j=c,k=Cc(f),p[j+72>>2]=k;f:{if(!r[c+78>>1]){d=0;break f}h=p[c+72>>2];d=r[c+78>>1];if(-1-h>>>0<d>>>0){break f}Tn(f,d+h|0);Hj(p[a+28>>2],oc(f,p[c+72>>2]),r[c+78>>1]);d=r[c+78>>1]}j=jc(e,b),k=d,o[j+12>>1]=k;d=p[c+72>>2];j=jc(e,b),k=d,p[j>>2]=k;if(od(a,6)){sj(p[a+28>>2],c+56|0);if(s[c+60>>2]>2147483647){break e}d=p[c+56>>2];j=jc(e,b),k=d,p[j+4>>2]=k}d=p[a+4>>2];g:{if(d){j=jc(e,b),k=d,p[j+8>>2]=k;break g}if(!od(a,7)){break g}sj(p[a+28>>2],c+56|0);if(s[c+60>>2]>2147483647){break d}d=p[c+56>>2];j=jc(e,b),k=d,p[j+8>>2]=k}h:{if(p[jc(e,b)+8>>2]==-1){break h}if(od(a,6)){break h}if(b){d=b+ -1|0;d=p[jc(e,d)+4>>2]+p[jc(e,d)+8>>2]|0}else{d=0}j=jc(e,b),k=d,p[j+4>>2]=k}if(od(a,8)){o[c+56>>1]=0;Pu(p[a+28>>2],c+56|0);d=od(a,9);Tk(p[a+28>>2],r[c+56>>1]<<d,-1)}b=b+1|0;if(b>>>0<s[a+92>>2]){continue}break}}df(c+56|0,p[a+28>>2]);b=p[c+68>>2];p[a+72>>2]=p[c+64>>2];p[a+76>>2]=b}tj(a,4,1);e=p[a+88>>2];if((e|0)!=p[a+64>>2]){break c}b=p[a+76>>2];d=p[a+72>>2];break b}vg(a,1073741829);break a}vg(a,1073741829);break a}b=p[a+12>>2];d=e+p[a+8>>2]|0;if(d>>>0<e>>>0){b=b+1|0}}e=d;p[i+80>>2]=e;p[g+84>>2]=b;g=p[a+28>>2];b=Bg(c+40|0,e,b);e=p[b+12>>2];p[c+16>>2]=p[b+8>>2];p[c+20>>2]=e;e=p[b+4>>2];p[c+8>>2]=p[b>>2];p[c+12>>2]=e;Ni(g,c+8|0);if(od(a,6)){break a}if((j=0,k=!od(a,7),l=p[a+4>>2],l?j:k)|!p[a+92>>2]){break a}b=p[a+80>>2];g=p[a+8>>2];g=b-g|0;e=a+44|0;b=0;while(1){d=jc(e,b);p[d+4>>2]=g+p[d+4>>2];b=b+1|0;if(b>>>0<s[a+92>>2]){continue}break}}fb=c+96|0}function mva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;e=fb-80|0;fb=e;w=p[a+16>>2];h=Df(e+48|0);p[h+8>>2]=a+112;p[h+16>>2]=p[a+128>>2];y=h,z=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[y+12>>2]=z;b=p[h+16>>2];if(b){y=h,z=Cf(a+8|0,b),p[y>>2]=z;p[h+4>>2]=ib}f=p[a+44>>2];p[e+32>>2]=f;m=p[a+48>>2];p[e+36>>2]=m;k=p[a+52>>2];p[e+40>>2]=k;l=p[a+56>>2];p[e+44>>2]=l;o=p[a+40>>2];q=p[a+36>>2];i=p[a+4>>2];g=p[a>>2];p[e+24>>2]=g;p[e+28>>2]=i;b=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=b;a:{if(!d){b=o>>12;j=q>>12;break a}while(1){b=0;f=b;j=g;p[e+72>>2]=g;p[e+76>>2]=b;i=(((i&2147483647)<<1|g>>>31)&-2)+w|0;b:{b=p[h+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;qd(p[h+8>>2],n[(g|1)+i|0]+n[i+(g&-2)|0]<<5);pd(p[h+8>>2],4);Kb(e+72|0,h);if((b|0)<2){break b}b=b+ -1|0;j=p[e+72>>2];f=p[e+76>>2];continue}}b=p[h+8>>2];Kb(b,b+8|0);b=p[h+8>>2];g=p[b+4>>2];if(g){f=b;b=(p[e+76>>2]&2147483647)<<1|p[e+72>>2]>>>31;qd(f,n[(b|1)+i|0]+n[i+(b&-2)|0]<<5);pd(p[h+8>>2],g);b=p[h+8>>2];g=p[b>>2];p[b>>2]=g;p[b+4>>2]=0}d=d+ -1|0;f=xf(b,p[h+12>>2]);p[e+12>>2]=f;p[e+8>>2]=f;j=0;m=1;while(1){k=p[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;r=p[i>>2];b=Pb(r,-16777216,16776704);u=p[a+64>>2];g=Pb(p[i+4>>2],-16777216,16776704);s=p[a+68>>2];x=s;s=s>>31;p[i+4>>2]=r;r=p[a+72>>2];t=k>>31;k=f<<8;f=k;f=NNa(l,t,f,f>>31);l=ib;t=(e+8|0)+(j<<2)|0;j=NNa(u,u>>31,b,b>>31);f=j+f|0;b=ib+l|0;b=f>>>0<j>>>0?b+1|0:b;l=f;f=NNa(x,s,g,g>>31);g=l+f|0;b=ib+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;p[t>>2]=(b|0)/256;p[i>>2]=b-(k&r);if(m){j=1;m=0;f=p[e+12>>2];continue}break}b=p[a+32>>2];q=p[a+28>>2]+q|0;j=q>>12;p[c>>2]=p[c>>2]+v(j,p[e+8>>2]);o=b+o|0;b=o>>12;p[c+4>>2]=p[c+4>>2]+v(b,p[e+12>>2]);Kb(e+24|0,e+16|0);if(d){c=c+8|0;g=p[e+24>>2];i=p[e+28>>2];continue}break}g=p[e+24>>2];i=p[e+28>>2];l=p[e+44>>2];k=p[e+40>>2];m=p[e+36>>2];f=p[e+32>>2]}p[a+40>>2]=o;p[a+20>>2]=j;p[a+36>>2]=q;p[a+56>>2]=l;p[a+52>>2]=k;p[a+48>>2]=m;p[a+44>>2]=f;p[a+24>>2]=b;p[a>>2]=g;p[a+4>>2]=i;fb=e+80|0}function Uva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;g=fb-48|0;fb=g;w=p[a+16>>2];a:{b:{c:{i=p[a+8>>2];f=p[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}x=b;h=p[a+44>>2];p[g+32>>2]=h;m=p[a+48>>2];p[g+36>>2]=m;k=p[a+52>>2];p[g+40>>2]=k;l=p[a+56>>2];p[g+44>>2]=l;q=p[a+40>>2];r=p[a+36>>2];e=p[a+4>>2];j=p[a>>2];p[g+24>>2]=j;p[g+28>>2]=e;p[g+16>>2]=i;p[g+20>>2]=f;e:{if(!d){b=q>>12;f=r>>12;break e}while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+w|0;e=(j>>>16&65520)+x|0;j=o[e+14>>1];i=o[e+12>>1];l=o[e+10>>1];s=o[e+8>>1];y=o[e+6>>1];n=o[e+4>>1];t=o[e+2>>1];u=o[e>>1];h=0;k=1;f=0;while(1){e=f<<1;p[(g+8|0)+(f<<2)>>2]=(((((((v(o[b+(e|-8)>>1],t)+v(o[b+(e|-12)>>1],u)|0)+v(o[b+(e|-4)>>1],n)|0)+v(o[b+e>>1],y)|0)+v(o[b+(e|4)>>1],s)|0)+v(o[b+(e|8)>>1],l)|0)+v(i,o[b+(e|12)>>1])|0)+v(j,o[b+(e|16)>>1])|0)/32768;e=k&1;k=0;f=1;if(e){continue}break}while(1){k=(g+8|0)+(h<<2)|0;j=p[k>>2];i=p[a+60>>2];e=(g+32|0)+(h<<3)|0;h=p[e>>2];b=Pb(h,-16777216,16776704);s=p[a+64>>2];f=Pb(p[e+4>>2],-16777216,16776704);n=p[a+68>>2];t=n;n=n>>31;p[e+4>>2]=h;u=p[a+72>>2];j=j<<8;h=j;h=NNa(i,i>>31,h,h>>31);i=ib;l=k;k=NNa(s,s>>31,b,b>>31);h=k+h|0;b=ib+i|0;b=h>>>0<k>>>0?b+1|0:b;i=h;h=NNa(t,n,f,f>>31);f=i+h|0;b=ib+b|0;b=f>>>0<h>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;p[l>>2]=(b|0)/256;p[e>>2]=b-(j&u);h=1;b=m&1;m=0;if(b){continue}break}b=p[a+32>>2];r=p[a+28>>2]+r|0;f=r>>12;p[c>>2]=p[c>>2]+v(f,p[g+8>>2]);q=b+q|0;b=q>>12;p[c+4>>2]=p[c+4>>2]+v(b,p[g+12>>2]);Kb(g+24|0,g+16|0);d=d+ -1|0;if(d){c=c+8|0;j=p[g+24>>2];e=p[g+28>>2];continue}break}j=p[g+24>>2];e=p[g+28>>2];l=p[g+44>>2];k=p[g+40>>2];m=p[g+36>>2];h=p[g+32>>2]}p[a+40>>2]=q;p[a+20>>2]=f;p[a+36>>2]=r;p[a+56>>2]=l;p[a+52>>2]=k;p[a+48>>2]=m;p[a+44>>2]=h;p[a+24>>2]=b;p[a>>2]=j;p[a+4>>2]=e;fb=g+48|0}function vJ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;e=v(b,896)+a|0;a:{if(q[e+1075074|0]&2){j=1;b:{if(!(q[a+480209|0]&16)){break b}j=0;if(!(p[a+480180>>2]&16777248)){break b}j=!(q[a+480208|0]&4)}if(p[a+480180>>2]==64){a=v(b,896)+a|0;b=a+1075823|0;d=q[b|0];if(d&1){p[c>>2]=p[c>>2]+v(q[a+1075828|0],167)}n[b|0]=d+1;break a}g=e+1074984|0;c:{if(!j){break c}vb(h+8|0,a+1074308|0,21);if(!tb(h+8|0)){break c}e=v(b,896)+a|0;f=e+1075823|0;n[f|0]=q[f|0]+(q[e+1075827|0]<<2)}f=v(b,896)+a|0;i=f+1075826|0;k=f+1075823|0;e=ex(a,q[i|0],q[k|0]);d:{if(dj(g)){t[d>>2]=w(w(v(q[f+1075828|0],e)|0)*w(6510417279059766e-21))+t[d>>2];c=f+1075856|0;d=q[c|0];n[c|0]=d&243|8;if(p[a+1074416>>2]!=(p[a+1074392>>2]+1|0)){break d}n[c|0]=d|12;break d}if((p[a+480208>>2]&2101248)==2101248|(q[a+480209|0]&16?p[a+480180>>2]&67633152:0)){break a}e=p[a+480180>>2]&5?(q[i|0]&3)==1?0-e|0:e:e;g=a+1074308|0;vb(h+8|0,g,21);d=tb(h+8|0);f=p[a+480208>>2];e:{if(d){d=f&4;e=d?e:0-e|0;d=d?5:6;break e}d=5;f:{if(f&131072){break f}d=8;if(p[a+480180>>2]==1024){break f}d=7;if(p[a+480180>>2]&524304|(q[a+480208|0]&4?0:p[a+480180>>2]&16777248)){break f}d=6}vb(h+8|0,g,80);if(!tb(h+8|0)){break e}d=q[(v(b,896)+a|0)+1075797|0]==26?d+2|0:d}d=(v(q[(v(b,896)+a|0)+1075828|0],e)|0)/(1<<d)|0;f=0-d|0;g:{if(!(q[a+480208|0]&16)|p[a+480180>>2]==4){break g}e=p[c>>2];if((d|0)<=-1){d=xx(a,f>>>2|0);d=rc(ONa(NNa(d,d>>31,e,e>>31),ib,65536,0),ib);e=p[c>>2];d=d-e|0;g=f&3;if(!g){break g}i=d;d=wK(a,g);d=(i+rc(ONa(NNa(d,d>>31,e,e>>31),ib,65536,0),ib)|0)-p[c>>2]|0;break g}g=d&3;d=wx(a,d>>>2|0);d=rc(ONa(NNa(d,d>>31,e,e>>31),ib,65536,0),ib);e=p[c>>2];d=d-e|0;if(!g){break g}i=d;d=vK(a,g);d=(i+rc(ONa(NNa(d,d>>31,e,e>>31),ib,65536,0),ib)|0)-p[c>>2]|0}p[c>>2]=p[c>>2]+d;c=yx(a,b);if(!c){break d}d=c;e=f<<16>>16;g=p[(v(b,896)+a|0)+1075640>>2];i=2;h:{if(!g){break h}i=q[g+33|0]}m[p[p[c>>2]+84>>2]](d,e,i<<24>>24,b)}if(!j){break a}vb(h+8|0,a+1074308|0,21);if(tb(h+8|0)){break a}n[k|0]=q[k|0]+q[(v(b,896)+a|0)+1075827|0];break a}if(!(q[e+1075654|0]&2)){break a}a=yx(a,b);if(!a){break a}m[p[p[a>>2]+84>>2]](a,0,0,b)}fb=h+16|0}function WB(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;j=fb-128|0;fb=j;a:{b:{c:{if(!Wk(f,g,h,i,0,0,0,0)){break c}o=cY(f,g,h,i);t=e>>>16|0;q=t&32767;if((q|0)==32767){break c}if(o){break b}}jd(j+16|0,b,c,d,e,f,g,h,i);b=p[j+16>>2];c=p[j+20>>2];d=p[j+24>>2];e=p[j+28>>2];SD(j,b,c,d,e,b,c,d,e);d=p[j+8>>2];e=p[j+12>>2];h=p[j>>2];i=p[j+4>>2];break a}l=q<<16;n=d;l=l|e&65535;o=l;m=h;s=i>>>16&32767;k=i&65535|s<<16;if((Wk(b,c,n,l,f,g,h,k)|0)<=0){if(Wk(b,c,n,o,f,g,m,k)){h=b;i=c;break a}jd(j+112|0,b,c,d,e,0,0,0,0);d=p[j+120>>2];e=p[j+124>>2];h=p[j+112>>2];i=p[j+116>>2];break a}if(q){i=c;h=b}else{jd(j+96|0,b,c,n,o,0,0,0,1081540608);h=p[j+108>>2];o=h;n=p[j+104>>2];q=(h>>>16|0)+ -120|0;i=p[j+100>>2];h=p[j+96>>2]}if(!s){jd(j+80|0,f,g,m,k,0,0,0,1081540608);f=p[j+92>>2];k=f;m=p[j+88>>2];s=(k>>>16|0)+ -120|0;g=p[j+84>>2];f=p[j+80>>2]}u=k&65535|65536;o=o&65535|65536;if((q|0)>(s|0)){while(1){k=n;r=k-m|0;l=(g|0)==(i|0)&h>>>0<f>>>0|i>>>0<g>>>0;k=(o-((k>>>0<m>>>0)+u|0)|0)-(r>>>0<l>>>0)|0;r=r-l|0;d:{if((k|0)>0?1:(k|0)>=0?r>>>0>=0:0){n=h;h=h-f|0;i=i-((n>>>0<f>>>0)+g|0)|0;if(!(h|r|(i|k))){jd(j+32|0,b,c,d,e,0,0,0,0);d=p[j+40>>2];e=p[j+44>>2];h=p[j+32>>2];i=p[j+36>>2];break a}n=i>>>31|0;o=0;l=k<<1|r>>>31;k=r<<1;break d}l=o<<1|n>>>31;n=n<<1;o=l;l=0;k=i>>>31|0}r=l;l=i<<1|h>>>31;h=h<<1;i=l;n=k|n;o=o|r;q=q+ -1|0;if((q|0)>(s|0)){continue}break}q=s}e:{k=n;l=k-m|0;k=o-((k>>>0<m>>>0)+u|0)|0;m=(g|0)==(i|0)&h>>>0<f>>>0|i>>>0<g>>>0;k=k-(l>>>0<m>>>0)|0;m=l-m|0;if((k|0)<0?1:(k|0)<=0?m>>>0<0:0){m=n;k=o;break e}n=h;h=h-f|0;i=i-((n>>>0<f>>>0)+g|0)|0;if(h|m|(i|k)){break e}jd(j+48|0,b,c,d,e,0,0,0,0);d=p[j+56>>2];e=p[j+60>>2];h=p[j+48>>2];i=p[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){d=i>>>31|0;b=0;q=q+ -1|0;l=i<<1|h>>>31;h=h<<1;i=l;l=k<<1|m>>>31;m=m<<1|d;b=b|l;k=b;if((k|0)==65536&m>>>0<0|k>>>0<65536){continue}break}}b=t&32768;if((q|0)<=0){jd(j- -64|0,h,i,m,k&65535|(b|q+120)<<16,0,0,0,1065811968);d=p[j+72>>2];e=p[j+76>>2];h=p[j+64>>2];i=p[j+68>>2];break a}d=m;e=k&65535|(b|q)<<16}p[a>>2]=h;p[a+4>>2]=i;p[a+8>>2]=d;p[a+12>>2]=e;fb=j+128|0}function Wva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;e=fb-48|0;fb=e;x=p[a+16>>2];a:{b:{c:{i=p[a+8>>2];f=p[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}y=b;g=p[a+44>>2];p[e+32>>2]=g;m=p[a+48>>2];p[e+36>>2]=m;k=p[a+52>>2];p[e+40>>2]=k;l=p[a+56>>2];p[e+44>>2]=l;r=p[a+40>>2];s=p[a+36>>2];h=p[a+4>>2];j=p[a>>2];p[e+24>>2]=j;p[e+28>>2]=h;p[e+16>>2]=i;p[e+20>>2]=f;e:{if(!d){b=r>>12;f=s>>12;break e}while(1){h=(((h&2147483647)<<1|j>>>31)&-2)+x|0;b=(j>>>16&65520)+y|0;f=o[b+14>>1];j=o[b+12>>1];i=o[b+10>>1];l=o[b+8>>1];t=o[b+6>>1];z=o[b+4>>1];q=o[b+2>>1];u=o[b>>1];g=0;m=1;k=1;b=0;while(1){p[(e+8|0)+(b<<2)>>2]=(((((((v(n[h+(b|-4)|0],q)+v(n[h+(b|-6)|0],u)|0)+v(n[h+(b|-2)|0],z)|0)+v(n[b+h|0],t)|0)+v(n[h+(b|2)|0],l)|0)+v(n[h+(b|4)|0],i)|0)+v(j,n[h+(b|6)|0])|0)+v(f,n[h+(b|8)|0])<<8)/32768;w=k&1;k=0;b=1;if(w){continue}break}while(1){k=(e+8|0)+(g<<2)|0;j=p[k>>2];i=p[a+60>>2];h=(e+32|0)+(g<<3)|0;g=p[h>>2];b=Pb(g,-16777216,16776704);t=p[a+64>>2];f=Pb(p[h+4>>2],-16777216,16776704);q=p[a+68>>2];u=q;q=q>>31;p[h+4>>2]=g;w=p[a+72>>2];j=j<<8;g=j;g=NNa(i,i>>31,g,g>>31);i=ib;l=k;k=NNa(t,t>>31,b,b>>31);g=k+g|0;b=ib+i|0;b=g>>>0<k>>>0?b+1|0:b;i=g;g=NNa(u,q,f,f>>31);f=i+g|0;b=ib+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;p[l>>2]=(b|0)/256;p[h>>2]=b-(j&w);g=1;b=m&1;m=0;if(b){continue}break}b=p[a+32>>2];s=p[a+28>>2]+s|0;f=s>>12;p[c>>2]=p[c>>2]+v(f,p[e+8>>2]);r=b+r|0;b=r>>12;p[c+4>>2]=p[c+4>>2]+v(b,p[e+12>>2]);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;j=p[e+24>>2];h=p[e+28>>2];continue}break}j=p[e+24>>2];h=p[e+28>>2];l=p[e+44>>2];k=p[e+40>>2];m=p[e+36>>2];g=p[e+32>>2]}p[a+40>>2]=r;p[a+20>>2]=f;p[a+36>>2]=s;p[a+56>>2]=l;p[a+52>>2]=k;p[a+48>>2]=m;p[a+44>>2]=g;p[a+24>>2]=b;p[a>>2]=j;p[a+4>>2]=h;fb=e+48|0}function z0(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,r=0;a=fb-1072|0;fb=a;p[a+16>>2]=f;p[a+20>>2]=g;p[a+24>>2]=h;p[a+28>>2]=i;p[a+956>>2]=a+960;j=fv(a+960|0,100,62383,a+16|0);p[a+48>>2]=2420;n=Hd(a+536|0,0,a+48|0);p[a+48>>2]=2420;m=Hd(a+528|0,0,a+48|0);l=a+544|0;a:{b:{c:{if(j>>>0>=100){p[114610]=0;j=Y(2445)|0;l=p[114610];p[114610]=0;if((l|0)==1){break b}p[a>>2]=f;p[a+4>>2]=g;p[114610]=0;p[a+8>>2]=h;p[a+12>>2]=i;j=U(2467,a+956|0,j|0,62383,a|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}f=p[a+956>>2];if(!f){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)!=1){break c}break b}pe(n,f);pe(m,fd(j<<2));if(aj(m)){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)==1){break b}break c}l=p[m>>2]}p[114610]=0;qc(a+520|0,d);f=p[114610];p[114610]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){p[114610]=0;r=M(2449,a+520|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break j}p[114610]=0;f=p[a+956>>2];U(2463,r|0,f|0,f+j|0,l|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break j}o=j?q[p[a+956>>2]]==45:o;h=Lb(a+488|0);g=Ue(a+472|0);f=Ue(a+456|0);p[114610]=0;ga(2503,c|0,o|0,a+520|0,a+512|0,a+508|0,a+504|0,h|0,g|0,f|0,a+452|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}p[a+36>>2]=2420;i=Hd(a+40|0,0,a+36|0);c=p[a+452>>2];k:{if((j|0)>(c|0)){k=wb(f)+(j-c<<1|1)|0;break k}k=wb(f)+2|0}c=a+48|0;k=(wb(g)+k|0)+p[a+452>>2]|0;if(k>>>0<101){break h}pe(i,fd(k<<2));c=p[i>>2];if(c){break h}p[114610]=0;R(2421);b=p[114610];p[114610]=0;if((b|0)!=1){break c}break g}j=I()|0;H()|0;break a}j=I()|0;H()|0;break e}j=I()|0;H()|0;break f}k=p[d+4>>2];p[114610]=0;la(2504,c|0,a+36|0,a+32|0,k|0,l|0,(j<<2)+l|0,r|0,o|0,a+512|0,p[a+508>>2],p[a+504>>2],h|0,g|0,f|0,p[a+452>>2]);j=p[114610];p[114610]=0;if((j|0)!=1){p[114610]=0;b=da(2479,b|0,c|0,p[a+36>>2],p[a+32>>2],d|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break d}}}j=I()|0;H()|0;wc(i)}yc(f);yc(g);pb(h)}Gb(a+520|0);break a}wc(i);yc(f);yc(g);pb(h);Gb(a+520|0);wc(m);wc(n);fb=a+1072|0;return b|0}E()}j=I()|0;H()|0}wc(m);wc(n);L(j|0);E()}function Pxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb+ -64|0;fb=d;o[d+62>>1]=c;Lg(d+62|0,32);f=wn(a);p[114610]=0;K(798,f|0,r[d+62>>1]);a=p[114610];p[114610]=0;a:{if((a|0)!=1){b:{c:{if(!r[d+62>>1]){break c}while(1){a=r[b+480190>>1]+1|0;o[d+60>>1]=a;d:{e:{if((a&65535)>>>0<4e3){break e}o[d+24>>1]=1;f:{if(!r[b+480190>>1]){break f}while(1){g:{if(ue(cp(b,r[d+24>>1]))){break g}i=d,j=Fy(Ub(f),Vb(f),d+24|0),p[i+48>>2]=j;i=d,j=Vb(f),p[i+40>>2]=j;if(!ll(d+48|0,d+40|0)){break g}o[d+60>>1]=r[d+24>>1];a=1;if(!r[b+480192>>1]){break f}while(1){c=p[(((a&65535)<<2)+b|0)+900380>>2];h:{if(!c){break h}c=c+236|0;e=xs(c);if((c|0)==(e|0)){break h}while(1){if(r[c>>1]==r[d+60>>1]){o[c>>1]=0}c=c+2|0;if((e|0)!=(c|0)){continue}break}}a=a+1|0;if((a&65535)>>>0<=r[b+480192>>1]){continue}break}break f}a=r[d+24>>1]+1|0;o[d+24>>1]=a;if((a&65535)>>>0<=r[b+480190>>1]){continue}break}}if(r[d+60>>1]<4e3){break e}a=Hs(d+48|0);p[114610]=0;c=J(1051,b|0,a|0)|0;e=p[114610];p[114610]=0;i:{j:{if((e|0)==1){break j}k:{if(c){p[114610]=0;J(1052,b|0,a|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break j}e=1;if(!r[b+480192>>1]){break k}while(1){c=p[(((e&65535)<<2)+b|0)+900380>>2];l:{if(!c){break l}c=c+236|0;g=xs(c);if((c|0)==(g|0)){break l}while(1){m:{if(s[a+4>>2]<=r[c>>1]){break m}Wd(d+40|0,a,r[c>>1]);if(tb(d+40|0)){break m}o[c>>1]=0}c=c+2|0;if((g|0)!=(c|0)){continue}break}}e=e+1|0;if((e&65535)>>>0<=r[b+480192>>1]){continue}break}break k}ce(a);break c}ej(d+24|0,a);p[114610]=0;N(1053,d+32|0,d+24|0,1);c=p[114610];p[114610]=0;if((c|0)!=1){bk(d+16|0,a);p[114610]=0;n[d+15|0]=0;Q(1054,d+40|0,d+32|0,d+16|0,d+15|0);c=p[114610];p[114610]=0;if((c|0)!=1){break i}}}c=I()|0;H()|0;ce(a);break a}ej(d,a);i=d,j=ki(d+40|0,d),o[i+60>>1]=j;ce(a);if(r[d+60>>1]>=4e3){break d}}p[114610]=0;K(461,f|0,d+60|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}if(r[d+60>>1]<=r[b+480190>>1]){break d}o[b+480190>>1]=r[d+60>>1]}h=h+1|0;if((h&65535)>>>0<r[d+62>>1]){continue}break}}fb=d- -64|0;return}c=I()|0;H()|0;break a}c=I()|0;H()|0}qf(f);L(c|0);E()}function dv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=p[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=p[d>>2];if(!g){break l}if(!a){d=c;break j}p[d>>2]=0;d=c;break k}m:{if(!p[p[21199]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=n[e|0];if(d){p[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g+ -1|0;if(g){continue}break a}break}p[a>>2]=0;p[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return ve(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=q[e|0]>>>3|0;if((f+ -16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}h=e;if((q[e+1|0]&192)!=128){break f}f=e+2|0;if(!(g&524288)){break n}if((q[h+2|0]&192)!=128){break f}f=e+3|0}e=f;d=d+ -1|0;f=1;continue}while(1){g=q[e|0];o:{if(e&3|g+ -1>>>0>126){break o}g=p[e>>2];if((g|g+ -16843009)&-2139062144){break o}while(1){d=d+ -4|0;g=p[e+4>>2];f=e+4|0;e=f;if(!((g+ -16843009|g)&-2139062144)){continue}break}e=f}f=g&255;if(f+ -1>>>0<=126){d=d+ -1|0;e=e+1|0;continue}break}f=f+ -194|0;if(f>>>0>50){break e}e=e+1|0;g=p[(f<<2)+57632>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=q[e|0];h=f+ -1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=p[e>>2];if((g|g+ -16843009)&-2139062144){break s}p[a>>2]=g&255;p[a+4>>2]=q[e+1|0];p[a+8>>2]=q[e+2|0];p[a+12>>2]=q[e+3|0];a=a+16|0;e=e+4|0;d=d+ -4|0;if(d>>>0>4){continue}break}g=q[e|0]}f=g&255;h=f+ -1|0}if(h>>>0>126){break p}}p[a>>2]=f;a=a+4|0;e=e+1|0;d=d+ -1|0;if(d){continue}break a}break}f=f+ -194|0;if(f>>>0>50){break e}e=e+1|0;g=p[(f<<2)+57632>>2];f=1;continue}h=q[e|0];f=h>>>3|0;if((f+ -16|f+(g>>26))>>>0>7){break f}t:{u:{f=h+ -128|g<<6;i=e+1|0;v:{if((f|0)>-1){break v}h=e;i=q[e+1|0]+ -128|0;if(i>>>0>63){break u}f=f<<6|i;i=e+2|0;if((f|0)>-1){break v}h=q[h+2|0]+ -128|0;if(h>>>0>63){break u}f=h|f<<6;i=e+3|0}e=i;p[a>>2]=f;d=d+ -1|0;a=a+4|0;break t}p[114584]=25;e=e+ -1|0;break c}f=0;continue}}e=e+ -1|0;if(g){break d}g=q[e|0]}if(g&255){break d}if(a){p[a>>2]=0;p[b>>2]=0}return c-d|0}p[114584]=25;if(!a){break b}}p[b>>2]=e}return-1}p[b>>2]=e;return c|0}function fda(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=fb-48|0;fb=k;a:{b:{c:{j=Rn(1,32);d:{e:{if(!j){a=W(4)|0;Kk(a);p[114610]=0;N(2009,a|0,71348,2008);a=p[114610];p[114610]=0;if((a|0)!=1){break a}i=O(0)|0;H()|0;break e}p[j+16>>2]=0;p[j+20>>2]=0;p[j+12>>2]=f;p[j+8>>2]=e;p[j+4>>2]=d;p[j+24>>2]=0;p[j+28>>2]=0;p[j>>2]=c?c:1997;d=js(k+32|0);f:{g:{if(!i){break g}c=p[i>>2];if(!c){break g}while(1){h:{e=p[i+4>>2];if(e){p[114610]=0;c=J(85,k+16|0,c|0)|0;f=p[114610];p[114610]=0;i:{if((f|0)!=1){p[114610]=0;f=J(2010,d|0,c|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break i}p[114610]=0;J(483,f|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break i}break h}i=O(0)|0;H()|0;break f}i=O(0)|0;H()|0;pb(c);break f}p[114610]=0;c=J(85,k+16|0,c|0)|0;e=p[114610];p[114610]=0;j:{if((e|0)!=1){p[114610]=0;J(2011,d|0,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break j}break h}i=O(0)|0;H()|0;break f}i=O(0)|0;H()|0;pb(c);break f}pb(c);c=p[i+8>>2];i=i+8|0;if(c){continue}break}}p[114610]=0;c=M(1398,96)|0;e=p[114610];p[114610]=0;k:{l:{m:{if((e|0)!=1){p[114610]=0;N(2012,k+16|0,j|0,j+4|0);e=p[114610];p[114610]=0;if((e|0)==1){break m}e=oo(k+8|0,k+16|0);p[114610]=0;Z(2087,c|0,a|0,b|0,e|0,d|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break l}p[j+28>>2]=c;Nc(e);Nc(k+16|0);a=p[j+28>>2];p[j+24>>2]=a?a+8|0:0;Yj(d);break d}i=O(0)|0;H()|0;break f}i=O(0)|0;H()|0;break k}i=O(0)|0;H()|0;Nc(e);Nc(k+16|0)}Nb(c)}Yj(d);T(i|0)|0;p[114610]=0;Q(1989,37159,j|0,g|0,h|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)!=1){a=p[j+28>>2];if(a){m[p[p[a>>2]+4>>2]](a)}p[j+24>>2]=0;p[j+28>>2]=0;a=p[j+20>>2];if(a){Nb(a)}Nb(j);j=0;break d}i=O(0)|0;H()|0;break e}i=O(0)|0;H()|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break b}}T(i|0)|0;j=0;p[114610]=0;Q(1989,37159,0,g|0,h|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}V()}fb=k+48|0;return j|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}a=O(0)|0;H()|0;rb(a)}E()}function pva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;e=fb-80|0;fb=e;s=p[a+16>>2];i=Df(e+48|0);p[i+8>>2]=a+112;p[i+16>>2]=p[a+128>>2];y=i,z=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[y+12>>2]=z;b=p[i+16>>2];if(b){y=i,z=Cf(a+8|0,b),p[y>>2]=z;p[i+4>>2]=ib}b=p[a+44>>2];p[e+32>>2]=b;g=p[a+48>>2];p[e+36>>2]=g;h=p[a+52>>2];p[e+40>>2]=h;l=p[a+56>>2];p[e+44>>2]=l;t=p[a+24>>2];u=p[a+20>>2];j=p[a+4>>2];f=p[a>>2];p[e+24>>2]=f;p[e+28>>2]=j;k=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=k;if(d){while(1){b=0;g=b;h=f;p[e+72>>2]=f;p[e+76>>2]=b;j=((((j&2147483647)<<1|f>>>31)&2147483646)<<1)+s|0;a:{b=p[i+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|h>>>31;qd(p[i+8>>2],(o[(f<<1|2)+j>>1]+o[j+((f&2147483646)<<1)>>1]|0)/8<<16>>16);pd(p[i+8>>2],4);Kb(e+72|0,i);if((b|0)<2){break a}b=b+ -1|0;h=p[e+72>>2];g=p[e+76>>2];continue}}b=p[i+8>>2];Kb(b,b+8|0);b=p[i+8>>2];f=p[b+4>>2];if(f){k=b;b=(p[e+76>>2]&2147483647)<<1|p[e+72>>2]>>>31;qd(k,(o[(b<<1|2)+j>>1]+o[j+((b&2147483646)<<1)>>1]|0)/8<<16>>16);pd(p[i+8>>2],f);b=p[i+8>>2];f=p[b>>2];p[b>>2]=f;p[b+4>>2]=0}d=d+ -1|0;h=xf(b,p[i+12>>2]);p[e+12>>2]=h;p[e+8>>2]=h;g=0;l=1;while(1){k=p[a+60>>2];q=k;j=(e+32|0)+(g<<3)|0;m=p[j>>2];b=Pb(m,-16777216,16776704);r=p[a+64>>2];f=Pb(p[j+4>>2],-16777216,16776704);n=p[a+68>>2];w=n;n=n>>31;p[j+4>>2]=m;m=p[a+72>>2];k=k>>31;h=h<<8;k=NNa(q,k,h,h>>31);q=ib;x=(e+8|0)+(g<<2)|0;g=k;k=NNa(r,r>>31,b,b>>31);g=g+k|0;b=ib+q|0;b=g>>>0<k>>>0?b+1|0:b;k=g;g=NNa(w,n,f,f>>31);f=k+g|0;b=ib+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;p[x>>2]=(b|0)/256;p[j>>2]=b-(h&m);if(l){g=1;l=0;h=p[e+12>>2];continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],u);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],t);Kb(e+24|0,e+16|0);if(d){c=c+8|0;f=p[e+24>>2];j=p[e+28>>2];continue}break}f=p[e+24>>2];j=p[e+28>>2];l=p[e+44>>2];h=p[e+40>>2];g=p[e+36>>2];b=p[e+32>>2]}p[a+56>>2]=l;p[a+52>>2]=h;p[a+48>>2]=g;p[a+44>>2]=b;p[a>>2]=f;p[a+4>>2]=j;fb=e+80|0}function jta(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-368|0;fb=c;NL(c+80|0);h=ac(b,c+80|0,282);b=0;if(Dh(a,20044)){jg(a,4);f=Re(c- -64|0,a);p[114610]=0;e=J(1202,f|0,h|0)|0;d=p[114610];p[114610]=0;a:{b:{c:{d:{if((d|0)==1){break d}if(!e){break a}e=h+26|0;d=q[e|0];p[114610]=0;d=J(258,f|0,d|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break d}if(!d){break a}if(!q[e|0]){d=0;break c}d=0;while(1){e:{p[114610]=0;g=M(375,f|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break e}n[(b+h|0)+27|0]=g;d=d+g|0;b=b+1|0;if(b>>>0<q[e|0]){continue}break c}break}b=I()|0;H()|0;break b}b=I()|0;H()|0;break b}b=0;p[114610]=0;g=d&65535;d=J(258,f|0,g|0)|0;i=p[114610];p[114610]=0;f:{if((i|0)==1){break f}if(!d){break a}p[114610]=0;J(338,f|0,g|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}jg(f,OL(h));p[114610]=0;d=M(1203,c+56|0)|0;b=p[114610];p[114610]=0;g:{if((b|0)!=1){ML(c+80|0);p[114610]=0;J(1204,f|0,c+80|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;o[c+102>>1]=0;o[c+104>>1]=0;P(1205,d|0,c+80|0,c+107|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}b=q[e|0];p[114610]=0;J(338,f|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}b=q[e|0];p[114610]=0;e=h+27|0;P(1205,d|0,e|0,b+e|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;N(341,c+40|0,f|0,g|0);b=p[114610];p[114610]=0;h:{i:{j:{if((b|0)!=1){p[114610]=0;K(862,c+16|0,c+40|0);b=p[114610];p[114610]=0;if((b|0)==1){break j}p[114610]=0;K(1207,c+8|0,c+16|0);b=p[114610];p[114610]=0;if((b|0)==1){break i}p[114610]=0;J(1208,d|0,c+8|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break i}uc(c+16|0);sb(c+40|0);b=0;p[114610]=0;d=M(1209,d|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break g}e=h+22|0;if((d|0)!=(q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))){break a}b=OL(h);p[114610]=0;J(338,a|0,b|0)|0;a=p[114610];p[114610]=0;b=1;if((a|0)!=1){break a}break f}b=I()|0;H()|0;break b}b=I()|0;H()|0;break h}b=I()|0;H()|0;uc(c+16|0)}sb(c+40|0);break b}b=I()|0;H()|0;break b}b=I()|0;H()|0;break b}b=I()|0;H()|0}sb(f);L(b|0);E()}sb(f)}fb=c+368|0;return b}function D0(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,o=0,r=0,s=0;a=fb-464|0;fb=a;p[a+16>>2]=f;p[a+20>>2]=g;p[a+24>>2]=h;p[a+28>>2]=i;p[a+348>>2]=a+352;j=fv(a+352|0,100,62383,a+16|0);p[a+48>>2]=2420;o=Hd(a+232|0,0,a+48|0);p[a+48>>2]=2420;m=Hd(a+224|0,0,a+48|0);l=a+240|0;a:{b:{c:{if(j>>>0>=100){p[114610]=0;j=Y(2445)|0;l=p[114610];p[114610]=0;if((l|0)==1){break b}p[a>>2]=f;p[a+4>>2]=g;p[114610]=0;p[a+8>>2]=h;p[a+12>>2]=i;j=U(2467,a+348|0,j|0,62383,a|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}f=p[a+348>>2];if(!f){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)!=1){break c}break b}pe(o,f);pe(m,fd(j));if(aj(m)){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)==1){break b}break c}l=p[m>>2]}p[114610]=0;qc(a+216|0,d);f=p[114610];p[114610]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){p[114610]=0;s=M(21,a+216|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break j}p[114610]=0;f=p[a+348>>2];U(2440,s|0,f|0,f+j|0,l|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break j}r=j?q[p[a+348>>2]]==45:r;h=Lb(a+192|0);g=Lb(a+176|0);f=Lb(a+160|0);p[114610]=0;ga(2501,c|0,r|0,a+216|0,a+208|0,a+207|0,a+206|0,h|0,g|0,f|0,a+156|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}p[a+36>>2]=2420;i=Hd(a+40|0,0,a+36|0);c=p[a+156>>2];k:{if((j|0)>(c|0)){k=wb(f)+(j-c<<1|1)|0;break k}k=wb(f)+2|0}c=a+48|0;k=(wb(g)+k|0)+p[a+156>>2]|0;if(k>>>0<101){break h}pe(i,fd(k));c=p[i>>2];if(c){break h}p[114610]=0;R(2421);b=p[114610];p[114610]=0;if((b|0)!=1){break c}break g}j=I()|0;H()|0;break a}j=I()|0;H()|0;break e}j=I()|0;H()|0;break f}k=p[d+4>>2];p[114610]=0;la(2502,c|0,a+36|0,a+32|0,k|0,l|0,j+l|0,s|0,r|0,a+208|0,n[a+207|0],n[a+206|0],h|0,g|0,f|0,p[a+156>>2]);j=p[114610];p[114610]=0;if((j|0)!=1){p[114610]=0;b=da(17,b|0,c|0,p[a+36>>2],p[a+32>>2],d|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break d}}}j=I()|0;H()|0;wc(i)}pb(f);pb(g);pb(h)}Gb(a+216|0);break a}wc(i);pb(f);pb(g);pb(h);Gb(a+216|0);wc(m);wc(o);fb=a+464|0;return b|0}E()}j=I()|0;H()|0}wc(m);wc(o);L(j|0);E()}function zma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=fb-208|0;fb=c;e=p[a+12>>2];k=1<<e;if(e>>>0>=2){j=k;n=2;f=1;while(1){j=j>>>2|0;if(j){q=v(f,3);r=f<<1;l=0;while(1){dJ(c+192|0,jc(a,l<<1));dJ(c+176|0,jc(a,l));wh(c+160|0,c+176|0,c+192|0);e=l<<n;o=f+e|0;if(e>>>0<o>>>0){while(1){d=jc(b,e);g=p[d+12>>2];p[c+152>>2]=p[d+8>>2];p[c+156>>2]=g;g=p[d+4>>2];p[c+144>>2]=p[d>>2];p[c+148>>2]=g;g=e+f|0;d=jc(b,g);h=p[d+12>>2];p[c+136>>2]=p[d+8>>2];p[c+140>>2]=h;h=p[d+4>>2];p[c+128>>2]=p[d>>2];p[c+132>>2]=h;h=e+r|0;d=jc(b,h);m=p[d+12>>2];p[c+120>>2]=p[d+8>>2];p[c+124>>2]=m;m=p[d+4>>2];p[c+112>>2]=p[d>>2];p[c+116>>2]=m;m=e+q|0;d=jc(b,m);i=p[d+12>>2];p[c+104>>2]=p[d+8>>2];p[c+108>>2]=i;i=p[d+4>>2];p[c+96>>2]=p[d>>2];p[c+100>>2]=i;Rj(c+80|0,c+144|0,c+128|0);ci(c- -64|0,c+144|0,c+128|0);Rj(c+48|0,c+112|0,c+96|0);ci(c+16|0,c+112|0,c+96|0);wh(c+32|0,30808,c+16|0);Rj(c+16|0,c+80|0,c+48|0);d=jc(b,e);i=p[c+28>>2];p[d+8>>2]=p[c+24>>2];p[d+12>>2]=i;i=p[c+20>>2];p[d>>2]=p[c+16>>2];p[d+4>>2]=i;Rj(c,c- -64|0,c+32|0);wh(c+16|0,c+192|0,c);d=jc(b,g);i=p[c+28>>2];p[d+8>>2]=p[c+24>>2];p[d+12>>2]=i;g=p[c+20>>2];p[d>>2]=p[c+16>>2];p[d+4>>2]=g;ci(c,c+80|0,c+48|0);wh(c+16|0,c+176|0,c);d=jc(b,h);h=p[c+28>>2];p[d+8>>2]=p[c+24>>2];p[d+12>>2]=h;g=p[c+20>>2];p[d>>2]=p[c+16>>2];p[d+4>>2]=g;ci(c,c- -64|0,c+32|0);wh(c+16|0,c+160|0,c);d=jc(b,m);h=p[c+28>>2];p[d+8>>2]=p[c+24>>2];p[d+12>>2]=h;g=p[c+20>>2];p[d>>2]=p[c+16>>2];p[d+4>>2]=g;e=e+1|0;if((o|0)!=(e|0)){continue}break}}l=l+1|0;if((l|0)!=(j|0)){continue}break}e=p[a+12>>2]}f=f<<2;n=n+2|0;if(n>>>0<=e>>>0){continue}break}}a:{if(!(e&1)){break a}j=k>>>1|0;if(!j){break a}e=0;while(1){k=e+j|0;a=jc(b,k);f=p[a+12>>2];p[c+200>>2]=p[a+8>>2];p[c+204>>2]=f;f=p[a+4>>2];p[c+192>>2]=p[a>>2];p[c+196>>2]=f;ci(c+176|0,jc(b,e),c+192|0);a=jc(b,k);f=p[c+188>>2];p[a+8>>2]=p[c+184>>2];p[a+12>>2]=f;k=p[c+180>>2];p[a>>2]=p[c+176>>2];p[a+4>>2]=k;Ww(jc(b,e),c+192|0);e=e+1|0;if((j|0)!=(e|0)){continue}break}}fb=c+208|0}function Zta(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-160|0;fb=d;f=Pk(d+56|0,a);p[114610]=0;e=J(686,d+40|0,18557)|0;a=p[114610];p[114610]=0;a:{b:{c:{d:{if((a|0)!=1){p[114610]=0;p[d+24>>2]=19464961;p[d+28>>2]=0;N(687,f|0,e|0,d+24|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}yb(e);if(!(p[f>>2]&1073741824)){break c}break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;yb(e);break b}p[114610]=0;n[d+39|0]=0;e=J(686,d+40|0,18564)|0;a=p[114610];p[114610]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){p[114610]=0;P(688,f|0,d+39|0,e|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break p}yb(e);e=Lb(d+40|0);p[114610]=0;g=J(686,d+24|0,18566)|0;a=p[114610];p[114610]=0;if((a|0)==1){break o}p[114610]=0;P(1183,f|0,e|0,g|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break n}yb(g);p[114610]=0;N(13,d+24|0,(q[d+39|0]?0:c)|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;K(487,b|0,d+24|0);a=p[114610];p[114610]=0;if((a|0)==1){break l}pb(d+24|0);p[114610]=0;o[d+22>>1]=0;c=J(686,d+24|0,18568)|0;a=p[114610];p[114610]=0;if((a|0)==1){break f}p[114610]=0;P(1184,f|0,d+22|0,c|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break k}yb(c);Lg(d+22|0,r[p[19847]+12>>1]);p[114610]=0;c=J(686,d+24|0,18570)|0;a=p[114610];p[114610]=0;if((a|0)==1){break j}a=p[Ic(d+16|0,r[d+22>>1])>>2];p[114610]=0;U(1185,f|0,b|0,c|0,a|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break i}yb(c);p[114610]=0;o[d+14>>1]=65535;c=J(686,d+24|0,18572)|0;a=p[114610];p[114610]=0;if((a|0)==1){break h}p[114610]=0;a=P(1184,f|0,d+14|0,c|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break g}g=r[d+22>>1];h=r[d+14>>1];yb(c);if(!((a|0)==1|h>>>0>=g>>>0)){Pe(b,r[d+14>>1])}pb(e);break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;yb(e);break b}a=I()|0;H()|0;break e}a=I()|0;H()|0;yb(g);break e}a=I()|0;H()|0;break e}a=I()|0;H()|0;pb(d+24|0);break e}a=I()|0;H()|0;yb(c);break e}a=I()|0;H()|0;break e}a=I()|0;H()|0;yb(c);break e}a=I()|0;H()|0;break e}a=I()|0;H()|0;yb(c);break e}a=I()|0;H()|0}pb(e)}hg(f);L(a|0);E()}hg(f);fb=d+160|0}function Zva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;f=fb-48|0;fb=f;t=p[a+16>>2];a:{b:{c:{h=p[a+8>>2];e=p[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}u=b;b=p[a+44>>2];p[f+32>>2]=b;i=p[a+48>>2];p[f+36>>2]=i;k=p[a+52>>2];p[f+40>>2]=k;l=p[a+56>>2];p[f+44>>2]=l;w=p[a+24>>2];x=p[a+20>>2];g=p[a+4>>2];j=p[a>>2];p[f+24>>2]=j;p[f+28>>2]=g;p[f+16>>2]=h;p[f+20>>2]=e;if(d){while(1){l=1;e=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+t|0;b=(j>>>16&65520)+u|0;j=o[b+14>>1];h=o[b+12>>1];n=o[b+10>>1];q=o[b+8>>1];r=o[b+6>>1];m=o[b+4>>1];s=o[b+2>>1];y=o[b>>1];k=0;b=1;i=0;while(1){g=i<<1;p[(f+8|0)+(i<<2)>>2]=(((((((v(o[e+(g|-8)>>1],s)+v(o[e+(g|-12)>>1],y)|0)+v(o[e+(g|-4)>>1],m)|0)+v(o[e+g>>1],r)|0)+v(o[e+(g|4)>>1],q)|0)+v(o[e+(g|8)>>1],n)|0)+v(o[e+(g|12)>>1],h)|0)+v(j,o[e+(g|16)>>1])|0)/32768;g=b;b=0;i=1;if(g){continue}break}while(1){i=(f+8|0)+(k<<2)|0;j=p[i>>2];h=p[a+60>>2];n=h;g=(f+32|0)+(k<<3)|0;k=p[g>>2];b=Pb(k,-16777216,16776704);q=p[a+64>>2];e=Pb(p[g+4>>2],-16777216,16776704);m=p[a+68>>2];s=m;m=m>>31;p[g+4>>2]=k;k=p[a+72>>2];r=h>>31;j=j<<8;h=j;h=NNa(n,r,h,h>>31);n=ib;r=i;i=h;h=NNa(q,q>>31,b,b>>31);i=i+h|0;b=ib+n|0;b=i>>>0<h>>>0?b+1|0:b;h=i;i=NNa(s,m,e,e>>31);e=h+i|0;b=ib+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|e>>>24;p[r>>2]=(b|0)/256;p[g>>2]=b-(j&k);k=1;b=l&1;l=0;if(b){continue}break}p[c>>2]=p[c>>2]+v(p[f+8>>2],x);p[c+4>>2]=p[c+4>>2]+v(p[f+12>>2],w);Kb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;j=p[f+24>>2];g=p[f+28>>2];continue}break}j=p[f+24>>2];g=p[f+28>>2];l=p[f+44>>2];k=p[f+40>>2];i=p[f+36>>2];b=p[f+32>>2]}p[a+56>>2]=l;p[a+52>>2]=k;p[a+48>>2]=i;p[a+44>>2]=b;p[a>>2]=j;p[a+4>>2]=g;fb=f+48|0}function OBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;n[a|0]=0;c=q[b|0];if(c){n[a|0]=c>>>0>96?-1:c+12|0}n[a+1|0]=q[b+1|0];c=a;d=q[b+2|0];e=d+ -16|0;a:{b:{if((e&255)>>>0<=128){n[a+2|0]=1;d=(e|0)/2|0;break b}c:{switch((d+96&240)>>>4|0){case 0:n[a+2|0]=4;d=d&15;break b;case 1:n[a+2|0]=3;d=d&15;break b;case 2:n[a+2|0]=6;d=d&15;break b;case 3:break c;default:break a}}n[a+2|0]=5;d=d&15}n[c+4|0]=d}d=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{c=q[b+4|0];if((c|0)<=28){switch(c|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(c+ -29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((c|0)==128){break e}if((c|0)!=157){break d}n[a+2|0]=15;c=q[b+6|0];n[a+3|0]=20;n[a+4|0]=c>>>3;n[f+15|0]=15;g=a,h=q[hc(b+5|0,f+15|0)|0]|208,n[g+5|0]=h;break d}c=q[b+6|0];e=q[b+5|0];if(!(c|e)){break d}n[a+5|0]=e;n[a+3|0]=c;fj(a);d=q[b+6|0]==15;break d}n[a+3|0]=2;g=a,h=kk(q[b+6|0]<<4|q[b+5|0]>>>4),n[g+5|0]=h;break d}n[a+3|0]=3;g=a,h=kk(q[b+6|0]<<4|q[b+5|0]>>>4),n[g+5|0]=h;break d}n[a+3|0]=4;g=a,h=kk(q[b+6|0]<<4|q[b+5|0]>>>4),n[g+5|0]=h;break d}n[a+3|0]=5;n[a+5|0]=q[b+6|0]&240|q[b+5|0]>>>4;break d}c=q[b+5|0];if(c){n[a+5|0]=c;n[a+3|0]=9;break d}if((q[b+6|0]+ -1&255)>>>0>1){break d}n[a+5|0]=145;n[a+3|0]=20;break d}n[a+3|0]=13;n[a+5|0]=q[b+6|0]>>>1;break d}c=q[b+6|0];if(c){n[a+5|0]=c;n[a+3|0]=17;break d}n[a+3|0]=16;n[a+5|0]=q[b+5|0]&15;break d}n[a+3|0]=q[b+6|0];n[a+5|0]=q[b+5|0];py(a,1);d=(q[a+3|0]&254)==16;break d}n[a+3|0]=18;n[a+5|0]=q[b+5|0];break d}n[a+3|0]=31;n[a+5|0]=q[b+6|0]>>>1;break d}n[a+3|0]=31;n[a+5|0]=q[b+6|0]>>>1&120;break d}n[a+5|0]=159;n[a+3|0]=20;break d}n[a+3|0]=21;n[a+5|0]=q[b+6|0]>>>2}b=q[b+3|0];t:{if(!b){break t}if(!q[a+3|0]){n[a+5|0]=b;n[a+3|0]=9;break t}if(q[a+2|0]){break t}n[a+2|0]=2;n[a+4|0]=b>>>2}fb=f+16|0;return d|0}function BU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=fb-16|0;fb=f;if((d|0)<1){a=0}else{Tn(c,d);p[f+4>>2]=b;p[f>>2]=a;a=ub(p[c>>2]);p[f+12>>2]=d;p[f+8>>2]=a;m=d;a=0;b=0;while(1){a:{e=lg(f,b);n=lg(f,b+4|0)<<8|lg(f,b+5|0);g=lg(f,b+6|0);i=lg(f,b+7|0);r=b+8|0;b:{c:{d:{switch(e|0){case 0:b=0;if(!n){break c}while(1){Wp(f,a+b|0,lg(f,b+r|0));b=b+1|0;if((n|0)!=(b|0)){continue}break}break c;case 1:break d;default:break a}}o=lg(f,b+10|0);Wp(f,a,o);e=i|g<<8;m=m-e|0;a=(a>>>0<d>>>0)+a|0;if(e>>>0>=2){j=b+11|0;b=e+ -1|0;g=0;k=0;l=0;q=0;while(1){i=Jf(j,g,1,f);e:{f:{g:{h:{i:{if((k|0)<=7){if(i){e=g;break f}g=g+1|0;l=8;break i}e=g+1|0;j:{if(!i){if(!Jf(j,e,1,f)){break f}e=2;k:{l:{h=g+2|0;if(!Jf(j,h,1,f)){break l}e=3;h=g+3|0;if(!Jf(j,h,1,f)){break l}e=Jf(j,h,3,f);g=g+6|0;break k}g=h+1|0}h=4;l=AU(((l<<3)+e|0)+ -17|0);if((l|0)!=8){break h}break j}h=4;g=e;if((l|0)!=8){break h}}l=8;h=1;if((q|0)>19){break h}}h=0;break g}q=q+8|0}e=b;m:{if((e|0)<1){break m}while(1){o=o-zU(j,g,l,f)|0;Wp(f,a,o&255);e=b+ -1|0;g=g+l|0;a=(a>>>0<d>>>0)+a|0;if((h|0)<1){break m}h=h+ -1|0;i=(b|0)>1;b=e;if(i){continue}break}}k=(k|0)==31?31:k+1|0;b=e;break e}n:{o:{p:{h=e+1|0;if(!Jf(j,h,1,f)){e=2;break p}h=e+2|0;if(!Jf(j,h,1,f)){e=4;break p}h=e+3|0;if(!Jf(j,h,1,f)){e=6;break p}i=e+5|0;if(!Jf(j,e+4|0,1,f)){g=e+8|0;h=Jf(j,i,3,f)+8|0;break n}g=e+10|0;e=16;i=Jf(j,i,5,f);break o}g=h+2|0;i=Jf(j,h+1|0,1,f)}h=e+i|0}q:{if(Jf(j,g,1,f)){i=-256;e=12;break q}g=g+1|0;e=Jf(j,g,1,f);i=e?-4352:0;e=e?14:8}g=g+1|0;s=Jf(j,g,e,f);if((h|0)>=3){k=k-((h|0)!=3)|0;k=(k|0)>0?k+ -1|0:0}g=e+g|0;if((h|0)<1|(b|0)<1){break e}e=(a+i|0)+(s^-1)|0;i=b;while(1){o=yU(f,e);Wp(f,a,o);b=i+ -1|0;a=(a>>>0<d>>>0)+a|0;if((h|0)<2){break e}e=e+1|0;h=h+ -1|0;s=(i|0)>1;i=b;if(s){continue}break}}q=q-(q>>3)|0;if((b|0)>0){continue}break}}b=(n+3&65532)+r|0;break b}m=m-n|0;a=a+n|0;b=n+r|0}if((m|0)>0){continue}}break}Tn(c,p[f+12>>2]-m|0);a=cd(c)^1}fb=f+16|0;return a|0}function cfa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=p[a+4>>2];s=e&2047;if(d){t=a+8256|0;u=a- -64|0;w=a+24640|0;x=a+16448|0;while(1){n=o[(((e+754&2047)<<2)+t|0)+2>>1];r=o[((e+1206&2047)<<2)+t>>1];f=o[(((e+1602&2047)<<2)+u|0)+2>>1];k=o[((e+1750&2047)<<2)+u>>1];i=((e+22&2047)<<2)+w|0;g=o[i+2>>1];i=o[i>>1];h=((e+502&2047)<<2)+w|0;j=o[h+2>>1];l=o[b>>1];m=o[b+2>>1];h=o[h>>1];q=Kc(o[a+32>>1]-h|0);y=o[a+24>>1];z=Kc(o[a+34>>1]-j|0);A=o[a+26>>1];B=Kc(o[a+36>>1]-i|0);C=o[a+28>>1];D=Kc(o[a+38>>1]-g|0);E=o[a+30>>1];F=a,G=Mc(Kc((v(q,y)|0)/65536<<1)+h|0),o[F+32>>1]=G;F=a,G=Mc(Kc((v(z,A)|0)/65536<<1)+j|0),o[F+34>>1]=G;F=a,G=Mc(Kc((v(B,C)|0)/65536<<1)+i|0),o[F+36>>1]=G;F=a,G=Mc(Kc((v(D,E)|0)/65536<<1)+g|0),o[F+38>>1]=G;g=Kc((v(o[a+32>>1],o[a+16>>1])|0)/32768|0);j=Kc((v(o[a+38>>1],o[a+22>>1])|0)/32768|0);i=Kc(g+((l|0)/4<<16>>16)|0);j=Kc(j+((m|0)/4<<16>>16)|0);h=Kc(i+((v(k,o[a+8>>1])|0)/-65536|0)|0);g=s<<2;l=g+u|0;m=Kc(j+((v(f,o[a+10>>1])|0)/-65536|0)|0);o[l+2>>1]=m;o[l>>1]=h;k=Kc(k+((v(h,o[a+8>>1])|0)/65536|0)|0);h=g+x|0;f=Kc(f+((v(m,o[a+10>>1])|0)/65536|0)|0);o[h+2>>1]=f;o[h>>1]=k;k=Kc(i+k|0);i=Kc(f+j|0);f=((e+426&2047)<<2)+x|0;j=o[f+2>>1];h=o[f>>1];e=((e+682&2047)<<2)+x|0;l=o[e+2>>1];m=o[e>>1];e=Kc((v(l,o[a+42>>1])+v(m,o[a+40>>1])|0)/32768|0);f=Kc((v(j,o[a+46>>1])+v(h,o[a+44>>1])|0)/32768|0);m=Kc(Kc(k+m|0)-e|0);l=Kc(Kc(i+l|0)-f|0);k=Kc(Kc(h+k|0)-e|0);i=Kc(Kc(i+j|0)-f|0);e=Kc(e+((v(o[a+8>>1],r)|0)/-65536|0)|0);f=Kc(f+((v(n,o[a+10>>1])|0)/-65536|0)|0);j=o[a+8>>1];h=o[a+10>>1];q=g+t|0;o[q+2>>1]=f;o[q>>1]=e;q=r;r=(v(e,j)|0)/65536|0;e=Kc(q+r|0);g=g+w|0;f=(v(f,h)|0)/65536|0;n=Kc(f+n|0);o[g+2>>1]=n;o[g>>1]=e;e=Kc(e+m|0);g=o[a+48>>1];n=Kc(l+n|0);p[c>>2]=(p[c>>2]+v(e,g)|0)+v(n,o[a+50>>1]);e=Kc(Kc(r)+k|0);g=o[a+52>>1];f=Kc(Kc(f)+i|0);p[c+4>>2]=(p[c+4>>2]+v(e,g)|0)+v(f,o[a+54>>1]);c=c+8|0;b=b+4|0;e=s+1|0;s=e&2047;d=d+ -1|0;if(d){continue}break}}p[a+4>>2]=s}function PG(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=fb-48|0;fb=k;a:{b:{c:{d:{e:{f:{j=Rn(1,28);if(!j){a=W(4)|0;Kk(a);p[114610]=0;N(2009,a|0,71348,2008);a=p[114610];p[114610]=0;if((a|0)!=1){break a}break f}p[j+24>>2]=0;p[j+16>>2]=0;p[j+20>>2]=0;p[j+12>>2]=f;p[j+8>>2]=e;p[j+4>>2]=d;p[j>>2]=c?c:1997;d=js(k+32|0);g:{h:{if(!i){break h}c=p[i>>2];if(!c){break h}while(1){i:{e=p[i+4>>2];if(e){p[114610]=0;c=J(85,k+16|0,c|0)|0;f=p[114610];p[114610]=0;j:{if((f|0)!=1){p[114610]=0;f=J(2010,d|0,c|0)|0;l=p[114610];p[114610]=0;if((l|0)==1){break j}p[114610]=0;J(483,f|0,e|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break j}break i}i=O(0)|0;H()|0;break g}i=O(0)|0;H()|0;pb(c);break g}p[114610]=0;c=J(85,k+16|0,c|0)|0;e=p[114610];p[114610]=0;k:{if((e|0)!=1){p[114610]=0;J(2011,d|0,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}break i}i=O(0)|0;H()|0;break g}i=O(0)|0;H()|0;pb(c);break g}pb(c);c=p[i+8>>2];i=i+8|0;if(c){continue}break}}p[114610]=0;c=M(1398,80)|0;e=p[114610];p[114610]=0;l:{m:{n:{if((e|0)!=1){p[114610]=0;N(2012,k+16|0,j|0,j+4|0);e=p[114610];p[114610]=0;if((e|0)==1){break n}e=oo(k+8|0,k+16|0);p[114610]=0;Z(2014,c|0,a|0,b|0,e|0,d|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[j+24>>2]=c;Nc(e);Nc(k+16|0);Yj(d);c=j;break d}i=O(0)|0;H()|0;break g}i=O(0)|0;H()|0;break l}i=O(0)|0;H()|0;Nc(e);Nc(k+16|0)}Nb(c)}Yj(d);T(i|0)|0;p[114610]=0;Q(1989,34649,j|0,g|0,h|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break f}a=p[j+24>>2];if(a){Nb(mr(a))}c=0;p[j+24>>2]=0;a=p[j+20>>2];if(a){Nb(a)}Nb(j);break d}i=O(0)|0;H()|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)!=1){break e}break b}i=O(0)|0;H()|0}T(i|0)|0;c=0;p[114610]=0;Q(1989,34649,0,g|0,h|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}V()}fb=k+48|0;return c|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}a=O(0)|0;H()|0;rb(a)}E()}function rva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;e=fb-80|0;fb=e;s=p[a+16>>2];i=Df(e+48|0);p[i+8>>2]=a+112;p[i+16>>2]=p[a+128>>2];y=i,z=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[y+12>>2]=z;b=p[i+16>>2];if(b){y=i,z=Cf(a+8|0,b),p[y>>2]=z;p[i+4>>2]=ib}b=p[a+44>>2];p[e+32>>2]=b;g=p[a+48>>2];p[e+36>>2]=g;h=p[a+52>>2];p[e+40>>2]=h;l=p[a+56>>2];p[e+44>>2]=l;t=p[a+24>>2];u=p[a+20>>2];j=p[a+4>>2];f=p[a>>2];p[e+24>>2]=f;p[e+28>>2]=j;k=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=k;if(d){while(1){b=0;g=b;h=f;p[e+72>>2]=f;p[e+76>>2]=b;j=(((j&2147483647)<<1|f>>>31)&-2)+s|0;a:{b=p[i+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|h>>>31;qd(p[i+8>>2],n[(f|1)+j|0]+n[j+(f&-2)|0]<<5);pd(p[i+8>>2],4);Kb(e+72|0,i);if((b|0)<2){break a}b=b+ -1|0;h=p[e+72>>2];g=p[e+76>>2];continue}}b=p[i+8>>2];Kb(b,b+8|0);b=p[i+8>>2];f=p[b+4>>2];if(f){k=b;b=(p[e+76>>2]&2147483647)<<1|p[e+72>>2]>>>31;qd(k,n[(b|1)+j|0]+n[j+(b&-2)|0]<<5);pd(p[i+8>>2],f);b=p[i+8>>2];f=p[b>>2];p[b>>2]=f;p[b+4>>2]=0}d=d+ -1|0;h=xf(b,p[i+12>>2]);p[e+12>>2]=h;p[e+8>>2]=h;g=0;l=1;while(1){k=p[a+60>>2];q=k;j=(e+32|0)+(g<<3)|0;m=p[j>>2];b=Pb(m,-16777216,16776704);r=p[a+64>>2];f=Pb(p[j+4>>2],-16777216,16776704);o=p[a+68>>2];w=o;o=o>>31;p[j+4>>2]=m;m=p[a+72>>2];k=k>>31;h=h<<8;k=NNa(q,k,h,h>>31);q=ib;x=(e+8|0)+(g<<2)|0;g=k;k=NNa(r,r>>31,b,b>>31);g=g+k|0;b=ib+q|0;b=g>>>0<k>>>0?b+1|0:b;k=g;g=NNa(w,o,f,f>>31);f=k+g|0;b=ib+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;p[x>>2]=(b|0)/256;p[j>>2]=b-(h&m);if(l){g=1;l=0;h=p[e+12>>2];continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],u);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],t);Kb(e+24|0,e+16|0);if(d){c=c+8|0;f=p[e+24>>2];j=p[e+28>>2];continue}break}f=p[e+24>>2];j=p[e+28>>2];l=p[e+44>>2];h=p[e+40>>2];g=p[e+36>>2];b=p[e+32>>2]}p[a+56>>2]=l;p[a+52>>2]=h;p[a+48>>2]=g;p[a+44>>2]=b;p[a>>2]=f;p[a+4>>2]=j;fb=e+80|0}function _va(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;f=fb-48|0;fb=f;u=p[a+16>>2];a:{b:{c:{g=p[a+8>>2];e=p[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}w=b;b=p[a+44>>2];p[f+32>>2]=b;k=p[a+48>>2];p[f+36>>2]=k;j=p[a+52>>2];p[f+40>>2]=j;l=p[a+56>>2];p[f+44>>2]=l;x=p[a+24>>2];y=p[a+20>>2];h=p[a+4>>2];i=p[a>>2];p[f+24>>2]=i;p[f+28>>2]=h;p[f+16>>2]=g;p[f+20>>2]=e;if(d){while(1){e=(((h&2147483647)<<1|i>>>31)&-2)+u|0;b=(i>>>16&65520)+w|0;i=o[b+14>>1];g=o[b+12>>1];q=o[b+10>>1];r=o[b+8>>1];s=o[b+6>>1];m=o[b+4>>1];t=o[b+2>>1];z=o[b>>1];j=0;l=1;k=1;b=0;while(1){p[(f+8|0)+(b<<2)>>2]=(((((((v(n[e+(b|-4)|0],t)+v(n[e+(b|-6)|0],z)|0)+v(n[e+(b|-2)|0],m)|0)+v(n[b+e|0],s)|0)+v(n[e+(b|2)|0],r)|0)+v(n[e+(b|4)|0],q)|0)+v(n[e+(b|6)|0],g)|0)+v(i,n[e+(b|8)|0])<<8)/32768;h=k;k=0;b=1;if(h){continue}break}while(1){e=(f+8|0)+(j<<2)|0;i=p[e>>2];g=p[a+60>>2];q=g;k=(f+32|0)+(j<<3)|0;j=p[k>>2];b=Pb(j,-16777216,16776704);r=p[a+64>>2];h=Pb(p[k+4>>2],-16777216,16776704);m=p[a+68>>2];t=m;m=m>>31;p[k+4>>2]=j;j=p[a+72>>2];s=g>>31;i=i<<8;g=i;g=NNa(q,s,g,g>>31);q=ib;s=e;e=g;g=NNa(r,r>>31,b,b>>31);e=e+g|0;b=ib+q|0;b=e>>>0<g>>>0?b+1|0:b;g=e;e=NNa(t,m,h,h>>31);h=g+e|0;b=ib+b|0;b=h>>>0<e>>>0?b+1|0:b;h=h+8388608|0;if(h>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|h>>>24;p[s>>2]=(b|0)/256;p[k>>2]=b-(i&j);j=1;b=l&1;l=0;if(b){continue}break}p[c>>2]=p[c>>2]+v(p[f+8>>2],y);p[c+4>>2]=p[c+4>>2]+v(p[f+12>>2],x);Kb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;i=p[f+24>>2];h=p[f+28>>2];continue}break}i=p[f+24>>2];h=p[f+28>>2];l=p[f+44>>2];j=p[f+40>>2];k=p[f+36>>2];b=p[f+32>>2]}p[a+56>>2]=l;p[a+52>>2]=j;p[a+48>>2]=k;p[a+44>>2]=b;p[a>>2]=i;p[a+4>>2]=h;fb=f+48|0}function sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=w(0),f=w(0),g=0,h=0,i=0,j=0,k=w(0),l=0,m=0,n=0,o=0,q=w(0),r=0,s=0,u=0,v=w(0),x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=w(0),K=w(0),L=w(0),M=w(0),N=w(0),O=w(0);m=a+44|0;if(fh(m)){B=Fd(m,0);C=Fd(m,1);D=_c(m,0);E=_c(m,1);r=p[a+4296>>2];o=p[a+4300>>2];if(d){j=a+4304|0;i=r+1|0;x=i+p[a+4272>>2]&4095;l=j+(x<<4)|0;y=i+p[a+4276>>2]&4095;g=((y<<4)+j|0)+4|0;z=i+p[a+4280>>2]&4095;n=((z<<4)+j|0)+8|0;A=i+p[a+4284>>2]&4095;h=((A<<4)+j|0)+12|0;s=p[a+4292>>2]+o|0;u=p[a+4288>>2]+o|0;G=a+69840|0;H=a+78032|0;F=d;while(1){x=x+ -1&4095;i=(x<<4)+j|0;e=t[i>>2];u=u&1023;I=(u<<3)+G|0;q=t[I+4>>2];J=t[h>>2];K=t[n>>2];L=t[g>>2];M=t[l>>2];N=t[C>>2];O=t[B>>2];v=t[a+4232>>2];y=y+ -1&4095;l=(y<<4)+j|0;k=t[l+4>>2];f=w(w(v*t[I>>2])+w(k*w(.6180340051651001)));h=o<<3;g=h+G|0;t[g+4>>2]=k-w(f*w(.6180340051651001));k=e;e=w(w(q*v)-w(e*w(.6180340051651001)));t[g>>2]=k+w(e*w(.6180340051651001));t[i>>2]=f;t[l+4>>2]=e;s=s&1023;g=(s<<3)+H|0;q=t[g+4>>2];z=z+ -1&4095;n=(z<<4)+j|0;f=t[n+8>>2];v=t[a+4236>>2];e=w(v*t[g>>2]);A=A+ -1&4095;g=(A<<4)+j|0;k=t[g+12>>2];e=w(e+w(k*w(.6180340051651001)));h=h+H|0;t[h+4>>2]=k-w(e*w(.6180340051651001));k=f;f=w(w(q*v)-w(f*w(.6180340051651001)));t[h>>2]=k+w(f*w(.6180340051651001));t[n+8>>2]=e;t[g+12>>2]=f;f=w(t[i>>2]+e);e=w(O+w(1.0000000031710769e-30));t[D>>2]=f+w(t[a+4224>>2]*e);f=w(N+w(1.0000000031710769e-30));t[E>>2]=w(w(t[a+4224>>2]*f)+t[l+4>>2])+t[g+12>>2];h=(r<<4)+j|0;q=t[a+4228>>2];e=w(q*e);t[h>>2]=w(w(t[a+4240>>2]*t[i>>2])+e)+w(M*t[a+4244>>2]);f=w(q*f);t[h+4>>2]=w(w(t[a+4248>>2]*t[l+4>>2])+f)+w(L*t[a+4252>>2]);t[h+8>>2]=w(w(t[a+4256>>2]*t[n+8>>2])-f)+w(K*t[a+4260>>2]);t[h+12>>2]=w(w(t[a+4264>>2]*t[g+12>>2])+e)+w(J*t[a+4268>>2]);h=g+12|0;n=n+8|0;g=l+4|0;E=E+4|0;D=D+4|0;C=C+4|0;B=B+4|0;s=s+ -1|0;u=u+ -1|0;o=o+ -1&1023;r=r+ -1&4095;l=i;F=F+ -1|0;if(F){continue}break}}p[a+4300>>2]=o;p[a+4296>>2]=r;Zh(a,b,c,_c(m,0),_c(m,1),d)}}function Zh(a,b,c,d,e,f){var g=0,h=0,i=0,j=w(0),k=w(0),l=0,n=0,o=w(0),r=w(0),s=0;if(!(m[p[p[a>>2]+132>>2]](a)|0)){g=q[p[a+20>>2]+25|0]}j=t[p[a+20>>2]+144>>2];k=w(1);if(!(m[p[p[a>>2]+132>>2]](a)|0)){k=t[p[a+20>>2]+144>>2]}j=w(w(1)-j);a:{if((m[p[p[a>>2]+148>>2]](a)|0)<1){break a}if(!GH(p[a+20>>2])){break a}j=w(w(j+j)+w(-1));k=w(-j)}o=t[a+4196>>2];k=w(o*k);j=w(o*j);l=a+44|0;n=Fd(l,0);l=Fd(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;s=h;k=w(t[g+n>>2]+t[h>>2]);h=c+g|0;t[s>>2]=w(k-w(t[g+l>>2]+w(k+t[h>>2])))+w(t[d+g>>2]*j);t[h>>2]=w(t[e+g>>2]*j)-k;i=i+1|0;if((i|0)!=(f|0)){continue}break}break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;t[h>>2]=w(w(t[g+n>>2]*j)-t[d+g>>2])+t[h>>2];h=c+g|0;t[h>>2]=w(w(t[g+l>>2]*j)-t[e+g>>2])+t[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;t[h>>2]=w(t[h>>2]+t[d+g>>2])-w(t[g+n>>2]*k);h=c+g|0;t[h>>2]=w(t[h>>2]+t[e+g>>2])-w(t[g+l>>2]*k);i=i+1|0;if((i|0)!=(f|0)){continue}break}break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;t[h>>2]=w(t[h>>2]+t[g+n>>2])-w(t[d+g>>2]*j);h=c+g|0;t[h>>2]=w(t[h>>2]+t[g+l>>2])-w(t[e+g>>2]*j);i=i+1|0;if((i|0)!=(f|0)){continue}break}break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;t[h>>2]=w(w(t[g+n>>2]*k)+w(t[d+g>>2]*j))+t[h>>2];h=c+g|0;t[h>>2]=w(w(t[g+l>>2]*k)+w(t[e+g>>2]*j))+t[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}break b;case 5:break c;default:break b}}g=GH(p[a+20>>2]);if(!f){break b}j=g?w(j*w(.5)):j;k=g?w(k*w(.5)):k;while(1){g=i<<2;h=g+b|0;o=w(t[d+g>>2]-t[g+n>>2]);r=w(t[g+l>>2]-t[e+g>>2]);t[h>>2]=w(t[h>>2]+w(o*j))+w(r*k);g=c+g|0;t[g>>2]=w(w(r*j)+w(o*k))+t[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((q[p[a+20>>2]+24|0]&4)>>>2|0)){break d}if(m[p[p[a>>2]+132>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;t[d>>2]=t[d>>2]+t[a+n>>2];d=a+c|0;t[d>>2]=t[d>>2]+t[a+l>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function Ama(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=fb-208|0;fb=c;f=1;e=p[a+12>>2];h=1<<e;if(e&1){i=h>>>1|0;if(i){e=0;while(1){j=e+i|0;f=jc(b,j);d=p[f+12>>2];p[c+200>>2]=p[f+8>>2];p[c+204>>2]=d;d=p[f+4>>2];p[c+192>>2]=p[f>>2];p[c+196>>2]=d;ci(c+176|0,jc(b,e),c+192|0);f=jc(b,j);d=p[c+188>>2];p[f+8>>2]=p[c+184>>2];p[f+12>>2]=d;j=p[c+180>>2];p[f>>2]=p[c+176>>2];p[f+4>>2]=j;Ww(jc(b,e),c+192|0);e=e+1|0;if((i|0)!=(e|0)){continue}break}e=p[a+12>>2]}f=2;h=h>>>3|0}else{h=h>>>2|0}j=e&-2;if(j){while(1){if(f){o=v(h,3);q=h<<1;i=0;while(1){e=jc(a,i<<1);d=p[e+12>>2];p[c+200>>2]=p[e+8>>2];p[c+204>>2]=d;d=p[e+4>>2];p[c+192>>2]=p[e>>2];p[c+196>>2]=d;e=jc(a,i);d=p[e+12>>2];p[c+184>>2]=p[e+8>>2];p[c+188>>2]=d;d=p[e+4>>2];p[c+176>>2]=p[e>>2];p[c+180>>2]=d;wh(c+160|0,c+176|0,c+192|0);e=i<<j;m=h+e|0;if(e>>>0<m>>>0){while(1){d=jc(b,e);g=p[d+12>>2];p[c+152>>2]=p[d+8>>2];p[c+156>>2]=g;g=p[d+4>>2];p[c+144>>2]=p[d>>2];p[c+148>>2]=g;g=e+h|0;wh(c+128|0,c+192|0,jc(b,g));k=e+q|0;wh(c+112|0,c+176|0,jc(b,k));n=e+o|0;wh(c+96|0,c+160|0,jc(b,n));Rj(c+80|0,c+144|0,c+112|0);ci(c- -64|0,c+144|0,c+112|0);Rj(c+48|0,c+128|0,c+96|0);ol(c+16|0,-u[3851],-u[3852]);ci(c,c+128|0,c+96|0);wh(c+32|0,c+16|0,c);Rj(c+16|0,c+80|0,c+48|0);d=jc(b,e);l=p[c+28>>2];p[d+8>>2]=p[c+24>>2];p[d+12>>2]=l;l=p[c+20>>2];p[d>>2]=p[c+16>>2];p[d+4>>2]=l;ci(c+16|0,c+80|0,c+48|0);d=jc(b,g);l=p[c+28>>2];p[d+8>>2]=p[c+24>>2];p[d+12>>2]=l;g=p[c+20>>2];p[d>>2]=p[c+16>>2];p[d+4>>2]=g;Rj(c+16|0,c- -64|0,c+32|0);d=jc(b,k);k=p[c+28>>2];p[d+8>>2]=p[c+24>>2];p[d+12>>2]=k;g=p[c+20>>2];p[d>>2]=p[c+16>>2];p[d+4>>2]=g;ci(c+16|0,c- -64|0,c+32|0);d=jc(b,n);k=p[c+28>>2];p[d+8>>2]=p[c+24>>2];p[d+12>>2]=k;g=p[c+20>>2];p[d>>2]=p[c+16>>2];p[d+4>>2]=g;e=e+1|0;if((m|0)!=(e|0)){continue}break}}i=i+1|0;if((f|0)!=(i|0)){continue}break}}h=h>>>2|0;f=f<<2;j=j+ -2|0;if(j){continue}break}}fb=c+208|0}function O9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-96|0;fb=e;a:{if(Pc(c)){break a}g=q[GG(c)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;Zq(e+80|0,c,0,wb(c)+ -1|0);xb(c,e+80|0);pb(e+80|0)}ud(e+80|0);f=p[e+80>>2];ud(e+72|0);g=FG(f,p[e+76>>2],c);ud(e+80|0);c:{d:{e:{f:{g:{if(p[e+84>>2]==(g|0)){if(Md(c,38139)){a=W(8)|0;p[114610]=0;b=J(85,e+80|0,39080)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}dc(a,b);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}c=I()|0;H()|0;pb(b);break d}if(!d){break g}a=W(8)|0;p[114610]=0;N(2136,e+80|0,39090,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){dc(a,e+80|0);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}c=I()|0;H()|0;pb(e+80|0);break d}c=I()|0;H()|0;X(a|0);break d}f=Lb(e+80|0);h:{i:{j:{k:{switch(p[g+4>>2]){case 0:xh(e- -64|0,c);p[114610]=0;c=p[e+68>>2];p[e+8>>2]=p[e+64>>2];p[e+12>>2]=c;b=P(2077,b|0,e+8|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){p[114610]=0;n[e+72|0]=b;K(2141,a|0,e+72|0);a=p[114610];p[114610]=0;if((a|0)!=1){break h}}break j;case 1:xh(e+56|0,c);p[114610]=0;c=p[e+60>>2];p[e+16>>2]=p[e+56>>2];p[e+20>>2]=c;b=UB(b,e+16|0,d);c=ib;d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;p[e+72>>2]=b;p[e+76>>2]=c;K(2143,a|0,e+72|0);a=p[114610];p[114610]=0;if((a|0)!=1){break h}}break j;case 2:xh(e+48|0,c);p[114610]=0;c=p[e+52>>2];p[e+24>>2]=p[e+48>>2];p[e+28>>2]=c;h=+ha(2079,b|0,e+24|0,d|0);b=p[114610];p[114610]=0;if((b|0)!=1){p[114610]=0;u[e+72>>3]=h;K(2144,a|0,e+72|0);a=p[114610];p[114610]=0;if((a|0)!=1){break h}}break j;case 3:break k;default:break i}}xh(e+40|0,c);p[114610]=0;c=p[e+44>>2];p[e+32>>2]=p[e+40>>2];p[e+36>>2]=c;Q(2080,a|0,b|0,e+32|0,d|0);a=p[114610];p[114610]=0;if((a|0)!=1){break h}}c=I()|0;H()|0;pb(f);break d}Wc(a,f)}pb(f);break f}Lb(a)}fb=e+96|0;return}c=I()|0;H()|0;X(a|0)}L(c|0)}E()}function Dva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;g=fb-48|0;fb=g;y=p[a+16>>2];j=p[a+44>>2];p[g+32>>2]=j;m=p[a+48>>2];p[g+36>>2]=m;i=p[a+52>>2];p[g+40>>2]=i;h=p[a+56>>2];p[g+44>>2]=h;r=p[a+40>>2];s=p[a+36>>2];e=p[a+4>>2];k=p[a>>2];p[g+24>>2]=k;p[g+28>>2]=e;f=p[a+12>>2];p[g+16>>2]=p[a+8>>2];p[g+20>>2]=f;a:{if(!d){l=r>>12;f=s>>12;break a}while(1){m=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+y|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=o[f+38>>1];h=o[f+36>>1];l=o[f+34>>1];n=o[f+32>>1];t=o[f+30>>1];u=o[f+28>>1];q=o[f+26>>1];w=o[f+24>>1];j=0;i=1;f=0;while(1){x=(g+8|0)+(f<<2)|0;f=f<<1;p[x>>2]=(((((v(o[e+(f|8)>>1],l)+v(o[e+(f|4)>>1],n)|0)+v(h,o[e+(f|12)>>1])|0)+v(k,o[e+(f|16)>>1])|0)/2|0)+((((v(o[e+(f|-8)>>1],q)+v(o[e+(f|-12)>>1],w)|0)+v(o[e+(f|-4)>>1],u)|0)+v(o[e+f>>1],t)|0)/2|0)|0)/16384;x=i&1;i=0;f=1;if(x){continue}break}while(1){i=(g+8|0)+(j<<2)|0;k=p[i>>2];h=p[a+60>>2];l=h;f=(g+32|0)+(j<<3)|0;n=p[f>>2];e=Pb(n,-16777216,16776704);t=p[a+64>>2];j=Pb(p[f+4>>2],-16777216,16776704);q=p[a+68>>2];w=q;q=q>>31;p[f+4>>2]=n;n=p[a+72>>2];u=h>>31;k=k<<8;h=k;h=NNa(l,u,h,h>>31);l=ib;u=i;i=h;h=NNa(t,t>>31,e,e>>31);i=i+h|0;e=ib+l|0;e=i>>>0<h>>>0?e+1|0:e;h=i;i=NNa(w,q,j,j>>31);j=h+i|0;e=ib+e|0;e=j>>>0<i>>>0?e+1|0:e;j=j+8388608|0;if(j>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|j>>>24;p[u>>2]=(e|0)/256;p[f>>2]=e-(k&n);j=1;e=m&1;m=0;if(e){continue}break}e=p[a+32>>2];s=p[a+28>>2]+s|0;f=s>>12;p[c>>2]=p[c>>2]+v(f,p[g+8>>2]);r=e+r|0;l=r>>12;p[c+4>>2]=p[c+4>>2]+v(l,p[g+12>>2]);Kb(g+24|0,g+16|0);d=d+ -1|0;if(d){c=c+8|0;k=p[g+24>>2];e=p[g+28>>2];continue}break}k=p[g+24>>2];e=p[g+28>>2];h=p[g+44>>2];i=p[g+40>>2];m=p[g+36>>2];j=p[g+32>>2]}p[a+40>>2]=r;p[a+20>>2]=f;p[a+36>>2]=s;p[a+56>>2]=h;p[a+52>>2]=i;p[a+48>>2]=m;p[a+44>>2]=j;p[a+24>>2]=l;p[a>>2]=k;p[a+4>>2]=e;fb=g+48|0}function Eva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;g=fb-48|0;fb=g;y=p[a+16>>2];j=p[a+44>>2];p[g+32>>2]=j;m=p[a+48>>2];p[g+36>>2]=m;i=p[a+52>>2];p[g+40>>2]=i;h=p[a+56>>2];p[g+44>>2]=h;s=p[a+40>>2];t=p[a+36>>2];e=p[a+4>>2];k=p[a>>2];p[g+24>>2]=k;p[g+28>>2]=e;f=p[a+12>>2];p[g+16>>2]=p[a+8>>2];p[g+20>>2]=f;a:{if(!d){f=s>>12;l=t>>12;break a}while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+y|0;m=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=o[f+38>>1];h=o[f+36>>1];l=o[f+34>>1];q=o[f+32>>1];u=o[f+30>>1];w=o[f+28>>1];r=o[f+26>>1];x=o[f+24>>1];j=0;i=1;f=0;while(1){p[(g+8|0)+(f<<2)>>2]=(((((v(n[e+(f|4)|0],l)+v(n[e+(f|2)|0],q)|0)+v(h,n[e+(f|6)|0])|0)+v(k,n[e+(f|8)|0])<<8)/2|0)+((((v(n[e+(f|-4)|0],r)+v(n[e+(f|-6)|0],x)|0)+v(n[e+(f|-2)|0],w)|0)+v(n[e+f|0],u)<<8)/2|0)|0)/16384;z=i&1;i=0;f=1;if(z){continue}break}while(1){i=(g+8|0)+(j<<2)|0;k=p[i>>2];h=p[a+60>>2];l=h;f=(g+32|0)+(j<<3)|0;q=p[f>>2];e=Pb(q,-16777216,16776704);u=p[a+64>>2];j=Pb(p[f+4>>2],-16777216,16776704);r=p[a+68>>2];x=r;r=r>>31;p[f+4>>2]=q;q=p[a+72>>2];w=h>>31;k=k<<8;h=k;h=NNa(l,w,h,h>>31);l=ib;w=i;i=h;h=NNa(u,u>>31,e,e>>31);i=i+h|0;e=ib+l|0;e=i>>>0<h>>>0?e+1|0:e;h=i;i=NNa(x,r,j,j>>31);j=h+i|0;e=ib+e|0;e=j>>>0<i>>>0?e+1|0:e;j=j+8388608|0;if(j>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|j>>>24;p[w>>2]=(e|0)/256;p[f>>2]=e-(k&q);j=1;e=m&1;m=0;if(e){continue}break}e=p[a+32>>2];t=p[a+28>>2]+t|0;l=t>>12;p[c>>2]=p[c>>2]+v(l,p[g+8>>2]);s=e+s|0;f=s>>12;p[c+4>>2]=p[c+4>>2]+v(f,p[g+12>>2]);Kb(g+24|0,g+16|0);d=d+ -1|0;if(d){c=c+8|0;k=p[g+24>>2];e=p[g+28>>2];continue}break}k=p[g+24>>2];e=p[g+28>>2];h=p[g+44>>2];i=p[g+40>>2];m=p[g+36>>2];j=p[g+32>>2]}p[a+40>>2]=s;p[a+20>>2]=l;p[a+36>>2]=t;p[a+56>>2]=h;p[a+52>>2]=i;p[a+48>>2]=m;p[a+44>>2]=j;p[a+24>>2]=f;p[a>>2]=k;p[a+4>>2]=e;fb=g+48|0}function mHa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=w(0);c=fb+ -64|0;fb=c;OGa(a,b+16|0);wQ(b+48|0);n[b+143|0]=0;p[b+152>>2]=-2147483648;p[b+156>>2]=-2147483648;d=Lf(a);ld(c+48|0,a,d);p[114610]=0;e=M(337,c+48|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}if(!e){break b}p[114610]=0;e=b+4|0;K(508,e|0,d|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}e=p[e>>2];p[114610]=0;P(701,c+48|0,e|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break b}}a=I()|0;H()|0;break a}p[114610]=0;d=M(390,a|0)|0;e=p[114610];p[114610]=0;d:{if((e|0)==1){break d}p[114610]=0;N(341,c+32|0,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}p[114610]=0;a=M(337,c+32|0)|0;d=p[114610];p[114610]=0;e:{if((d|0)!=1){f:{g:{h:{if(!a){break h}while(1){p[114610]=0;a=J(258,c+32|0,5)|0;d=p[114610];p[114610]=0;i:{if((d|0)!=1){if(!a){break h}p[114610]=0;J(702,c+32|0,c+28|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break g}a=4;if((q[c+28|0]|q[c+29|0]<<8|(q[c+30|0]<<16|q[c+31|0]<<24))==1414682436|(q[c+28|0]|q[c+29|0]<<8|(q[c+30|0]<<16|q[c+31|0]<<24))==1196380752){break i}p[114610]=0;a=M(390,c+32|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break i}a=I()|0;H()|0;break e}a=I()|0;H()|0;break e}p[114610]=0;N(341,c+8|0,c+32|0,a|0);a=p[114610];p[114610]=0;j:{k:{if((a|0)!=1){if((q[c+28|0]|q[c+29|0]<<8|(q[c+30|0]<<16|q[c+31|0]<<24))!=1414682436){break k}p[114610]=0;g=w(ua(703,c+8|0));a=p[114610];p[114610]=0;if((a|0)==1){break f}t[b+144>>2]=g;break j}a=I()|0;H()|0;break e}if((q[c+28|0]|q[c+29|0]<<8|(q[c+30|0]<<16|q[c+31|0]<<24))!=1196380752){break j}p[114610]=0;a=M(390,c+8|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}p[b+148>>2]=a}sb(c+8|0);continue}}sb(c+32|0);sb(c+48|0);fb=c- -64|0;return}a=I()|0;H()|0;break e}a=I()|0;H()|0;sb(c+8|0);break e}a=I()|0;H()|0}sb(c+32|0);break a}a=I()|0;H()|0}sb(c+48|0);L(a|0);E()}function _ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=w(0),g=w(0),h=w(0),i=0,j=0,k=0,l=w(0),n=w(0),o=0,q=0,r=0,s=0,u=0,v=0,y=0,z=0,A=w(0),B=0,C=w(0),D=0,E=0,F=0,G=w(0);a:{if(!p[a+4276>>2]){break a}i=a+44|0;if(!fh(i)){break a}q=Fd(i,0);r=Fd(i,1);s=_c(i,0);u=_c(i,1);B=m[p[p[a>>2]+188>>2]](a)|0;f=w(m[p[p[a>>2]+196>>2]](a));A=w(m[p[p[a>>2]+184>>2]](a));v=m[p[p[a>>2]+208>>2]](a)|0;if(d){C=w(f*w(.009999999776482582));D=v&1;j=a+4260|0;k=p[a+4256>>2];e=p[a+4272>>2];y=d;while(1){h=t[q>>2];l=t[r>>2];k=Cm(a,e+k|0);e=Cm(a,e);f=t[Fb(j,k)>>2];F=Fb(j,e),G=w(w(C*f)+w(w(l+h)*w(.5))),t[F>>2]=G;b:{if(B){g=t[a+4244>>2];f=w(t[a+4236>>2]+g);t[a+4236>>2]=f;g=w(g+t[a+4240>>2]);t[a+4240>>2]=g;if(!(f<=w(1))){f=w(f+w(-2));t[a+4236>>2]=f}if(!(g<=w(1))){t[a+4240>>2]=g+w(-2)}f=w(x(f));f=w(w(f+f)+w(-1));g=w(x(t[a+4240>>2]));g=w(w(g+g)+w(-1));break b}g=t[a+4244>>2];n=t[a+4240>>2];f=w(w(g*n)+t[a+4236>>2]);t[a+4236>>2]=f;g=w(n-w(f*g));t[a+4240>>2]=g}n=t[Fb(j,Cm(a,p[a+4280>>2]+p[a+4272>>2]|0))>>2];F=s,G=w(w(w(w(n-h)+w(w(w(t[Fb(j,Cm(a,p[a+4284>>2]+p[a+4272>>2]|0))>>2]-n)*w(.000244140625))*w(p[a+4280>>2]&4095)))*A)+h),t[F>>2]=G;h=t[Fb(j,Cm(a,p[a+4288>>2]+p[a+4272>>2]|0))>>2];F=u,G=w(w(w(w(h-l)+w(w(w(t[Fb(j,Cm(a,p[a+4292>>2]+p[a+4272>>2]|0))>>2]-h)*w(.000244140625))*w(p[a+4288>>2]&4095)))*A)+l),t[F>>2]=G;z=a;k=p[a+4256>>2];o=k;h=t[a+4248>>2];l=w(h*(D?g:f));c:{if(w(x(l))<w(2147483648)){e=~~l;break c}e=-2147483648}o=o+(v>>>0>1?e:0-e|0)|0;p[z+4288>>2]=o;E=v>>>0<4;z=a;f=w(h*f);d:{if(w(x(f))<w(2147483648)){e=~~f;break d}e=-2147483648}e=(E?e:0-e|0)+k|0;p[z+4280>>2]=e;p[a+4292>>2]=o+4096;p[a+4284>>2]=e+4096;e=p[a+4272>>2];if((e|0)<=0){e=(p[a+4276>>2]<<12)+e|0;p[a+4272>>2]=e}r=r+4|0;q=q+4|0;u=u+4|0;s=s+4|0;e=e+ -4096|0;p[a+4272>>2]=e;y=y+ -1|0;if(y){continue}break}}Zh(a,b,c,_c(i,0),_c(i,1),d)}}function S1(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=fb-432|0;fb=i;p[i+424>>2]=37;p[i+428>>2]=0;j=Aq(i+424|1,62138,p[c+4>>2]);p[i+380>>2]=i+384;a=de();a:{if(j){k=p[c+8>>2];p[i+72>>2]=g;p[i+76>>2]=h;l=i- -64|0;p[l>>2]=e;p[l+4>>2]=f;p[i+48>>2]=k;a=Te(i+384|0,30,a,i+424|0,i+48|0);break a}p[i+80>>2]=e;p[i+84>>2]=f;p[i+88>>2]=g;p[i+92>>2]=h;a=Te(i+384|0,30,a,i+424|0,i+80|0)}p[i+128>>2]=2420;k=Hd(i+368|0,0,i+128|0);b:{c:{d:{if((a|0)>=30){e:{if(j){p[114610]=0;a=Y(2445)|0;j=p[114610];p[114610]=0;if((j|0)==1){break c}j=p[c+8>>2];p[i+16>>2]=e;p[i+20>>2]=f;p[i+24>>2]=g;p[i+28>>2]=h;p[i>>2]=j;p[114610]=0;a=U(2467,i+380|0,a|0,i+424|0,i|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break e}break c}p[114610]=0;a=Y(2445)|0;j=p[114610];p[114610]=0;if((j|0)==1){break c}p[i+32>>2]=e;p[i+36>>2]=f;p[114610]=0;p[i+40>>2]=g;p[i+44>>2]=h;a=U(2467,i+380|0,a|0,i+424|0,i+32|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}}e=p[i+380>>2];if(!e){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)==1){break c}break d}pe(k,e)}e=p[i+380>>2];g=e+a|0;h=Yf(e,g,c);p[i+116>>2]=2420;f=Hd(i+120|0,0,i+116|0);f:{g:{if(p[i+380>>2]==(i+384|0)){a=i+128|0;e=i+384|0;break g}a=fd(a<<3);if(!a){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)!=1){break d}c=I()|0;H()|0;break f}pe(f,a);e=p[i+380>>2]}p[114610]=0;qc(i+104|0,c);j=p[114610];p[114610]=0;h:{i:{if((j|0)!=1){p[114610]=0;ca(2478,e|0,h|0,g|0,a|0,i+116|0,i+112|0,i+104|0);e=p[114610];p[114610]=0;if((e|0)==1){break i}Gb(i+104|0);p[114610]=0;a=da(2479,b|0,a|0,p[i+116>>2],p[i+112>>2],c|0,d|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break h}wc(f);wc(k);fb=i+432|0;return a|0}c=I()|0;H()|0;break f}c=I()|0;H()|0;Gb(i+104|0);break f}c=I()|0;H()|0}wc(f);break b}E()}c=I()|0;H()|0}wc(k);L(c|0);E()}function a2(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=fb-256|0;fb=i;p[i+248>>2]=37;p[i+252>>2]=0;j=Aq(i+248|1,62138,p[c+4>>2]);p[i+204>>2]=i+208;a=de();a:{if(j){k=p[c+8>>2];p[i+72>>2]=g;p[i+76>>2]=h;l=i- -64|0;p[l>>2]=e;p[l+4>>2]=f;p[i+48>>2]=k;a=Te(i+208|0,30,a,i+248|0,i+48|0);break a}p[i+80>>2]=e;p[i+84>>2]=f;p[i+88>>2]=g;p[i+92>>2]=h;a=Te(i+208|0,30,a,i+248|0,i+80|0)}p[i+128>>2]=2420;k=Hd(i+192|0,0,i+128|0);b:{c:{d:{if((a|0)>=30){e:{if(j){p[114610]=0;a=Y(2445)|0;j=p[114610];p[114610]=0;if((j|0)==1){break c}j=p[c+8>>2];p[i+16>>2]=e;p[i+20>>2]=f;p[i+24>>2]=g;p[i+28>>2]=h;p[i>>2]=j;p[114610]=0;a=U(2467,i+204|0,a|0,i+248|0,i|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break e}break c}p[114610]=0;a=Y(2445)|0;j=p[114610];p[114610]=0;if((j|0)==1){break c}p[i+32>>2]=e;p[i+36>>2]=f;p[114610]=0;p[i+40>>2]=g;p[i+44>>2]=h;a=U(2467,i+204|0,a|0,i+248|0,i+32|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}}e=p[i+204>>2];if(!e){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)==1){break c}break d}pe(k,e)}e=p[i+204>>2];g=e+a|0;h=Yf(e,g,c);p[i+116>>2]=2420;f=Hd(i+120|0,0,i+116|0);f:{g:{if(p[i+204>>2]==(i+208|0)){a=i+128|0;e=i+208|0;break g}a=fd(a<<1);if(!a){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)!=1){break d}c=I()|0;H()|0;break f}pe(f,a);e=p[i+204>>2]}p[114610]=0;qc(i+104|0,c);j=p[114610];p[114610]=0;h:{i:{if((j|0)!=1){p[114610]=0;ca(2468,e|0,h|0,g|0,a|0,i+116|0,i+112|0,i+104|0);e=p[114610];p[114610]=0;if((e|0)==1){break i}Gb(i+104|0);p[114610]=0;a=da(17,b|0,a|0,p[i+116>>2],p[i+112>>2],c|0,d|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break h}wc(f);wc(k);fb=i+256|0;return a|0}c=I()|0;H()|0;break f}c=I()|0;H()|0;Gb(i+104|0);break f}c=I()|0;H()|0}wc(f);break b}E()}c=I()|0;H()|0}wc(k);L(c|0);E()}function baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;g=Xg(a);a=b+24|0;f=Ob(p[a>>2]+484360|0);p[114610]=0;i=M(2192,f|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;K(1532,g|0,i|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}d:{e:{if(i){f=0;while(1){c=r[kc(Ob(p[a>>2]+484360|0),f)>>1];d=p[a>>2];p[114610]=0;d=J(918,d+484344|0,c|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break b}f:{if(d){c=Rb(p[a>>2]+484344|0,r[kc(Ob(p[a>>2]+484360|0),f)>>1]);p[114610]=0;K(2193,e|0,c|0);c=p[114610];p[114610]=0;g:{h:{i:{if((c|0)!=1){p[114610]=0;N(2185,e+16|0,b|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}p[114610]=0;K(1534,g|0,e+16|0);c=p[114610];p[114610]=0;if((c|0)==1){break h}pb(e+16|0);pb(e);break f}a=I()|0;H()|0;break a}a=I()|0;H()|0;break g}a=I()|0;H()|0;pb(e+16|0)}pb(e);break a}p[114610]=0;d=Y(965)|0;h=p[114610];p[114610]=0;if((h|0)==1){break b}if((c|0)==(d|0)){p[114610]=0;c=J(85,e+16|0,38758)|0;d=p[114610];p[114610]=0;j:{if((d|0)!=1){p[114610]=0;K(1534,g|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break j}pb(c);break f}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(c);break a}p[114610]=0;d=Y(964)|0;h=p[114610];p[114610]=0;if((h|0)==1){break b}if((c|0)==(d|0)){p[114610]=0;c=J(85,e+16|0,38767)|0;d=p[114610];p[114610]=0;k:{if((d|0)!=1){p[114610]=0;K(1534,g|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break k}pb(c);break f}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(c);break a}p[114610]=0;c=J(85,e+16|0,38776)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}p[114610]=0;K(1534,g|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}pb(c)}f=f+1|0;if((i|0)!=(f|0)){continue}break}}fb=e+32|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(c);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0}bd(g);L(a|0);E()}function mna(a,b,c){var d=0,e=0,f=0,g=0,h=0;h=fb-16|0;fb=h;d=a+1074308|0;vb(h+8|0,d,71);a:{if(tb(h+8|0)){e=(v(b,896)+a|0)+1075843|0;d=n[e|0];if((d|0)>-1){break a}if(!(q[a+480209|0]&16|q[(v(b,896)+a|0)+1075811|0]!=18)){f=d&-33;n[e|0]=f;b:{c:{if((f|0)!=-64){d=d&223;if((d|0)!=128){break c}d=q[(v(b,896)+a|0)+1075844|0]>>>4|-64;break b}d=q[(v(b,896)+a|0)+1075844|0]&15|-128;break b}d=d+ -1|0}n[e|0]=d;e=(v(b,896)+a|0)+1075072|0;p[e>>2]=p[e>>2]|2097152}if((d&224)!=128){break a}p[c>>2]=0;break a}if(q[(v(b,896)+a|0)+1075811|0]!=18){break a}vb(h+8|0,d,22);d:{if(tb(h+8|0)){g=v(b,896)+a|0;e=g+1075843|0;f=q[e|0];d=f<<24>>24;if(!((d|0)>-1|!p[g+1075060>>2])){e:{f:{if((f|0)!=192){if((f|0)!=128){break f}d=q[(v(b,896)+a|0)+1075844|0]>>>4|-64;break e}d=q[(v(b,896)+a|0)+1075844|0]&15|-128;break e}d=d+ -1|0}n[e|0]=d}if((d&192)!=128){break d}p[c>>2]=0;break d}d=q[(v(b,896)+a|0)+1075844|0];e=d>>>4|0;f=e+(d&15)|0;if(!(q[a+480208|0]&4?0:p[a+480180>>2]&16777248)){f=f+2|0;e=e+1|0}g=(v(b,896)+a|0)+1075843|0;d=q[g|0];if(!(p[a+480180>>2]&4)){d=(d&255)>>>0<f>>>0?d:0;if((d&255)>>>0>=e>>>0){p[c>>2]=0}n[g|0]=d+1;break d}g:{if(q[a+480209|0]&16){d=d&255?d+ -1|0:0;break g}n[g|0]=d+1}if(((d&255)>>>0)%(f>>>0)>>>0<e>>>0){break d}p[c>>2]=0}d=(v(b,896)+a|0)+1075072|0;p[d>>2]=p[d>>2]|2097152}d=v(b,896)+a|0;h:{if(q[d+1075811|0]!=18){break h}f=d+1075640|0;d=p[f>>2];if(!d|!q[d+34|0]|q[d+15|0]&2){break h}d=v(b,896)+a|0;if(p[d+1075072>>2]&134218752){break h}e=d+1075805|0;if(!Ud(q[e|0])){break h}f=p[f>>2];d=p[(v(q[f+34|0],160)+a|0)+906140>>2];if(!d){break h}g=m[p[p[d>>2]+96>>2]](d,q[e|0],b)|0;c=p[c>>2];if(!(!g|c)){m[p[p[d>>2]+88>>2]](d,f,q[e|0]+255|0,0,b);break h}if(g|!c){break h}m[p[p[d>>2]+88>>2]](d,f,q[e|0],r[(v(b,896)+a|0)+1075672>>1],b)}fb=h+16|0}function g7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;d=-2;a:{if(!a){break a}c=p[a+28>>2];if(!c){break a}b=(b|0)==1?2:b;if(b>>>0>4|!(1<<b&21)){break a}f=p[c+11e3>>2];j=p[a+4>>2];p[c+11e3>>2]=0;b:{if(p[c+43780>>2]<0){break b}h=(b|0)==4;g=p[c+11004>>2];if(g?!h:0){break a}d=p[c+11008>>2]>0?9:8;p[c+11004>>2]=h|g;if(!(!f|(b|0)!=4)){p[e+12>>2]=p[a+4>>2];p[e+8>>2]=p[a+16>>2];b=p[a+12>>2];b=tF(c,p[a>>2],e+12|0,b,b,e+8|0,d|4);p[c+43780>>2]=b;d=p[e+12>>2];p[a>>2]=d+p[a>>2];p[a+4>>2]=p[a+4>>2]-d;p[a+8>>2]=d+p[a+8>>2];p[a+48>>2]=p[c+28>>2];d=p[e+8>>2];p[a+12>>2]=d+p[a+12>>2];p[a+16>>2]=p[a+16>>2]-d;p[a+20>>2]=d+p[a+20>>2];d=-3;if((b|0)<0){break a}if(!b){d=1;break a}p[c+43780>>2]=-1;d=-5;break a}f=p[c+10996>>2];if(!f){i=(b|0)!=4;k=i?d|2:d;h=c+11012|0;b=p[c+10992>>2];while(1){d=p[a+4>>2];p[e+8>>2]=32768-b;p[e+12>>2]=d;f=tF(c,p[a>>2],e+12|0,h,b+h|0,e+8|0,k);p[c+43780>>2]=f;b=p[e+12>>2];p[a>>2]=b+p[a>>2];p[a+4>>2]=p[a+4>>2]-b;p[a+8>>2]=b+p[a+8>>2];p[a+48>>2]=p[c+28>>2];b=p[e+8>>2];p[c+10996>>2]=b;d=p[a+16>>2];b=b>>>0<d>>>0?b:d;ac(p[a+12>>2],h+p[c+10992>>2]|0,b);p[a+12>>2]=b+p[a+12>>2];p[a+16>>2]=p[a+16>>2]-b;p[a+20>>2]=b+p[a+20>>2];g=p[c+10996>>2]-b|0;p[c+10996>>2]=g;b=b+p[c+10992>>2]&32767;p[c+10992>>2]=b;if((f|0)<0){break b}d=-5;if((f|0)==1?!j:0){break a}if(!i){if(!f){d=g?-5:1;break a}if(p[a+16>>2]){continue}break a}if(f){d=0;if(g|!p[a+4>>2]){break a}if(p[a+16>>2]){continue}break a}break}d=!g;break a}b=p[a+16>>2];b=f>>>0<b>>>0?f:b;ac(p[a+12>>2],(p[c+10992>>2]+c|0)+11012|0,b);p[a+12>>2]=b+p[a+12>>2];p[a+16>>2]=p[a+16>>2]-b;p[a+20>>2]=b+p[a+20>>2];a=p[c+10996>>2]-b|0;p[c+10996>>2]=a;p[c+10992>>2]=b+p[c+10992>>2]&32767;d=0;if(p[c+43780>>2]){break a}d=!a;break a}d=-3}fb=e+16|0;return d|0}function Rxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;j=c+484344|0;Pf(j,q[b+70|0]|q[b+71|0]<<8);a:{if(q[b+70|0]|q[b+71|0]<<8){while(1){f=p[a+8>>2];g=Lf(a);Sb(a,1);b:{if((q[b+58|0]|q[b+59|0]<<8)==258){c=td(a)+1|0;break b}c=kg(a)}d=kg(a);Jc(a,f+g|0);ld(e+16|0,a,d);p[114610]=0;c=P(402,j|0,i&65535,(c?c>>>0<1024?c:1024:64)|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}c:{if(!d|c^1){break c}c=Rb(j,i);k=e,l=Ub(c),p[k+8>>2]=l;k=e,l=Vb(c),p[k>>2]=l;if(!Ab(e+8|0,e)){break c}while(1){d=p[e+8>>2];p[114610]=0;c=M(387,e+16|0)|0;f=p[114610];p[114610]=0;d:{e:{f:{if((f|0)!=1){if(!(c&128)){break f}if(c&1){p[114610]=0;f=M(387,e+16|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break a}n[d|0]=f}if(c&2){break e}break d}break a}n[d|0]=c;c=255}p[114610]=0;f=M(387,e+16|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break a}n[d+1|0]=f}f=0;if(c&4){p[114610]=0;f=M(387,e+16|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break a}}if(c&8){p[114610]=0;g=M(387,e+16|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}n[d+3|0]=g}if(c&16){p[114610]=0;c=M(387,e+16|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break a}n[d+5|0]=c}c=d;g:{h:{g=q[d|0];if(!g){break h}h=255;if((g|0)==97){break g}if(g>>>0>96){break h}h=g+12|0;break g}h=0}n[c|0]=h;i:{if(q[d+5|0]|q[d+3|0]){p[114610]=0;S(577,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){break i}break a}n[d+3|0]=0}if(q[d+1|0]==255){n[d+1|0]=0}c=f+ -16|0;j:{if((c&255)>>>0<=64){n[d+4|0]=c;n[d+2|0]=1;break j}if(f>>>0<96){break j}c=f&15;n[d+4|0]=c;f=f+ -96>>4;n[d+2|0]=q[f+17919|0];if((f|0)!=6){break j}n[d+4|0]=c<<2}uk(e+8|0);if(Ab(e+8|0,e)){continue}break}}sb(e+16|0);i=i+1|0;if(i>>>0<(q[b+70|0]|q[b+71|0]<<8)>>>0){continue}break}}fb=e+32|0;return}a=I()|0;H()|0;sb(e+16|0);L(a|0);E()}function Gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-1136|0;fb=e;Ac(b);d=e+1112|0;h=qla(b,d);if(!h){TI(d)}a:{if(!h){break a}if(!XI(e+1112|0)){break a}d=e+1120|0;if((q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24))!=(qj(b)|0)){break a}d=e+1128|0;if((q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24))!=(pf(b)|0)){break a}if(!c){f=1;break a}Jb(e+1056|0,0,56);if(h7(e+1056|0)){break a}d=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);p[e+1052>>2]=d;f=e+1132|0;f=q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24);g=(f|0)!=0;h=pz(e+1040|0,f);b:{c:{d:{e:{if(!f|!d){break e}while(1){p[114610]=0;p[e+12>>2]=1024;d=J(632,e+12|0,e+1052|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break d}d=p[d>>2];p[114610]=0;P(261,b|0,e+16|0,d|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;i=P(1556,i|0,e+16|0,d|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[e+1072>>2]=f;p[e+1060>>2]=d;p[e+1056>>2]=e+16;g=p[h>>2];p[114610]=0;p[e+1068>>2]=g+j;k=J(1557,e+1056|0,0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}l=p[e+1052>>2]-d|0;p[e+1052>>2]=l;d=p[e+1072>>2];g=(d|0)!=0;if(!d|(k|0)==1){break e}j=(f+j|0)-d|0;f=d;if(l){continue}break}}p[114610]=0;M(1558,e+1056|0)|0;b=p[114610];p[114610]=0;f:{g:{if((b|0)!=1){f=0;b=e+1124|0;if(!((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))!=(i|0)|g|(k|0)!=1)){p[114610]=0;K(836,e|0,h|0);b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;b=P(837,e+16|0,e|0,0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break g}p[114610]=0;f=P(1496,a|0,b|0,c|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break f}sb(b)}Xd(h);break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;break b}a=I()|0;H()|0;sb(b);break b}a=I()|0;H()|0;break b}a=I()|0;H()|0}Xd(h);L(a|0);E()}fb=e+1136|0;return f|0}function Af(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;h=p[a+8>>2]+(v(r[a+14>>1],(q[a+80|0]?c:0)+b|0)>>>1|0)|0;p[a+8>>2]=h;b=r[a+20>>1];g=r[a+22>>1];j=r[a+70>>1];i=q[a+79|0]?r[p[a>>2]+3836>>1]:i;a:{b:{c:{switch(p[a+16>>2]){case 0:c=r[p[a>>2]+3832>>1];c=b+(c&r[a+34>>1]?0:r[a+24>>1]?v(r[a+36>>1]>>>r[p[a+40>>2]+((c>>>r[a+32>>1]&7)<<1)>>1]|0,(b^-1)<<16>>16)>>>3|0:0)|0;o[a+20>>1]=c;if(c<<16>>16>0){break b}p[a+16>>2]=1;o[a+20>>1]=0;break b;case 1:c=r[p[a>>2]+3832>>1];c=b+(c&r[a+46>>1]?0:r[a+26>>1]?r[a+48>>1]>>>r[p[a+52>>2]+((c>>>r[a+44>>1]&7)<<1)>>1]|0:0)|0;o[a+20>>1]=c;f=c<<16>>16;c=r[a+28>>1];if((f|0)<(c|0)){break b}p[a+16>>2]=2;o[a+20>>1]=c;break b;case 2:if(q[a+78|0]){break b};case 3:c=0;f=r[p[a>>2]+3832>>1];f=b+(f&r[a+58>>1]?0:r[a+30>>1]?r[a+60>>1]>>>r[p[a+64>>2]+((f>>>r[a+56>>1]&7)<<1)>>1]|0:0)|0;o[a+20>>1]=f;if(f<<16>>16<511){break b}p[a+16>>2]=-1;o[a+20>>1]=511;p[a+72>>2]=0;break a;default:break c}}c=0;p[a+72>>2]=0;break a}g=((b+g|0)+j|0)+i<<3;if(e){d=(o[a+74>>1]+o[a+72>>1]>>(e&65535))+d|0}d=(h>>>10|0)+d|0;c=d&255;b=d&65535;d:{e:{switch(r[a+12>>1]){case 0:d=(b&512)>>>9|0;b=r[((b&256?c^255:c)<<1)+19232>>1];break d;case 1:d=0;b=r[((b&512?0:b&256?c^255:c)<<1)+19232>>1];break d;case 2:d=0;b=r[((b&256?c^255:c)<<1)+19232>>1];break d;case 3:d=0;b=r[((b&256?0:c)<<1)+19232>>1];break d;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=r[(e<<1)+19232>>1];break d;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=r[(b<<1)+19232>>1];break d;case 6:d=(d&512)>>>9|0;b=0;break d;default:break e}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}o[a+74>>1]=r[a+72>>1];e=a;a=b+g|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^r[((a&255)<<1)+18720>>1]+1024>>>((a&65280)>>>8)<<1;o[e+72>>1]=c}return c<<16>>16}function x6(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{b:{c:{f=p[a+1420>>2];if((f|0)<1){break c}while(1){p[(v(d,20)+a|0)+1436>>2]=0;d=d+1|0;if((f|0)!=(d|0)){continue}break}if((f|0)<=3){break c}g=c;break b}if((c|0)<4){break a}h=c+ -3|0;d:{while(1){e:{e=b+g|0;if(q[e|0]!=79|(q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))!=(q[84608]|q[84609]<<8|(q[84610]<<16|q[84611]<<24))){break e}j=g+26|0;if((j|0)>=(h|0)){break d}i=g+27|0;l=b+j|0;c=q[l|0];if((i+c|0)>=(h|0)){break d}k=c+27|0;d=0;if(c){while(1){k=q[(d+i|0)+b|0]+k|0;d=d+1|0;if((c|0)!=(d|0)){continue}break}}d=0;c=0;while(1){i=22;d=Nv(d,q[(c+g|0)+b|0]);c=c+1|0;if((c|0)!=22){continue}break}while(1){d=Nv(d,0);i=i+1|0;if((i|0)!=26){continue}break}p[a+1420>>2]=f+1;c=v(f,20)+a|0;p[c+1432>>2]=d;p[c+1428>>2]=k+ -26;p[c+1424>>2]=q[e+22|0]|q[e+23|0]<<8|(q[e+24|0]<<16|q[e+25|0]<<24);if(q[(j+q[l|0]|0)+b|0]==255){d=-1}else{d=q[e+6|0]|q[e+7|0]<<8|(q[e+8|0]<<16|q[e+9|0]<<24)}p[c+1436>>2]=j;p[c+1440>>2]=d;f=p[a+1420>>2];if((f|0)!=4){break e}g=h;break b}g=g+1|0;if((h|0)!=(g|0)){continue}break}g=h}if((f|0)<1){break a}}h=0;while(1){e=v(h,20)+a|0;i=e+1432|0;c=p[i>>2];d=0;j=p[e+1436>>2];f=g-j|0;l=e+1428|0;k=p[l>>2];f=(k|0)>(f|0)?f:k;if((f|0)>=1){while(1){c=Nv(c,q[(d+j|0)+b|0]);d=d+1|0;if((f|0)!=(d|0)){continue}break}}d=k-f|0;p[l>>2]=d;p[i>>2]=c;f:{if(!d){d=c;c=e+1424|0;if((d|0)==p[c>>2]){p[a+1380>>2]=-1;p[a+992>>2]=0;p[a+1420>>2]=-1;b=p[(v(h,20)+a|0)+1440>>2];p[a+1060>>2]=b;p[a+1064>>2]=(b|0)!=-1;return f+j|0}d=p[a+1420>>2]+ -1|0;p[a+1420>>2]=d;d=v(d,20)+a|0;p[c+16>>2]=p[d+1440>>2];e=d+1432|0;f=p[e+4>>2];p[c+8>>2]=p[e>>2];p[c+12>>2]=f;d=d+1424|0;e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;break f}h=h+1|0}if((h|0)<p[a+1420>>2]){continue}break}}return g}function Eq(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,o=0,r=0,s=0,t=0,u=0,v=0;i=fb-128|0;fb=i;p[i+120>>2]=b;k=As(c,d);p[i+4>>2]=2420;m=Hd(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=fd(k);if(!j){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;break b}pe(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{p[114610]=0;h=J(2422,a|0,i+120|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){p[114610]=0;b=J(2423,a|0,i+120|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}if(!b){break d}p[f>>2]=p[f>>2]|2;break d}p[114610]=0;o=M(2424,a|0)|0;b=p[114610];p[114610]=0;g:{if((b|0)!=1){if(g){break g}p[114610]=0;o=J(2425,e|0,o|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break g}}b=I()|0;H()|0;break b}r=t+1|0;u=0;h=j;b=c;while(1){if((b|0)==(d|0)){t=r;if(!u){continue e}p[114610]=0;M(2426,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(q[h|0]!=2){break h}if((wb(b)|0)==(r|0)){break h}n[h|0]=0;l=l+ -1|0}h=h+1|0;b=b+12|0;continue}}b=I()|0;H()|0;break b}i:{if(q[h|0]!=1){break i}s=n[cc(b,t)|0];j:{if(g){break j}p[114610]=0;s=J(2425,e|0,s<<24>>24)|0;v=p[114610];p[114610]=0;if((v|0)!=1){break j}b=I()|0;H()|0;break b}k:{if((o&255)==(s&255)){u=1;if((wb(b)|0)!=(r|0)){break i}n[h|0]=2;l=l+1|0;break k}n[h|0]=0}k=k+ -1|0}h=h+1|0;b=b+12|0;continue}}break}b=I()|0;H()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(q[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}p[f>>2]=p[f>>2]|4}wc(m);fb=i+128|0;return d|0}b=I()|0;H()|0}else{n:{if(!Pc(b)){n[h|0]=1;break n}n[h|0]=2;l=l+1|0;k=k+ -1|0}h=h+1|0;b=b+12|0;continue}break}}wc(m);L(b|0)}E()}function gY(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=p[a+4>>2];d=g&-8;f=d+a|0;a:{if(!(g&3)){if(b>>>0<256){break a}if(d>>>0>=b+4>>>0){c=a;if(d-b>>>0<=p[116040]<<1>>>0){break a}}return 0}b:{if(d>>>0>=b>>>0){c=d-b|0;if(c>>>0<16){break b}p[a+4>>2]=g&1|b|2;b=a+b|0;p[b+4>>2]=c|3;p[f+4>>2]=p[f+4>>2]|1;nq(b,c);break b}if(p[115926]==(f|0)){d=d+p[115923]|0;if(d>>>0<=b>>>0){break a}p[a+4>>2]=g&1|b|2;c=a+b|0;b=d-b|0;p[c+4>>2]=b|1;p[115923]=b;p[115926]=c;break b}if(p[115925]==(f|0)){d=d+p[115922]|0;if(d>>>0<b>>>0){break a}c=d-b|0;c:{if(c>>>0>=16){p[a+4>>2]=g&1|b|2;b=a+b|0;p[b+4>>2]=c|1;d=a+d|0;p[d>>2]=c;p[d+4>>2]=p[d+4>>2]&-2;break c}p[a+4>>2]=d|g&1|2;b=a+d|0;p[b+4>>2]=p[b+4>>2]|1;c=0;b=0}p[115925]=b;p[115922]=c;break b}e=p[f+4>>2];if(e&2){break a}h=d+(e&-8)|0;if(h>>>0<b>>>0){break a}j=h-b|0;d:{if(e>>>0<=255){c=p[f+8>>2];e=e>>>3|0;d=p[f+12>>2];if((d|0)==(c|0)){l=463680,m=p[115920]&SNa(-2,e),p[l>>2]=m;break d}p[c+12>>2]=d;p[d+8>>2]=c;break d}i=p[f+24>>2];d=p[f+12>>2];e:{if((f|0)!=(d|0)){c=p[f+8>>2];p[c+12>>2]=d;p[d+8>>2]=c;break e}f:{c=f+20|0;e=p[c>>2];if(e){break f}c=f+16|0;e=p[c>>2];if(e){break f}d=0;break e}while(1){k=c;d=e;c=d+20|0;e=p[c>>2];if(e){continue}c=d+16|0;e=p[d+16>>2];if(e){continue}break}p[k>>2]=0}if(!i){break d}c=p[f+28>>2];e=(c<<2)+463984|0;g:{if(p[e>>2]==(f|0)){p[e>>2]=d;if(d){break g}l=463684,m=p[115921]&SNa(-2,c),p[l>>2]=m;break d}p[i+(p[i+16>>2]==(f|0)?16:20)>>2]=d;if(!d){break d}}p[d+24>>2]=i;c=p[f+16>>2];if(c){p[d+16>>2]=c;p[c+24>>2]=d}c=p[f+20>>2];if(!c){break d}p[d+20>>2]=c;p[c+24>>2]=d}if(j>>>0<=15){p[a+4>>2]=g&1|h|2;b=a+h|0;p[b+4>>2]=p[b+4>>2]|1;break b}p[a+4>>2]=g&1|b|2;b=a+b|0;p[b+4>>2]=j|3;c=a+h|0;p[c+4>>2]=p[c+4>>2]|1;nq(b,j)}c=a}return c}function O0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-624|0;fb=a;p[a+608>>2]=c;p[a+616>>2]=b;p[a+16>>2]=2482;b=Hd(a+200|0,a+208|0,a+16|0);p[114610]=0;qc(a+192|0,e);h=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){p[114610]=0;h=M(2449,a+192|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break j}n[a+191|0]=0;e=p[e+4>>2];p[114610]=0;c=ma(2493,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}if(!c){break f}c=q[62379]|q[62380]<<8|(q[62381]<<16|q[62382]<<24);n[a+183|0]=c;n[a+184|0]=c>>>8;n[a+185|0]=c>>>16;n[a+186|0]=c>>>24;c=q[62376]|q[62377]<<8|(q[62378]<<16|q[62379]<<24);p[a+176>>2]=q[62372]|q[62373]<<8|(q[62374]<<16|q[62375]<<24);p[a+180>>2]=c;p[114610]=0;U(2463,h|0,a+176|0,a+186|0,a+128|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break i}p[a+4>>2]=2420;d=Hd(a+8|0,0,a+4|0);c=a+16|0;if((p[a+196>>2]-p[b>>2]|0)<393){break g}pe(d,fd((p[a+196>>2]-p[b>>2]>>2)+2|0));if(p[d>>2]){break h}p[114610]=0;R(2421);c=p[114610];p[114610]=0;if((c|0)==1){break d}break a}e=I()|0;H()|0;break b}e=I()|0;H()|0;break c}e=I()|0;H()|0;break c}c=p[d>>2]}if(q[a+191|0]){n[c|0]=45;c=c+1|0}e=p[b>>2];while(1){if(e>>>0>=s[a+196>>2]){n[c|0]=0;p[a>>2]=g;if((ID(a+16|0,a)|0)!=1){p[114610]=0;S(2484,62356);c=p[114610];p[114610]=0;if((c|0)!=1){break a}break d}wc(d)}else{j=c,k=q[(a+176|0)+(Wu(a+128|0,a+168|0,e)-(a+128|0)>>2)|0],n[j|0]=k;c=c+1|0;e=e+4|0;continue}break}}p[114610]=0;c=J(2455,a+616|0,a+608|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}if(c){p[f>>2]=p[f>>2]|2}c=p[a+616>>2];Gb(a+192|0);wc(b);fb=a+624|0;return c|0}e=I()|0;H()|0;break c}e=I()|0;H()|0;wc(d)}Gb(a+192|0)}wc(b);L(e|0);E()}E()}function Cq(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,o=0,r=0,s=0,t=0,u=0,v=0;i=fb-128|0;fb=i;p[i+120>>2]=b;k=As(c,d);p[i+4>>2]=2420;m=Hd(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=fd(k);if(!j){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;break b}pe(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{p[114610]=0;h=J(2454,a|0,i+120|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){p[114610]=0;b=J(2455,a|0,i+120|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}if(!b){break d}p[f>>2]=p[f>>2]|2;break d}p[114610]=0;o=M(2456,a|0)|0;b=p[114610];p[114610]=0;g:{if((b|0)!=1){if(g){break g}p[114610]=0;o=J(2457,e|0,o|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break g}}b=I()|0;H()|0;break b}r=t+1|0;u=0;h=j;b=c;while(1){if((b|0)==(d|0)){t=r;if(!u){continue e}p[114610]=0;M(2458,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(q[h|0]!=2){break h}if((wb(b)|0)==(r|0)){break h}n[h|0]=0;l=l+ -1|0}h=h+1|0;b=b+12|0;continue}}b=I()|0;H()|0;break b}i:{if(q[h|0]!=1){break i}s=p[Ui(b,t)>>2];j:{if(g){break j}p[114610]=0;s=J(2457,e|0,s|0)|0;v=p[114610];p[114610]=0;if((v|0)!=1){break j}b=I()|0;H()|0;break b}k:{if((o|0)==(s|0)){u=1;if((wb(b)|0)!=(r|0)){break i}n[h|0]=2;l=l+1|0;break k}n[h|0]=0}k=k+ -1|0}h=h+1|0;b=b+12|0;continue}}break}b=I()|0;H()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(q[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}p[f>>2]=p[f>>2]|4}wc(m);fb=i+128|0;return d|0}b=I()|0;H()|0}else{n:{if(!Pc(b)){n[h|0]=1;break n}n[h|0]=2;l=l+1|0;k=k+ -1|0}h=h+1|0;b=b+12|0;continue}break}}wc(m);L(b|0)}E()}function m2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-352|0;fb=a;p[a+336>>2]=c;p[a+344>>2]=b;h=Lb(a+208|0);p[114610]=0;qc(a+16|0,d);b=p[114610];p[114610]=0;a:{b:{c:{d:{if((b|0)!=1){p[114610]=0;b=M(2449,a+16|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break d}p[114610]=0;U(2463,b|0,62096,62122,a+224|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}Gb(a+16|0);c=Lb(a+192|0);b=Bc(c);p[114610]=0;K(149,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}b=cc(c,0);p[a+188>>2]=b;p[a+12>>2]=a+16;p[a+8>>2]=0;while(1){e:{p[114610]=0;d=J(2454,a+344|0,a+336|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}if(!d){break c}if(p[a+188>>2]==(wb(c)+b|0)){d=wb(c);b=wb(c);p[114610]=0;K(149,c|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break b}b=Bc(c);p[114610]=0;K(149,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}b=cc(c,0);p[a+188>>2]=d+b}p[114610]=0;d=M(2456,a+344|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}p[114610]=0;d=Dj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=p[114610];p[114610]=0;if((g|0)==1){break e}if(d){break c}p[114610]=0;M(2458,a+344|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){continue}}break}break b}b=I()|0;H()|0;break a}b=I()|0;H()|0;Gb(a+16|0);break a}p[114610]=0;K(149,c|0,p[a+188>>2]-b|0);b=p[114610];p[114610]=0;f:{if((b|0)==1){break f}b=Ib(c);p[114610]=0;d=Y(2445)|0;g=p[114610];p[114610]=0;if((g|0)==1){break f}p[a>>2]=f;p[114610]=0;b=U(2446,b|0,d|0,62129,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}if((b|0)!=1){p[e>>2]=4}p[114610]=0;b=J(2455,a+344|0,a+336|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}if(b){p[e>>2]=p[e>>2]|2}b=p[a+344>>2];pb(c);pb(h);fb=a+352|0;return b|0}}b=I()|0;H()|0;pb(c)}pb(h);L(b|0);E()}function Hva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;f=fb-48|0;fb=f;u=p[a+16>>2];e=p[a+44>>2];p[f+32>>2]=e;i=p[a+48>>2];p[f+36>>2]=i;l=p[a+52>>2];p[f+40>>2]=l;m=p[a+56>>2];p[f+44>>2]=m;w=p[a+24>>2];x=p[a+20>>2];g=p[a+4>>2];j=p[a>>2];p[f+24>>2]=j;p[f+28>>2]=g;h=p[a+12>>2];p[f+16>>2]=p[a+8>>2];p[f+20>>2]=h;if(d){while(1){m=1;h=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+u|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=o[e+38>>1];k=o[e+36>>1];q=o[e+34>>1];r=o[e+32>>1];s=o[e+30>>1];n=o[e+28>>1];t=o[e+26>>1];y=o[e+24>>1];l=0;e=1;i=0;while(1){g=i<<1;p[(f+8|0)+(i<<2)>>2]=(((((v(o[h+(g|8)>>1],q)+v(o[h+(g|4)>>1],r)|0)+v(o[h+(g|12)>>1],k)|0)+v(j,o[h+(g|16)>>1])|0)/2|0)+((((v(o[h+(g|-8)>>1],t)+v(o[h+(g|-12)>>1],y)|0)+v(o[h+(g|-4)>>1],n)|0)+v(o[h+g>>1],s)|0)/2|0)|0)/16384;g=e;e=0;i=1;if(g){continue}break}while(1){i=(f+8|0)+(l<<2)|0;j=p[i>>2];k=p[a+60>>2];q=k;g=(f+32|0)+(l<<3)|0;l=p[g>>2];e=Pb(l,-16777216,16776704);r=p[a+64>>2];h=Pb(p[g+4>>2],-16777216,16776704);n=p[a+68>>2];t=n;n=n>>31;p[g+4>>2]=l;l=p[a+72>>2];k=k>>31;j=j<<8;k=NNa(q,k,j,j>>31);q=ib;s=i;i=k;k=NNa(r,r>>31,e,e>>31);i=i+k|0;e=ib+q|0;e=i>>>0<k>>>0?e+1|0:e;k=i;i=NNa(t,n,h,h>>31);h=k+i|0;e=ib+e|0;e=h>>>0<i>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|h>>>24;p[s>>2]=(e|0)/256;p[g>>2]=e-(j&l);l=1;e=m&1;m=0;if(e){continue}break}p[c>>2]=p[c>>2]+v(p[f+8>>2],x);p[c+4>>2]=p[c+4>>2]+v(p[f+12>>2],w);Kb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;j=p[f+24>>2];g=p[f+28>>2];continue}break}j=p[f+24>>2];g=p[f+28>>2];m=p[f+44>>2];l=p[f+40>>2];i=p[f+36>>2];e=p[f+32>>2]}p[a+56>>2]=m;p[a+52>>2]=l;p[a+48>>2]=i;p[a+44>>2]=e;p[a>>2]=j;p[a+4>>2]=g;fb=f+48|0}function J2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-272|0;fb=a;p[a+256>>2]=c;p[a+264>>2]=b;h=Lb(a+208|0);p[114610]=0;qc(a+16|0,d);b=p[114610];p[114610]=0;a:{b:{c:{d:{if((b|0)!=1){p[114610]=0;b=M(21,a+16|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break d}p[114610]=0;U(2440,b|0,62096,62122,a+224|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}Gb(a+16|0);c=Lb(a+192|0);b=Bc(c);p[114610]=0;K(149,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}b=cc(c,0);p[a+188>>2]=b;p[a+12>>2]=a+16;p[a+8>>2]=0;while(1){e:{p[114610]=0;d=J(2422,a+264|0,a+256|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}if(!d){break c}if(p[a+188>>2]==(wb(c)+b|0)){d=wb(c);b=wb(c);p[114610]=0;K(149,c|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break b}b=Bc(c);p[114610]=0;K(149,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}b=cc(c,0);p[a+188>>2]=d+b}p[114610]=0;d=M(2424,a+264|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}p[114610]=0;d=Ej(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=p[114610];p[114610]=0;if((g|0)==1){break e}if(d){break c}p[114610]=0;M(2426,a+264|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){continue}}break}break b}b=I()|0;H()|0;break a}b=I()|0;H()|0;Gb(a+16|0);break a}p[114610]=0;K(149,c|0,p[a+188>>2]-b|0);b=p[114610];p[114610]=0;f:{if((b|0)==1){break f}b=Ib(c);p[114610]=0;d=Y(2445)|0;g=p[114610];p[114610]=0;if((g|0)==1){break f}p[a>>2]=f;p[114610]=0;b=U(2446,b|0,d|0,62129,a|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}if((b|0)!=1){p[e>>2]=4}p[114610]=0;b=J(2423,a+264|0,a+256|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}if(b){p[e>>2]=p[e>>2]|2}b=p[a+264>>2];pb(c);pb(h);fb=a+272|0;return b|0}}b=I()|0;H()|0;pb(c)}pb(h);L(b|0);E()}function XT(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))==1229999433){Qt(e,3,a+32|0);zc(e+16|0,e);p[114610]=0;J(369,b+492|0,e+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}pb(e+16|0);yi(e,1,a+4|0);zc(e+16|0,e);p[114610]=0;J(369,b+524|0,e+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}pb(e+16|0);d=a+20|0;p[b>>2]=(q[d|0]|q[d+1|0]<<8)<<5;p[b+4>>2]=q[a+24|0]>>>1;vc(b+4|0,64);d=a+25|0;f=q[d|0]&127;p[b+8>>2]=f>>>0>64?128:f<<2;n[b+15|0]=(q[b+15|0]&254|q[d|0]>>>7)^1;n[e+16|0]=q[a+26|0];n[e|0]=100;h=b,i=q[hc(e+16|0,e)|0],n[h+20|0]=i;n[e+16|0]=q[a+27|0];n[e|0]=64;h=b,i=q[hc(e+16|0,e)|0],n[h+19|0]=i;n[b+16|0]=q[a+17|0];n[b+17|0]=q[a+18|0];n[b+18|0]=q[a+19|0];n[b+26|0]=q[a+22|0];n[b+27|0]=q[a+23|0];d=a+58|0;Mt(b,q[d|0]&127,n[d|0]<0);d=a+59|0;Lt(b,q[d|0]&127,n[d|0]<0);b:{c:{d:{d=a+28|0;if(!((q[d|0]|q[d+1|0]<<8)==514|(q[d|0]|q[d+1|0]<<8)==529|(q[d|0]|q[d+1|0]<<8)==544)){if((q[d|0]|q[d+1|0]<<8)!=532){break d}}d=a+61|0;if(q[d|0]==255){break d}if(q[d|0]<=128){n[b+30|0]=q[d|0]}d=q[a+62|0]|q[a+63|0]<<8;if(d>>>0<129){break c}break b}d=0;f=a+61|0;if(n[f|0]>=0){n[b+30|0]=q[f|0]+1}f=a+62|0;if(n[f|0]>=0){d=q[f|0]+1|0}f=a+63|0;if(n[f|0]<0){break c}d=(q[f|0]<<7)+d|0}o[b+28>>1]=d}d=n[a+60|0];n[b+31|0]=d;if((d|0)<=-1){n[b+31|0]=0;n[b+34|0]=d^128}d=0;c=c&16777216?240:25;St(a+304|0,b+48|0,0,c);St(a+386|0,b+68|0,32,c);St(a+468|0,b+88|0,32,c);n[b+100|0]=q[b+100|0]&239|q[a+468|0]>>>3&16;c=b+108|0;f=b+236|0;a=a- -64|0;while(1){g=d<<1;b=q[g+a|0];g=q[a+(g|1)|0];h=Yc(f,d),i=g,o[h>>1]=i;h=Yb(c,d),i=(b>>>0<120?b:d)+1|0,n[h|0]=i;d=d+1|0;if((d|0)!=120){continue}break}d=554}fb=e+32|0;return d}a=I()|0;H()|0;pb(e+16|0);L(a|0);E()}function Yva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=fb-16|0;fb=i;u=p[a+16>>2];a:{b:{c:{j=p[a+8>>2];g=p[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?j>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?j>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?j>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?j>>>0>2147483648:0){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}f=p[a+48>>2];l=p[a+40>>2];m=p[a+36>>2];e=p[a+44>>2];h=p[a+4>>2];k=p[a>>2];p[i+8>>2]=k;p[i+12>>2]=h;p[i>>2]=j;p[i+4>>2]=g;e:{if(!d){g=l>>12;j=m>>12;break e}while(1){b=h+u|0;g=n[b+4|0];h=(k>>>16&65520)+r|0;k=o[h+14>>1];j=n[b+3|0];w=o[h+12>>1];x=n[b+2|0];y=o[h+10>>1];z=n[b+1|0];A=o[h+8>>1];B=n[b|0];C=o[h+6>>1];D=n[b+ -1|0];E=o[h+4>>1];F=n[b+ -2|0];G=o[h+2>>1];H=n[b+ -3|0];I=o[h>>1];b=p[a+60>>2];J=b;K=b>>31;b=e;e=Pb(e,-16777216,16776704);q=p[a+64>>2];f=Pb(f,-16777216,16776704);L=p[a+72>>2];M=p[a+32>>2];h=c;N=p[h>>2];e=NNa(q,q>>31,e,e>>31);q=ib;s=e;e=p[a+68>>2];t=NNa(e,e>>31,f,f>>31);e=s+t|0;f=ib+q|0;f=e>>>0<t>>>0?f+1|0:f;s=e;k=(((((((v(F,G)+v(H,I)|0)+v(D,E)|0)+v(B,C)|0)+v(z,A)|0)+v(x,y)|0)+v(j,w)|0)+v(g,k)<<8)/32768<<8;e=k;g=NNa(J,K,e,e>>31);e=s+g|0;f=ib+f|0;f=e>>>0<g>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=p[a+28>>2]+m|0;j=m>>12;p[h>>2]=v(f,j)+N;l=l+M|0;g=l>>12;p[c+4>>2]=p[c+4>>2]+v(f,g);e=e-(k&L)|0;Kb(i+8|0,i);d=d+ -1|0;if(d){c=c+8|0;k=p[i+8>>2];h=p[i+12>>2];f=b;continue}break}k=p[i+8>>2];h=p[i+12>>2];f=b}p[a+40>>2]=l;p[a+20>>2]=j;p[a+36>>2]=m;p[a+48>>2]=f;p[a+44>>2]=e;p[a+24>>2]=g;p[a>>2]=k;p[a+4>>2]=h;fb=i+16|0}function Xva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=fb-16|0;fb=i;u=p[a+16>>2];a:{b:{c:{j=p[a+8>>2];g=p[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?j>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?j>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?j>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?j>>>0>2147483648:0){break b}}r=b+196648|0;break a}r=b+131112|0;break a}r=b+262184|0}e=p[a+48>>2];l=p[a+40>>2];m=p[a+36>>2];k=p[a+44>>2];h=p[a+4>>2];f=p[a>>2];p[i+8>>2]=f;p[i+12>>2]=h;p[i>>2]=j;p[i+4>>2]=g;e:{if(!d){g=l>>12;j=m>>12;break e}while(1){b=(f>>>16&65520)+r|0;g=o[b>>1];h=(h<<1)+u|0;j=o[h+ -6>>1];n=o[b+2>>1];w=o[h+ -4>>1];x=o[b+4>>1];y=o[h+ -2>>1];z=o[b+6>>1];A=o[h>>1];B=o[b+8>>1];C=o[h+2>>1];D=o[b+10>>1];E=o[h+4>>1];F=o[b+12>>1];G=o[h+6>>1];H=o[b+14>>1];I=o[h+8>>1];t=p[a+60>>2];b=k;f=Pb(b,-16777216,16776704);q=p[a+64>>2];k=Pb(e,-16777216,16776704);J=p[a+72>>2];K=p[a+32>>2];h=c;L=p[h>>2];e=NNa(q,q>>31,f,f>>31);q=ib;s=e;n=(((((((v(n,w)+v(g,j)|0)+v(x,y)|0)+v(z,A)|0)+v(B,C)|0)+v(D,E)|0)+v(F,G)|0)+v(H,I)|0)/32768<<8;e=n;g=NNa(t,t>>31,e,e>>31);f=s+g|0;e=ib+q|0;e=f>>>0<g>>>0?e+1|0:e;s=f;f=p[a+68>>2];k=NNa(f,f>>31,k,k>>31);f=s+k|0;e=ib+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=p[a+28>>2]+m|0;j=m>>12;p[h>>2]=v(e,j)+L;l=l+K|0;g=l>>12;p[c+4>>2]=p[c+4>>2]+v(e,g);k=f-(n&J)|0;Kb(i+8|0,i);d=d+ -1|0;if(d){c=c+8|0;f=p[i+8>>2];h=p[i+12>>2];e=b;continue}break}f=p[i+8>>2];h=p[i+12>>2];e=b}p[a+40>>2]=l;p[a+20>>2]=j;p[a+36>>2]=m;p[a+48>>2]=e;p[a+44>>2]=k;p[a+24>>2]=g;p[a>>2]=f;p[a+4>>2]=h;fb=i+16|0}function Y0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-288|0;fb=a;p[a+272>>2]=c;p[a+280>>2]=b;p[a+16>>2]=2482;b=Hd(a+152|0,a+160|0,a+16|0);p[114610]=0;qc(a+144|0,e);h=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){p[114610]=0;h=M(21,a+144|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break j}n[a+143|0]=0;e=p[e+4>>2];p[114610]=0;c=ma(2483,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}if(!c){break f}c=q[62379]|q[62380]<<8|(q[62381]<<16|q[62382]<<24);n[a+135|0]=c;n[a+136|0]=c>>>8;n[a+137|0]=c>>>16;n[a+138|0]=c>>>24;c=q[62376]|q[62377]<<8|(q[62378]<<16|q[62379]<<24);p[a+128>>2]=q[62372]|q[62373]<<8|(q[62374]<<16|q[62375]<<24);p[a+132>>2]=c;p[114610]=0;U(2440,h|0,a+128|0,a+138|0,a+118|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break i}p[a+4>>2]=2420;d=Hd(a+8|0,0,a+4|0);c=a+16|0;if((p[a+148>>2]-p[b>>2]|0)<99){break g}pe(d,fd((p[a+148>>2]-p[b>>2]|0)+2|0));if(p[d>>2]){break h}p[114610]=0;R(2421);c=p[114610];p[114610]=0;if((c|0)==1){break d}break a}e=I()|0;H()|0;break b}e=I()|0;H()|0;break c}e=I()|0;H()|0;break c}c=p[d>>2]}if(q[a+143|0]){n[c|0]=45;c=c+1|0}e=p[b>>2];while(1){if(e>>>0>=s[a+148>>2]){n[c|0]=0;p[a>>2]=g;if((ID(a+16|0,a)|0)!=1){p[114610]=0;S(2484,62356);c=p[114610];p[114610]=0;if((c|0)!=1){break a}break d}wc(d)}else{j=c,k=q[((Gm(a+118|0,a+128|0,e)-a|0)+a|0)+10|0],n[j|0]=k;c=c+1|0;e=e+1|0;continue}break}}p[114610]=0;c=J(2423,a+280|0,a+272|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}if(c){p[f>>2]=p[f>>2]|2}c=p[a+280>>2];Gb(a+144|0);wc(b);fb=a+288|0;return c|0}e=I()|0;H()|0;break c}e=I()|0;H()|0;wc(d)}Gb(a+144|0)}wc(b);L(e|0);E()}E()}function Iva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;f=fb-48|0;fb=f;w=p[a+16>>2];g=p[a+44>>2];p[f+32>>2]=g;e=p[a+48>>2];p[f+36>>2]=e;k=p[a+52>>2];p[f+40>>2]=k;m=p[a+56>>2];p[f+44>>2]=m;x=p[a+24>>2];y=p[a+20>>2];l=p[a+4>>2];i=p[a>>2];p[f+24>>2]=i;p[f+28>>2]=l;h=p[a+12>>2];p[f+16>>2]=p[a+8>>2];p[f+20>>2]=h;if(d){while(1){h=(((l&2147483647)<<1|i>>>31)&-2)+w|0;m=1;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=o[e+38>>1];j=o[e+36>>1];r=o[e+34>>1];s=o[e+32>>1];t=o[e+30>>1];q=o[e+28>>1];u=o[e+26>>1];z=o[e+24>>1];k=0;e=1;g=0;while(1){p[(f+8|0)+(g<<2)>>2]=(((((v(n[h+(g|4)|0],r)+v(n[h+(g|2)|0],s)|0)+v(n[h+(g|6)|0],j)|0)+v(i,n[h+(g|8)|0])<<8)/2|0)+((((v(n[h+(g|-4)|0],u)+v(n[h+(g|-6)|0],z)|0)+v(n[h+(g|-2)|0],q)|0)+v(n[g+h|0],t)<<8)/2|0)|0)/16384;l=e;e=0;g=1;if(l){continue}break}while(1){h=(f+8|0)+(k<<2)|0;i=p[h>>2];j=p[a+60>>2];r=j;l=(f+32|0)+(k<<3)|0;k=p[l>>2];e=Pb(k,-16777216,16776704);s=p[a+64>>2];g=Pb(p[l+4>>2],-16777216,16776704);q=p[a+68>>2];u=q;q=q>>31;p[l+4>>2]=k;k=p[a+72>>2];j=j>>31;i=i<<8;j=NNa(r,j,i,i>>31);r=ib;t=h;h=j;j=NNa(s,s>>31,e,e>>31);h=h+j|0;e=ib+r|0;e=h>>>0<j>>>0?e+1|0:e;j=h;h=NNa(u,q,g,g>>31);g=j+h|0;e=ib+e|0;e=g>>>0<h>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;p[t>>2]=(e|0)/256;p[l>>2]=e-(i&k);k=1;e=m&1;m=0;if(e){continue}break}p[c>>2]=p[c>>2]+v(p[f+8>>2],y);p[c+4>>2]=p[c+4>>2]+v(p[f+12>>2],x);Kb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;i=p[f+24>>2];l=p[f+28>>2];continue}break}i=p[f+24>>2];l=p[f+28>>2];m=p[f+44>>2];k=p[f+40>>2];g=p[f+32>>2];e=p[f+36>>2]}p[a+56>>2]=m;p[a+52>>2]=k;p[a+48>>2]=e;p[a+44>>2]=g;p[a>>2]=i;p[a+4>>2]=l;fb=f+48|0}function Rw(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=q[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}n[a|0]=1;n[f+15|0]=64;i=b,j=q[hc(b,f+15|0)|0],n[i|0]=j;break a}d=q[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}n[b|0]=(d&252)>>>2;n[a|0]=12;e=1;break a}d=q[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}n[b|0]=(d&252)>>>2;n[a|0]=13;e=1;break a}g=q[b|0];if(g>>>0<240){d=0;while(1){h=q[d+20768|0];m:{n:{if(c){if(g>>>0<=h>>>0){break n}break m}if((g|0)!=(h|0)){break m}}n[a|0]=11;n[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}n[a|0]=11;n[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=q[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}n[b|0]=0;n[a|0]=0;e=1;break a}n[a|0]=2;n[b|0]=q[b|0]<<2&60|2;e=1;break a}e=0;c=q[b|0];if(!c){break a}d=c&15;if(!d){n[b|0]=c>>>4;n[a|0]=3;e=1;break a}g=c&240;if(!g){n[a|0]=4;e=1;break a}if((d|0)==15){n[b|0]=c>>>4;n[a|0]=5;e=1;break a}if((g|0)!=240){break a}n[b|0]=d;n[a|0]=6;e=1;break a}c=b;b=q[b|0];n[c|0]=(b|0)==255?64:b>>>2|0;n[a|0]=2;break a}r:{if(c){n[b|0]=0;break r}e=0;if(q[b|0]){break a}}n[a|0]=8;e=1;break a}s:{if(c){n[f+14|0]=q[b|0]&15;n[f+13|0]=9;d=q[hc(f+14|0,f+13|0)|0];n[b|0]=d;break s}e=0;d=q[b|0];if((d&14)>>>0>9|d&240){break a}}n[b|0]=d&15;n[a|0]=8;e=1}fb=f+16|0;return e}function Cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-128|0;fb=e;a:{if(Pc(b)){break a}f=q[GG(b)|0];g=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}g=0}d=g;Zq(e+112|0,b,0,wb(b)+ -1|0);xb(b,e+112|0);pb(e+112|0)}ud(e+112|0);f=p[e+112>>2];ud(e+96|0);f=FG(f,p[e+100>>2],b);ud(e+112|0);c:{d:{e:{f:{if((f|0)==p[e+116>>2]){if(Md(b,38139)){a=W(8)|0;p[114610]=0;N(2136,e+112|0,39211,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}dc(a,e+112|0);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}b=I()|0;H()|0;pb(e+112|0);break d}if(!d){break f}a=W(8)|0;p[114610]=0;N(2136,e+80|0,39090,b|0);b=p[114610];p[114610]=0;g:{h:{i:{j:{k:{if((b|0)!=1){p[114610]=0;N(2137,e+96|0,e+80|0,39226);b=p[114610];p[114610]=0;if((b|0)==1){break k}p[114610]=0;N(805,e+112|0,e+96|0,c|0);b=p[114610];p[114610]=0;c=1;if((b|0)==1){break j}dc(a,e+112|0);p[114610]=0;N(2009,a|0,83568,2017);b=p[114610];p[114610]=0;if((b|0)!=1){break c}b=I()|0;H()|0;pb(e+112|0);c=0;break i}b=I()|0;H()|0;break g}c=1;b=I()|0;H()|0;break h}b=I()|0;H()|0}pb(e+96|0)}pb(e+80|0);if(!c){break d}}X(a|0);break d}l:{switch(p[f+4>>2]){case 0:xh(e+72|0,b);b=(kG(c)|0)!=0;c=p[e+76>>2];p[e>>2]=p[e+72>>2];p[e+4>>2]=c;EG(a,e,b,d);break f;case 1:xh(e- -64|0,b);b=n9(c);c=p[e+68>>2];p[e+8>>2]=p[e+64>>2];p[e+12>>2]=c;DG(a,e+8|0,b,ib,d);break f;case 2:xh(e+56|0,b);h=f9(c);b=p[e+60>>2];p[e+16>>2]=p[e+56>>2];p[e+20>>2]=b;CG(a,e+16|0,h,d);break f;case 3:break l;default:break f}}xh(e+48|0,b);xh(e+40|0,c);b=p[e+52>>2];p[e+32>>2]=p[e+48>>2];p[e+36>>2]=b;b=p[e+44>>2];p[e+24>>2]=p[e+40>>2];p[e+28>>2]=b;BG(a,e+32|0,e+24|0,d)}fb=e+128|0;return}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function kwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0;b=fb-48|0;fb=b;u=p[a+16>>2];h=p[a+44>>2];p[b+32>>2]=h;l=p[a+48>>2];p[b+36>>2]=l;i=p[a+52>>2];p[b+40>>2]=i;g=p[a+56>>2];p[b+44>>2]=g;q=p[a+40>>2];r=p[a+36>>2];e=p[a+4>>2];j=p[a>>2];p[b+24>>2]=j;p[b+28>>2]=e;f=p[a+12>>2];p[b+16>>2]=p[a+8>>2];p[b+20>>2]=f;a:{if(!d){k=q>>12;f=r>>12;break a}while(1){l=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+u|0;h=(j>>>21&2040)+27824|0;j=o[h+6>>1];g=o[h+4>>1];k=o[h+2>>1];m=o[h>>1];h=0;i=1;f=0;while(1){n=(b+8|0)+(f<<2)|0;f=f<<1;p[n>>2]=(((v(o[f+e>>1],k)+v(o[e+(f|-4)>>1],m)|0)+v(g,o[e+(f|4)>>1])|0)+v(j,o[e+(f|8)>>1])|0)/16384;s=i&1;i=0;f=1;if(s){continue}break}while(1){i=(b+8|0)+(h<<2)|0;j=p[i>>2];g=p[a+60>>2];k=g;h=(b+32|0)+(h<<3)|0;m=p[h>>2];e=Pb(m,-16777216,16776704);s=p[a+64>>2];f=Pb(p[h+4>>2],-16777216,16776704);n=p[a+68>>2];w=n;n=n>>31;p[h+4>>2]=m;m=p[a+72>>2];t=g>>31;j=j<<8;g=j;g=NNa(k,t,g,g>>31);k=ib;t=i;i=g;g=NNa(s,s>>31,e,e>>31);i=i+g|0;e=ib+k|0;e=i>>>0<g>>>0?e+1|0:e;g=i;i=NNa(w,n,f,f>>31);f=g+i|0;e=ib+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;p[t>>2]=(e|0)/256;p[h>>2]=e-(j&m);h=1;e=l&1;l=0;if(e){continue}break}e=p[a+32>>2];r=p[a+28>>2]+r|0;f=r>>12;p[c>>2]=p[c>>2]+v(f,p[b+8>>2]);q=e+q|0;k=q>>12;p[c+4>>2]=p[c+4>>2]+v(k,p[b+12>>2]);Kb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;j=p[b+24>>2];e=p[b+28>>2];continue}break}j=p[b+24>>2];e=p[b+28>>2];g=p[b+44>>2];i=p[b+40>>2];l=p[b+36>>2];h=p[b+32>>2]}p[a+40>>2]=q;p[a+20>>2]=f;p[a+36>>2]=r;p[a+56>>2]=g;p[a+52>>2]=i;p[a+48>>2]=l;p[a+44>>2]=h;p[a+24>>2]=k;p[a>>2]=j;p[a+4>>2]=e;fb=b+48|0}function Ipa(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=c&15;f=v(b,896)+a|0;e=f+1074984|0;a:{b:{switch(c>>>4|0){case 0:if(!r[a+480188>>1]){break a}b=(c&1)<<14;c=0;while(1){d=(v(c,896)+a|0)+1075072|0;p[d>>2]=(b|p[d>>2]&-16385)^16384;c=c+1|0;if(c>>>0<r[a+480188>>1]){continue}break}break a;case 1:if(p[a+480180>>2]&1048580?0:!d){break a}zK(a,e,d);return;case 2:if(p[a+480180>>2]&1048580?0:!d){break a}xK(a,e,d);return;case 3:a=f+1075072|0;p[a>>2]=p[a>>2]&-1048577|((d|0)!=0)<<20;return;case 4:n[f+1075826|0]=c&7;return;case 5:if(!(q[a+480209|0]&16)){break a}if(p[a+480180>>2]&69206025){c=v(b,896)+a|0;e=c+1075752|0;p[e>>2]=d<<28>>24;d=c+1075684|0;if(!p[d>>2]){break a}if(!Sf(c+1075794|0)){break a}c=a;a=v(b,896)+a|0;g=d,h=dg(c,q[a+1075803|0],p[e>>2],p[a+1075688>>2]),p[g>>2]=h;return}f=p[a+480180>>2];e=Sf((v(b,896)+a|0)+1075794|0);if((f|0)==16){if(!e){break a}c=v(b,896)+a|0;e=p[c+1075088>>2];if(!e){break a}n[e+37|0]=d;p[c+1075752>>2]=d;c=c+1075684|0;if(!p[c>>2]){break a}e=a;a=v(b,896)+a|0;g=c,h=dg(e,q[a+1075803|0],d,p[a+1075688>>2]),p[g>>2]=h;return}if(!e){break a}b=v(b,896)+a|0;c=c<<28>>24^-128;p[b+1075752>>2]=c;d=b+1075684|0;if(!p[d>>2]){break a}g=d,h=dg(a,q[b+1075803|0],c,p[b+1075688>>2]),p[g>>2]=h;return;case 7:n[f+1075829|0]=c&7;return;case 8:if(!(q[a+480209|0]&16)){break a}kl(a,e,d,4);return;case 9:zx(a,b,d,0);return;case 10:if(p[a+480180>>2]&1048580?0:!d){break a}Ko(a,e,d,0);return;case 11:if(p[a+480180>>2]&1048580?0:!d){break a}Jo(a,e,d,0);return;case 12:Bx(a,b,d,0);return;case 15:break b;default:break a}}if(p[a+480180>>2]==1){n[(v(b,896)+a|0)+1075850|0]=d;if(!(q[a+480209|0]&16)){break a}KK(a,e);return}n[(v(b,896)+a|0)+1075848|0]=d}}function VMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;Ac(c);a:{if(!Hb(c,3)){break a}while(1){It(h+8|0,c);j=Zc(h+8|0);d=Tf(h+8|0);f=h+8|0;if(s[a+12>>2]<=q[f|0]){break a}g=_e(a,q[f|0],b);e=q[j|0];b:{if(e>>>0<=126){if(!(e|q[d|0])){n[g|0]=254;break b}n[g|0]=e+1;if(q[d|0]==255){break b}if(!q[g+1|0]){n[g+1|0]=k}n[g+2|0]=1;n[g+4|0]=q[d|0];break b}c:{switch(e+ -127|0){case 0:f=q[f|0]+n[d|0]|0;if((f|0)<0|(f|0)>=p[a+12>>2]<<16>>16){break b}e=_e(a,f,b);f=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);n[g|0]=f;n[g+1|0]=f>>>8;n[g+2|0]=f>>>16;n[g+3|0]=f>>>24;f=q[e+4|0]|q[e+5|0]<<8;n[g+4|0]=f;n[g+5|0]=f>>>8;break b;case 1:k=q[d|0]+1|0;n[g+1|0]=k;break b;default:break c}}d=n[d|0];n[h+7|0]=d;i=0;f=e&127;if(f>>>0<=23){i=q[f+12144|0]}f=h;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{e=q[j|0];switch((e&127)+ -2|0){case 21:break h;case 18:break i;case 17:break j;case 16:case 20:break k;case 15:break l;case 2:break m;case 1:break n;case 0:case 8:case 9:break o;default:break e}}if((d|0)>-1){break g}e=0-d&15;break f}n[h+6|0]=64;d=q[hc(h+7|0,h+6|0)|0];n[h+7|0]=d;if(q[g+2|0]>1){break e}n[g+4|0]=d;n[g+2|0]=1;break b}if((d|0)>-1){i=3;break d}e=0-d&127;break f}if(!d){break b}e=0-d|-16;if((d|0)<=-1){break f}e=d<<4|15;break f}if(!d){break b}f=(d|0)>-1;if(!f){d=0-d&15;n[h+7|0]=d;e=q[j|0]}i=f?3:2;d=((e|0)==22?-32:-16)|d;n[h+7|0]=d;break d}e=d&15|-48;break f}e=d&15|-64;break f}d=d- -64&127;n[h+7|0]=d;if(!q[g+3|0]){break e}p:{switch(q[g+2|0]){case 0:case 2:break p;default:break b}}n[g+2|0]=2;n[g+4|0]=d>>>1;break b}e=d<<4}d=e;n[f+7|0]=d}if(!(i&255)){break b}}n[g+5|0]=d;n[g+3|0]=i}if(Hb(c,3)){continue}break}}fb=h+16|0}function iNa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0;d=fb-384|0;fb=d;Ac(b);f=d+344|0;g=JMa(b,f);if(!g){YS(f)}a:{b:{if(!g){break b}if(!qT(d+344|0)){break b}if(!Hb(b,dd(pT(d+344|0),ib))){break b}c:{if(!c){break c}xd(a,2097152);ei(a);Xi(a,1);o[a+480188>>1]=8;p[a+480196>>2]=q[d+376|0];p[a+480204>>2]=v(q[d+377|0],1e4);o[a+480190>>1]=q[d+378|0];if(q[d+381|0]<q[d+380|0]){Pe(Ob(a+484360|0),q[d+381|0])}e=Mb(d+80|0,12002);xb(a+1304436|0,e);pb(e);e=Mb(d+80|0,12022);xb(a+1304448|0,e);pb(e);p[a+1304496>>2]=4;hA(b,d+80|0);Et(Ob(a+484360|0),d+80|0,q[d+380|0],65535,65535);if(r[a+480190>>1]){e=1;f=1;while(1){oT(b,d+40|0);hNa(d+40|0,(v(e,104)+a|0)+484380|0);xn(d+8|0,2,d+40|0);zc(d+24|0,d+8|0);p[114610]=0;J(369,((e<<5)+a|0)+946300|0,d+24|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}pb(d+24|0);f=f+1|0;e=f&65535;if(e>>>0<=r[a+480190>>1]){continue}break}}Sb(b,v(64-q[d+378|0]|0,37));g=a+484344|0;Pf(g,q[d+379|0]);if(q[d+379|0]){i=c&1;f=0;while(1){d:{e:{if(i){if(ag(g,f&65535,64)){break e}}Sb(b,2048);break d}e=Rb(g,f);m=d,s=Ub(e),p[m+40>>2]=s;m=d,s=Vb(e),p[m+24>>2]=s;if(!Ab(d+40|0,d+24|0)){break d}while(1){e=p[d+40>>2];Dl(d+8|0,b);j=Zc(d+8|0);k=Tf(d+8|0);l=vi(d+8|0);h=q[d+8|0];if((h+ -1&255)>>>0<=106){n[e|0]=h+13}n[e+1|0]=q[j|0];n[e+3|0]=q[k|0];n[e+5|0]=q[l|0];fj(e);uk(d+40|0);if(Ab(d+40|0,d+24|0)){continue}break}}f=f+1|0;if(f>>>0<q[d+379|0]){continue}break}}if(!(c&2)){break c}e=1;c=Tc(d+40|0,8,1,0,0);if(!r[a+480190>>1]){break c}while(1){fg(c,(v(e&65535,104)+a|0)+484380|0,b);e=e+1|0;if((e&65535)>>>0<=r[a+480190>>1]){continue}break}}e=1}fb=d+384|0;return e|0}a=I()|0;H()|0;pb(d+24|0);L(a|0);E()}function M6(a,b){var c=0,d=w(0),e=w(0),f=0,g=w(0),h=w(0),i=0,j=w(0),k=0,l=0,m=0,n=w(0),o=w(0),q=0,r=w(0),s=w(0),u=w(0),x=w(0),y=w(0),z=w(0),A=w(0);k=fb-128|0;if((b|0)>=1){while(1){i=(q<<2)+a|0;f=0;c=k;l=c;while(1){o=t[v(31-f|0,72)+i>>2];m=v(f,72)+i|0;g=t[m>>2];h=w(o+g);e=t[m+1152>>2];d=t[v(15-f|0,72)+i>>2];j=w(e+d);t[l>>2]=h+j;m=v(f,12)+48960|0;g=w(t[m+4>>2]*w(g-o));e=w(t[m>>2]*w(d-e));t[l+64>>2]=g+e;d=t[m+8>>2];t[l+32>>2]=d*w(h-j);t[l+96>>2]=w(g-e)*d;l=l+4|0;f=f+1|0;if((f|0)!=8){continue}break}f=0;while(1){r=t[c+28>>2];s=t[c>>2];u=w(r+s);x=t[c+16>>2];y=t[c+12>>2];z=w(x+y);n=w(u+z);A=t[c+24>>2];o=t[c+4>>2];h=w(A+o);j=t[c+20>>2];g=t[c+8>>2];e=w(j+g);d=w(h+e);t[c>>2]=n+d;t[c+16>>2]=w(n-d)*w(.7071067690849304);n=w(u-z);d=w(w(n+w(h-e))*w(.7071067690849304));t[c+24>>2]=w(n-d)*w(1.3065630197525024);t[c+8>>2]=w(d+n)*w(.5411961078643799);e=w(o-A);d=w(g-j);j=w(w(e+d)*w(.7071067690849304));h=w(s-r);g=w(j+h);e=w(h+e);d=w(w(w(y-x)+d)+w(e*w(-.1989123672246933)));e=w(w(d*w(.3826834261417389))+e);t[c+28>>2]=w(g-e)*w(2.562915563583374);t[c+4>>2]=w(e+g)*w(.509795606136322);e=w(d+w(e*w(-.1989123672246933)));d=w(h-j);t[c+20>>2]=w(e+d)*w(.8999761939048767);t[c+12>>2]=w(d-e)*w(.601344883441925);c=c+32|0;f=f+1|0;if((f|0)!=4){continue}break}f=0;g=t[k+32>>2];d=t[k+96>>2];h=t[k+64>>2];while(1){c=i;p[c>>2]=p[(f<<2)+k>>2];f=f+1|0;i=(f<<2)+k|0;e=t[i+96>>2];j=w(e+d);t[c+72>>2]=j+h;d=t[i+32>>2];t[c+144>>2]=d+g;h=t[i- -64>>2];t[c+216>>2]=j+h;i=c+288|0;g=d;d=e;if((f|0)!=7){continue}break}p[c+288>>2]=p[k+28>>2];d=t[k+124>>2];t[c+360>>2]=d+t[k+92>>2];i=p[k+60>>2];t[c+504>>2]=d;p[c+432>>2]=i;q=q+1|0;if((q|0)!=(b|0)){continue}break}}}function lwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0;b=fb-48|0;fb=b;w=p[a+16>>2];i=p[a+44>>2];p[b+32>>2]=i;l=p[a+48>>2];p[b+36>>2]=l;h=p[a+52>>2];p[b+40>>2]=h;g=p[a+56>>2];p[b+44>>2]=g;q=p[a+40>>2];r=p[a+36>>2];e=p[a+4>>2];j=p[a>>2];p[b+24>>2]=j;p[b+28>>2]=e;f=p[a+12>>2];p[b+16>>2]=p[a+8>>2];p[b+20>>2]=f;a:{if(!d){f=q>>12;k=r>>12;break a}while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+w|0;f=(j>>>21&2040)+27824|0;j=o[f+6>>1];g=o[f+4>>1];k=o[f+2>>1];m=o[f>>1];i=0;l=1;h=1;f=0;while(1){p[(b+8|0)+(f<<2)>>2]=(((v(n[e+f|0],k)+v(n[e+(f|-2)|0],m)|0)+v(g,n[e+(f|2)|0])|0)+v(j,n[e+(f|4)|0])<<8)/16384;s=h&1;h=0;f=1;if(s){continue}break}while(1){h=(b+8|0)+(i<<2)|0;j=p[h>>2];g=p[a+60>>2];k=g;f=(b+32|0)+(i<<3)|0;m=p[f>>2];e=Pb(m,-16777216,16776704);s=p[a+64>>2];i=Pb(p[f+4>>2],-16777216,16776704);t=p[a+68>>2];x=t;t=t>>31;p[f+4>>2]=m;m=p[a+72>>2];u=g>>31;j=j<<8;g=j;g=NNa(k,u,g,g>>31);k=ib;u=h;h=g;g=NNa(s,s>>31,e,e>>31);h=h+g|0;e=ib+k|0;e=h>>>0<g>>>0?e+1|0:e;g=h;h=NNa(x,t,i,i>>31);i=g+h|0;e=ib+e|0;e=i>>>0<h>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|i>>>24;p[u>>2]=(e|0)/256;p[f>>2]=e-(j&m);i=1;e=l&1;l=0;if(e){continue}break}e=p[a+32>>2];r=p[a+28>>2]+r|0;k=r>>12;p[c>>2]=p[c>>2]+v(k,p[b+8>>2]);q=e+q|0;f=q>>12;p[c+4>>2]=p[c+4>>2]+v(f,p[b+12>>2]);Kb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;j=p[b+24>>2];e=p[b+28>>2];continue}break}j=p[b+24>>2];e=p[b+28>>2];g=p[b+44>>2];h=p[b+40>>2];l=p[b+36>>2];i=p[b+32>>2]}p[a+40>>2]=q;p[a+20>>2]=k;p[a+36>>2]=r;p[a+56>>2]=g;p[a+52>>2]=h;p[a+48>>2]=l;p[a+44>>2]=i;p[a+24>>2]=f;p[a>>2]=j;p[a+4>>2]=e;fb=b+48|0}function Yg(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;a:{if((b|0)==189){n[a+3843|0]=c>>>7;n[a+3844|0]=c>>>6&1;break a}d=b&224;if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=v(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;h=c&d;b:{if(h){Vm(e,f);break b}Vm(e,0)}n[f+40|0]=!h;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}n[a+3842|0]=c>>>6&1;b=0;while(1){Xx((v(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d+ -160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}d=(v(b&256?d+9|0:d,44)+a|0)+16|0;p[g+8>>2]=d;e=p[d+36>>2];p[g+12>>2]=e;a=1;f=e?2:1;c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}a=c&32;ZL(d,a>>>5|0);h=c>>>2&7;YL(d,h);c=c&3;XL(d,c);if(!e){break a}b=1;d=f>>>0>1?f:1;f=(a|0)!=0;while(1){a=p[(g+8|0)+(b<<2)>>2];ZL(a,f);YL(a,h);XL(a,c);b=b+1|0;if((d|0)!=(b|0)){continue}break}break a}WL(d,c);if(!e){break a}b=f>>>0>1?f:1;while(1){WL(p[(g+8|0)+(a<<2)>>2],c);a=a+1|0;if((b|0)!=(a|0)){continue}break}break a}n[d+42|0]=(c&32)>>>5;n[d+41|0]=(c&16)>>>4;a=c>>>1&7;o[d+30>>1]=a?9-a|0:0;o[d+32>>1]=c&1;break a}if((d|0)!=224?d>>>0>=129:0){break a}f=b&31;if(-4144960>>>f&1){break a}e=a;a=n[f+19824|0];a=(e+v(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d+ -32>>>5|0){case 0:n[a+79|0]=c>>>7;n[a+80|0]=(c&64)>>>6;n[a+78|0]=(c&32)>>>5;n[a+77|0]=(c&16)>>>4;Wm(a);o[a+14>>1]=r[((c&15)<<1)+19856>>1];break a;case 1:o[a+68>>1]=q[(c>>>6|0)+19888|0];VL(a);o[a+22>>1]=(c&63)<<2;break a;case 2:o[a+24>>1]=c>>>4;Wm(a);o[a+26>>1]=c&15;Wm(a);break a;case 3:b=c>>>4|0;o[a+28>>1]=b>>>0<15?b<<4:496;o[a+30>>1]=c&15;Wm(a);break a;case 6:break d;default:break a}}o[a+12>>1]=c&7}fb=g+16|0}function pja(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;a:{b:{e=p[b>>2];c:{if(!e){d=b;break c}if(!p[b+4>>2]){d=b;break b}d=tP(b);e=p[d>>2];if(e){break b}}e=p[d+4>>2];if(e){break b}e=0;g=1;break a}p[e+8>>2]=p[d+8>>2];g=0}d:{e:{if(_g(d)){p[p[d+8>>2]>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=p[d+8>>2]+4|0;break e}p[p[d+8>>2]+4>>2]=e;c=p[d+8>>2]}c=p[c>>2]}h=!q[d+12|0];if((b|0)!=(d|0)){p[d+8>>2]=p[b+8>>2];f:{if(_g(b)){f=p[d+8>>2];break f}f=p[d+8>>2]+4|0}p[f>>2]=d;f=p[b>>2];p[d>>2]=f;hn(f,d);f=p[b+4>>2];p[d+4>>2]=f;if(f){hn(f,d)}n[d+12|0]=q[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){d=_g(c);b=q[c+12|0];g:{h:{if(!d){if(!b){n[c+12|0]=1;n[p[c+8>>2]+12|0]=0;mp(p[c+8>>2]);b=p[c>>2];a=(b|0)==(a|0)?c:a;c=p[b+4>>2]}d=p[c>>2];i:{j:{k:{if(!(q[d+12|0]?0:d)){b=p[c+4>>2];if(q[b+12|0]?0:b){break k}n[c+12|0]=0;l:{b=p[c+8>>2];if((b|0)!=(a|0)){if(q[b+12|0]){break l}a=b}n[a+12|0]=1;return}if(!_g(b)){break h}b=p[b+8>>2]+4|0;break g}b=p[c+4>>2];if(!b){break j}}if(!q[b+12|0]){break i}}n[d+12|0]=1;n[c+12|0]=0;lp(c);c=p[c+8>>2]}n[c+12|0]=q[p[c+8>>2]+12|0];n[p[c+8>>2]+12|0]=1;n[p[c+4>>2]+12|0]=1;mp(p[c+8>>2]);return}if(!b){n[c+12|0]=1;n[p[c+8>>2]+12|0]=0;lp(p[c+8>>2]);b=p[c+4>>2];a=(b|0)==(a|0)?c:a;c=p[b>>2]}d=p[c>>2];m:{if(q[d+12|0]?0:d){break m}b=p[c+4>>2];if(!(q[b+12|0]?0:b)){n[c+12|0]=0;b=p[c+8>>2];if(!(q[b+12|0]?(b|0)!=(a|0):0)){n[b+12|0]=1;return}if(_g(b)){b=p[b+8>>2]+4|0;break g}b=p[b+8>>2];break g}if(d){if(!q[d+12|0]){break m}b=p[c+4>>2]}n[b+12|0]=1;n[c+12|0]=0;mp(c);c=p[c+8>>2]}n[c+12|0]=q[p[c+8>>2]+12|0];n[p[c+8>>2]+12|0]=1;n[p[c>>2]+12|0]=1;lp(p[c+8>>2]);return}b=p[b+8>>2]}c=p[b>>2];continue}}n[e+12|0]=1}}function Qr(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-160|0;fb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}d=p[c+4>>2];if(!d&s[c>>2]>=eh(b)>>>0|d>>>0>0){break h}b=W(8)|0;p[114610]=0;J(214,b|0,20461)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break g}a=I()|0;H()|0;X(b|0);break a}if(!p[b>>2]){b=W(8)|0;p[114610]=0;J(1403,b|0,20461)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break f}a=I()|0;H()|0;X(b|0);break a}j=Aoa(f+136|0,kh(f+128|0,b));i:{j:{if(a&2){d=Ao(f+104|0,j);p[114610]=0;g=J(1404,d|0,c|0)|0;e=p[114610];p[114610]=0;d=1;if((e|0)==1){break i}if((g|0)==1){break j}e=Ao(f+80|0,j);p[114610]=0;e=J(1405,e|0,c|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break e}k=(e|0)==1;if(k){break j}h=Ao(f+56|0,j);p[114610]=0;h=J(1406,h|0,c|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break d}l=(h|0)==1;if(l){break j}i=Ao(f+32|0,j);p[114610]=0;i=J(1407,i|0,c|0)|0;m=p[114610];p[114610]=0;if((m|0)==1){break c}if((i|0)==1){break j}d=(g|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;g=(i|0)==-1?-1:l?d:(h|0)==-1?-1:d}if(a&1){a=77888;while(1){d=p[a>>2];if(d){e=Ao(f+8|0,j);p[114610]=0;e=J(d|0,e|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break j}g=(e|0)==-1?-1:g}a=a+12|0;if((a|0)!=78344){continue}break}}if(c){d=0;if((g|0)!=-1){break j}a=p[c+4>>2];c=p[c>>2];p[114610]=0;a=rg(446,c,a);c=p[114610];p[114610]=0;if((c|0)!=1){d=a>>>0>eh(b)>>>0?-1:0;break j}a=I()|0;H()|0;break a}d=0;if((g|0)!=-1){break j}d=eh(b)>>>0>2047?1:-1}fb=f+160|0;return d}a=I()|0;H()|0;break a}ba(b|0,71608,24);E()}ba(b|0,71504,24);E()}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0}L(a|0);E()}function nva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0;g=fb-48|0;fb=g;r=p[a+16>>2];h=Df(g+16|0);p[h+8>>2]=a+112;p[h+16>>2]=p[a+128>>2];w=h,x=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[w+12>>2]=x;b=p[h+16>>2];if(b){w=h,x=Cf(a+8|0,b),p[w>>2]=x;p[h+4>>2]=ib}k=p[a+48>>2];l=p[a+40>>2];m=p[a+36>>2];b=p[a+44>>2];f=p[a+4>>2];e=p[a>>2];p[g+8>>2]=e;p[g+12>>2]=f;n=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=n;a:{if(!d){i=l>>12;j=m>>12;break a}while(1){n=b;b=0;i=b;p[g+40>>2]=e;p[g+44>>2]=b;f=(f<<1)+r|0;b:{b=p[h+16>>2];if((b|0)<=0){break b}while(1){qd(p[h+8>>2],o[(i<<1)+f>>1]/4<<16>>16);pd(p[h+8>>2],4);Kb(g+40|0,h);if((b|0)<2){break b}b=b+ -1|0;i=p[g+44>>2];continue}}d=d+ -1|0;b=p[h+8>>2];Kb(b,b+8|0);b=p[h+8>>2];e=p[b+4>>2];if(e){qd(b,o[f+(p[g+44>>2]<<1)>>1]/4<<16>>16);pd(p[h+8>>2],e);b=p[h+8>>2];e=p[b>>2];p[b>>2]=e;p[b+4>>2]=0}e=xf(b,p[h+12>>2]);i=p[a+60>>2];b=Pb(n,-16777216,16776704);j=p[a+64>>2];f=Pb(k,-16777216,16776704);s=p[a+72>>2];t=p[a+32>>2];k=c;u=p[c>>2];q=e<<8;e=q;e=NNa(i,i>>31,e,e>>31);i=ib;j=NNa(j,j>>31,b,b>>31);e=j+e|0;b=ib+i|0;b=e>>>0<j>>>0?b+1|0:b;i=e;e=p[a+68>>2];e=NNa(e,e>>31,f,f>>31);f=i+e|0;b=ib+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;m=p[a+28>>2]+m|0;j=m>>12;p[k>>2]=v(b,j)+u;l=l+t|0;i=l>>12;p[c+4>>2]=p[c+4>>2]+v(b,i);b=f-(s&q)|0;Kb(g+8|0,g);if(d){c=c+8|0;e=p[g+8>>2];f=p[g+12>>2];k=n;continue}break}e=p[g+8>>2];f=p[g+12>>2];k=n}p[a+40>>2]=l;p[a+20>>2]=j;p[a+36>>2]=m;p[a+48>>2]=k;p[a+44>>2]=b;p[a+24>>2]=i;p[a>>2]=e;p[a+4>>2]=f;fb=g+48|0}function UAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,p=0,s=0,t=0;d=fb-16|0;fb=d;a:{if(!Hb(a,2)){ag(c+484344|0,b,64);break a}j=c+484344|0;h=sd(zp(a),1,1024);if(!ag(j,b,h)|!h){break a}k=r[c+480188>>1];while(1){o=Jp(Rb(j,b),i);g=0;if(k){while(1){Dl(d+8|0,a);e=Zc(d+8|0);p=Tf(d+8|0);c=v(g,6)+o|0;f=q[vi(d+8|0)|0];n[c+5|0]=f;l=0;m=q[d+8|0];if((m+ -1&255)>>>0<=35){n[c|0]=m+48;l=q[e|0]+1|0}e=c+5|0;n[c+1|0]=l;b:{c:{d:{switch(q[p|0]){case 1:n[c+3|0]=2;n[e|0]=f&15;break b;case 2:n[c+3|0]=3;n[e|0]=f&15;break b;case 12:if(!f){break b}n[c+3|0]=1;break b;case 13:if(!f){break b}n[c+3|0]=36;n[d+7|0]=15;s=e,t=q[hc(d+7|0,e)|0]|16,n[s|0]=t;break b;case 30:if(!f){break b}n[c+3|0]=35;n[d+6|0]=15;s=e,t=q[hc(d+6|0,e)|0]|16,n[s|0]=t;break b;case 21:if(!f){break b}n[c+3|0]=36;n[d+5|0]=15;s=e,t=q[hc(d+5|0,e)|0]|80,n[s|0]=t;break b;case 17:if(!f){break b}n[c+3|0]=35;n[d+4|0]=15;s=e,t=q[hc(d+4|0,e)|0]|80,n[s|0]=t;break b;case 15:n[c+3|0]=19;n[e|0]=(f|0)!=0;break b;case 25:n[c+3|0]=12;break b;case 27:Gs(c);n[c|0]=255;break b;case 28:n[c+3|0]=16;break b;case 31:n[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}n[e|0]=f&15;break b;case 5:n[e|0]=f<<4;break b;case 6:n[d+3|0]=f&15;n[d+2|0]=14;s=e,t=q[hc(d+3|0,d+2|0)|0]|240,n[s|0]=t;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}n[d+1|0]=f&15;n[d|0]=14;s=e,t=q[hc(d+1|0,d)|0]<<4|15,n[s|0]=t;break b}n[c+4|0]=f;n[c+2|0]=1}n[c+3|0]=0;break c;case 0:break c;default:break d}}n[c+3|0]=0}n[e|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}fb=d+16|0}function THa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;b=b&4095;o[d+94>>1]=b;a:{b:{c:{d:{e:{f:{g:{if(b>>>0>=81){e=((b|0)==4095?c:b+ -80|0)+734016|0;c=NNa(e,e>>31,1e4,0)+14780|0;b=ib;b=ONa(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+v(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<=-1){b=b+ -1|0;c=(((e+((b|0)/-4|0)|0)+v(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=Mb(d- -64|0,13390);p[114610]=0;K(219,d+80|0,e|0);f=p[114610];p[114610]=0;h=(v(c,100)+52|0)/3060|0;h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=1){p[114610]=0;g=b;b=h+2|0;f=(b|0)/12|0;p[d+44>>2]=g+f;K(191,d+48|0,d+44|0);g=p[114610];p[114610]=0;if((g|0)==1){break o}p[114610]=0;p[d+28>>2]=(b-v(f,12)|0)+1;K(193,d+32|0,d+28|0);b=p[114610];p[114610]=0;if((b|0)==1){break n}p[114610]=0;p[d+12>>2]=(((v(h,306)+5|0)/-10|0)+c|0)+1;K(193,d+16|0,d+12|0);b=p[114610];p[114610]=0;if((b|0)==1){break m}p[114610]=0;_(622,a|0,d+80|0,d+48|0,d+32|0,d+16|0);a=p[114610];p[114610]=0;if((a|0)==1){break l}pb(d+16|0);pb(d+32|0);pb(d+48|0);yb(d+80|0);pb(e);break g}b=I()|0;H()|0;break h}b=I()|0;H()|0;break i}b=I()|0;H()|0;break j}b=I()|0;H()|0;break k}b=I()|0;H()|0;pb(d+16|0)}pb(d+32|0)}pb(d+48|0)}yb(d+80|0)}pb(e);break a}c=Mb(d,13414);p[114610]=0;K(219,d+80|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;K(623,d+48|0,d+94|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;N(247,a|0,d+80|0,d+48|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}pb(d+48|0);yb(d+80|0);pb(c)}fb=d+96|0;return}b=I()|0;H()|0;break b}b=I()|0;H()|0;break c}b=I()|0;H()|0;pb(d+48|0)}yb(d+80|0)}pb(c)}L(b|0);E()}function Yka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=fb-144|0;fb=c;e=Pk(c+40|0,a);p[114610]=0;d=J(686,c+24|0,32235)|0;a=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){p[114610]=0;p[c>>2]=19464961;p[c+4>>2]=0;N(687,e|0,d|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break n}yb(d);if(p[e>>2]&1073741824){break e}p[114610]=0;d=J(686,c+24|0,32240)|0;a=p[114610];p[114610]=0;if((a|0)==1){break m}p[114610]=0;U(1569,e|0,b|0,d|0,1570)|0;a=p[114610];p[114610]=0;if((a|0)==1){break l}yb(d);p[114610]=0;p[c+20>>2]=0;p[c+16>>2]=0;d=J(686,c+24|0,32245)|0;a=p[114610];p[114610]=0;if((a|0)==1){break k}p[114610]=0;P(1571,e|0,c+20|0,d|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break j}yb(d);p[114610]=0;d=J(686,c+24|0,32250)|0;a=p[114610];p[114610]=0;if((a|0)==1){break i}p[114610]=0;P(1571,e|0,c+16|0,d|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break h}yb(d);mla(b,p[c+20>>2],p[c+16>>2]);d=ux(c+24|0);p[114610]=0;f=J(686,c|0,32255)|0;a=p[114610];p[114610]=0;if((a|0)==1){break d}p[114610]=0;U(1572,e|0,d|0,f|0,678)|0;a=p[114610];p[114610]=0;if((a|0)==1){break g}yb(f);if(cd(d)){break f}p[114610]=0;N(1573,d|0,p[c+20>>2],16777216);a=p[114610];p[114610]=0;if((a|0)!=1){break f}break c}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(d);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(d);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(d);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;yb(d);break a}a=I()|0;H()|0;yb(f);break b}p[114610]=0;K(1574,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}be(d)}hg(e);fb=c+144|0;return}a=I()|0;H()|0;break b}a=I()|0;H()|0}be(d)}hg(e);L(a|0);E()}function MB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-128|0;fb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=p[b>>2];l:{if(!b){Mb(a,7037);break l}if(!(b&65535)){e=Mb(c+96|0,7045);p[114610]=0;K(219,c+112|0,e|0);d=p[114610];p[114610]=0;m:{n:{o:{p:{q:{r:{if((d|0)!=1){p[114610]=0;p[c+24>>2]=b>>>24;K(220,c+80|0,c+24|0);d=p[114610];p[114610]=0;if((d|0)==1){break r}p[114610]=0;p[c+8>>2]=b>>>16&255;K(221,c- -64|0,c+8|0);b=p[114610];p[114610]=0;if((b|0)==1){break q}p[114610]=0;Q(222,a|0,c+112|0,c+80|0,c- -64|0);a=p[114610];p[114610]=0;if((a|0)==1){break p}pb(c- -64|0);pb(c+80|0);yb(c+112|0);pb(e);break l}b=I()|0;H()|0;break m}b=I()|0;H()|0;break n}b=I()|0;H()|0;break o}b=I()|0;H()|0;pb(c- -64|0)}pb(c+80|0)}yb(c+112|0)}break a}e=Mb(c+48|0,7051);p[114610]=0;K(219,c+112|0,e|0);d=p[114610];p[114610]=0;if((d|0)==1){break k}p[114610]=0;p[c+44>>2]=b>>>24;K(220,c+80|0,c+44|0);d=p[114610];p[114610]=0;if((d|0)==1){break j}p[114610]=0;p[c+40>>2]=b>>>16&255;K(221,c- -64|0,c+40|0);d=p[114610];p[114610]=0;if((d|0)==1){break i}p[114610]=0;p[c+20>>2]=b>>>8&255;K(221,c+24|0,c+20|0);d=p[114610];p[114610]=0;if((d|0)==1){break h}p[114610]=0;p[c+4>>2]=b&255;K(221,c+8|0,c+4|0);b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;fa(223,a|0,c+112|0,c+80|0,c- -64|0,c+24|0,c+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break f}pb(c+8|0);pb(c+24|0);pb(c- -64|0);pb(c+80|0);yb(c+112|0);pb(e)}fb=c+128|0;return}b=I()|0;H()|0;break a}b=I()|0;H()|0;break b}b=I()|0;H()|0;break c}b=I()|0;H()|0;break d}b=I()|0;H()|0;break e}b=I()|0;H()|0;pb(c+8|0)}pb(c+24|0)}pb(c- -64|0)}pb(c+80|0)}yb(c+112|0)}pb(e);L(b|0);E()}function U1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-384|0;fb=f;p[f+376>>2]=37;p[f+380>>2]=0;g=Aq(f+376|1,62137,p[c+4>>2]);p[f+332>>2]=f+336;a=de();a:{if(g){h=p[c+8>>2];u[f+40>>3]=e;p[f+32>>2]=h;a=Te(f+336|0,30,a,f+376|0,f+32|0);break a}u[f+48>>3]=e;a=Te(f+336|0,30,a,f+376|0,f+48|0)}p[f+80>>2]=2420;h=Hd(f+320|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){p[114610]=0;a=Y(2445)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[f>>2]=p[c+8>>2];p[114610]=0;u[f+8>>3]=e;a=U(2467,f+332|0,a|0,f+376|0,f|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break e}break c}p[114610]=0;a=Y(2445)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}u[f+16>>3]=e;p[114610]=0;a=U(2467,f+332|0,a|0,f+376|0,f+16|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}}g=p[f+332>>2];if(!g){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)==1){break c}break d}pe(h,g)}g=p[f+332>>2];j=g+a|0;k=Yf(g,j,c);p[f+68>>2]=2420;i=Hd(f+72|0,0,f+68|0);f:{g:{if(p[f+332>>2]==(f+336|0)){a=f+80|0;g=f+336|0;break g}a=fd(a<<3);if(!a){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)!=1){break d}c=I()|0;H()|0;break f}pe(i,a);g=p[f+332>>2]}p[114610]=0;qc(f+56|0,c);l=p[114610];p[114610]=0;h:{i:{if((l|0)!=1){p[114610]=0;ca(2478,g|0,k|0,j|0,a|0,f+68|0,f- -64|0,f+56|0);g=p[114610];p[114610]=0;if((g|0)==1){break i}Gb(f+56|0);p[114610]=0;a=da(2479,b|0,a|0,p[f+68>>2],p[f+64>>2],c|0,d|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break h}wc(i);wc(h);fb=f+384|0;return a|0}c=I()|0;H()|0;break f}c=I()|0;H()|0;Gb(f+56|0);break f}c=I()|0;H()|0}wc(i);break b}E()}c=I()|0;H()|0}wc(h);L(c|0);E()}function d2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-208|0;fb=f;p[f+200>>2]=37;p[f+204>>2]=0;g=Aq(f+200|1,62137,p[c+4>>2]);p[f+156>>2]=f+160;a=de();a:{if(g){h=p[c+8>>2];u[f+40>>3]=e;p[f+32>>2]=h;a=Te(f+160|0,30,a,f+200|0,f+32|0);break a}u[f+48>>3]=e;a=Te(f+160|0,30,a,f+200|0,f+48|0)}p[f+80>>2]=2420;h=Hd(f+144|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){p[114610]=0;a=Y(2445)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[f>>2]=p[c+8>>2];p[114610]=0;u[f+8>>3]=e;a=U(2467,f+156|0,a|0,f+200|0,f|0)|0;g=p[114610];p[114610]=0;if((g|0)!=1){break e}break c}p[114610]=0;a=Y(2445)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}u[f+16>>3]=e;p[114610]=0;a=U(2467,f+156|0,a|0,f+200|0,f+16|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}}g=p[f+156>>2];if(!g){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)==1){break c}break d}pe(h,g)}g=p[f+156>>2];j=g+a|0;k=Yf(g,j,c);p[f+68>>2]=2420;i=Hd(f+72|0,0,f+68|0);f:{g:{if(p[f+156>>2]==(f+160|0)){a=f+80|0;g=f+160|0;break g}a=fd(a<<1);if(!a){p[114610]=0;R(2421);a=p[114610];p[114610]=0;if((a|0)!=1){break d}c=I()|0;H()|0;break f}pe(i,a);g=p[f+156>>2]}p[114610]=0;qc(f+56|0,c);l=p[114610];p[114610]=0;h:{i:{if((l|0)!=1){p[114610]=0;ca(2468,g|0,k|0,j|0,a|0,f+68|0,f- -64|0,f+56|0);g=p[114610];p[114610]=0;if((g|0)==1){break i}Gb(f+56|0);p[114610]=0;a=da(17,b|0,a|0,p[f+68>>2],p[f+64>>2],c|0,d|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break h}wc(i);wc(h);fb=f+208|0;return a|0}c=I()|0;H()|0;break f}c=I()|0;H()|0;Gb(f+56|0);break f}c=I()|0;H()|0}wc(i);break b}E()}c=I()|0;H()|0}wc(h);L(c|0);E()}function ova(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0;g=fb-48|0;fb=g;r=p[a+16>>2];h=Df(g+16|0);p[h+8>>2]=a+112;p[h+16>>2]=p[a+128>>2];w=h,x=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[w+12>>2]=x;b=p[h+16>>2];if(b){w=h,x=Cf(a+8|0,b),p[w>>2]=x;p[h+4>>2]=ib}k=p[a+48>>2];l=p[a+40>>2];m=p[a+36>>2];b=p[a+44>>2];f=p[a+4>>2];e=p[a>>2];p[g+8>>2]=e;p[g+12>>2]=f;o=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=o;a:{if(!d){i=l>>12;j=m>>12;break a}while(1){o=b;b=0;i=b;p[g+40>>2]=e;p[g+44>>2]=b;f=f+r|0;b:{b=p[h+16>>2];if((b|0)<=0){break b}while(1){qd(p[h+8>>2],n[f+i|0]<<6);pd(p[h+8>>2],4);Kb(g+40|0,h);if((b|0)<2){break b}b=b+ -1|0;i=p[g+44>>2];continue}}d=d+ -1|0;b=p[h+8>>2];Kb(b,b+8|0);b=p[h+8>>2];e=p[b+4>>2];if(e){qd(b,n[f+p[g+44>>2]|0]<<6);pd(p[h+8>>2],e);b=p[h+8>>2];e=p[b>>2];p[b>>2]=e;p[b+4>>2]=0}e=xf(b,p[h+12>>2]);i=p[a+60>>2];b=Pb(o,-16777216,16776704);j=p[a+64>>2];f=Pb(k,-16777216,16776704);s=p[a+72>>2];t=p[a+32>>2];k=c;u=p[c>>2];q=e<<8;e=q;e=NNa(i,i>>31,e,e>>31);i=ib;j=NNa(j,j>>31,b,b>>31);e=j+e|0;b=ib+i|0;b=e>>>0<j>>>0?b+1|0:b;i=e;e=p[a+68>>2];e=NNa(e,e>>31,f,f>>31);f=i+e|0;b=ib+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;m=p[a+28>>2]+m|0;j=m>>12;p[k>>2]=v(b,j)+u;l=l+t|0;i=l>>12;p[c+4>>2]=p[c+4>>2]+v(b,i);b=f-(s&q)|0;Kb(g+8|0,g);if(d){c=c+8|0;e=p[g+8>>2];f=p[g+12>>2];k=o;continue}break}e=p[g+8>>2];f=p[g+12>>2];k=o}p[a+40>>2]=l;p[a+20>>2]=j;p[a+36>>2]=m;p[a+48>>2]=k;p[a+44>>2]=b;p[a+24>>2]=i;p[a>>2]=e;p[a+4>>2]=f;fb=g+48|0}function x0(a,b,c,d,e,f,g,h,i,j,k,l,m,o,r){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;o=o|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=fb-16|0;fb=x;p[c>>2]=a;A=d&512;a:{while(1){if((z|0)==4){b:{if(wb(o)>>>0>1){C=x,D=wd(o),p[C+8>>2]=D;C=c,D=ij(Yo(x+8|0,1),Aj(o),p[c>>2]),p[C>>2]=D}d=d&176;if((d|0)==16){break a}if((d|0)!=32){break b}p[b>>2]=p[c>>2];break a}}else{c:{d:{switch(n[i+z|0]){case 0:p[b>>2]=p[c>>2];break c;case 1:p[b>>2]=p[c>>2];t=Nq(g,32);s=p[c>>2];p[c>>2]=s+4;p[s>>2]=t;break c;case 3:if(Pc(o)){break c}t=p[Ui(o,0)>>2];s=p[c>>2];p[c>>2]=s+4;p[s>>2]=t;break c;case 2:if(Pc(m)|!A){break c}C=c,D=ij(wd(m),Aj(m),p[c>>2]),p[C>>2]=D;break c;case 4:break d;default:break c}}B=p[c>>2];e=h?e+4|0:e;u=e;while(1){e:{if(u>>>0>=f>>>0){break e}if(!Gj(g,2048,p[u>>2])){break e}u=u+4|0;continue}break}s=r;if((s|0)>=1){while(1){t=(s|0)<1;if(!(t|u>>>0<=e>>>0)){u=u+ -4|0;v=p[u>>2];t=p[c>>2];p[c>>2]=t+4;p[t>>2]=v;s=s+ -1|0;continue}break}if(t){y=0}else{y=Nq(g,48)}t=p[c>>2];while(1){v=t+4|0;if((s|0)>=1){p[t>>2]=y;s=s+ -1|0;t=v;continue}break}p[c>>2]=v;p[t>>2]=j}f:{if((e|0)==(u|0)){t=Nq(g,48);s=p[c>>2];u=s+4|0;p[c>>2]=u;p[s>>2]=t;break f}v=-1;g:{if(Pc(l)){break g}v=n[cc(l,0)|0]}s=0;w=0;while(1){if((e|0)!=(u|0)){h:{if((s|0)!=(v|0)){t=s;break h}t=p[c>>2];p[c>>2]=t+4;p[t>>2]=k;t=0;w=w+1|0;if(w>>>0>=wb(l)>>>0){v=s;break h}if(q[cc(l,w)|0]==127){v=-1;break h}v=n[cc(l,w)|0]}u=u+ -4|0;y=p[u>>2];s=p[c>>2];p[c>>2]=s+4;p[s>>2]=y;s=t+1|0;continue}break}u=p[c>>2]}Xn(B,u)}z=z+1|0;continue}break}p[b>>2]=a}fb=x+16|0}function n2(a,b,c,d,e){var f=0,g=0;f=fb-384|0;fb=f;p[f+368>>2]=b;p[f+376>>2]=a;Xu(f+216|0,c,f+240|0,f+236|0,f+232|0);b=Lb(f+200|0);a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;a:{b:{if((a|0)!=1){a=cc(b,0);p[f+196>>2]=a;p[f+28>>2]=f+32;p[f+24>>2]=0;n[f+23|0]=1;n[f+22|0]=69;while(1){c:{p[114610]=0;c=J(2454,f+376|0,f+368|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+196>>2]==(wb(b)+a|0)){c=wb(b);a=wb(b);p[114610]=0;K(149,b|0,a<<1);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=cc(b,0);p[f+196>>2]=c+a}p[114610]=0;c=M(2456,f+376|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Bq(c,f+23|0,f+22|0,a,f+196|0,p[f+236>>2],p[f+232>>2],f+216|0,f+32|0,f+28|0,f+24|0,f+240|0);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2458,f+376|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+216|0)|!q[f+23|0]){break d}c=p[f+28>>2];if((c-(f+32|0)|0)>159){break d}p[f+28>>2]=c+4;p[c>>2]=p[f+24>>2]}p[114610]=0;Q(2443,f|0,a|0,p[f+196>>2],d|0);a=p[114610];p[114610]=0;e:{if((a|0)==1){break e}a=p[f+8>>2];c=p[f+12>>2];g=p[f+4>>2];p[e>>2]=p[f>>2];p[e+4>>2]=g;p[e+8>>2]=a;p[e+12>>2]=c;p[114610]=0;we(f+216|0,f+32|0,p[f+28>>2],d);a=p[114610];p[114610]=0;if((a|0)==1){break e}p[114610]=0;a=J(2455,f+376|0,f+368|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(a){p[d>>2]=p[d>>2]|2}a=p[f+376>>2];pb(b);pb(f+216|0);fb=f+384|0;return a}}a=I()|0;H()|0;pb(b);pb(f+216|0);L(a|0);E()}function L2(a,b,c,d,e){var f=0,g=0;f=fb-288|0;fb=f;p[f+272>>2]=b;p[f+280>>2]=a;Zu(f+224|0,c,f+240|0,f+239|0,f+238|0);b=Lb(f+208|0);a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;a:{b:{if((a|0)!=1){a=cc(b,0);p[f+204>>2]=a;p[f+28>>2]=f+32;p[f+24>>2]=0;n[f+23|0]=1;n[f+22|0]=69;while(1){c:{p[114610]=0;c=J(2422,f+280|0,f+272|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+204>>2]==(wb(b)+a|0)){c=wb(b);a=wb(b);p[114610]=0;K(149,b|0,a<<1);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=cc(b,0);p[f+204>>2]=c+a}p[114610]=0;c=M(2424,f+280|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Dq(c,f+23|0,f+22|0,a,f+204|0,n[f+239|0],n[f+238|0],f+224|0,f+32|0,f+28|0,f+24|0,f+240|0);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2426,f+280|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+224|0)|!q[f+23|0]){break d}c=p[f+28>>2];if((c-(f+32|0)|0)>159){break d}p[f+28>>2]=c+4;p[c>>2]=p[f+24>>2]}p[114610]=0;Q(2443,f|0,a|0,p[f+204>>2],d|0);a=p[114610];p[114610]=0;e:{if((a|0)==1){break e}a=p[f+8>>2];c=p[f+12>>2];g=p[f+4>>2];p[e>>2]=p[f>>2];p[e+4>>2]=g;p[e+8>>2]=a;p[e+12>>2]=c;p[114610]=0;we(f+224|0,f+32|0,p[f+28>>2],d);a=p[114610];p[114610]=0;if((a|0)==1){break e}p[114610]=0;a=J(2423,f+280|0,f+272|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(a){p[d>>2]=p[d>>2]|2}a=p[f+280>>2];pb(b);pb(f+224|0);fb=f+288|0;return a}}a=I()|0;H()|0;pb(b);pb(f+224|0);L(a|0);E()}function $va(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=fb-16|0;fb=h;r=p[a+16>>2];a:{b:{c:{j=p[a+8>>2];g=p[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?j>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?j>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?j>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?j>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}f=p[a+48>>2];s=p[a+24>>2];t=p[a+20>>2];k=p[a+44>>2];e=p[a+4>>2];i=p[a>>2];p[h+8>>2]=i;p[h+12>>2]=e;p[h>>2]=j;p[h+4>>2]=g;e:{if(!d){b=k;k=f;break e}while(1){b=(i>>>16&65520)+m|0;g=o[b>>1];e=(e<<1)+r|0;i=o[e+ -6>>1];j=o[b+2>>1];u=o[e+ -4>>1];w=o[b+4>>1];x=o[e+ -2>>1];y=o[b+6>>1];z=o[e>>1];A=o[b+8>>1];B=o[e+2>>1];C=o[b+10>>1];D=o[e+4>>1];E=o[b+12>>1];F=o[e+6>>1];G=o[b+14>>1];e=o[e+8>>1];q=p[a+60>>2];b=Pb(k,-16777216,16776704);l=p[a+64>>2];f=Pb(f,-16777216,16776704);H=p[a+72>>2];I=p[c>>2];b=NNa(l,l>>31,b,b>>31);l=ib;n=b;i=(((((((v(j,u)+v(g,i)|0)+v(w,x)|0)+v(y,z)|0)+v(A,B)|0)+v(C,D)|0)+v(E,F)|0)+v(e,G)|0)/32768<<8;b=i;g=NNa(q,q>>31,b,b>>31);e=n+g|0;b=ib+l|0;b=e>>>0<g>>>0?b+1|0:b;n=e;e=p[a+68>>2];e=NNa(e,e>>31,f,f>>31);f=n+e|0;b=ib+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;p[c>>2]=v(f,t)+I;p[c+4>>2]=p[c+4>>2]+v(f,s);b=b-(i&H)|0;Kb(h+8|0,h);d=d+ -1|0;if(d){c=c+8|0;i=p[h+8>>2];e=p[h+12>>2];f=k;k=b;continue}break}i=p[h+8>>2];e=p[h+12>>2]}p[a+48>>2]=k;p[a+44>>2]=b;p[a>>2]=i;p[a+4>>2]=e;fb=h+16|0}function awa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=fb-16|0;fb=h;r=p[a+16>>2];a:{b:{c:{i=p[a+8>>2];g=p[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?i>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?i>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?i>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?i>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}f=p[a+48>>2];s=p[a+24>>2];t=p[a+20>>2];k=p[a+44>>2];e=p[a+4>>2];j=p[a>>2];p[h+8>>2]=j;p[h+12>>2]=e;p[h>>2]=i;p[h+4>>2]=g;e:{if(!d){b=k;k=f;break e}while(1){b=e+r|0;g=n[b+4|0];e=(j>>>16&65520)+m|0;j=o[e+14>>1];i=n[b+3|0];u=o[e+12>>1];w=n[b+2|0];x=o[e+10>>1];y=n[b+1|0];z=o[e+8>>1];A=n[b|0];B=o[e+6>>1];C=n[b+ -1|0];D=o[e+4>>1];E=n[b+ -2|0];F=o[e+2>>1];G=n[b+ -3|0];e=o[e>>1];b=p[a+60>>2];H=b;I=b>>31;b=Pb(k,-16777216,16776704);l=p[a+64>>2];f=Pb(f,-16777216,16776704);J=p[a+72>>2];K=p[c>>2];b=NNa(l,l>>31,b,b>>31);l=ib;L=b;b=p[a+68>>2];q=NNa(b,b>>31,f,f>>31);f=L+q|0;b=ib+l|0;b=f>>>0<q>>>0?b+1|0:b;e=(((((((v(E,F)+v(e,G)|0)+v(C,D)|0)+v(A,B)|0)+v(y,z)|0)+v(w,x)|0)+v(i,u)|0)+v(g,j)<<8)/32768<<8;g=NNa(H,I,e,e>>31);f=f+g|0;b=ib+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;p[c>>2]=v(f,t)+K;p[c+4>>2]=p[c+4>>2]+v(f,s);b=b-(e&J)|0;Kb(h+8|0,h);d=d+ -1|0;if(d){c=c+8|0;j=p[h+8>>2];e=p[h+12>>2];f=k;k=b;continue}break}j=p[h+8>>2];e=p[h+12>>2]}p[a+48>>2]=k;p[a+44>>2]=b;p[a>>2]=j;p[a+4>>2]=e;fb=h+16|0}function Awa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0;b=fb-48|0;fb=b;u=p[a+16>>2];l=p[a+44>>2];p[b+32>>2]=l;f=p[a+48>>2];p[b+36>>2]=f;j=p[a+52>>2];p[b+40>>2]=j;k=p[a+56>>2];p[b+44>>2]=k;m=p[a+40>>2];n=p[a+36>>2];e=p[a+4>>2];i=p[a>>2];p[b+24>>2]=i;p[b+28>>2]=e;g=p[a+12>>2];p[b+16>>2]=p[a+8>>2];p[b+20>>2]=g;a:{if(!d){g=m>>12;h=n>>12;break a}while(1){f=i>>>18|0;l=1;e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+u|0;g=0;j=1;h=0;while(1){k=h<<1;i=o[k+e>>1];p[(b+8|0)+(h<<2)>>2]=i+((v(f,o[e+(k|4)>>1]-i|0)|0)/16384|0);i=j&1;j=0;h=1;if(i){continue}break}while(1){h=(b+8|0)+(g<<2)|0;j=p[h>>2];f=p[a+60>>2];k=f;i=(b+32|0)+(g<<3)|0;q=p[i>>2];e=Pb(q,-16777216,16776704);t=p[a+64>>2];g=Pb(p[i+4>>2],-16777216,16776704);r=p[a+68>>2];w=r;r=r>>31;p[i+4>>2]=q;q=p[a+72>>2];s=f>>31;j=j<<8;f=j;f=NNa(k,s,f,f>>31);k=ib;s=h;h=f;f=NNa(t,t>>31,e,e>>31);h=h+f|0;e=ib+k|0;e=h>>>0<f>>>0?e+1|0:e;f=h;h=NNa(w,r,g,g>>31);g=f+h|0;e=ib+e|0;e=g>>>0<h>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;p[s>>2]=(e|0)/256;p[i>>2]=e-(j&q);g=1;e=l&1;l=0;if(e){continue}break}e=p[a+32>>2];n=p[a+28>>2]+n|0;h=n>>12;p[c>>2]=p[c>>2]+v(h,p[b+8>>2]);m=e+m|0;g=m>>12;p[c+4>>2]=p[c+4>>2]+v(g,p[b+12>>2]);Kb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;i=p[b+24>>2];e=p[b+28>>2];continue}break}i=p[b+24>>2];e=p[b+28>>2];k=p[b+44>>2];j=p[b+40>>2];f=p[b+36>>2];l=p[b+32>>2]}p[a+40>>2]=m;p[a+20>>2]=h;p[a+36>>2]=n;p[a+56>>2]=k;p[a+52>>2]=j;p[a+48>>2]=f;p[a+44>>2]=l;p[a+24>>2]=g;p[a>>2]=i;p[a+4>>2]=e;fb=b+48|0}function rDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0;g=fb-16|0;fb=g;if(c){m=b,o=td(a),n[m|0]=o;i=b+1|0;j=c+ -1|0;a:{if(!j){break a}while(1){b:{c:{d=f<<1;f=d&254;d:{if(!f){if(!Ae(a,g+15|0)){break a}d=q[g+15|0]<<1|1;f=d&255;if(d>>>0>255){break d}break c}if((d&65535)>>>0<256){break c}}h=1;while(1){e:{f:{g:{e=f<<1&254;d=f>>>0>127;h:{if(e){break h}if(!Ae(a,g+14|0)){break g}d=q[g+14|0]<<1|1;e=d&255;d=d>>>0>255}h=d|h<<1;f=e<<1&254;if(f){break f}if(!Ae(a,g+13|0)){break g}d=q[g+13|0]<<1|1;f=d&255;if(d>>>0>255){continue}break e}f=0;break e}if(e>>>0>127){continue}}break}i:{if((h|0)<=2){l=0;h=h+ -2|0;break i}if(!Ae(a,g+12|0)){break a}d=(q[g+12|0]|h<<8)+ -768|0;l=((d|0)>1279?2:1)+((d|0)>31999)|0;k=d^-1;h=0}e=f<<1&254;d=f>>>0>127;j:{if(e){break j}if(!Ae(a,g+11|0)){break a}d=q[g+11|0]<<1|1;e=d&255;d=d>>>0>255}f=e<<1&254;e=e>>>0>127;k:{if(f){break k}if(!Ae(a,g+10|0)){break a}e=q[g+10|0]<<1|1;f=e&255;e=e>>>0>255}e=e|(h<<2|(d?2:0));if(!e){h=1;while(1){l:{m:{n:{e=f<<1&254;d=f>>>0>127;o:{if(e){break o}if(!Ae(a,g+9|0)){break n}d=q[g+9|0]<<1|1;e=d&255;d=d>>>0>255}h=d|h<<1;f=e<<1&254;if(f){break m}if(!Ae(a,g+8|0)){break n}d=q[g+8|0]<<1|1;f=d&255;if(d>>>0>255){continue}break l}f=0;break l}if(e>>>0>127){continue}}break}e=h+2|0}if((k|0)>-1){break a}e=e+l|0;if(j>>>0<e>>>0|(e|0)<1|((i-b|0)+k|0)<0){break a}h=i+k|0;j=j-e|0;while(1){n[i|0]=q[h|0];i=i+1|0;h=h+1|0;d=(e|0)>1;e=e+ -1|0;if(d){continue}break}break b}if(!Ae(a,i)){break a}j=j+ -1|0;i=i+1|0}if(j){continue}break}}a=(i-b|0)==(c|0)}else{a=0}fb=g+16|0;return a|0}function B0(a,b,c,d,e,f,g,h,i,j,k,l,m,o,r){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;o=o|0;r=r|0;var s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=fb-16|0;fb=x;p[c>>2]=a;A=d&512;while(1){a:{b:{c:{d:{if((y|0)==4){if(wb(o)>>>0>1){C=x,D=wd(o),p[C+8>>2]=D;C=c,D=ij(lf(x+8|0,1),jf(o),p[c>>2]),p[C>>2]=D}d=d&176;if((d|0)==16){break c}if((d|0)!=32){break d}p[b>>2]=p[c>>2];break c}e:{switch(n[i+y|0]){case 0:p[b>>2]=p[c>>2];break a;case 1:p[b>>2]=p[c>>2];t=Bk(g,32);s=p[c>>2];p[c>>2]=s+1;n[s|0]=t;break a;case 3:if(Pc(o)){break a}t=q[cc(o,0)|0];s=p[c>>2];p[c>>2]=s+1;n[s|0]=t;break a;case 2:if(Pc(m)|!A){break a}C=c,D=ij(wd(m),jf(m),p[c>>2]),p[C>>2]=D;break a;case 4:break e;default:break a}}B=p[c>>2];e=h?e+1|0:e;u=e;while(1){f:{if(u>>>0>=f>>>0){break f}if(!wg(g,2048,n[u|0])){break f}u=u+1|0;continue}break}t=r;if((t|0)>=1){while(1){s=(t|0)<1;if(!(s|u>>>0<=e>>>0)){u=u+ -1|0;s=q[u|0];v=p[c>>2];p[c>>2]=v+1;n[v|0]=s;t=t+ -1|0;continue}break}if(s){s=0}else{s=Bk(g,48)}while(1){v=p[c>>2];p[c>>2]=v+1;if((t|0)>=1){n[v|0]=s;t=t+ -1|0;continue}break}n[v|0]=j}if((e|0)==(u|0)){t=Bk(g,48);s=p[c>>2];p[c>>2]=s+1;n[s|0]=t;break b}s=-1;g:{if(Pc(l)){break g}s=n[cc(l,0)|0]}t=0;w=0;while(1){if((e|0)==(u|0)){break b}h:{if((t|0)!=(s|0)){v=t;break h}s=p[c>>2];p[c>>2]=s+1;n[s|0]=k;v=0;w=w+1|0;if(w>>>0>=wb(l)>>>0){s=t;break h}if(q[cc(l,w)|0]==127){s=-1;break h}s=n[cc(l,w)|0]}u=u+ -1|0;t=q[u|0];z=p[c>>2];p[c>>2]=z+1;n[z|0]=t;t=v+1|0;continue}}p[b>>2]=a}fb=x+16|0;return}Bj(B,p[c>>2])}y=y+1|0;continue}}function Bwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;b=fb-48|0;fb=b;s=p[a+16>>2];j=p[a+44>>2];p[b+32>>2]=j;l=p[a+48>>2];p[b+36>>2]=l;i=p[a+52>>2];p[b+40>>2]=i;k=p[a+56>>2];p[b+44>>2]=k;m=p[a+40>>2];o=p[a+36>>2];e=p[a+4>>2];h=p[a>>2];p[b+24>>2]=h;p[b+28>>2]=e;g=p[a+12>>2];p[b+16>>2]=p[a+8>>2];p[b+20>>2]=g;a:{if(!d){g=m>>12;f=o>>12;break a}while(1){j=h>>>18|0;e=(((e&2147483647)<<1|h>>>31)&-2)+s|0;f=0;l=1;i=1;g=0;while(1){h=n[e+g|0]<<8;p[(b+8|0)+(g<<2)>>2]=((v(j,(n[e+(g|2)|0]<<8)-h|0)|0)/16384|0)+h;h=i&1;i=0;g=1;if(h){continue}break}while(1){i=(b+8|0)+(f<<2)|0;j=p[i>>2];k=p[a+60>>2];h=(b+32|0)+(f<<3)|0;f=p[h>>2];e=Pb(f,-16777216,16776704);r=p[a+64>>2];g=Pb(p[h+4>>2],-16777216,16776704);q=p[a+68>>2];t=q;q=q>>31;p[h+4>>2]=f;u=p[a+72>>2];j=j<<8;f=j;f=NNa(k,k>>31,f,f>>31);k=ib;w=i;i=NNa(r,r>>31,e,e>>31);f=i+f|0;e=ib+k|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=NNa(t,q,g,g>>31);g=i+f|0;e=ib+e|0;e=g>>>0<f>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;p[w>>2]=(e|0)/256;p[h>>2]=e-(j&u);f=1;e=l&1;l=0;if(e){continue}break}e=p[a+32>>2];o=p[a+28>>2]+o|0;f=o>>12;p[c>>2]=p[c>>2]+v(f,p[b+8>>2]);m=e+m|0;g=m>>12;p[c+4>>2]=p[c+4>>2]+v(g,p[b+12>>2]);Kb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;h=p[b+24>>2];e=p[b+28>>2];continue}break}h=p[b+24>>2];e=p[b+28>>2];k=p[b+44>>2];i=p[b+40>>2];l=p[b+36>>2];j=p[b+32>>2]}p[a+40>>2]=m;p[a+20>>2]=f;p[a+36>>2]=o;p[a+56>>2]=k;p[a+52>>2]=i;p[a+48>>2]=l;p[a+44>>2]=j;p[a+24>>2]=g;p[a>>2]=h;p[a+4>>2]=e;fb=b+48|0}function e7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0;f=fb-17168|0;fb=f;p[f+17164>>2]=0;a:{b:{c:{if(q[a+6152|0]!=255|(c|0)<5){break c}if(!ko(a+6152|0,b)){break c}h=Sv(b,p[a+6148>>2])+jo(b)|0;p[f+17164>>2]=h;if((c|0)==(h|0)){h=c;break b}d:{if((h+4|0)<=(c|0)){if(ko(b,b+h|0)){break d}}p[f+17164>>2]=0;break c}if(h){break b}}g=c7(b,c,Jb(a,0,6668)+6148|0,f+17164|0);h=p[f+17164>>2];if((g+h|0)<=(c|0)?h:0){break b}p[e>>2]=g;g=0;break a}c=b+g|0;p[a+6152>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[e+4>>2]=g;p[e>>2]=g+h;p[e+8>>2]=q[c+3|0]>191?1:2;m=e,o=sF(c),p[m+12>>2]=o;p[e+16>>2]=4-(q[c+1|0]>>>1&3);m=e,o=Rv(c),p[m+20>>2]=o;if(!d){g=Qv(c);break a}rF(f+17152|0,c+4|0,h+ -4|0);if(!(n[c+1|0]&1)){Kd(f+17152|0,16)}e:{if(p[e+16>>2]==3){g=0;b=b7(f+17152|0,f+3740|0,c);if(!((b|0)<0|p[f+17156>>2]>p[f+17160>>2])){h=a7(a,f+17152|0,f+912|0,b);if(h){i=a+2304|0;g=p[e+8>>2];j=f+8620|0;k=f+3852|0;b=0;while(1){l=Jb(k,0,4608);_6(a,f+912|0,(v(v(b,g),28)+f|0)+3740|0,g);qF(i,l,18,p[e+8>>2],d,j);g=p[e+8>>2];d=v(g,1152)+d|0;b=b+1|0;if(b>>>0<(q[c+1|0]&8?2:1)>>>0){continue}break}}Z6(a,f+912|0);break e}Tv(a);break a}Y6(c,f+17152|0,f);g=0;b=Jb(f+3852|0,0,4608);h=a+2304|0;i=f+8620|0;c=0;f:{while(1){c=X6(((c<<2)+f|0)+3852|0,f+17152|0,f,p[e+16>>2]|1)+c|0;if((c|0)==12){W6(f,(g<<2)+f|0,b);qF(h,b,12,p[e+8>>2],d,i);Jb(b,0,4608);d=v(p[e+8>>2],768)+d|0;c=0}if(p[f+17156>>2]<=p[f+17160>>2]){g=g+1|0;if((g|0)==3){break f}continue}break}Tv(a);g=0;break a}h=1}g=v(Qv(a+6152|0),h)}fb=f+17168|0;return g|0}function YK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;h=fb-16|0;fb=h;a:{if((b|0)==(c|0)){break a}p[h+12>>2]=-1953789045;Dx(b,c,h+12|0);d=c-b>>2;p[h+8>>2]=d;n=Bb(a);g=n+1|0;p[h+4>>2]=g;k=p[Uc(h+4|0,h+8|0)>>2];j=p[((p[h+8>>2]<<2)+b|0)+ -4>>2];c=d;e=c;f=11;b:{if(c>>>0>622){break b}f=7;if(d>>>0>67){break b}f=5;if(d>>>0>38){break b}f=3;if(d>>>0>6){break b}f=d+ -1>>>1|0}l=e-f>>>1|0;c=(l<<2)+b|0;e=v(as(j^(p[c>>2]^p[b>>2])),1664525);p[c>>2]=e+p[c>>2];o=l+f|0;c=(o<<2)+b|0;d=c;f=p[c>>2];c=e+n|0;p[d>>2]=f+c;p[b>>2]=c;if(n){m=p[h+8>>2];c=1;while(1){e=c+ -1|0;d=((c+l>>>0)%(m>>>0)<<2)+b|0;f=(c>>>0)%(m>>>0)|0;i=(f<<2)+b|0;q=v(as(p[((e>>>0)%(m>>>0)<<2)+b>>2]^(p[d>>2]^p[i>>2])),1664525);p[d>>2]=q+p[d>>2];d=Fb(a,e);m=p[h+8>>2];e=((c+o>>>0)%(m>>>0)<<2)+b|0;j=e;r=p[e>>2];e=p[d>>2]+(f+q|0)|0;p[j>>2]=r+e;p[i>>2]=e;c=c+1|0;if(c>>>0<=n>>>0){continue}break}}c=p[h+8>>2];if(g>>>0<k>>>0){while(1){a=((g+l>>>0)%(c>>>0)<<2)+b|0;d=(g>>>0)%(c>>>0)|0;e=(d<<2)+b|0;i=v(as(p[((g+ -1>>>0)%(c>>>0)<<2)+b>>2]^(p[a>>2]^p[e>>2])),1664525);p[a>>2]=i+p[a>>2];c=p[h+8>>2];a=((g+o>>>0)%(c>>>0)<<2)+b|0;f=a;j=p[a>>2];a=d+i|0;p[f>>2]=j+a;p[e>>2]=a;g=g+1|0;if((k|0)!=(g|0)){continue}break}}if(k>>>0>=c+k>>>0){break a}g=k;while(1){a=((g+l>>>0)%(c>>>0)<<2)+b|0;d=(g>>>0)%(c>>>0)|0;e=(d<<2)+b|0;i=v(as(p[((g+ -1>>>0)%(c>>>0)<<2)+b>>2]+(p[a>>2]+p[e>>2]|0)|0),1566083941);p[a>>2]=i^p[a>>2];c=p[h+8>>2];a=((g+o>>>0)%(c>>>0)<<2)+b|0;f=a;j=p[a>>2];a=i-d|0;p[f>>2]=j^a;p[e>>2]=a;g=g+1|0;if(g>>>0<c+k>>>0){continue}break}}fb=h+16|0}function goa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-48|0;fb=d;c=r[a+480190>>1];n[d+32|0]=0;xL(b,c+1|0,d+32|0);if(r[a+480192>>1]){g=Yt(d+32|0);c=a+484344|0;j=d,k=Ub(c),p[j+24>>2]=k;j=d,k=Vb(c),p[j+16>>2]=k;if(Ab(d+24|0,d+16|0)){while(1){a:{h=p[d+24>>2];if(!Ch(h)){break a}c=r[a+480188>>1];p[114610]=0;n[d|0]=0;N(1424,g|0,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){b:{j=d,k=Ub(h),p[j+8>>2]=k;i=0;if(!p[h+12>>2]){break a}while(1){f=0;c:{if(!r[a+480188>>1]){break c}while(1){d:{c=p[d+8>>2];p[114610]=0;c=M(556,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break d}e:{if(!c){break e}c=q[p[d+8>>2]+1|0];if(!q[p[d+8>>2]+1|0]){c=q[oc(g,f)|0]}e=c&255;if(e){f:{if(!(e>>>0<=256&e>>>0>=0)){break f}e=p[((q[p[d+8>>2]+1|0]<<2)+a|0)+900380>>2];if(!e){break f}e=r[Yc(e+236|0,q[p[d+8>>2]]+ -1|0)>>1];if(e>>>0>r[a+480190>>1]){break f}Wd(d,b,e);Zd(d,1)}j=oc(g,f),k=c,n[j|0]=k;break e}c=r[a+480192>>1];if(!c){break e}while(1){e=c;c=p[((c<<2)+a|0)+900380>>2];g:{if(!c){break g}c=r[Yc(c+236|0,q[p[d+8>>2]]+ -1|0)>>1];if(c>>>0>r[a+480190>>1]){break g}Wd(d,b,c);Zd(d,1)}c=e+ -1|0;if((e&65535)!=1){continue}break}}uk(d+8|0);f=f+1|0;if(f>>>0<r[a+480188>>1]){continue}break c}break}break b}i=i+1|0;if(i>>>0<s[h+12>>2]){continue}break}break a}}a=I()|0;H()|0;Xd(g);L(a|0);E()}Qx(d+24|0);if(Ab(d+24|0,d+16|0)){continue}break}}c=r[a+480190>>1];h:{if(!c){f=0;break h}f=0;while(1){Wd(d,b,c);if(!tb(d)){f=ue((v(c,104)+a|0)+484380|0)+f|0}e=c&65535;c=c+ -1|0;if((e|0)!=1){continue}break}}Xd(g)}fb=d+48|0;return f&65535}function owa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0;e=fb-48|0;fb=e;r=p[a+16>>2];b=p[a+44>>2];p[e+32>>2]=b;h=p[a+48>>2];p[e+36>>2]=h;f=p[a+52>>2];p[e+40>>2]=f;l=p[a+56>>2];p[e+44>>2]=l;s=p[a+24>>2];t=p[a+20>>2];g=p[a+4>>2];i=p[a>>2];p[e+24>>2]=i;p[e+28>>2]=g;j=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=j;if(d){while(1){l=1;j=((((g&2147483647)<<1|i>>>31)&2147483646)<<1)+r|0;b=(i>>>21&2040)+27824|0;i=o[b+6>>1];k=o[b+4>>1];q=o[b+2>>1];m=o[b>>1];f=0;b=1;h=0;while(1){g=h<<1;p[(e+8|0)+(h<<2)>>2]=(((v(o[g+j>>1],q)+v(o[j+(g|-4)>>1],m)|0)+v(o[j+(g|4)>>1],k)|0)+v(i,o[j+(g|8)>>1])|0)/16384;g=b;b=0;h=1;if(g){continue}break}while(1){i=(e+8|0)+(f<<2)|0;j=p[i>>2];k=p[a+60>>2];g=(e+32|0)+(f<<3)|0;f=p[g>>2];b=Pb(f,-16777216,16776704);m=p[a+64>>2];h=Pb(p[g+4>>2],-16777216,16776704);n=p[a+68>>2];u=n;n=n>>31;p[g+4>>2]=f;w=p[a+72>>2];j=j<<8;f=j;f=NNa(k,k>>31,f,f>>31);k=ib;x=i;i=NNa(m,m>>31,b,b>>31);f=i+f|0;b=ib+k|0;b=f>>>0<i>>>0?b+1|0:b;q=f;f=NNa(u,n,h,h>>31);h=q+f|0;b=ib+b|0;b=h>>>0<f>>>0?b+1|0:b;h=h+8388608|0;if(h>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|h>>>24;p[x>>2]=(b|0)/256;p[g>>2]=b-(j&w);f=1;b=l&1;l=0;if(b){continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],t);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],s);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;i=p[e+24>>2];g=p[e+28>>2];continue}break}i=p[e+24>>2];g=p[e+28>>2];l=p[e+44>>2];f=p[e+40>>2];h=p[e+36>>2];b=p[e+32>>2]}p[a+56>>2]=l;p[a+52>>2]=f;p[a+48>>2]=h;p[a+44>>2]=b;p[a>>2]=i;p[a+4>>2]=g;fb=e+48|0}function Sta(a,b,c){var d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;f=Pk(d+56|0,a);p[114610]=0;e=J(686,d+8|0,18574)|0;a=p[114610];p[114610]=0;a:{b:{c:{d:{if((a|0)!=1){p[114610]=0;p[d+48>>2]=19464961;p[d+52>>2]=0;N(687,f|0,e|0,d+48|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}yb(e);if(!(p[f>>2]&1073741824)){break c}break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;yb(e);break b}p[114610]=0;n[d+48|0]=0;n[d+47|0]=0;e=J(686,d+8|0,18566)|0;a=p[114610];p[114610]=0;e:{if((a|0)!=1){p[114610]=0;P(1188,f|0,d+48|0,e|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}yb(e);if(!q[d+48|0]){break a}Ke(d+48|0,50);p[114610]=0;e=J(686,d+8|0,18582)|0;a=p[114610];p[114610]=0;f:{g:{h:{i:{if((a|0)!=1){p[114610]=0;P(1188,f|0,d+47|0,e|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break i}yb(e);e=Ah(b);a=q[d+48|0];if(e>>>0<a>>>0){e=_x(d+8|0,p[b+12>>2]);p[114610]=0;N(1189,b|0,a|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break h}pl(e)}e=r[li(b,0)+28>>1];n[d+7|0]=0;if(q[d+48|0]){a=0;while(1){Pe(li(b,a&255),e);a=li(b,q[d+7|0]);p[114610]=0;K(1190,d+8|0,d+7|0);g=p[114610];p[114610]=0;if((g|0)==1){break g}p[114610]=0;Q(1191,f|0,a|0,d+8|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break f}yb(d+8|0);a=q[d+7|0]+1|0;n[d+7|0]=a;if((a&255)>>>0<q[d+48|0]){continue}break}}a=q[d+47|0];c=Ah(b);n[b+16|0]=a>>>0<c>>>0?q[d+47|0]:0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;yb(e);break b}a=I()|0;H()|0;pl(e);break b}a=I()|0;H()|0;break b}a=I()|0;H()|0;yb(d+8|0);break b}a=I()|0;H()|0;break b}a=I()|0;H()|0;yb(e)}hg(f);L(a|0);E()}hg(f);fb=d+160|0}function yw(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-208|0;fb=d;a:{b:{c:{if(q[c|0]&2){if(p[b>>2]==-2147483648){e=nj(d+48|0,1,45);b=p[b>>2];p[114610]=0;p[d+188>>2]=b;N(137,d+192|0,d+188|0,c|0);b=p[114610];p[114610]=0;d:{e:{if((b|0)!=1){p[114610]=0;N(138,a|0,e|0,d+192|0);a=p[114610];p[114610]=0;if((a|0)==1){break e}pb(d+192|0);pb(e);break b}c=I()|0;H()|0;break d}c=I()|0;H()|0;pb(d+192|0)}pb(e);break a}e=p[b>>2];if((e|0)>-1){break c}e=nj(d+48|0,1,45);b=p[b>>2];p[114610]=0;p[d+188>>2]=0-b;N(137,d+192|0,d+188|0,c|0);b=p[114610];p[114610]=0;f:{g:{if((b|0)!=1){p[114610]=0;N(138,a|0,e|0,d+192|0);a=p[114610];p[114610]=0;if((a|0)==1){break g}pb(d+192|0);pb(e);break b}c=I()|0;H()|0;break f}c=I()|0;H()|0;pb(d+192|0)}pb(e);break a}e=Vg(d+48|0);f=p[p[e>>2]+ -12>>2];p[114610]=0;g=Y(122)|0;h=p[114610];p[114610]=0;h:{i:{j:{k:{l:{if((h|0)==1){break l}p[114610]=0;N(123,d+40|0,f+(d+48|0)|0,g|0);f=p[114610];p[114610]=0;if((f|0)==1){break l}Gb(d+40|0);p[114610]=0;K(139,e|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break l}p[114610]=0;K(124,e|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break l}p[114610]=0;K(125,d+8|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break l}p[114610]=0;N(140,d+24|0,d+8|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break k}p[114610]=0;N(141,a|0,d+24|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break j}pb(d+24|0);pb(d+8|0);Qd(e);break b}c=I()|0;H()|0;break h}c=I()|0;H()|0;break i}c=I()|0;H()|0;pb(d+24|0)}pb(d+8|0)}Qd(e);break a}p[d+48>>2]=e;Ar(a,d+48|0,c)}fb=d+208|0;return}L(c|0);E()}function Wra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;vd(b,2);mk(d+16|0,2,a+1|0);zc(d+32|0,d+16|0);p[114610]=0;J(370,b+43|0,d+32|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(d+32|0);a:{if(!(q[a|0]?q[a|0]!=1:0)){if(q[a|0]==1){c=a+16|0;p[b>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+20|0;p[d+32>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[d+16>>2]=p[b>>2]+ -1;f=b,g=p[Cb(d+32|0,d+16|0)>>2],p[f+4>>2]=g;c=a+24|0;p[d+32>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);f=b,g=p[Cb(d+32|0,b)>>2],p[f+8>>2]=g;o[b+34>>1]=r[b+34>>1]&65533|q[a+31|0]<<1&2}c=p[b+8>>2];if(c>>>0>s[b+4>>2]?c>>>0>=2:0){break a}o[b+34>>1]=0;p[b+4>>2]=0;p[b+8>>2]=0;break a}if(q[a|0]!=2){break a}jh(d+16|0,a+16|0);c=d+32|0;e=p[d+16>>2];e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);n[c|0]=e;n[c+1|0]=e>>>8;n[c+2|0]=e>>>16;n[c+3|0]=e>>>24;jh(d+16|0,a+20|0);c=d+32|0;e=p[d+16>>2];e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);n[c+4|0]=e;n[c+5|0]=e>>>8;n[c+6|0]=e>>>16;n[c+7|0]=e>>>24;jh(d+16|0,a+24|0);c=d+32|0;e=p[d+16>>2];e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);n[c+8|0]=e;n[c+9|0]=e>>>8;n[c+10|0]=e>>>16;n[c+11|0]=e>>>24;p[d+8>>2]=p[d+40>>2];c=p[d+36>>2];p[d>>2]=p[d+32>>2];p[d+4>>2]=c;Xo(b,1,d)}n[d+32|0]=q[a+28|0];n[d+16|0]=64;f=b,g=q[hc(d+32|0,d+16|0)|0]<<2,o[f+30>>1]=g;a=a+32|0;a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);p[b+24>>2]=a;b:{c:{if(!a){c=8363;break c}c=1024;if(a>>>0>1023){break b}}p[b+24>>2]=c}fb=d+48|0;return}a=I()|0;H()|0;pb(d+32|0);L(a|0);E()}function sva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0;f=fb-48|0;fb=f;m=p[a+16>>2];h=Df(f+16|0);p[h+8>>2]=a+112;p[h+16>>2]=p[a+128>>2];u=h,w=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[u+12>>2]=w;b=p[h+16>>2];if(b){u=h,w=Cf(a+8|0,b),p[u>>2]=w;p[h+4>>2]=ib}i=p[a+48>>2];n=p[a+24>>2];q=p[a+20>>2];k=p[a+44>>2];e=p[a+4>>2];g=p[a>>2];p[f+8>>2]=g;p[f+12>>2]=e;b=p[a+12>>2];p[f>>2]=p[a+8>>2];p[f+4>>2]=b;a:{if(!d){b=k;k=i;break a}while(1){b=0;j=b;p[f+40>>2]=g;p[f+44>>2]=b;e=(e<<1)+m|0;b:{b=p[h+16>>2];if((b|0)<=0){break b}while(1){qd(p[h+8>>2],o[(j<<1)+e>>1]/4<<16>>16);pd(p[h+8>>2],4);Kb(f+40|0,h);if((b|0)<2){break b}b=b+ -1|0;j=p[f+44>>2];continue}}d=d+ -1|0;b=p[h+8>>2];Kb(b,b+8|0);b=p[h+8>>2];g=p[b+4>>2];if(g){qd(b,o[e+(p[f+44>>2]<<1)>>1]/4<<16>>16);pd(p[h+8>>2],g);b=p[h+8>>2];g=p[b>>2];p[b>>2]=g;p[b+4>>2]=0}e=xf(b,p[h+12>>2]);g=p[a+60>>2];j=g;b=Pb(k,-16777216,16776704);l=p[a+64>>2];i=Pb(i,-16777216,16776704);r=p[a+72>>2];s=p[c>>2];t=g>>31;g=e<<8;e=g;e=NNa(j,t,e,e>>31);j=ib;l=NNa(l,l>>31,b,b>>31);e=l+e|0;b=ib+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=p[a+68>>2];e=NNa(e,e>>31,i,i>>31);i=j+e|0;b=ib+b|0;b=i>>>0<e>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|i>>>24;i=(b|0)/256|0;p[c>>2]=v(i,q)+s;p[c+4>>2]=p[c+4>>2]+v(i,n);b=b-(g&r)|0;Kb(f+8|0,f);if(d){c=c+8|0;g=p[f+8>>2];e=p[f+12>>2];i=k;k=b;continue}break}g=p[f+8>>2];e=p[f+12>>2]}p[a+48>>2]=k;p[a+44>>2]=b;p[a>>2]=g;p[a+4>>2]=e;fb=f+48|0}function pwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;e=fb-48|0;fb=e;s=p[a+16>>2];g=p[a+44>>2];p[e+32>>2]=g;b=p[a+48>>2];p[e+36>>2]=b;f=p[a+52>>2];p[e+40>>2]=f;l=p[a+56>>2];p[e+44>>2]=l;t=p[a+24>>2];u=p[a+20>>2];i=p[a+4>>2];h=p[a>>2];p[e+24>>2]=h;p[e+28>>2]=i;j=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=j;if(d){while(1){j=(((i&2147483647)<<1|h>>>31)&-2)+s|0;b=(h>>>21&2040)+27824|0;h=o[b+6>>1];k=o[b+4>>1];r=o[b+2>>1];m=o[b>>1];f=0;l=1;b=1;g=0;while(1){p[(e+8|0)+(g<<2)>>2]=(((v(n[g+j|0],r)+v(n[j+(g|-2)|0],m)|0)+v(n[j+(g|2)|0],k)|0)+v(h,n[j+(g|4)|0])<<8)/16384;i=b;b=0;g=1;if(i){continue}break}while(1){h=(e+8|0)+(f<<2)|0;j=p[h>>2];k=p[a+60>>2];i=(e+32|0)+(f<<3)|0;f=p[i>>2];b=Pb(f,-16777216,16776704);m=p[a+64>>2];g=Pb(p[i+4>>2],-16777216,16776704);q=p[a+68>>2];w=q;q=q>>31;p[i+4>>2]=f;x=p[a+72>>2];j=j<<8;f=j;f=NNa(k,k>>31,f,f>>31);k=ib;y=h;h=NNa(m,m>>31,b,b>>31);f=h+f|0;b=ib+k|0;b=f>>>0<h>>>0?b+1|0:b;r=f;f=NNa(w,q,g,g>>31);g=r+f|0;b=ib+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;p[y>>2]=(b|0)/256;p[i>>2]=b-(j&x);f=1;b=l&1;l=0;if(b){continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],u);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],t);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;h=p[e+24>>2];i=p[e+28>>2];continue}break}h=p[e+24>>2];i=p[e+28>>2];l=p[e+44>>2];f=p[e+40>>2];g=p[e+32>>2];b=p[e+36>>2]}p[a+56>>2]=l;p[a+52>>2]=f;p[a+48>>2]=b;p[a+44>>2]=g;p[a>>2]=h;p[a+4>>2]=i;fb=e+48|0}function r2(a,b,c,d,e){var f=0,g=0,h=w(0);f=fb-368|0;fb=f;p[f+352>>2]=b;p[f+360>>2]=a;Xu(f+200|0,c,f+224|0,f+220|0,f+216|0);b=Lb(f+184|0);a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;a:{b:{if((a|0)!=1){a=cc(b,0);p[f+180>>2]=a;p[f+12>>2]=f+16;p[f+8>>2]=0;n[f+7|0]=1;n[f+6|0]=69;while(1){c:{p[114610]=0;c=J(2454,f+360|0,f+352|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+180>>2]==(wb(b)+a|0)){c=wb(b);a=wb(b);p[114610]=0;K(149,b|0,a<<1);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=cc(b,0);p[f+180>>2]=c+a}p[114610]=0;c=M(2456,f+360|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Bq(c,f+7|0,f+6|0,a,f+180|0,p[f+220>>2],p[f+216>>2],f+200|0,f+16|0,f+12|0,f+8|0,f+224|0);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2458,f+360|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+200|0)|!q[f+7|0]){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;h=w(oa(2439,a|0,p[f+180>>2],d|0));a=p[114610];p[114610]=0;e:{if((a|0)==1){break e}t[e>>2]=h;p[114610]=0;we(f+200|0,f+16|0,p[f+12>>2],d);a=p[114610];p[114610]=0;if((a|0)==1){break e}p[114610]=0;a=J(2455,f+360|0,f+352|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(a){p[d>>2]=p[d>>2]|2}a=p[f+360>>2];pb(b);pb(f+200|0);fb=f+368|0;return a}}a=I()|0;H()|0;pb(b);pb(f+200|0);L(a|0);E()}function R2(a,b,c,d,e){var f=0,g=0,h=w(0);f=fb-272|0;fb=f;p[f+256>>2]=b;p[f+264>>2]=a;Zu(f+208|0,c,f+224|0,f+223|0,f+222|0);b=Lb(f+192|0);a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;a:{b:{if((a|0)!=1){a=cc(b,0);p[f+188>>2]=a;p[f+12>>2]=f+16;p[f+8>>2]=0;n[f+7|0]=1;n[f+6|0]=69;while(1){c:{p[114610]=0;c=J(2422,f+264|0,f+256|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(b)+a|0)){c=wb(b);a=wb(b);p[114610]=0;K(149,b|0,a<<1);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=cc(b,0);p[f+188>>2]=c+a}p[114610]=0;c=M(2424,f+264|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Dq(c,f+7|0,f+6|0,a,f+188|0,n[f+223|0],n[f+222|0],f+208|0,f+16|0,f+12|0,f+8|0,f+224|0);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2426,f+264|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)|!q[f+7|0]){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;h=w(oa(2439,a|0,p[f+188>>2],d|0));a=p[114610];p[114610]=0;e:{if((a|0)==1){break e}t[e>>2]=h;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);a=p[114610];p[114610]=0;if((a|0)==1){break e}p[114610]=0;a=J(2423,f+264|0,f+256|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(a){p[d>>2]=p[d>>2]|2}a=p[f+264>>2];pb(b);pb(f+208|0);fb=f+272|0;return a}}a=I()|0;H()|0;pb(b);pb(f+208|0);L(a|0);E()}function p2(a,b,c,d,e){var f=0,g=0,h=0;f=fb-368|0;fb=f;p[f+352>>2]=b;p[f+360>>2]=a;Xu(f+200|0,c,f+224|0,f+220|0,f+216|0);b=Lb(f+184|0);a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;a:{b:{if((a|0)!=1){a=cc(b,0);p[f+180>>2]=a;p[f+12>>2]=f+16;p[f+8>>2]=0;n[f+7|0]=1;n[f+6|0]=69;while(1){c:{p[114610]=0;c=J(2454,f+360|0,f+352|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+180>>2]==(wb(b)+a|0)){c=wb(b);a=wb(b);p[114610]=0;K(149,b|0,a<<1);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=cc(b,0);p[f+180>>2]=c+a}p[114610]=0;c=M(2456,f+360|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Bq(c,f+7|0,f+6|0,a,f+180|0,p[f+220>>2],p[f+216>>2],f+200|0,f+16|0,f+12|0,f+8|0,f+224|0);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2458,f+360|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+200|0)|!q[f+7|0]){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;h=+ha(2442,a|0,p[f+180>>2],d|0);a=p[114610];p[114610]=0;e:{if((a|0)==1){break e}u[e>>3]=h;p[114610]=0;we(f+200|0,f+16|0,p[f+12>>2],d);a=p[114610];p[114610]=0;if((a|0)==1){break e}p[114610]=0;a=J(2455,f+360|0,f+352|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(a){p[d>>2]=p[d>>2]|2}a=p[f+360>>2];pb(b);pb(f+200|0);fb=f+368|0;return a}}a=I()|0;H()|0;pb(b);pb(f+200|0);L(a|0);E()}function O2(a,b,c,d,e){var f=0,g=0,h=0;f=fb-272|0;fb=f;p[f+256>>2]=b;p[f+264>>2]=a;Zu(f+208|0,c,f+224|0,f+223|0,f+222|0);b=Lb(f+192|0);a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;a:{b:{if((a|0)!=1){a=cc(b,0);p[f+188>>2]=a;p[f+12>>2]=f+16;p[f+8>>2]=0;n[f+7|0]=1;n[f+6|0]=69;while(1){c:{p[114610]=0;c=J(2422,f+264|0,f+256|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(b)+a|0)){c=wb(b);a=wb(b);p[114610]=0;K(149,b|0,a<<1);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=Bc(b);p[114610]=0;K(149,b|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}a=cc(b,0);p[f+188>>2]=c+a}p[114610]=0;c=M(2424,f+264|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Dq(c,f+7|0,f+6|0,a,f+188|0,n[f+223|0],n[f+222|0],f+208|0,f+16|0,f+12|0,f+8|0,f+224|0);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2426,f+264|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)|!q[f+7|0]){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;h=+ha(2442,a|0,p[f+188>>2],d|0);a=p[114610];p[114610]=0;e:{if((a|0)==1){break e}u[e>>3]=h;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);a=p[114610];p[114610]=0;if((a|0)==1){break e}p[114610]=0;a=J(2423,f+264|0,f+256|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(a){p[d>>2]=p[d>>2]|2}a=p[f+264>>2];pb(b);pb(f+208|0);fb=f+272|0;return a}}a=I()|0;H()|0;pb(b);pb(f+208|0);L(a|0);E()}function px(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=92;i=91;j=85;k=84;l=83;m=5;n=107;o=106;p=96;c=88;q=82;r=80;s=78;t=79;u=77;v=57;w=47;d=10;e=8;f=7;a=tx(a);a:{b:{c:{d:{switch(b+ -1|0){default:c=(b|0)==16777216;if((b|0)!=32?!c:0){break c}Eb(a,0,1);Eb(a,7,1);Eb(a,8,1);Eb(a,9,1);Eb(a,10,1);Eb(a,11,1);Eb(a,12,1);Eb(a,13,1);Eb(a,14,1);Eb(a,15,1);Eb(a,16,1);Eb(a,17,1);Eb(a,18,1);Eb(a,19,1);Eb(a,20,1);Eb(a,21,1);Eb(a,22,1);Eb(a,23,1);Eb(a,24,1);Eb(a,25,1);Eb(a,26,1);Eb(a,27,1);Eb(a,28,1);Eb(a,29,1);Eb(a,30,1);Eb(a,31,1);Eb(a,32,1);Eb(a,33,1);Eb(a,34,1);Eb(a,35,1);Eb(a,36,1);Eb(a,37,1);Eb(a,38,1);Eb(a,39,1);Eb(a,40,1);Eb(a,41,1);Eb(a,42,1);Eb(a,43,1);Eb(a,44,1);Eb(a,45,1);Eb(a,46,1);Eb(a,47,1);Eb(a,48,1);Eb(a,103,1);Eb(a,50,1);Eb(a,87,1);Eb(a,88,1);Eb(a,100,1);Eb(a,102,1);Eb(a,104,1);if(!c){break a}d=108;e=105;f=99;break b;case 3:Eb(a,0,1);Eb(a,4,1);Eb(a,8,1);Eb(a,9,1);Eb(a,10,1);Eb(a,17,1);Eb(a,40,1);Eb(a,51,1);Eb(a,52,1);Eb(a,53,1);Eb(a,54,1);Eb(a,55,1);Eb(a,56,1);Eb(a,57,1);Eb(a,58,1);Eb(a,59,1);Eb(a,60,1);Eb(a,61,1);Eb(a,62,1);Eb(a,63,1);Eb(a,64,1);Eb(a,65,1);Eb(a,66,1);Eb(a,67,1);Eb(a,68,1);n=98;o=93;p=90;c=89;q=88;r=86;s=76;t=75;u=74;v=73;w=72;d=71;e=70;g=69;case 1:Eb(a,g,1);Eb(a,e,1);Eb(a,d,1);Eb(a,w,1);Eb(a,v,1);Eb(a,u,1);Eb(a,t,1);m=s;l=r;k=q;j=c;i=p;h=o;c=n;break;case 2:break c;case 0:break d}}Eb(a,m,1);Eb(a,l,1);Eb(a,k,1);g=j;f=i;e=h;d=c}Eb(a,g,1)}Eb(a,f,1);Eb(a,e,1);Eb(a,d,1)}}function Tsa(a){var b=0,c=0,d=0,e=0;b=fb-400|0;fb=b;IL(b+384|0,8);p[114610]=0;ka(1211,b+368|0,9);e=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((e|0)!=1){p[114610]=0;e=J(1212,b+352|0,14)|0;c=p[114610];p[114610]=0;if((c|0)==1){break k}p[114610]=0;K(1213,b+384|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break j}p[114610]=0;K(1213,b+368|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break j}HL(b+280|0,4900);HL(b+208|0,32e3);EL(b+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);p[114610]=0;c=J(1214,b+104|0,b+384|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break i}ls(b+120|0,b+280|0,c);zf(c);p[114610]=0;c=J(1214,b+72|0,b+368|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break h}ls(b+88|0,b+208|0,c);zf(c);p[114610]=0;c=J(1214,b+40|0,b+120|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}ls(b+56|0,b+136|0,c);zf(c);p[114610]=0;c=J(1214,b+8|0,b+88|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}ls(b+24|0,b+136|0,c);zf(c);So(b+120|0);So(b+56|0);So(b+88|0);So(b+24|0);So(b+368|0);Ro(b+120|0,hi(a,0));Ro(b+56|0,hi(a,1));Ro(b+88|0,hi(a,2));Ro(b+24|0,hi(a,3));Ro(b+368|0,hi(a,4));zf(b+24|0);zf(b+56|0);zf(b+88|0);zf(b+120|0);Qo(e);zf(b+368|0);zf(b+384|0);fb=b+400|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;break c}a=I()|0;H()|0;break c}a=I()|0;H()|0;break d}a=I()|0;H()|0;break e}a=I()|0;H()|0;zf(b+56|0)}zf(b+88|0)}zf(b+120|0)}Qo(e)}zf(b+368|0)}zf(b+384|0);L(a|0);E()}function qJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,s=0,t=0,u=0,w=0;c=fb-16|0;fb=c;d=v(b,896)+a|0;a:{if(p[d+1075072>>2]&134218752){break a}if(!Zi(d+1074984|0)){break a}h=p[(v(b,896)+a|0)+1075640>>2];if(q[h+15|0]&2){break a}d=Km(a,b,2,1);if(d+ -251>>>0<5|!d){break a}g=p[(v(d,160)+a|0)+906140>>2];if(!g){break a}e=v(b,896)+a|0;d=q[e+1075794|0];b:{if(q[e+1075796|0]==1){n[c+8|0]=64;f=q[hc(e+1075798|0,c+8|0)|0];break b}f=255;if(q[e+1075797|0]!=13){break b}n[c+8|0]=64;f=q[hc((v(b,896)+a|0)+1075799|0,c+8|0)|0]}j=a+1074308|0;vb(c+8|0,j,2);if(tb(c+8|0)){if(d){e=a;f=b;if(Ud(d)){d=q[Yb(h+108|0,d+ -1|0)|0]}Tj(e,f,d,r[(v(b,896)+a|0)+1075672>>1]);break a}if((f|0)==255){break a}m[p[p[g>>2]+76>>2]](g,39,f,b);break a}k=p[h+4>>2];if(d){e=k<<2;p[c+4>>2]=e;if(!q[h+35|0]){e=p[(v(b,896)+a|0)+1075672>>2];p[c+4>>2]=e}i=o[(v(b,896)+a|0)+1075772>>1];vb(c+8|0,j,28);l=c,s=(tb(c+8|0)?i<<2:i)+e|0,p[l+4>>2]=s;Vd(c+4|0,0,256);e=d;i=b;if(Ud(d)){e=q[Yb(h+108|0,d+ -1|0)|0]}Tj(a,i,e&255,r[c+4>>1])}e=q[h+35|0];vb(c+8|0,j,101);a=(d|0)!=0;c:{if(tb(c+8|0)){break c}a=Ud(d)}a=a^1;if(a|(e|0)!=1?!(a&(f|0)!=255):0){break a}d:{switch(q[h+36|0]){case 1:if((f|0)!=255){HH(g,f<<1);break a}HH(g,k<<1);break a;case 0:break d;default:break a}}if((f|0)!=255){n[c+8|0]=127;n[c+4|0]=f<<1;s=g,t=7,u=q[hc(c+8|0,c+4|0)|0],w=b,l=p[p[g>>2]+76>>2],m[l](s|0,t|0,u|0,w|0);break a}p[c+8>>2]=127;p[c+4>>2]=k<<1;w=g,u=7,t=q[Cb(c+8|0,c+4|0)|0],s=b,l=p[p[g>>2]+76>>2],m[l](w|0,u|0,t|0,s|0)}fb=c+16|0}function Nfa(a){var b=0,c=0,d=w(0),e=w(0),f=0,g=w(0),h=0,i=w(0),j=0,k=w(0),l=0;f=fb-16|0;fb=f;g=t[a+4268>>2];d=w(t[a+4232>>2]*w(.30000001192092896));t[f+12>>2]=t[a+4240>>2]*w(.10000000149011612);p[f+8>>2]=1000593162;b=a;i=t[xw(f+12|0,f+8|0)>>2];e=w(g*w(w(d+w(.007000000216066837))+i));a:{if(w(x(e))<w(2147483648)){c=~~e;break a}c=-2147483648}p[b+4352>>2]=c;b=1;while(1){h=((v(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=w(w(w(t[(b<<2)+33504>>2]*i)+d)*g);b:{if(w(x(e))<w(2147483648)){c=~~e;break b}c=-2147483648}p[h>>2]=c;b=b+1|0;if((b|0)!=12){continue}break}t[f+12>>2]=w(w(t[a+4248>>2]*w(100))*w(.009091000072658062))+w(.09091000258922577);p[f+8>>2]=1065353216;d=w(t[bl(f+12|0,f+8|0)>>2]*g);i=w(d*w(.07500000298023224));d=w(d*w(.06700000166893005));b=0;while(1){c=(b<<2)+a|0;l=c+4316|0;j=b+j|0;e=fe(w(.9300000071525574),w(j|0));k=w(i*e);c:{if(w(x(k))<w(2147483648)){h=~~k;break c}h=-2147483648}p[l>>2]=h;h=c+4292|0;e=w(d*e);d:{if(w(x(e))<w(2147483648)){c=~~e;break d}c=-2147483648}p[h>>2]=c;b=b+1|0;if((b|0)!=6){continue}break}c=a+4348|0;d=w(g*w(.0035299998708069324));e:{if(w(x(d))<w(2147483648)){b=~~d;break e}b=-2147483648}p[c>>2]=b;c=a+4344|0;d=w(g*w(.0032500000670552254));f:{if(w(x(d))<w(2147483648)){b=~~d;break f}b=-2147483648}p[c>>2]=b;c=a+4340|0;g=w(g*w(.009999999776482582));g:{if(w(x(g))<w(2147483648)){b=~~g;break g}b=-2147483648}p[c>>2]=b;b=0;while(1){kH((v(b,24)+a|0)+4504|0,p[((b<<2)+a|0)+4292>>2]);b=b+1|0;if(b>>>0<15){continue}break}fb=f+16|0}function Fva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;i=fb-16|0;fb=i;f=p[a+48>>2];m=p[a+40>>2];n=p[a+36>>2];e=p[a+44>>2];s=p[a+16>>2];g=p[a+4>>2];j=p[a>>2];p[i+8>>2]=j;p[i+12>>2]=g;h=p[a+12>>2];p[i>>2]=p[a+8>>2];p[i+4>>2]=h;a:{if(!d){k=m>>12;q=n>>12;break a}while(1){h=(g<<1)+s|0;k=o[h+ -6>>1];g=(((j>>>16|0)+4&131064)<<1)+b|0;j=o[g+24>>1];q=o[h+ -4>>1];t=o[g+26>>1];u=o[h+ -2>>1];w=o[g+28>>1];x=o[h>>1];y=o[g+30>>1];z=o[h+2>>1];A=o[g+32>>1];B=o[h+4>>1];C=o[g+34>>1];D=o[h+6>>1];E=o[g+36>>1];F=o[h+8>>1];G=o[g+38>>1];h=p[a+60>>2];H=h;I=h>>31;h=e;e=Pb(e,-16777216,16776704);l=p[a+64>>2];f=Pb(f,-16777216,16776704);J=p[a+72>>2];K=p[a+32>>2];g=c;L=p[g>>2];e=NNa(l,l>>31,e,e>>31);l=ib;M=e;e=p[a+68>>2];r=NNa(e,e>>31,f,f>>31);e=M+r|0;f=ib+l|0;f=e>>>0<r>>>0?f+1|0:f;l=e;j=(((((v(B,C)+v(z,A)|0)+v(D,E)|0)+v(F,G)|0)/2|0)+((((v(q,t)+v(j,k)|0)+v(u,w)|0)+v(x,y)|0)/2|0)|0)/16384<<8;e=j;k=NNa(H,I,e,e>>31);e=l+k|0;f=ib+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;n=p[a+28>>2]+n|0;q=n>>12;p[g>>2]=v(f,q)+L;m=m+K|0;k=m>>12;p[c+4>>2]=p[c+4>>2]+v(f,k);e=e-(j&J)|0;Kb(i+8|0,i);d=d+ -1|0;if(d){c=c+8|0;j=p[i+8>>2];g=p[i+12>>2];f=h;continue}break}j=p[i+8>>2];g=p[i+12>>2];f=h}p[a+40>>2]=m;p[a+20>>2]=q;p[a+36>>2]=n;p[a+48>>2]=f;p[a+44>>2]=e;p[a+24>>2]=k;p[a>>2]=j;p[a+4>>2]=g;fb=i+16|0}function tva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;f=fb-48|0;fb=f;m=p[a+16>>2];h=Df(f+16|0);p[h+8>>2]=a+112;p[h+16>>2]=p[a+128>>2];u=h,w=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[u+12>>2]=w;b=p[h+16>>2];if(b){u=h,w=Cf(a+8|0,b),p[u>>2]=w;p[h+4>>2]=ib}i=p[a+48>>2];o=p[a+24>>2];q=p[a+20>>2];k=p[a+44>>2];e=p[a+4>>2];g=p[a>>2];p[f+8>>2]=g;p[f+12>>2]=e;b=p[a+12>>2];p[f>>2]=p[a+8>>2];p[f+4>>2]=b;a:{if(!d){b=k;k=i;break a}while(1){b=0;j=b;p[f+40>>2]=g;p[f+44>>2]=b;e=e+m|0;b:{b=p[h+16>>2];if((b|0)<=0){break b}while(1){qd(p[h+8>>2],n[e+j|0]<<6);pd(p[h+8>>2],4);Kb(f+40|0,h);if((b|0)<2){break b}b=b+ -1|0;j=p[f+44>>2];continue}}d=d+ -1|0;b=p[h+8>>2];Kb(b,b+8|0);b=p[h+8>>2];g=p[b+4>>2];if(g){qd(b,n[e+p[f+44>>2]|0]<<6);pd(p[h+8>>2],g);b=p[h+8>>2];g=p[b>>2];p[b>>2]=g;p[b+4>>2]=0}e=xf(b,p[h+12>>2]);g=p[a+60>>2];j=g;b=Pb(k,-16777216,16776704);l=p[a+64>>2];i=Pb(i,-16777216,16776704);r=p[a+72>>2];s=p[c>>2];t=g>>31;g=e<<8;e=g;e=NNa(j,t,e,e>>31);j=ib;l=NNa(l,l>>31,b,b>>31);e=l+e|0;b=ib+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=p[a+68>>2];e=NNa(e,e>>31,i,i>>31);i=j+e|0;b=ib+b|0;b=i>>>0<e>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|i>>>24;i=(b|0)/256|0;p[c>>2]=v(i,q)+s;p[c+4>>2]=p[c+4>>2]+v(i,o);b=b-(g&r)|0;Kb(f+8|0,f);if(d){c=c+8|0;g=p[f+8>>2];e=p[f+12>>2];i=k;k=b;continue}break}g=p[f+8>>2];e=p[f+12>>2]}p[a+48>>2]=k;p[a+44>>2]=b;p[a>>2]=g;p[a+4>>2]=e;fb=f+48|0}function Gva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=fb-16|0;fb=i;f=p[a+48>>2];m=p[a+40>>2];q=p[a+36>>2];e=p[a+44>>2];t=p[a+16>>2];g=p[a+4>>2];j=p[a>>2];p[i+8>>2]=j;p[i+12>>2]=g;h=p[a+12>>2];p[i>>2]=p[a+8>>2];p[i+4>>2]=h;a:{if(!d){k=m>>12;r=q>>12;break a}while(1){h=g+t|0;k=n[h+ -3|0];g=(((j>>>16|0)+4&131064)<<1)+b|0;j=o[g+24>>1];r=n[h+ -2|0];u=o[g+26>>1];w=n[h+ -1|0];x=o[g+28>>1];y=n[h|0];z=o[g+30>>1];A=n[h+1|0];B=o[g+32>>1];C=n[h+2|0];D=o[g+34>>1];E=n[h+3|0];F=o[g+36>>1];G=n[h+4|0];H=o[g+38>>1];h=p[a+60>>2];I=h;J=h>>31;h=e;e=Pb(e,-16777216,16776704);l=p[a+64>>2];f=Pb(f,-16777216,16776704);K=p[a+72>>2];L=p[a+32>>2];g=c;M=p[g>>2];e=NNa(l,l>>31,e,e>>31);l=ib;N=e;e=p[a+68>>2];s=NNa(e,e>>31,f,f>>31);e=N+s|0;f=ib+l|0;f=e>>>0<s>>>0?f+1|0:f;l=e;j=(((((v(C,D)+v(A,B)|0)+v(E,F)|0)+v(G,H)<<8)/2|0)+((((v(r,u)+v(j,k)|0)+v(w,x)|0)+v(y,z)<<8)/2|0)|0)/16384<<8;e=j;k=NNa(I,J,e,e>>31);e=l+k|0;f=ib+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;q=p[a+28>>2]+q|0;r=q>>12;p[g>>2]=v(f,r)+M;m=m+L|0;k=m>>12;p[c+4>>2]=p[c+4>>2]+v(f,k);e=e-(j&K)|0;Kb(i+8|0,i);d=d+ -1|0;if(d){c=c+8|0;j=p[i+8>>2];g=p[i+12>>2];f=h;continue}break}j=p[i+8>>2];g=p[i+12>>2];f=h}p[a+40>>2]=m;p[a+20>>2]=r;p[a+36>>2]=q;p[a+48>>2]=f;p[a+44>>2]=e;p[a+24>>2]=k;p[a>>2]=j;p[a+4>>2]=g;fb=i+16|0}function Qwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0;b=fb-48|0;fb=b;u=p[a+16>>2];j=p[a+44>>2];p[b+32>>2]=j;l=p[a+48>>2];p[b+36>>2]=l;g=p[a+52>>2];p[b+40>>2]=g;h=p[a+56>>2];p[b+44>>2]=h;m=p[a+40>>2];n=p[a+36>>2];e=p[a+4>>2];i=p[a>>2];p[b+24>>2]=i;p[b+28>>2]=e;f=p[a+12>>2];p[b+16>>2]=p[a+8>>2];p[b+20>>2]=f;a:{if(!d){k=m>>12;f=n>>12;break a}while(1){e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+u|0;h=o[e>>1];p[b+8>>2]=h;p[b+12>>2]=o[e+2>>1];f=0;l=1;while(1){g=p[a+60>>2];k=g;i=(b+32|0)+(f<<3)|0;q=p[i>>2];e=Pb(q,-16777216,16776704);t=p[a+64>>2];j=Pb(p[i+4>>2],-16777216,16776704);r=p[a+68>>2];w=r;r=r>>31;p[i+4>>2]=q;q=p[a+72>>2];s=g>>31;h=h<<8;g=h;g=NNa(k,s,g,g>>31);k=ib;s=(b+8|0)+(f<<2)|0;f=g;g=NNa(t,t>>31,e,e>>31);f=f+g|0;e=ib+k|0;e=f>>>0<g>>>0?e+1|0:e;j=NNa(w,r,j,j>>31);f=j+f|0;e=ib+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;p[s>>2]=(e|0)/256;p[i>>2]=e-(h&q);if(l){f=1;l=0;h=p[b+12>>2];continue}break}e=p[a+32>>2];n=p[a+28>>2]+n|0;f=n>>12;p[c>>2]=p[c>>2]+v(f,p[b+8>>2]);m=e+m|0;k=m>>12;p[c+4>>2]=p[c+4>>2]+v(k,p[b+12>>2]);Kb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;i=p[b+24>>2];e=p[b+28>>2];continue}break}i=p[b+24>>2];e=p[b+28>>2];h=p[b+44>>2];g=p[b+40>>2];l=p[b+36>>2];j=p[b+32>>2]}p[a+40>>2]=m;p[a+20>>2]=f;p[a+36>>2]=n;p[a+56>>2]=h;p[a+52>>2]=g;p[a+48>>2]=l;p[a+44>>2]=j;p[a+24>>2]=k;p[a>>2]=i;p[a+4>>2]=e;fb=b+48|0}function t2(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-352|0;fb=f;p[f+336>>2]=b;p[f+344>>2]=a;h=Ng(c);i=fm(c,f+224|0);em(f+208|0,c,f+332|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2454,f+344|0,f+336|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2456,f+344|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Dj(c,h,b,f+188|0,f+8|0,p[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2458,f+344|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=Qn(2437,b,p[f+188>>2],d,h);c=ib;h=p[114610];p[114610]=0;e:{if((h|0)==1){break e}p[e>>2]=b;p[e+4>>2]=c;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2455,f+344|0,f+336|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+344>>2];pb(a);pb(f+208|0);fb=f+352|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function C2(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-352|0;fb=f;p[f+336>>2]=b;p[f+344>>2]=a;h=Ng(c);i=fm(c,f+224|0);em(f+208|0,c,f+332|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2454,f+344|0,f+336|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2456,f+344|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Dj(c,h,b,f+188|0,f+8|0,p[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2458,f+344|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=Qn(2433,b,p[f+188>>2],d,h);c=ib;h=p[114610];p[114610]=0;e:{if((h|0)==1){break e}p[e>>2]=b;p[e+4>>2]=c;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2455,f+344|0,f+336|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+344>>2];pb(a);pb(f+208|0);fb=f+352|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function Ula(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,p=0,s=0,t=0;f=fb-16|0;fb=f;a:{if(Ys(a)){break a}l=d+484344|0;i=sd(td(a)+1|0,1,1024);if(!ag(l,b,i)){break a}d=r[d+480188>>1];if(!d|!i){break a}m=d+ -1|0;while(1){if(!Hb(a,1)){break a}g=td(a);b:{if(!g){j=j+1|0;break b}d=Rb(l,b);o[f+14>>1]=g&31;o[f+12>>1]=m;d=_e(d,j,r[rf(f+14|0,f+12|0)>>1]);if(!(g&224)){break b}c:{if(!(g&128)){break c}s=d,t=td(a),n[s+5|0]=t;d:{e=td(a);if(e>>>0>=26){break d}e=q[e+31760|0];n[d+3|0]=e;e:{switch(e+ -1|0){case 0:if(!q[d+5|0]){break d}break c;case 12:if(q[d+2|0]){break c}n[d+2|0]=1;e=sd(q[d+5|0],0,64);n[d+5|0]=0;n[d+3|0]=0;n[d+4|0]=e;break c;case 5:case 6:case 10:case 23:case 28:e=q[d+5|0]&240;if(!e){break c}n[d+5|0]=e;break c;case 8:e=q[d+5|0];if(e>>>0<=128){s=d,t=kk(e<<1),n[s+5|0]=t;break c}if((e|0)!=164){break c}n[d+5|0]=145;n[d+3|0]=20;break c;case 13:e=q[d+5|0];n[d+5|0]=v(e>>>4|0,10)+(e&15);break c;case 18:Sw(d);break c;case 16:if(q[d+5|0]>31){break c}n[d+3|0]=16;break c;case 27:break e;default:break c}}p=d;e=q[d+5|0];h=e&240;k=2;f:{g:{if((h|0)==16){break g}if((h|0)!=32){break f}k=3}n[p+3|0]=k}n[d+5|0]=e&15|224;break c}n[d+3|0]=0}h:{if(!(g&64)){break h}Dt(f+8|0,a);e=Zc(f+8|0);n[d+1|0]=q[f+8|0];e=q[e|0];n[d|0]=e;h=255;if((e|0)!=128){h=253;if(e>>>0<129){break h}}n[d|0]=h}if(!(g&32)){break b}n[d+2|0]=1;e=td(a);n[d+4|0]=e;if(!c){break b}n[d+4|0]=(e<<6>>>0)/127}if(j>>>0<i>>>0){continue}break}}fb=f+16|0}function Ssa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-48|0;fb=d;e=GL(d+32|0,1<<p[b+12>>2]);if(ng(a)){while(1){g=u[Fk(a,c)>>3];FL(jc(e,c),g);c=c+1|0;if(c>>>0<ng(a)>>>0){continue}break}}p[114610]=0;K(1216,b|0,e|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}h=d,i=Ub(e),p[h>>2]=i;h=d,i=Vb(e),p[h+24>>2]=i;b:{if(Ab(d,d+24|0)){while(1){c=p[d>>2];p[114610]=0;g=+ea(1217,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break b}FL(c,eo(g));Ff(d);if(Ab(d,d+24|0)){continue}break}}p[114610]=0;K(1218,b|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}p[114610]=0;S(1219,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}if(gd(e)>>>0>3){c=1;while(1){Tx(jc(e,c),2);Tx(jc(e,(gd(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<gd(e)>>>1>>>0){continue}break}}p[114610]=0;K(1216,b|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}h=d,i=Ub(e),p[h+24>>2]=i;h=d,i=Vb(e),p[h+16>>2]=i;if(Ab(d+24|0,d+16|0)){while(1){c=p[d+24>>2];p[114610]=0;K(1220,d|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break b}f=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=f;f=p[d+12>>2];p[c+8>>2]=p[d+8>>2];p[c+12>>2]=f;Ff(d+24|0);if(Ab(d+24|0,d+16|0)){continue}break}}p[114610]=0;K(1218,b|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;S(1219,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}if(ng(a)){c=0;while(1){g=u[jc(e,c)>>3];h=Fk(a,c),j=g,u[h>>3]=j;c=c+1|0;if(c>>>0<ng(a)>>>0){continue}break}}Qo(e);fb=d+48|0;return}}a=I()|0;H()|0;Qo(e);L(a|0);E()}function Rwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;b=fb-48|0;fb=b;u=p[a+16>>2];j=p[a+44>>2];p[b+32>>2]=j;l=p[a+48>>2];p[b+36>>2]=l;g=p[a+52>>2];p[b+40>>2]=g;h=p[a+56>>2];p[b+44>>2]=h;m=p[a+40>>2];o=p[a+36>>2];e=p[a+4>>2];i=p[a>>2];p[b+24>>2]=i;p[b+28>>2]=e;f=p[a+12>>2];p[b+16>>2]=p[a+8>>2];p[b+20>>2]=f;a:{if(!d){k=m>>12;f=o>>12;break a}while(1){e=(((e&2147483647)<<1|i>>>31)&-2)+u|0;h=n[e|0]<<8;p[b+8>>2]=h;p[b+12>>2]=n[e+1|0]<<8;f=0;l=1;while(1){g=p[a+60>>2];k=g;i=(b+32|0)+(f<<3)|0;q=p[i>>2];e=Pb(q,-16777216,16776704);t=p[a+64>>2];j=Pb(p[i+4>>2],-16777216,16776704);r=p[a+68>>2];w=r;r=r>>31;p[i+4>>2]=q;q=p[a+72>>2];s=g>>31;h=h<<8;g=h;g=NNa(k,s,g,g>>31);k=ib;s=(b+8|0)+(f<<2)|0;f=g;g=NNa(t,t>>31,e,e>>31);f=f+g|0;e=ib+k|0;e=f>>>0<g>>>0?e+1|0:e;j=NNa(w,r,j,j>>31);f=j+f|0;e=ib+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;p[s>>2]=(e|0)/256;p[i>>2]=e-(h&q);if(l){f=1;l=0;h=p[b+12>>2];continue}break}e=p[a+32>>2];o=p[a+28>>2]+o|0;f=o>>12;p[c>>2]=p[c>>2]+v(f,p[b+8>>2]);m=e+m|0;k=m>>12;p[c+4>>2]=p[c+4>>2]+v(k,p[b+12>>2]);Kb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;i=p[b+24>>2];e=p[b+28>>2];continue}break}i=p[b+24>>2];e=p[b+28>>2];h=p[b+44>>2];g=p[b+40>>2];l=p[b+36>>2];j=p[b+32>>2]}p[a+40>>2]=m;p[a+20>>2]=f;p[a+36>>2]=o;p[a+56>>2]=h;p[a+52>>2]=g;p[a+48>>2]=l;p[a+44>>2]=j;p[a+24>>2]=k;p[a>>2]=i;p[a+4>>2]=e;fb=b+48|0}function x2(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-352|0;fb=f;p[f+336>>2]=b;p[f+344>>2]=a;h=Ng(c);i=fm(c,f+224|0);em(f+208|0,c,f+332|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2454,f+344|0,f+336|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2456,f+344|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Dj(c,h,b,f+188|0,f+8|0,p[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2458,f+344|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=U(2435,b|0,p[f+188>>2],d|0,h|0)|0;c=p[114610];p[114610]=0;e:{if((c|0)==1){break e}p[e>>2]=b;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2455,f+344|0,f+336|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+344>>2];pb(a);pb(f+208|0);fb=f+352|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function v2(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-352|0;fb=f;p[f+336>>2]=b;p[f+344>>2]=a;h=Ng(c);i=fm(c,f+224|0);em(f+208|0,c,f+332|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2454,f+344|0,f+336|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2456,f+344|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Dj(c,h,b,f+188|0,f+8|0,p[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2458,f+344|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=U(2436,b|0,p[f+188>>2],d|0,h|0)|0;c=p[114610];p[114610]=0;e:{if((c|0)==1){break e}p[e>>2]=b;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2455,f+344|0,f+336|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+344>>2];pb(a);pb(f+208|0);fb=f+352|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function E2(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-352|0;fb=f;p[f+336>>2]=b;p[f+344>>2]=a;h=Ng(c);i=fm(c,f+224|0);em(f+208|0,c,f+332|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2454,f+344|0,f+336|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2456,f+344|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Dj(c,h,b,f+188|0,f+8|0,p[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2458,f+344|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=U(2429,b|0,p[f+188>>2],d|0,h|0)|0;c=p[114610];p[114610]=0;e:{if((c|0)==1){break e}p[e>>2]=b;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2455,f+344|0,f+336|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+344>>2];pb(a);pb(f+208|0);fb=f+352|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function A2(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-352|0;fb=f;p[f+336>>2]=b;p[f+344>>2]=a;h=Ng(c);i=fm(c,f+224|0);em(f+208|0,c,f+332|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2454,f+344|0,f+336|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2456,f+344|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Dj(c,h,b,f+188|0,f+8|0,p[f+332>>2],f+208|0,f+16|0,f+12|0,i);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2458,f+344|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=U(2434,b|0,p[f+188>>2],d|0,h|0)|0;c=p[114610];p[114610]=0;e:{if((c|0)==1){break e}o[e>>1]=b;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2455,f+344|0,f+336|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+344>>2];pb(a);pb(f+208|0);fb=f+352|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function iDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=q[f+4|0];j=Yb(h,d),k=i+1|0,n[j|0]=k;f=f+6|0;f=q[f|0]|q[f+1|0]<<8;j=Yc(g,d),k=f+1|0,o[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=q[h|0]|q[h+1|0]<<8;j=Yc(g,d+12|0),k=h+1|0,o[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}Ly(a+484|0,b+48|0,0);Ly(a+590|0,b+68|0,0);Ly(a+696|0,b+88|0,5);d=a+806|0;p[b>>2]=q[d|0]|q[d+1|0]<<8;d=a+808|0;g=q[d|0];b:{if(n[d|0]<=-1){n[b+34|0]=g+ -127;break b}if(!(!(n[a|0]&1)|g>>>0>16)){n[b+31|0]=q[d|0]+1;break b}if(!q[d|0]|q[d|0]>16){break b}n[b+31|0]=q[d|0]+1}if(q[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(n[d|0]>=0){o[b+28>>1]=q[d|0]+1}d=a+810|0;if(n[d|0]<0){break c}}n[b+30|0]=q[d|0]+1}n[b+33|0]=q[a+811|0]}if((c|0)==32){n[e+15|0]=q[a+812|0];n[e+14|0]=128;j=b,k=q[hc(e+15|0,e+14|0)|0]>>>1|0,p[j+4>>2]=k}c=a+813|0;if((q[c|0]|q[c+1|0]<<8)>>>0<=256){p[b+8>>2]=q[c|0]|q[c+1|0]<<8;n[b+15|0]=q[b+15|0]|1}n[b+16|0]=q[a+815|0];n[b+26|0]=q[a+816|0];n[b+27|0]=q[a+817|0];n[b+17|0]=q[a+818|0];n[b+18|0]=q[a+819|0];c=a+820|0;o[e+12>>1]=q[c|0]|q[c+1|0]<<8;o[e+10>>1]=100;j=b,k=q[rf(e+12|0,e+10|0)|0],n[j+20|0]=k;c=a+822|0;o[e+8>>1]=q[c|0]|q[c+1|0]<<8;o[e+6>>1]=256;j=b,k=r[rf(e+8|0,e+6|0)>>1]>>>2|0,n[j+19|0]=k;c=a+824|0;Mt(b,q[c|0]&127,n[c|0]<0);a=a+825|0;Lt(b,q[a|0]&127,n[a|0]<0);fb=e+16|0}function jfa(a,b,c){var d=0,e=0,f=w(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=w(0);e=p[a+24>>2];p[b>>2]=e;d=p[a+16>>2];p[b+4>>2]=d;p[b+8>>2]=p[a+4>>2];h=(e|0)>(d|0)?e:d;if((h|0)<=-601){g=d;d=h+600|0;p[b+4>>2]=g-d;p[b>>2]=e-d}d=b;f=w(t[a+36>>2]*w(79.30999755859375));a:{if(w(x(f))<w(2147483648)){e=~~f;break a}e=-2147483648}p[d+16>>2]=e- -8192;e=b;f=w(w(t[a+32>>2]*w(117.9612045288086))+w(4915.05029296875));b:{if(w(x(f))<w(2147483648)){d=~~f;break b}d=-2147483648}p[e+20>>2]=(d|0)<32512?d:32512;h=0;f=w(w(z(t[a+20>>2],w(.10000000149011612)))*c);c:{if(w(x(f))<w(2147483648)){e=~~f;break c}e=-2147483648}d=(e|0)<96;i=d?96:e;j=(i|0)>7500;g=j?i+ -7500|0:0;d=d?e+ -96|0:0;f=w(t[a+28>>2]*c);d:{if(w(x(f))<w(2147483648)){e=~~f;break d}e=-2147483648}f=t[a+8>>2];e=g+(d+e|0)|0;d=(e|0)<128;g=d?128:e;k=(g|0)>3800;l=k?3800:g;p[b+24>>2]=l;e=d?e+ -128|0:0;d=b;c=w(f*c);e:{if(w(x(c))<w(2147483648)){m=~~c;break e}m=-2147483648}g=(m+e|0)+(k?g+ -3800|0:0)|0;p[d+32>>2]=g;i=j?7500:i;while(1){d=v(h,12);e=d+b|0;d=d+33936|0;o[e+42>>1]=r[d+10>>1];o[e+36>>1]=r[d+4>>1];j=r[d+6>>1]|r[d+8>>1]<<16;o[e+38>>1]=j;o[e+40>>1]=j>>>16;p[e+44>>2]=i+((v(p[d>>2],l)+50|0)/100|0);h=h+1|0;if((h|0)!=8){continue}break}d=b;c=w(g|0);f=w(fe(w(.0010000000474974513),(g|0)<4721?w(1):w(w(4720)/c))*w(32768));f:{if(w(x(f))<w(2147483648)){e=~~f;break f}e=-2147483648}p[d+12>>2]=e;c=w(t[a+12>>2]*c);n=b,q=fe(w(.0010000000474974513),c>w(4720)?w(w(4720)/c):w(1)),t[n+28>>2]=q}function Aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=fb-176|0;fb=b;d=Mb(b+8|0,38630);p[114610]=0;J(85,b+20|0,38635)|0;e=p[114610];p[114610]=0;c=1;a:{b:{if((e|0)==1){break b}p[114610]=0;J(85,b+32|0,38645)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=2;break b}p[114610]=0;J(85,b+44|0,38658)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=3;break b}p[114610]=0;J(85,b+56|0,38676)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=4;break b}p[114610]=0;J(85,b+68|0,38686)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=5;break b}p[114610]=0;J(85,b+80|0,38701)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=6;break b}p[114610]=0;J(85,b+92|0,38709)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=7;break b}p[114610]=0;J(85,b+104|0,38716)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=8;break b}p[114610]=0;J(85,b+116|0,38722)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=9;break b}p[114610]=0;J(85,b+128|0,38727)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=10;break b}p[114610]=0;J(85,b+140|0,38735)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=11;break b}p[114610]=0;J(85,b+152|0,38747)|0;c=p[114610];p[114610]=0;if((c|0)==1){c=12;break b}p[114610]=0;p[b+172>>2]=13;p[b+168>>2]=d;c=p[b+172>>2];p[b>>2]=p[b+168>>2];p[b+4>>2]=c;J(2179,a|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){c=b+164|0;while(1){c=pb(c+ -12|0);if((d|0)!=(c|0)){continue}break}fb=b+176|0;return}c=b+164|0;break a}c=(b+8|0)+v(c,12)|0}a=I()|0;H()|0;while(1){c=pb(c+ -12|0);if((d|0)!=(c|0)){continue}break}L(a|0);E()}function c3(a,b,c,d,e){var f=0,g=0,h=0;f=fb-272|0;fb=f;p[f+256>>2]=b;p[f+264>>2]=a;h=Ng(c);gm(f+208|0,c,f+255|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2422,f+264|0,f+256|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2424,f+264|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Ej(c,h,b,f+188|0,f+8|0,n[f+255|0],f+208|0,f+16|0,f+12|0,62096);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2426,f+264|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=Qn(2433,b,p[f+188>>2],d,h);c=ib;h=p[114610];p[114610]=0;e:{if((h|0)==1){break e}p[e>>2]=b;p[e+4>>2]=c;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2423,f+264|0,f+256|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+264>>2];pb(a);pb(f+208|0);fb=f+272|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function U2(a,b,c,d,e){var f=0,g=0,h=0;f=fb-272|0;fb=f;p[f+256>>2]=b;p[f+264>>2]=a;h=Ng(c);gm(f+208|0,c,f+255|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2422,f+264|0,f+256|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2424,f+264|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Ej(c,h,b,f+188|0,f+8|0,n[f+255|0],f+208|0,f+16|0,f+12|0,62096);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2426,f+264|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=Qn(2437,b,p[f+188>>2],d,h);c=ib;h=p[114610];p[114610]=0;e:{if((h|0)==1){break e}p[e>>2]=b;p[e+4>>2]=c;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2423,f+264|0,f+256|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+264>>2];pb(a);pb(f+208|0);fb=f+272|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function kF(a){var b=0,c=0,d=0,e=0;Od(a,p[a+20>>2]);if(p[a+24>>2]>=1){while(1){Od(a,p[p[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<p[a+24>>2]){continue}break}}Od(a,p[a+28>>2]);a:{b=p[a+396>>2];if(!b|p[a+264>>2]<1){break a}while(1){c=v(e,24)+b|0;b=p[c+16>>2];if(b){d=a;if(p[(p[a+124>>2]+v(q[c+13|0],2096)|0)+4>>2]>=1){Od(a,p[b>>2]);b=1;if(p[(p[a+124>>2]+v(q[c+13|0],2096)|0)+4>>2]>=2){while(1){Od(a,p[p[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<p[(p[a+124>>2]+v(q[c+13|0],2096)|0)+4>>2]){continue}break}}b=p[c+16>>2]}Od(d,b)}Od(a,p[c+20>>2]);e=e+1|0;if((e|0)>=p[a+264>>2]){break a}b=p[a+396>>2];continue}}b=p[a+124>>2];if(b){d=a;if(p[a+120>>2]>=1){c=0;while(1){b=v(c,2096)+b|0;Od(a,p[b+8>>2]);Od(a,p[b+28>>2]);Od(a,p[b+32>>2]);Od(a,p[b+2084>>2]);b=p[b+2088>>2];Od(a,b?b+ -4|0:0);c=c+1|0;if((c|0)<p[a+120>>2]){b=p[a+124>>2];continue}break}b=p[a+124>>2]}Od(d,b)}Od(a,p[a+260>>2]);Od(a,p[a+396>>2]);d=p[a+404>>2];if(d){b=1;c=a;if(p[a+400>>2]>=1){Od(a,p[d+4>>2]);if(p[a+400>>2]>=2){while(1){Od(a,p[(p[a+404>>2]+v(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<p[a+400>>2]){continue}break}}d=p[a+404>>2]}Od(c,d)}c=1;b:{if(p[a+4>>2]<1){break b}b=0;while(1){d=(b<<2)+a|0;Od(a,p[d+800>>2]);Od(a,p[d+928>>2]);Od(a,p[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<p[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;Od(a,p[b+1068>>2]);Od(a,p[b+1076>>2]);Od(a,p[b+1084>>2]);Od(a,p[b+1092>>2]);Od(a,p[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function f3(a,b,c,d,e){var f=0,g=0,h=0;f=fb-272|0;fb=f;p[f+256>>2]=b;p[f+264>>2]=a;h=Ng(c);gm(f+208|0,c,f+255|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2422,f+264|0,f+256|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2424,f+264|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Ej(c,h,b,f+188|0,f+8|0,n[f+255|0],f+208|0,f+16|0,f+12|0,62096);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2426,f+264|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=U(2429,b|0,p[f+188>>2],d|0,h|0)|0;c=p[114610];p[114610]=0;e:{if((c|0)==1){break e}p[e>>2]=b;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2423,f+264|0,f+256|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+264>>2];pb(a);pb(f+208|0);fb=f+272|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function Y2(a,b,c,d,e){var f=0,g=0,h=0;f=fb-272|0;fb=f;p[f+256>>2]=b;p[f+264>>2]=a;h=Ng(c);gm(f+208|0,c,f+255|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2422,f+264|0,f+256|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2424,f+264|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Ej(c,h,b,f+188|0,f+8|0,n[f+255|0],f+208|0,f+16|0,f+12|0,62096);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2426,f+264|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=U(2435,b|0,p[f+188>>2],d|0,h|0)|0;c=p[114610];p[114610]=0;e:{if((c|0)==1){break e}p[e>>2]=b;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2423,f+264|0,f+256|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+264>>2];pb(a);pb(f+208|0);fb=f+272|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function W2(a,b,c,d,e){var f=0,g=0,h=0;f=fb-272|0;fb=f;p[f+256>>2]=b;p[f+264>>2]=a;h=Ng(c);gm(f+208|0,c,f+255|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2422,f+264|0,f+256|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2424,f+264|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Ej(c,h,b,f+188|0,f+8|0,n[f+255|0],f+208|0,f+16|0,f+12|0,62096);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2426,f+264|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=U(2436,b|0,p[f+188>>2],d|0,h|0)|0;c=p[114610];p[114610]=0;e:{if((c|0)==1){break e}p[e>>2]=b;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2423,f+264|0,f+256|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+264>>2];pb(a);pb(f+208|0);fb=f+272|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function $2(a,b,c,d,e){var f=0,g=0,h=0;f=fb-272|0;fb=f;p[f+256>>2]=b;p[f+264>>2]=a;h=Ng(c);gm(f+208|0,c,f+255|0);a=Lb(f+192|0);b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=cc(a,0);p[f+188>>2]=b;p[f+12>>2]=f+16;p[f+8>>2]=0;while(1){c:{p[114610]=0;c=J(2422,f+264|0,f+256|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}if(!c){break b}if(p[f+188>>2]==(wb(a)+b|0)){c=wb(a);b=wb(a);p[114610]=0;K(149,a|0,b<<1);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=Bc(a);p[114610]=0;K(149,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=cc(a,0);p[f+188>>2]=c+b}p[114610]=0;c=M(2424,f+264|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;c=Ej(c,h,b,f+188|0,f+8|0,n[f+255|0],f+208|0,f+16|0,f+12|0,62096);g=p[114610];p[114610]=0;if((g|0)==1){break c}if(c){break b}p[114610]=0;M(2426,f+264|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}break a}d:{if(!wb(f+208|0)){break d}c=p[f+12>>2];if((c-(f+16|0)|0)>159){break d}p[f+12>>2]=c+4;p[c>>2]=p[f+8>>2]}p[114610]=0;b=U(2434,b|0,p[f+188>>2],d|0,h|0)|0;c=p[114610];p[114610]=0;e:{if((c|0)==1){break e}o[e>>1]=b;p[114610]=0;we(f+208|0,f+16|0,p[f+12>>2],d);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;b=J(2423,f+264|0,f+256|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}if(b){p[d>>2]=p[d>>2]|2}b=p[f+264>>2];pb(a);pb(f+208|0);fb=f+272|0;return b}}b=I()|0;H()|0;pb(a);pb(f+208|0);L(b|0);E()}function Baa(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-96|0;fb=d;a:{b:{c:{d:{e:{f:{g:{if(Xh(a)){mo(d+88|0);break g}xm(d+48|0,a);p[114610]=0;K(2175,d+88|0,d+48|0);c=p[114610];p[114610]=0;if((c|0)==1){break f}gf(d+48|0)}c=a+36|0;h:{if(Xh(a)){break h}c=p[d+88>>2]}e=p[a+8>>2];if((e|0)!=-1){break c}e=uy(c);if(Dd(c)){break e}break d}f=I()|0;H()|0;gf(d+48|0);break a}while(1){if(!(u[Gc(c,f)>>3]+h<=b)){e=Gc(c,f);break d}h=u[e>>3]+h;f=f+1|0;if(f>>>0<Dd(c)>>>0){continue}break}}b=b-h;break b}e=Gc(c,e)}f=a+24|0;i=p[f>>2];c=jw(QO(d+48|0,b),q[e+16|0],r[e+12>>1],p[e+8>>2]);p[114610]=0;g=p[c+12>>2];p[d+32>>2]=p[c+8>>2];p[d+36>>2]=g;g=p[c+20>>2];p[d+40>>2]=p[c+16>>2];p[d+44>>2]=g;g=p[c+4>>2];p[d+24>>2]=p[c>>2];p[d+28>>2]=g;Q(2129,d+72|0,i|0,0,d+24|0);c=p[114610];p[114610]=0;if((c|0)!=1){i:{c=qg(d+72|0);i=p[c+8>>2];c=r[c+20>>1];ck(d+72|0);o[p[f>>2]+1074438>>1]=c;g=p[f>>2];p[114610]=0;K(2178,g|0,c|0);g=p[114610];p[114610]=0;if((g|0)==1){break i}p[p[f>>2]+1074428>>2]=i;f=p[f>>2];g=q[a+64|0];c=jw(LJ(d+48|0,c,i),q[e+16|0],r[e+12>>1],p[e+8>>2]);p[114610]=0;e=p[c+12>>2];p[d+8>>2]=p[c+8>>2];p[d+12>>2]=e;e=p[c+20>>2];p[d+16>>2]=p[c+16>>2];p[d+20>>2]=e;e=p[c+4>>2];p[d>>2]=p[c>>2];p[d+4>>2]=e;Q(2129,d+72|0,f|0,(g?7:1)|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}j=a,k=u[qg(d+72|0)>>3]+h,u[j+16>>3]=k;ck(d+72|0);b=u[a+16>>3];Nj(d+88|0);fb=d+96|0;return+b}}f=I()|0;H()|0;Nj(d+88|0)}L(f|0);E()}function Ewa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0;e=fb-48|0;fb=e;q=p[a+16>>2];f=p[a+44>>2];p[e+32>>2]=f;h=p[a+48>>2];p[e+36>>2]=h;l=p[a+52>>2];p[e+40>>2]=l;i=p[a+56>>2];p[e+44>>2]=i;r=p[a+24>>2];s=p[a+20>>2];b=p[a+4>>2];g=p[a>>2];p[e+24>>2]=g;p[e+28>>2]=b;j=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=j;t=a;if(d){while(1){j=g>>>18|0;l=1;i=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+q|0;f=0;b=1;h=0;while(1){k=h<<1;g=o[k+i>>1];p[(e+8|0)+(h<<2)>>2]=g+((v(j,o[i+(k|4)>>1]-g|0)|0)/16384|0);g=b;b=0;h=1;if(g){continue}break}while(1){h=(e+8|0)+(f<<2)|0;j=p[h>>2];k=p[a+60>>2];g=(e+32|0)+(f<<3)|0;f=p[g>>2];b=Pb(f,-16777216,16776704);n=p[a+64>>2];i=Pb(p[g+4>>2],-16777216,16776704);m=p[a+68>>2];u=m;m=m>>31;p[g+4>>2]=f;w=p[a+72>>2];j=j<<8;f=j;f=NNa(k,k>>31,f,f>>31);k=ib;x=h;h=NNa(n,n>>31,b,b>>31);f=h+f|0;b=ib+k|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=NNa(u,m,i,i>>31);i=h+f|0;b=ib+b|0;b=i>>>0<f>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|i>>>24;p[x>>2]=(b|0)/256;p[g>>2]=b-(j&w);f=1;b=l&1;l=0;if(b){continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],s);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],r);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;g=p[e+24>>2];b=p[e+28>>2];continue}break}g=p[e+24>>2];b=p[e+28>>2];l=p[e+40>>2];h=p[e+36>>2];f=p[e+32>>2];i=p[e+44>>2]}p[t+56>>2]=i;p[a+52>>2]=l;p[a+48>>2]=h;p[a+44>>2]=f;p[a>>2]=g;p[a+4>>2]=b;fb=e+48|0}function Y1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,o=0,r=0;k=fb-16|0;fb=k;l=sv(g);g=Yu(g);Zf(k,g);a:{b:{if(Pc(k)){p[114610]=0;U(2463,l|0,a|0,c|0,d|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;p[f>>2]=g;break a}p[f>>2]=d;c:{d:{j=a;h=q[j|0];switch(h+ -43|0){case 0:case 2:break d;default:break c}}p[114610]=0;j=J(2475,l|0,h<<24>>24)|0;h=p[114610];p[114610]=0;if((h|0)==1){break b}h=p[f>>2];p[f>>2]=h+4;p[h>>2]=j;j=a+1|0}if(!(q[j|0]!=48|(c-j|0)<2|(q[j+1|0]|32)!=120)){p[114610]=0;h=J(2475,l|0,48)|0;i=p[114610];p[114610]=0;if((i|0)==1){break b}i=p[f>>2];p[f>>2]=i+4;p[i>>2]=h;h=n[j+1|0];p[114610]=0;h=J(2475,l|0,h|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break b}i=p[f>>2];p[f>>2]=i+4;p[i>>2]=h;j=j+2|0}i=0;p[114610]=0;Bj(j,c);h=p[114610];p[114610]=0;if((h|0)==1){break b}p[114610]=0;r=M(2460,g|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(g>>>0>=c>>>0){g=p[f>>2];p[114610]=0;Xn((j-a<<2)+d|0,g);g=p[114610];p[114610]=0;if((g|0)==1){break e}g=p[f>>2];break a}f:{if(!q[cc(k,h)|0]){break f}if(n[cc(k,h)|0]!=(i|0)){break f}i=p[f>>2];p[f>>2]=i+4;p[i>>2]=r;h=(h>>>0<wb(k)+ -1>>>0)+h|0;i=0}o=n[g|0];p[114610]=0;o=J(2475,l|0,o|0)|0;m=p[114610];p[114610]=0;if((m|0)!=1){m=p[f>>2];p[f>>2]=m+4;p[m>>2]=o;g=g+1|0;i=i+1|0;continue}}break}}a=I()|0;H()|0;pb(k);L(a|0);E()}p[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;pb(k);fb=k+16|0}function Fwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=fb-48|0;fb=e;s=p[a+16>>2];f=p[a+44>>2];p[e+32>>2]=f;i=p[a+48>>2];p[e+36>>2]=i;b=p[a+52>>2];p[e+40>>2]=b;l=p[a+56>>2];p[e+44>>2]=l;t=p[a+24>>2];u=p[a+20>>2];h=p[a+4>>2];g=p[a>>2];p[e+24>>2]=g;p[e+28>>2]=h;k=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=k;if(d){while(1){k=g>>>18|0;g=(((h&2147483647)<<1|g>>>31)&-2)+s|0;i=0;l=1;b=1;f=0;while(1){h=n[g+f|0]<<8;p[(e+8|0)+(f<<2)>>2]=((v(k,(n[g+(f|2)|0]<<8)-h|0)|0)/16384|0)+h;h=b;b=0;f=1;if(h){continue}break}while(1){f=(e+8|0)+(i<<2)|0;k=p[f>>2];j=p[a+60>>2];o=j;h=(e+32|0)+(i<<3)|0;i=p[h>>2];b=Pb(i,-16777216,16776704);r=p[a+64>>2];g=Pb(p[h+4>>2],-16777216,16776704);m=p[a+68>>2];w=m;m=m>>31;p[h+4>>2]=i;i=p[a+72>>2];q=j>>31;k=k<<8;j=k;j=NNa(o,q,j,j>>31);o=ib;q=f;f=j;j=NNa(r,r>>31,b,b>>31);f=f+j|0;b=ib+o|0;b=f>>>0<j>>>0?b+1|0:b;j=f;f=NNa(w,m,g,g>>31);g=j+f|0;b=ib+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;p[q>>2]=(b|0)/256;p[h>>2]=b-(i&k);i=1;b=l&1;l=0;if(b){continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],u);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],t);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;g=p[e+24>>2];h=p[e+28>>2];continue}break}g=p[e+24>>2];h=p[e+28>>2];l=p[e+44>>2];i=p[e+36>>2];f=p[e+32>>2];b=p[e+40>>2]}p[a+56>>2]=l;p[a+52>>2]=b;p[a+48>>2]=i;p[a+44>>2]=f;p[a>>2]=g;p[a+4>>2]=h;fb=e+48|0}function Oo(a,b,c,d){var e=0,f=w(0),g=w(0),h=w(0),i=0,j=0,k=0,l=0,m=w(0),u=0,x=0,y=0;e=fb-16|0;fb=e;p[e+12>>2]=o[b+792>>1]+q[b+857|0];p[e+8>>2]=o[b+794>>1]+(q[b+858|0]&127);Vd(e+12|0,0,127);Vd(e+8|0,0,127);k=a+1074308|0;vb(e,k,1);i=tb(e);j=p[e+12>>2];if(!i){o[b+792>>1]=0;n[b+857|0]=j;i=p[e+8>>2];o[b+794>>1]=0;n[b+858|0]=i}vb(e,k,36);i=v(j,d+256|0);j=(i|0)/256|0;u=tb(e);l=p[e+8>>2];a:{if(!(l|!u|(i|0)<65024)){j=-1;a=b+810|0;if(!Sf(a)){break a}if(es(a)|r[b+808>>1]|(p[b>>2]|p[b+4>>2])){break a}a=p[b+88>>2];if(a&8192){break a}p[b+88>>2]=a&-32769;break a}p[b+88>>2]=p[b+88>>2]|32768;f=fe(w(10),w(w(0-l|0)*w(.00937500037252903)));d=oqa(a,p[e+12>>2],d);vb(e,k,36);h=w(w(d>>>0)*w(6.2831854820251465));b:{if(!(!tb(e)|p[a+480208>>2]&32768)){g=w(w(s[a+24620>>2])/h);h=w(w(f+w(-1))+w(g*f));t[e>>2]=h;f=w(g*g);break b}g=w(h/w(s[a+24620>>2]));f=w(f+f);t[e>>2]=g*w(w(1)-f);dL(e,w(2));h=w(w(f-t[e>>2])/g);t[e>>2]=h;f=w(w(1)/w(g*g))}g=w(w(h+f)+w(1));h=w(w(w(f+f)+h)/g);m=w(w(16777216)/g);f=w(w(-f)/g);c:{if(q[b+865|0]==1){x=b,y=zh(w(w(16777216)-m)),p[x+60>>2]=y;x=b,y=zh(w(h*w(16777216))),p[x+64>>2]=y;x=b,y=zh(w(f*w(16777216))),p[x+68>>2]=y;a=-1;break c}x=b,y=zh(m),p[x+60>>2]=y;x=b,y=zh(w(h*w(16777216))),p[x+64>>2]=y;x=b,y=zh(w(f*w(16777216))),p[x+68>>2]=y;a=0;if(p[b+60>>2]){break c}p[b+60>>2]=1}p[b+72>>2]=a;if(!c){break a}p[b+44>>2]=0;p[b+48>>2]=0;p[b+52>>2]=0;p[b+56>>2]=0}fb=e+16|0;return j}function h2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,o=0,r=0;k=fb-16|0;fb=k;l=_t(g);g=$u(g);Zf(k,g);a:{b:{if(Pc(k)){p[114610]=0;U(2440,l|0,a|0,c|0,d|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;p[f>>2]=g;break a}p[f>>2]=d;c:{d:{j=a;h=q[j|0];switch(h+ -43|0){case 0:case 2:break d;default:break c}}p[114610]=0;j=J(22,l|0,h<<24>>24)|0;h=p[114610];p[114610]=0;if((h|0)==1){break b}h=p[f>>2];p[f>>2]=h+1;n[h|0]=j;j=a+1|0}if(!(q[j|0]!=48|(c-j|0)<2|(q[j+1|0]|32)!=120)){p[114610]=0;h=J(22,l|0,48)|0;i=p[114610];p[114610]=0;if((i|0)==1){break b}i=p[f>>2];p[f>>2]=i+1;n[i|0]=h;h=n[j+1|0];p[114610]=0;h=J(22,l|0,h|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break b}i=p[f>>2];p[f>>2]=i+1;n[i|0]=h;j=j+2|0}i=0;p[114610]=0;Bj(j,c);h=p[114610];p[114610]=0;if((h|0)==1){break b}p[114610]=0;r=M(2431,g|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(g>>>0>=c>>>0){g=p[f>>2];p[114610]=0;Bj((j-a|0)+d|0,g);g=p[114610];p[114610]=0;if((g|0)==1){break e}g=p[f>>2];break a}f:{if(!q[cc(k,h)|0]){break f}if(n[cc(k,h)|0]!=(i|0)){break f}i=p[f>>2];p[f>>2]=i+1;n[i|0]=r;h=(h>>>0<wb(k)+ -1>>>0)+h|0;i=0}o=n[g|0];p[114610]=0;o=J(22,l|0,o|0)|0;m=p[114610];p[114610]=0;if((m|0)!=1){m=p[f>>2];p[f>>2]=m+1;n[m|0]=o;g=g+1|0;i=i+1|0;continue}}break}}a=I()|0;H()|0;pb(k);L(a|0);E()}p[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;pb(k);fb=k+16|0}function Zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=w(0),o=w(0),q=0,r=0,u=w(0),v=0;g=fb-16|0;fb=g;m=a+44|0;if(fh(m)){j=Fd(m,0);k=Fd(m,1);h=_c(m,0);i=_c(m,1);u=t[a+4212>>2];p[g+12>>2]=d;if(d){e=p[a+4224>>2];while(1){v=a;f=p[a+4220>>2];a:{if(f>>>0>e>>>0){p[g+8>>2]=f-e;f=p[Cb(g+12|0,g+8|0)>>2];b:{if(!(u<w(1))){e=0;if(!f){break b}while(1){p[h>>2]=p[j>>2];p[i>>2]=p[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}break b}e=p[a+4224>>2];l=f+e|0;if(e>>>0>=l>>>0){break b}o=w(w(1)/w(s[a+4220>>2]));while(1){n=w(w(e>>>0)*o);t[h>>2]=n*t[j>>2];t[i>>2]=n*t[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}l=p[g+12>>2]-f|0;p[g+12>>2]=l;e=f+p[a+4224>>2]|0;break a}p[g+4>>2]=p[a+4216>>2]-e;f=p[Cb(g+12|0,g+4|0)>>2];c:{d:{e:{if(!(u<w(1))){e=0;if(f){break e}break d}q=p[a+4216>>2];r=p[a+4224>>2];e=q-r|0;l=e-f|0;if(e>>>0<=l>>>0){break c}o=w(w(1)/w(s[a+4220>>2]));while(1){n=w(w(e>>>0)*o);t[h>>2]=n*t[j>>2];t[i>>2]=n*t[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+ -1|0;if(e>>>0>l>>>0){continue}break}break c}while(1){p[h>>2]=0;p[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}}e=f<<2;k=e+k|0;j=e+j|0;q=p[a+4216>>2];r=p[a+4224>>2]}l=p[g+12>>2]-f|0;p[g+12>>2]=l;e=f+r|0;p[a+4224>>2]=e;e=e>>>0<q>>>0?e:0}p[v+4224>>2]=e;if(l){continue}break}}Zh(a,b,c,_c(m,0),_c(m,1),d)}fb=g+16|0}function zv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:while(1){i=b+ -4|0;b:while(1){d=a;c:while(1){d:{e:{f:{g:{h:{i:{j:{k:{a=b-d|0;e=a>>2;switch(e|0){case 4:break j;case 2:break k;case 0:case 1:break d;case 3:break g;case 5:break i;default:break h}}a=b+ -4|0;if(!zd(a,d)){break d}Qb(d,a);return}yv(d,d+4|0,d+8|0,b+ -4|0);return}xv(d,d+4|0,d+8|0,d+12|0,b+ -4|0);return}if((a|0)<=123){s5(d,b);return}g=((e|0)/2<<2)+d|0;l:{if((a|0)>=3997){a=(e|0)/4<<2;h=xv(d,a+d|0,g,a+g|0,i);break l}h=nm(d,g,i)}a=i;if(!zd(d,g)){while(1){a=a+ -4|0;if((d|0)==(a|0)){f=d+4|0;if(zd(d,i)){break e}while(1){if((f|0)==(i|0)){break d}if(zd(d,f)){Qb(f,i);f=f+4|0;break e}else{f=f+4|0;continue}}}if(!zd(a,g)){continue}break}Qb(d,a);h=h+1|0}e=d+4|0;if(e>>>0>=a>>>0){break f}while(1){f=e;e=e+4|0;if(zd(f,g)){continue}while(1){a=a+ -4|0;if(!zd(a,g)){continue}break}if(f>>>0>a>>>0){e=f;break f}else{Qb(f,a);g=(f|0)==(g|0)?a:g;h=h+1|0;continue}}}nm(d,d+4|0,b+ -4|0);break d}m:{if((e|0)==(g|0)){break m}if(!zd(g,e)){break m}Qb(e,g);h=h+1|0}if(!h){f=GE(d,e);a=e+4|0;if(GE(a,b)){b=e;a=d;if(!f){continue a}break d}if(f){continue b}}if((e-d|0)<(b-e|0)){zv(d,e,c);a=e+4|0;continue b}zv(e+4|0,b,c);b=e;a=d;continue a}a=i;if((f|0)==(a|0)){break d}while(1){e=f;f=e+4|0;if(!zd(d,e)){continue}while(1){a=a+ -4|0;if(zd(d,a)){continue}break}if(e>>>0>=a>>>0){d=e;continue c}else{Qb(e,a);continue}}}break}break}break}}function pca(a,b){var c=0,d=0;c=fb-32|0;fb=c;a:{b:{c:{if(Md(b,38139)){Lb(a);break c}if(Md(b,38140)){oca(a);break c}if(Md(b,38156)){p[c>>2]=0;or(a,c);break c}if(Md(b,38178)){p[c>>2]=5;or(a,c);break c}if(Md(b,38200)){p[c>>2]=3;or(a,c);break c}if(Md(b,38222)){b=fb-16|0;fb=b;_ba(a);fb=b+16|0;break c}if(Md(b,38252)){d=Mb(c,38245);b=wb(d);p[114610]=0;J(85,a|0,(b?38281:38279)|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break b}pb(d);break c}if(Md(b,38283)){nca(a);break c}if(Md(b,38300)){mca(a);break c}if(Md(b,38313)){lca(a);break c}if(Md(b,38324)){kca(a);break c}if(Md(b,38336)){jca(a);break c}if(Md(b,38352)){Gk(c);b=q[c+16|0];p[114610]=0;J(85,a|0,(b?38279:38281)|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){Se(c);break c}b=I()|0;H()|0;Se(c);break a}if(Md(b,38371)){Gk(c);b=q[c+17|0];p[114610]=0;J(85,a|0,(b?38279:38281)|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){Se(c);break c}b=I()|0;H()|0;Se(c);break a}if(Md(b,38397)){Gk(c);b=q[c+18|0];p[114610]=0;J(85,a|0,(b?38279:38281)|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){Se(c);break c}b=I()|0;H()|0;Se(c);break a}if(Md(b,38415)){ica(a);break c}if(Md(b,38421)){hca(a);break c}if(Md(b,38436)){fca(a);break c}if(Md(b,38444)){eca(a);break c}if(Md(b,38452)){dca(a);break c}if(Md(b,38460)){cca(a);break c}if(Md(b,38464)){bca(a);break c}if(Md(b,38482)){aca(a);break c}Lb(a)}fb=c+32|0;return}b=I()|0;H()|0;pb(d)}L(b|0);E()}function Eua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-32|0;fb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}g=a,h=ss(n[a+36|0],n[a+37|0]),p[g+24>>2]=h;o[a+36>>1]=0;if((b|0)!=1){break a}e=NNa(p[a+24>>2],0,8272,0)+4181|0;d=ib;g=a,h=dd(QNa(e,e>>>0<4181?d+1|0:d,8363,0),ib),p[g+24>>2]=h;break a}if(d){break a}if((c|0)==1){e=NNa(p[a+24>>2],0,8363,0)+4136|0;d=ib;g=a,h=dd(QNa(e,e>>>0<4136?d+1|0:d,8272,0),ib),p[g+24>>2]=h}Dua(a)}if(c&3){o[a+38>>1]=0;o[a+40>>1]=0;n[a+36|0]=0;o[a+34>>1]=r[a+34>>1]&65499}if(c&7){o[a+32>>1]=64;d=r[a+34>>1];if(d&8){e=p[a+16>>2];p[a+4>>2]=p[a+12>>2];p[a+8>>2]=e;d=d&16?d|6:d&65529|2;o[a+34>>1]=d}p[a+12>>2]=0;p[a+16>>2]=0;o[a+34>>1]=d&65511}d=c&4;if(d){e=r[a+34>>1];if(!(e&32)){o[a+28>>1]=128;o[a+34>>1]=e|32}Ke(a+40|0,15);Ke(a+41|0,63)}b:{if(!q[a+41|0]|(!(b&16777248)|!d?!(c&16777248?b&4:0):0)){break b}d=q[a+40|0];if(!d){break b}b=q[a+39|0];if(b){g=a,h=en(dd(((d<<8|b>>>1)>>>0)/(b>>>0)|0,0)),n[g+39|0]=h;break b}n[a+39|0]=255}c:{d:{if((c|0)!=4){if((c|0)==16777216){break c}if((c|0)!=32|q[a+38|0]!=2){break d}n[a+38|0]=3;break d}if(q[a+38|0]!=4){break d}n[a+38|0]=0}o[a+34>>1]=r[a+34>>1]&49151}e:{if(!(!(q[a+35|0]&2)|c&16777218)){p[f+24>>2]=0;p[f+8>>2]=0;p[f+16>>2]=0;p[f+20>>2]=0;p[f>>2]=0;p[f+4>>2]=0;Xo(a,0,f);break e}if(!(q[a+35|0]&2)|(c|0)!=2){break e}a=a+68|0;b=Yb(a,8);n[b|0]=q[b|0]&3;a=Yb(a,9);n[a|0]=q[a|0]&3}fb=f+32|0}function una(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,n=0,o=0,r=0,s=0,t=0,u=0,w=0;g=fb-32|0;fb=g;k=a+24604|0;if(!tna(k)){YJ(g+16|0,20592,20612,207);qca(g+16|0)}i=a+946300|0;e=a+906300|0;while(1){a:{l=p[e>>2];e=e+160|0;if((i|0)==(e|0)){break a}if(!l){continue}}break}b:{if(!b){break b}e=p[a+480208>>2];if(e&512){break b}r=a+8204|0;s=a+1074328|0;t=a+393352|0;i=a+12|0;n=a+1304392|0;h=p[a+1074380>>2];while(1){c:{if(h){break c}j=a;h=e|512;d:{if(e&256){break d}if(sna(a)){e=p[a+480208>>2];break c}h=p[a+480208>>2]|512;if(q[a+1304512|0]){break d}e=wna(a);f=p[a+480208>>2];h=f|256;if(e){break d}h=f|512}e=h;p[j+480208>>2]=e}if(e&512){u=a+1074392|0,w=il(a),p[u>>2]=w;break b}p[g+16>>2]=512;e=p[a+1074380>>2];p[g+12>>2]=3;p[g+24>>2]=b;p[g+20>>2]=e;p[g+8>>2]=g+16;e=p[g+12>>2];p[g>>2]=p[g+8>>2];p[g+4>>2]=e;f=iR(g);if(p[a+24632>>2]){vna(a,d,f)}wU(a,f);if(kd(n)){ota(p[n>>2],i,f,(v(p[a+480232>>2],p[a+480236>>2])>>>0)/48|0)}hfa(t,i,f);if(l){sU(a,f)}if(p[a+24624>>2]==1){gva(i,f)}if(q[s+36|0]){rna(a,f)}if(p[k>>2]!=128){dna(a+12|0,a+8204|0,p[a+24624>>2],f,p[a+24604>>2])}h=c;j=i;e=p[a+24624>>2];if((e|0)==4){hva(i,r,f);e=p[a+24624>>2]}m[p[p[c>>2]+8>>2]](h,j,e,f);h=p[a+1074380>>2]-f|0;p[a+1074380>>2]=h;p[a+1074376>>2]=f+p[a+1074376>>2];o=f+o|0;b=b-f|0;if(!b){break b}e=p[a+480208>>2];if(!(e&512)){continue}break}}fb=g+32|0;return o|0}function I5(a){var b=w(0),c=0,d=0,g=w(0),h=w(0),k=w(0);a:{b:{c:{d:{e:{c=(i(a),e(2));d=c&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break a}if((c|0)<0){return w(-1)}if(a>w(88.7216796875)^1){break e}return w(a*w(1.7014118346046923e+38))}if(d>>>0<1051816473){break c}if(d>>>0>1065686417){break e}if((c|0)>=0){c=1;g=w(905800061445916e-20);b=w(a+w(-.6931381225585938));break d}c=-1;g=w(-905800061445916e-20);b=w(a+w(.6931381225585938));break d}b=w(w(a*w(1.4426950216293335))+(f(2,(i(a),e(2))&-2147483648|1056964608),j()));f:{if(w(x(b))<w(2147483648)){c=~~b;break f}c=-2147483648}b=w(c|0);g=w(b*w(905800061445916e-20));b=w(a+w(b*w(-.6931381225585938)))}a=b;a=w(a-g);g=w(w(b-a)-g);break b}if(d>>>0<855638016){break a}c=0}b=w(a*w(.5));h=w(a*b);k=w(w(h*w(w(h*w(.0015807170420885086))+w(-.03333321213722229)))+w(1));b=w(w(3)-w(b*k));b=w(h*w(w(k-b)/w(w(6)-w(a*b))));if(!c){return w(a-w(w(a*b)-h))}b=w(w(w(a*w(b-g))-g)-h);g:{switch(c+1|0){case 0:return w(w(w(a-b)*w(.5))+w(-.5));case 2:if(!(a<w(-.25)^1)){return w(w(b-w(a+w(.5)))*w(-2))}a=w(a-b);return w(w(a+a)+w(1));default:break g}}d=c<<23;k=(f(2,d+1065353216|0),j());if(c>>>0>=57){a=w(w(a-b)+w(1));return w(((c|0)==128?w(w(a+a)*w(1.7014118346046923e+38)):w(a*k))+w(-1))}d=1065353216-d|0;h:{if((c|0)<=22){a=w(a-b);b=w(w(1)-(f(2,d),j()));break h}b=w(a-w(b+(f(2,d),j())));a=w(1)}a=w(w(b+a)*k)}return a}function cx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;h=uJ(b,c);a:{if(!p[b+656>>2]|!(n[h|0]&1)){break a}g=p[h+4>>2];i=a+1074308|0;vb(e+8|0,i,31);f=tb(e+8|0);d=oA(p[b+656>>2],c);if(cd(d)){break a}g=g+(f^1)|0;vb(e+8|0,i,31);j=tb(e+8|0);f=q[d+12|0];b:{c:{if(!j){d:{if(!(f&2)){break d}f=r[Fb(d,q[d+14|0])>>1]+!(p[a+480180>>2]&1048580)|0;if(!(!(q[b+89|0]&8)|(!(q[d+12|0]&4)|q[d+14|0]!=q[d+16|0]))){vb(e+8|0,i,70);k=tb(e+8|0)}if((g|0)!=(f|0)|k){break d}g=r[Fb(d,q[d+13|0])>>1]}if(!(!(q[d+12|0]&4)|q[b+89|0]&8)){if((r[Fb(d,q[d+16|0])>>1]+1|0)!=(g|0)){break b}g=r[Fb(d,q[d+15|0])>>1];vb(e+8|0,i,93);if(!tb(e+8|0)|(c|0)!=1|p[b+88>>2]&2048){break b}n[h|0]=q[h|0]&254;break b}if(g>>>0<=r[_i(d)>>1]){break b}k=1;g=r[_i(d)>>1];break c}e:{f:{if(!(!(f&4)|q[b+669|0]&8)){if(p[h+8>>2]==-1){break f}vb(e+8|0,i,97);if(tb(e+8|0)){break f}f=q[d+12|0]}if(f&2){f=r[Fb(d,q[d+13|0])>>1];j=r[Fb(d,q[d+14|0])>>1]+1|0;break e}f=r[_i(d)>>1];k=g>>>0>f>>>0;j=f;break e}f=r[Fb(d,q[d+15|0])>>1];j=r[Fb(d,q[d+16|0])>>1]+1|0}g=g>>>0<j>>>0?g:f}if(!k|c){break b}if(!(!(q[b+89|0]&8)|p[a+480180>>2]==16384?!(p[a+480180>>2]&16777248):0)){p[b+88>>2]=p[b+88>>2]|4096}if(q[_i(d)+2|0]|(p[a+480180>>2]&16777248?0:!r[b+808>>1])){break b}p[b+696>>2]=0;p[b+720>>2]=0;p[b+680>>2]=0;p[b+88>>2]=p[b+88>>2]|4096}vb(e+8|0,i,31);l=h,m=tb(e+8|0)+g|0,p[l+4>>2]=m}fb=e+16|0}function bwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0;g=fb-32|0;fb=g;m=p[a+16>>2];a:{b:{c:{h=p[a+8>>2];e=p[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}j=p[a+40>>2];k=p[a+36>>2];f=p[a+4>>2];i=p[a>>2];p[g+24>>2]=i;p[g+28>>2]=f;p[g+16>>2]=h;p[g+20>>2]=e;e:{if(!d){b=j>>12;h=k>>12;break e}while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=o[b+14>>1];n=o[b+12>>1];q=o[b+10>>1];r=o[b+8>>1];s=o[b+6>>1];t=o[b+4>>1];u=o[b+2>>1];w=o[b>>1];h=0;b=1;while(1){f=h<<1;p[(g+8|0)+(h<<2)>>2]=(((((((v(o[(f|-8)+e>>1],u)+v(o[(f|-12)+e>>1],w)|0)+v(o[(f|-4)+e>>1],t)|0)+v(o[e+f>>1],s)|0)+v(o[(f|4)+e>>1],r)|0)+v(o[(f|8)+e>>1],q)|0)+v(o[(f|12)+e>>1],n)|0)+v(o[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=p[a+32>>2];k=p[a+28>>2]+k|0;h=k>>12;p[c>>2]=p[c>>2]+v(h,p[g+8>>2]);j=b+j|0;b=j>>12;p[c+4>>2]=p[c+4>>2]+v(b,p[g+12>>2]);Kb(g+24|0,g+16|0);d=d+ -1|0;if(d){c=c+8|0;i=p[g+24>>2];f=p[g+28>>2];continue}break}i=p[g+24>>2];f=p[g+28>>2]}p[a+40>>2]=j;p[a+20>>2]=h;p[a+36>>2]=k;p[a+24>>2]=b;p[a>>2]=i;p[a+4>>2]=f;fb=g+32|0}function wF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-16|0;fb=g;a:{b:{c:{d:{e:{h=(b|0)>=0;i=a+8|0;f:{if($k(i)){f=$k(i);break f}f=lr(i)}if(!((f|0)>(b|0)?h:0)){a=W(8)|0;p[114610]=0;b=J(85,g|0,40585)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}dc(a,b);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}c=I()|0;H()|0;pb(b);break d}if(c>>>0>=120){a=W(8)|0;p[114610]=0;b=J(85,g|0,40604)|0;c=p[114610];p[114610]=0;if((c|0)!=1){dc(a,b);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break c}c=I()|0;H()|0;pb(b);break d}c=I()|0;H()|0;X(a|0);break d}j=c+1|0;f=255;o[g>>1]=255;if((al(i)|0)>255){break a}k=a+32|0;h=255;c=255;while(1){h=p[k>>2]+v(h,896)|0;if(!p[h+1075060>>2]){break b}if(q[h+1075073|0]&16){o[g>>1]=c;f=c}c=c+ -1|0;h=c&65535;if((al(i)|0)<=(h|0)){continue}break}break a}c=I()|0;H()|0;X(a|0)}L(c|0)}E()}o[g>>1]=c;f=c}a=a+32|0;c=p[a>>2]+v(f&65535,896)|0;f=c+1074984|0;_m(f,p[a>>2],65535);n[c+1075808|0]=j;n[c+1075805|0]=j;o[c+1075792>>1]=0;jl(f);Mo(p[a>>2],f,b+1|0,0,1,1);p[c+1075680>>2]=65536;bs(p[a>>2],f,j,0,1,1,65535);l=c+1075676|0,m=Xm(Hx(e*128,-128,128)+128),p[l>>2]=m;l=c+1075672|0,m=Xm(Hx(d*256,0,256)),p[l>>2]=m;b=p[a>>2]+1074466|0;b=Lx(b,p7(b,b+(r[p[a>>2]+480212>>1]<<1)|0,g));o[p[a>>2]+480212>>1]=b;fb=g+16|0;return r[g>>1]}function KD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-272|0;fb=e;a:{if(q[b|0]){break a}b=Gq(57936);if(q[b|0]?b:0){break a}b=Gq(v(a,12)+57952|0);if(q[b|0]?b:0){break a}b=Gq(58024);if(q[b|0]?b:0){break a}b=58029}b:{while(1){d=q[b+c|0];if(!(!d|(d|0)==47)){f=15;c=c+1|0;if((c|0)!=15){continue}break b}break}f=c}d=58029;c:{d:{c=q[b|0];e:{f:{if(!(q[b+f|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!q[d+1|0]){break e}}if(!Th(d,58029)){break e}if(Th(d,58037)){break d}}if(!a){c=57860;if(q[d+1|0]==46){break c}}c=0;break c}c=p[115399];if(c){while(1){if(!Th(d,c+8|0)){break c}c=p[c+24>>2];if(c){continue}break}}c=p[115399];if(c){while(1){if(!Th(d,c+8|0)){break c}c=p[c+24>>2];if(c){continue}break}}b=0;g:{h:{i:{if(p[114587]){break i}c=Gq(58043);if(!c|!q[c|0]){break i}j=f+1|0;k=254-f|0;while(1){h=LD(c,58);g=q[h|0];i=(h-c|0)-((g|0)!=0)|0;if(i>>>0<k>>>0){ac(e+16|0,c,i);c=i+(e+16|0)|0;n[c|0]=47;ac(c+1|0,d,f);n[e+16+(i+j)|0]=0;g=Qa(e+16|0,e+12|0)|0;if(g){c=fd(28);if(c){break h}hv(Pa(g|0,p[e+12>>2])|0);break i}g=q[h|0]}c=((g|0)!=0)+h|0;if(q[c|0]){continue}break}}c=fd(28);if(!c){break g}b=p[14466];p[c>>2]=p[14465];p[c+4>>2]=b;b=c+8|0;ac(b,d,f);n[b+f|0]=0;p[c+24>>2]=p[115399];p[115399]=c;b=c;break g}p[c>>2]=g;p[c+4>>2]=p[e+12>>2];b=c+8|0;ac(b,d,f);n[b+f|0]=0;p[c+24>>2]=p[115399];p[115399]=c;b=c}c=a|b?b:57860}fb=e+272|0;return c}function uva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0;e=fb-48|0;fb=e;m=p[a+16>>2];f=Df(e+16|0);p[f+8>>2]=a+112;p[f+16>>2]=p[a+128>>2];n=f,q=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[n+12>>2]=q;b=p[f+16>>2];if(b){n=f,q=Cf(a+8|0,b),p[n>>2]=q;p[f+4>>2]=ib}j=p[a+40>>2];k=p[a+36>>2];h=p[a+4>>2];g=p[a>>2];p[e+8>>2]=g;p[e+12>>2]=h;b=p[a+12>>2];p[e>>2]=p[a+8>>2];p[e+4>>2]=b;a:{if(!d){b=j>>12;i=k>>12;break a}while(1){b=0;i=b;l=g;p[e+40>>2]=g;p[e+44>>2]=b;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+m|0;b:{b=p[f+16>>2];if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|l>>>31;qd(p[f+8>>2],(o[(g<<1|2)+h>>1]+o[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);pd(p[f+8>>2],4);Kb(e+40|0,f);if((b|0)<2){break b}b=b+ -1|0;l=p[e+40>>2];i=p[e+44>>2];continue}}d=d+ -1|0;b=p[f+8>>2];Kb(b,b+8|0);b=p[f+8>>2];g=p[b+4>>2];if(g){i=b;b=(p[e+44>>2]&2147483647)<<1|p[e+40>>2]>>>31;qd(i,(o[(b<<1|2)+h>>1]+o[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);pd(p[f+8>>2],g);b=p[f+8>>2];g=p[b>>2];p[b>>2]=g;p[b+4>>2]=0}h=xf(b,p[f+12>>2]);b=p[a+32>>2];k=p[a+28>>2]+k|0;i=k>>12;p[c>>2]=p[c>>2]+v(h,i);j=b+j|0;b=j>>12;p[c+4>>2]=p[c+4>>2]+v(h,b);Kb(e+8|0,e);if(d){c=c+8|0;g=p[e+8>>2];h=p[e+12>>2];continue}break}g=p[e+8>>2];h=p[e+12>>2]}p[a+40>>2]=j;p[a+20>>2]=i;p[a+36>>2]=k;p[a+24>>2]=b;p[a>>2]=g;p[a+4>>2]=h;fb=e+48|0}function Jva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=fb-16|0;fb=h;f=p[a+48>>2];m=p[a+24>>2];n=p[a+20>>2];k=p[a+44>>2];q=p[a+16>>2];g=p[a+4>>2];i=p[a>>2];p[h+8>>2]=i;p[h+12>>2]=g;e=p[a+12>>2];p[h>>2]=p[a+8>>2];p[h+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=(g<<1)+q|0;r=o[e+ -6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=o[g+24>>1];s=o[e+ -4>>1];t=o[g+26>>1];u=o[e+ -2>>1];w=o[g+28>>1];x=o[e>>1];y=o[g+30>>1];z=o[e+2>>1];A=o[g+32>>1];B=o[e+4>>1];C=o[g+34>>1];D=o[e+6>>1];E=o[g+36>>1];F=o[e+8>>1];g=o[g+38>>1];e=p[a+60>>2];G=e;H=e>>31;e=Pb(k,-16777216,16776704);j=p[a+64>>2];f=Pb(f,-16777216,16776704);I=p[a+72>>2];J=p[c>>2];e=NNa(j,j>>31,e,e>>31);j=ib;K=e;e=p[a+68>>2];l=NNa(e,e>>31,f,f>>31);e=K+l|0;f=ib+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((v(B,C)+v(z,A)|0)+v(D,E)|0)+v(g,F)|0)/2|0)+((((v(s,t)+v(i,r)|0)+v(u,w)|0)+v(x,y)|0)/2|0)|0)/16384<<8;e=g;i=NNa(G,H,e,e>>31);e=j+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;p[c>>2]=v(e,n)+J;p[c+4>>2]=p[c+4>>2]+v(e,m);e=f-(g&I)|0;Kb(h+8|0,h);d=d+ -1|0;if(d){c=c+8|0;i=p[h+8>>2];g=p[h+12>>2];f=k;k=e;continue}break}i=p[h+8>>2];g=p[h+12>>2]}p[a+48>>2]=k;p[a+44>>2]=e;p[a>>2]=i;p[a+4>>2]=g;fb=h+16|0}function VT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))==1397771593){vd(b,32);yi(d,1,a+4|0);zc(d+16|0,d);p[114610]=0;J(370,b+43|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}pb(d+16|0);o[b+30>>1]=q[a+19|0]<<2;Lg(b+30|0,256);o[b+32>>1]=q[a+17|0];Lg(b+32|0,64);c=a+47|0;o[b+28>>1]=(q[c|0]&127)<<2;Lg(b+28|0,256);if(n[c|0]<=-1){o[b+34>>1]=r[b+34>>1]|32}c=a+18|0;if(q[c|0]&16){o[b+34>>1]=r[b+34>>1]|2}if(q[c|0]&32){o[b+34>>1]=r[b+34>>1]|8}if(q[c|0]&64){o[b+34>>1]=r[b+34>>1]|4}if(n[c|0]<=-1){o[b+34>>1]=r[b+34>>1]|16}c=a+60|0;c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=c?c:8363;p[b+24>>2]=c>>>0>256?c:256;c=a+48|0;p[b>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+52|0;p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+56|0;p[b+8>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a- -64|0;p[b+12>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+68|0;p[b+16>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);Ym(b);n[b+38|0]=q[(q[a+79|0]&7)+27808|0];n[b+41|0]=q[a+76|0];n[b+40|0]=q[a+77|0]&127;n[b+39|0]=q[a+78|0];c=512;e=a+46|0;b:{if(q[e|0]!=64){c=16384;if(q[e|0]!=128){break b}}o[b+34>>1]=r[b+34>>1]|c}a=a+72|0;c=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24)}fb=d+32|0;return c|0}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function dg(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;p[f+12>>2]=d;e=b+ -1|0;g=0;a:{if(e>>>0>249){break a}h=dt(a);g=p[a+480180>>2];if(!h){if(g&17408){a=((e&255)>>>0)/12|0;g=r[((e-v(a,12)&255)<<1)+21360>>1]<<4>>>a|0;break a}if(!(p[a+480180>>2]!=64?!(q[a+480208|0]&16):0)){vb(f,a+1074308|0,7);if(!(i=!tb(f),j=0,k=p[a+480180>>2]!=64,k?i:j)){a=((e&255)>>>0)/12|0;b=NNa(p[f+12>>2],0,p[(e-v(a,12)<<6&960)+25248>>2]<<a,0);a=ib;c=a>>>21|0;g=dd((a&2097151)<<11|b>>>21,c);break a}a=((e&255)>>>0)/12|0;g=r[((e-v(a,12)&255)<<1)+21360>>1]<<5>>>a|0;break a}if(!d){p[f+12>>2]=8363}a=((e&255)>>>0)/12|0;vc(f+12|0,-1>>>a|0);g=dd(QNa(NNa(r[((e-v(a,12)&255)<<1)+21360>>1],0,267616,0),ib,p[f+12>>2]<<a,0),ib);break a}if(g&20){d=e>>>0>12;if(p[a+480180>>2]==16){b=c<<4}else{vb(f,a+1074308|0,76);b=tb(f)?c&-8:c}c=d?e:12;if(q[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;g=(a|0)>1?a:1;break a}c=c+ -12|0;a=((c&255)>>>0)/12|0;c=((b|0)/16|0)+(c-v(a,12)<<3&248)|0;p[f>>2]=c+8;Vd(f,0,103);c=c+((b|0)<0?-1:1)|0;c=(c|0)>-8?c:-8;d=b;b=b>>31;b=(d+b^b)&15;g=v(r[((((c|0)<95?c:95)<<1)+21840|0)+16>>1],b)+v(r[(p[f>>2]<<1)+21840>>1],16-b|0)<<1>>>a|0;break a}a=c>>>4&15;if(!(e>>>0<108?!(a|e>>>0<24):0)){b=v(a,12);a=((e&255)>>>0)/12|0;g=r[(b+(e-v(a,12)&255)<<1)+20960>>1]<<5>>>a|0;break a}g=r[(b<<1)+20734>>1]<<2}fb=f+16|0;return g}function Lva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=fb-16|0;fb=h;f=p[a+48>>2];m=p[a+24>>2];q=p[a+20>>2];k=p[a+44>>2];r=p[a+16>>2];g=p[a+4>>2];i=p[a>>2];p[h+8>>2]=i;p[h+12>>2]=g;e=p[a+12>>2];p[h>>2]=p[a+8>>2];p[h+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=g+r|0;s=n[e+ -3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=o[g+24>>1];t=n[e+ -2|0];u=o[g+26>>1];w=n[e+ -1|0];x=o[g+28>>1];y=n[e|0];z=o[g+30>>1];A=n[e+1|0];B=o[g+32>>1];C=n[e+2|0];D=o[g+34>>1];E=n[e+3|0];F=o[g+36>>1];G=n[e+4|0];g=o[g+38>>1];e=p[a+60>>2];H=e;I=e>>31;e=Pb(k,-16777216,16776704);j=p[a+64>>2];f=Pb(f,-16777216,16776704);J=p[a+72>>2];K=p[c>>2];e=NNa(j,j>>31,e,e>>31);j=ib;L=e;e=p[a+68>>2];l=NNa(e,e>>31,f,f>>31);e=L+l|0;f=ib+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((v(C,D)+v(A,B)|0)+v(E,F)|0)+v(g,G)<<8)/2|0)+((((v(t,u)+v(i,s)|0)+v(w,x)|0)+v(y,z)<<8)/2|0)|0)/16384<<8;e=g;i=NNa(H,I,e,e>>31);e=j+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;p[c>>2]=v(e,q)+K;p[c+4>>2]=p[c+4>>2]+v(e,m);e=f-(g&J)|0;Kb(h+8|0,h);d=d+ -1|0;if(d){c=c+8|0;i=p[h+8>>2];g=p[h+12>>2];f=k;k=e;continue}break}i=p[h+8>>2];g=p[h+12>>2]}p[a+48>>2]=k;p[a+44>>2]=e;p[a>>2]=i;p[a+4>>2]=g;fb=h+16|0}function Vwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0;b=fb-48|0;fb=b;s=p[a+16>>2];j=p[a+44>>2];p[b+32>>2]=j;f=p[a+48>>2];p[b+36>>2]=f;h=p[a+52>>2];p[b+40>>2]=h;k=p[a+56>>2];p[b+44>>2]=k;t=p[a+24>>2];u=p[a+20>>2];e=p[a+4>>2];i=p[a>>2];p[b+24>>2]=i;p[b+28>>2]=e;g=p[a+12>>2];p[b+16>>2]=p[a+8>>2];p[b+20>>2]=g;if(d){while(1){e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+s|0;h=o[e>>1];p[b+8>>2]=h;p[b+12>>2]=o[e+2>>1];f=0;k=1;while(1){g=p[a+60>>2];n=g;i=(b+32|0)+(f<<3)|0;l=p[i>>2];e=Pb(l,-16777216,16776704);r=p[a+64>>2];j=Pb(p[i+4>>2],-16777216,16776704);m=p[a+68>>2];w=m;m=m>>31;p[i+4>>2]=l;l=p[a+72>>2];q=g>>31;h=h<<8;g=h;g=NNa(n,q,g,g>>31);n=ib;q=(b+8|0)+(f<<2)|0;f=g;g=NNa(r,r>>31,e,e>>31);f=f+g|0;e=ib+n|0;e=f>>>0<g>>>0?e+1|0:e;j=NNa(w,m,j,j>>31);f=j+f|0;e=ib+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;p[q>>2]=(e|0)/256;p[i>>2]=e-(h&l);if(k){f=1;k=0;h=p[b+12>>2];continue}break}p[c>>2]=p[c>>2]+v(p[b+8>>2],u);p[c+4>>2]=p[c+4>>2]+v(p[b+12>>2],t);Kb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;i=p[b+24>>2];e=p[b+28>>2];continue}break}i=p[b+24>>2];k=p[b+44>>2];h=p[b+40>>2];j=p[b+32>>2];f=p[b+36>>2];e=p[b+28>>2]}p[a+56>>2]=k;p[a+52>>2]=h;p[a+48>>2]=f;p[a+44>>2]=j;p[a>>2]=i;p[a+4>>2]=e;fb=b+48|0}function cwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0;f=fb-32|0;fb=f;m=p[a+16>>2];a:{b:{c:{g=p[a+8>>2];e=p[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}j=p[a+40>>2];k=p[a+36>>2];i=p[a+4>>2];h=p[a>>2];p[f+24>>2]=h;p[f+28>>2]=i;p[f+16>>2]=g;p[f+20>>2]=e;e:{if(!d){b=j>>12;e=k>>12;break e}while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=o[b+14>>1];q=o[b+12>>1];r=o[b+10>>1];s=o[b+8>>1];t=o[b+6>>1];u=o[b+4>>1];w=o[b+2>>1];x=o[b>>1];b=0;e=1;while(1){p[(f+8|0)+(b<<2)>>2]=(((((((v(n[(b|-4)+g|0],w)+v(n[(b|-6)+g|0],x)|0)+v(n[(b|-2)+g|0],u)|0)+v(n[b+g|0],t)|0)+v(n[(b|2)+g|0],s)|0)+v(n[(b|4)+g|0],r)|0)+v(n[(b|6)+g|0],q)|0)+v(n[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=p[a+32>>2];k=p[a+28>>2]+k|0;e=k>>12;p[c>>2]=p[c>>2]+v(e,p[f+8>>2]);j=b+j|0;b=j>>12;p[c+4>>2]=p[c+4>>2]+v(b,p[f+12>>2]);Kb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;h=p[f+24>>2];i=p[f+28>>2];continue}break}h=p[f+24>>2];i=p[f+28>>2]}p[a+40>>2]=j;p[a+20>>2]=e;p[a+36>>2]=k;p[a+24>>2]=b;p[a>>2]=h;p[a+4>>2]=i;fb=f+32|0}function fna(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;p[b+28>>2]=0;p[b+32>>2]=0;a:{b:{c=p[b+88>>2];if(!(c&65536)){g=p[b+676>>2];d=p[b+672>>2];break b}d=p[b+20>>2];h=p[b+672>>2];c:{if((d|0)!=(h|0)){g=p[b+24>>2];i=p[b+676>>2];break c}i=p[b+676>>2];g=p[b+24>>2];if((i|0)==(g|0)){break b}}e=a+24604|0;c=f;h=(h|0)>(d|0);d:{if(!((i|0)<=(g|0)?!h:0)){d=KM(e);break d}d=JM(e)}p[c+12>>2]=d;vb(f,a+1074308|0,4);if(!(!tb(f)|!(p[a+480180>>2]&4))){d=p[a+24620>>2];d=NNa(d,d>>31,5,0)+500|0;c=ib;d=rc(ONa(d,d>>>0<500?c+1|0:c,1e3,0),ib);p[f+12>>2]=d}c=p[b+656>>2];e:{if(!(!c|!(h|(i|0)>(g|0)))){e=d;c=r[c+12>>1];if(c){e=(v(c,p[a+24620>>2])>>>0)/1e5|0}p[f+12>>2]=e;c=(c|0)!=0;break e}e=p[f+12>>2];c=0}if(!e){p[f+12>>2]=1;e=1}i=p[b+676>>2];j=p[b+24>>2];l=i-j<<12;h=p[b+672>>2];k=p[b+20>>2];g=h-k<<12;if(!(q[b+90|0]&32|(!(h|i)|(c|!(j|k))))){p[f+12>>2]=p[a+1074380>>2];Vd(f+12|0,d,2048);i=p[b+676>>2];e=p[f+12>>2];h=p[b+672>>2]}c=(l|0)/(e|0)|0;p[b+32>>2]=c;a=(g|0)/(e|0)|0;p[b+28>>2]=a;g=((v(e,c)|0)/-4096|0)+i|0;p[b+24>>2]=g;d=((v(a,e)|0)/-4096|0)+h|0;p[b+20>>2]=d;if(a|c){p[b+100>>2]=e;e=p[b+88>>2];break a}p[b+24>>2]=i;p[b+20>>2]=h;e=p[b+88>>2]&-65537;p[b+88>>2]=e;g=i;d=h;break a}p[b+24>>2]=g;p[b+20>>2]=d;e=c&-65537;p[b+88>>2]=e}p[b+88>>2]=e&-2097153;p[b+40>>2]=g<<12;p[b+36>>2]=d<<12;fb=f+16|0}function Wwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;b=fb-48|0;fb=b;s=p[a+16>>2];j=p[a+44>>2];p[b+32>>2]=j;f=p[a+48>>2];p[b+36>>2]=f;h=p[a+52>>2];p[b+40>>2]=h;k=p[a+56>>2];p[b+44>>2]=k;t=p[a+24>>2];u=p[a+20>>2];e=p[a+4>>2];i=p[a>>2];p[b+24>>2]=i;p[b+28>>2]=e;g=p[a+12>>2];p[b+16>>2]=p[a+8>>2];p[b+20>>2]=g;if(d){while(1){e=(((e&2147483647)<<1|i>>>31)&-2)+s|0;h=n[e|0]<<8;p[b+8>>2]=h;p[b+12>>2]=n[e+1|0]<<8;f=0;k=1;while(1){g=p[a+60>>2];o=g;i=(b+32|0)+(f<<3)|0;l=p[i>>2];e=Pb(l,-16777216,16776704);r=p[a+64>>2];j=Pb(p[i+4>>2],-16777216,16776704);m=p[a+68>>2];w=m;m=m>>31;p[i+4>>2]=l;l=p[a+72>>2];q=g>>31;h=h<<8;g=h;g=NNa(o,q,g,g>>31);o=ib;q=(b+8|0)+(f<<2)|0;f=g;g=NNa(r,r>>31,e,e>>31);f=f+g|0;e=ib+o|0;e=f>>>0<g>>>0?e+1|0:e;j=NNa(w,m,j,j>>31);f=j+f|0;e=ib+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;p[q>>2]=(e|0)/256;p[i>>2]=e-(h&l);if(k){f=1;k=0;h=p[b+12>>2];continue}break}p[c>>2]=p[c>>2]+v(p[b+8>>2],u);p[c+4>>2]=p[c+4>>2]+v(p[b+12>>2],t);Kb(b+24|0,b+16|0);d=d+ -1|0;if(d){c=c+8|0;i=p[b+24>>2];e=p[b+28>>2];continue}break}i=p[b+24>>2];k=p[b+44>>2];h=p[b+40>>2];j=p[b+32>>2];f=p[b+36>>2];e=p[b+28>>2]}p[a+56>>2]=k;p[a+52>>2]=h;p[a+48>>2]=f;p[a+44>>2]=j;p[a>>2]=i;p[a+4>>2]=e;fb=b+48|0}function tua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb+ -64|0;fb=c;o[c+62>>1]=b;f=bj(a);e=rua(c+48|0,f);a:{b:{if(!f){break b}b=0;while(1){i=kc(e,b),j=b-d|0,o[i>>1]=j;p[114610]=0;g=J(1171,a|0,b|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}d=(r[g>>1]==r[c+62>>1])+d|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}if(!(d&65535)){break b}b=Ub(a);d=Vb(a);p[114610]=0;b=P(1172,b|0,d|0,c+62|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[c+32>>2]=b;b=Ld(c+40|0,c+32|0);i=c,j=Vb(a),p[i+16>>2]=j;d=p[Ld(c+24|0,c+16|0)>>2];b=p[b>>2];p[114610]=0;P(1173,a|0,b|0,d|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}i=c,j=Ub(a),p[i+32>>2]=j;i=c,j=Vb(a),p[i+16>>2]=j;if(Ab(c+32|0,c+16|0)){while(1){b=r[p[c+32>>2]>>1];d=p[a+24>>2];p[114610]=0;d=J(442,d+484344|0,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}c:{if(!d){break c}b=Rb(p[a+24>>2]+484344|0,b);i=c,j=Ub(b),p[i+8>>2]=j;i=c,j=Vb(b),p[i>>2]=j;if(!Ab(c+8|0,c)){break c}while(1){b=p[c+8>>2];d:{if(q[b+3|0]!=12){break d}d=q[b+5|0];if(fc(e)>>>0<=d>>>0){break d}i=b,j=q[kc(e,q[b+5|0])|0],n[i+5|0]=j}uk(c+8|0);if(Ab(c+8|0,c)){continue}break}}te(c+32|0);if(Ab(c+32|0,c+16|0)){continue}break}}b=r[a+28>>1];if(fc(e)>>>0<=b>>>0){break b}i=a,j=r[kc(e,r[a+28>>1])>>1],o[i+28>>1]=j}qf(e);fb=c- -64|0;return}a=I()|0;H()|0;qf(e);L(a|0);E()}function dIa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{b=q[a+3|0];switch(b+ -14|0){case 2:case 3:case 4:case 5:break b;case 8:break f;case 6:case 7:break g;case 1:break h;case 0:break i;default:break j}}switch(b+ -31|0){case 2:break d;case 0:break e;default:break b}}k:{l:{b=q[a+5|0];if((b|0)!=240){if((b|0)==15){break l}if(b){break k}n[a+3|0]=11;break a}n[a+5|0]=239;break c}n[a+5|0]=254;break c}if(b>>>0>=16){n[a+5|0]=b|15;break c}n[a+5|0]=b|240;break c}n[c+15|0]=q[a+5|0]>>>4;n[c+14|0]=15;e=a,f=q[hc(c+15|0,c+14|0)|0]|32,n[e+5|0]=f;break c}b=q[a+5|0];if(b>>>0>=16){n[c+13|0]=b>>>4;n[c+12|0]=15;e=a,f=q[hc(c+13|0,c+12|0)|0]|240,n[e+5|0]=f;break c}n[a+5|0]=b|224;break c}n[a+5|0]=((q[a+5|0]^-1)&254)>>>1;break c}e=a,f=kk(q[a+5|0]<<1),n[e+5|0]=f;break c}b=32;m:{n:{o:{p:{q:{r:{s:{t:{d=q[a+5|0];switch(d>>>4|0){case 3:break m;case 5:break n;case 14:break o;case 12:case 13:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break t}}n[a+3|0]=0;break c}b=64;break m}b=176;break m}b=224;break m}if(d){break c}n[a+3|0]=0;break c}n[a+5|0]=119;break c}b=48}n[a+5|0]=d&15|b}b=q[a+3|0]}if(b>>>0>=36){n[a+3|0]=0;break a}n[a+3|0]=q[b+13344|0];if(q[a+2|0]|(b|0)!=12){break a}n[a+2|0]=1;n[a+3|0]=0;b=q[a+5|0];n[a+5|0]=0;n[a+4|0]=b}fb=c+16|0}function G_(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;p[c>>2]=a;p[f>>2]=d;a:{b:{c:{while(1){d:{d=p[c>>2];if(d>>>0>=b>>>0){break d}h=p[f>>2];if(h>>>0>=e>>>0){break d}j=2;a=q[d|0];if(a>>>0>1114111){break a}l=c;e:{if(a<<24>>24>=0){o[h>>1]=a;a=d+1|0;break e}if(a>>>0<194){break a}if(a>>>0<=223){if((b-d|0)<2){break b}g=q[d+1|0];if((g&192)!=128){break c}a=g&63|a<<6&1984;if(a>>>0>1114111){break c}o[h>>1]=a;a=d+2|0;break e}if(a>>>0<=239){if((b-d|0)<3){break b}i=q[d+2|0];g=q[d+1|0];f:{g:{if((a|0)!=237){if((a|0)!=224){break g}if((g&224)==160){break f}break c}if((g&224)==128){break f}break c}if((g&192)!=128){break c}}if((i&192)!=128){break c}a=i&63|((g&63)<<6|a<<12);if((a&65535)>>>0>1114111){break c}o[h>>1]=a;a=d+3|0;break e}if(a>>>0>244){break a}j=1;if((b-d|0)<4){break c}i=q[d+3|0];g=q[d+2|0];d=q[d+1|0];h:{i:{switch(a+ -240|0){case 0:if((d+112&255)>>>0>=48){break a}break h;case 4:if((d&240)!=128){break a}break h;default:break i}}if((d&192)!=128){break a}}if((g&192)!=128|(i&192)!=128){break a}if((e-h|0)<4){break c}j=2;i=i&63;k=g<<6;a=a&7;if((i|(k&4032|(d<<12&258048|a<<18)))>>>0>1114111){break c}d=d<<2;o[h>>1]=(d&192|a<<8|(g>>>4&3|d&60))+16320|55296;p[f>>2]=h+2;o[h+2>>1]=i|k&960|56320;a=p[c>>2]+4|0}p[l>>2]=a;p[f>>2]=p[f>>2]+2;continue}break}j=d>>>0<b>>>0}return j}return 1}return 2}function w0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-496|0;fb=a;qc(a+488|0,d);p[114610]=0;l=M(2449,a+488|0)|0;g=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(wb(f)){g=p[Ui(f,0)>>2];p[114610]=0;i=J(2475,l|0,45)|0;j=p[114610];p[114610]=0;if((j|0)==1){break g}m=(g|0)==(i|0)}j=Lb(a+456|0);i=Ue(a+440|0);g=Ue(a+424|0);p[114610]=0;ga(2503,c|0,m|0,a+488|0,a+480|0,a+476|0,a+472|0,j|0,i|0,g|0,a+420|0);c=p[114610];p[114610]=0;if((c|0)==1){break f}p[a+4>>2]=2420;k=Hd(a+8|0,0,a+4|0);h:{if((wb(f)|0)>p[a+420>>2]){c=wb(f);h=p[a+420>>2];h=(wb(g)+(c-h<<1)|0)+1|0;break h}h=wb(g)+2|0}c=a+16|0;h=(wb(i)+h|0)+p[a+420>>2]|0;if(h>>>0<101){break e}pe(k,fd(h<<2));c=p[k>>2];if(c){break e}p[114610]=0;R(2421);b=p[114610];p[114610]=0;if((b|0)==1){break d}E()}f=I()|0;H()|0;break b}f=I()|0;H()|0;break b}f=I()|0;H()|0;break c}h=p[d+4>>2];n=Ib(f);o=Ib(f);f=wb(f);p[114610]=0;la(2504,c|0,a+4|0,a|0,h|0,n|0,(f<<2)+o|0,l|0,m|0,a+480|0,p[a+476>>2],p[a+472>>2],j|0,i|0,g|0,p[a+420>>2]);f=p[114610];p[114610]=0;if((f|0)!=1){p[114610]=0;b=da(2479,b|0,c|0,p[a+4>>2],p[a>>2],d|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break a}}}f=I()|0;H()|0;wc(k)}yc(g);yc(i);pb(j)}Gb(a+488|0);L(f|0);E()}wc(k);yc(g);yc(i);pb(j);Gb(a+488|0);fb=a+496|0;return b|0}function bU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=fb-32|0;fb=d;a:{b:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=1229999433){break b}Qt(d,3,a+32|0);zc(d+16|0,d);p[114610]=0;J(369,b+492|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}pb(d+16|0);yi(d,1,a+4|0);zc(d+16|0,d);p[114610]=0;J(369,b+524|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}pb(d+16|0);c=a+24|0;c=q[c|0]|q[c+1|0]<<8;p[b+4>>2]=64;p[b+8>>2]=128;p[b>>2]=c<<6;n[b+16|0]=q[a+26|0];n[b+17|0]=q[a+27|0];h=b+108|0;i=b+236|0;c=0;e=a- -64|0;while(1){f=c<<1;g=q[f+e|0];f=q[e+(f|1)|0];l=Yc(i,c),m=f,o[l>>1]=m;l=Yb(h,c),m=(g>>>0<120?g:c)+1|0,n[l|0]=m;c=c+1|0;if((c|0)!=120){continue}break}c=a+17|0;n[b+60|0]=q[b+60|0]&254|n[c|0]&1;n[b+60|0]=q[b+60|0]&253|q[c|0]&2;n[b+60|0]=q[b+60|0]&251|q[c|0]&4;h=b+61|0;n[h|0]=q[a+18|0];i=b+62|0;n[i|0]=q[a+19|0];f=b+63|0;n[f|0]=q[a+20|0];j=b- -64|0;n[j|0]=q[a+21|0];e=b+48|0;Vf(e,25);c=0;while(1){c:{k=c<<1;g=q[(k+a|0)+504|0];l=Fb(e,c),m=g,o[l>>1]=m;if((g|0)==255){Vf(e,c);break c}g=q[((k|1)+a|0)+504|0];l=Fb(e,c),m=g,n[l+2|0]=m;c=c+1|0;if((c|0)!=25){continue}}break}a=q[dh(h,i)|0];if(Bb(e)>>>0<=a>>>0){n[b+60|0]=q[b+60|0]&253}a=q[dh(f,j)|0];if(Bb(e)>>>0>a>>>0){break b}n[b+60|0]=q[b+60|0]&251}fb=d+32|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function LNa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=y(f)-y(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1&c>>>0>=0|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;gb=a-v(b,c)|0;hb=0;ib=0;return b}e=d;if(!a){break g}if(!e){break f}f=e+ -1|0;if(f&e){break f}gb=a;hb=f&g;a=g>>>(MNa(e)&31)|0;ib=0;return a}f=e+ -1|0;if(!(f&e)){break e}j=(y(e)+33|0)-y(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}gb=0;a=(g>>>0)/(e>>>0)|0;hb=g-v(a,e)|0;ib=0;return a}f=y(e)-y(g)|0;if(f>>>0<31){break d}break b}gb=a&f;hb=0;if((e|0)==1){break a}c=a;a=MNa(e);d=a&31;if(32<=(a&63)>>>0){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}ib=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if(32<=(f&63)>>>0){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if(32<=(a&63)>>>0){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d+ -1|0;e=c+ -1|0;if((e|0)!=-1){g=g+1|0}h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((h>>>0<f>>>0)+e|0)|0;e=i>>31;i=i>>31;f=c&i;l=k-f|0;f=m-((d&e)+(k>>>0<f>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;e=0;m=e;k=i&1;n=k;j=j+ -1|0;if(j){continue}break}}gb=l;hb=f;e=b<<1|a>>>31;a=k|a<<1;ib=e|m;return a}gb=a;hb=b;a=0;b=0}ib=b;return a}function A0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,r=0;a=fb-192|0;fb=a;qc(a+184|0,d);p[114610]=0;l=M(21,a+184|0)|0;g=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(wb(f)){g=q[cc(f,0)|0];p[114610]=0;i=J(22,l|0,45)|0;j=p[114610];p[114610]=0;if((j|0)==1){break g}m=(g|0)==(i&255)}j=Lb(a+160|0);i=Lb(a+144|0);g=Lb(a+128|0);p[114610]=0;ga(2501,c|0,m|0,a+184|0,a+176|0,a+175|0,a+174|0,j|0,i|0,g|0,a+124|0);c=p[114610];p[114610]=0;if((c|0)==1){break f}p[a+4>>2]=2420;k=Hd(a+8|0,0,a+4|0);h:{if((wb(f)|0)>p[a+124>>2]){c=wb(f);h=p[a+124>>2];h=(wb(g)+(c-h<<1)|0)+1|0;break h}h=wb(g)+2|0}c=a+16|0;h=(wb(i)+h|0)+p[a+124>>2]|0;if(h>>>0<101){break e}pe(k,fd(h));c=p[k>>2];if(c){break e}p[114610]=0;R(2421);b=p[114610];p[114610]=0;if((b|0)==1){break d}E()}f=I()|0;H()|0;break b}f=I()|0;H()|0;break b}f=I()|0;H()|0;break c}h=p[d+4>>2];o=Ib(f);r=Ib(f);f=wb(f);p[114610]=0;la(2502,c|0,a+4|0,a|0,h|0,o|0,f+r|0,l|0,m|0,a+176|0,n[a+175|0],n[a+174|0],j|0,i|0,g|0,p[a+124>>2]);f=p[114610];p[114610]=0;if((f|0)!=1){p[114610]=0;b=da(17,b|0,c|0,p[a+4>>2],p[a>>2],d|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break a}}}f=I()|0;H()|0;wc(k)}pb(g);pb(i);pb(j)}Gb(a+184|0);L(f|0);E()}wc(k);pb(g);pb(i);pb(j);Gb(a+184|0);fb=a+192|0;return b|0}function vva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0;e=fb-48|0;fb=e;m=p[a+16>>2];f=Df(e+16|0);p[f+8>>2]=a+112;p[f+16>>2]=p[a+128>>2];o=f,q=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[o+12>>2]=q;b=p[f+16>>2];if(b){o=f,q=Cf(a+8|0,b),p[o>>2]=q;p[f+4>>2]=ib}j=p[a+40>>2];k=p[a+36>>2];h=p[a+4>>2];g=p[a>>2];p[e+8>>2]=g;p[e+12>>2]=h;b=p[a+12>>2];p[e>>2]=p[a+8>>2];p[e+4>>2]=b;a:{if(!d){b=j>>12;i=k>>12;break a}while(1){b=0;i=b;l=g;p[e+40>>2]=g;p[e+44>>2]=b;h=(((h&2147483647)<<1|g>>>31)&-2)+m|0;b:{b=p[f+16>>2];if((b|0)<=0){break b}while(1){g=(i&2147483647)<<1|l>>>31;qd(p[f+8>>2],n[(g|1)+h|0]+n[h+(g&-2)|0]<<5);pd(p[f+8>>2],4);Kb(e+40|0,f);if((b|0)<2){break b}b=b+ -1|0;l=p[e+40>>2];i=p[e+44>>2];continue}}d=d+ -1|0;b=p[f+8>>2];Kb(b,b+8|0);b=p[f+8>>2];g=p[b+4>>2];if(g){i=b;b=(p[e+44>>2]&2147483647)<<1|p[e+40>>2]>>>31;qd(i,n[(b|1)+h|0]+n[h+(b&-2)|0]<<5);pd(p[f+8>>2],g);b=p[f+8>>2];g=p[b>>2];p[b>>2]=g;p[b+4>>2]=0}h=xf(b,p[f+12>>2]);b=p[a+32>>2];k=p[a+28>>2]+k|0;i=k>>12;p[c>>2]=p[c>>2]+v(h,i);j=b+j|0;b=j>>12;p[c+4>>2]=p[c+4>>2]+v(h,b);Kb(e+8|0,e);if(d){c=c+8|0;g=p[e+8>>2];h=p[e+12>>2];continue}break}g=p[e+8>>2];h=p[e+12>>2]}p[a+40>>2]=j;p[a+20>>2]=i;p[a+36>>2]=k;p[a+24>>2]=b;p[a>>2]=g;p[a+4>>2]=h;fb=e+48|0}function bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,h=0,i=0,j=0,k=0,l=0,n=0,o=0,r=0;j=fb-16|0;fb=j;if(!q[a+4242|0]){Cw(a);a:{if(!q[a+4240|0]){break a}e=SJ(p[a+16>>2]);if(e==u[a+4288>>3]){break a}u[a+4288>>3]=e;Dr(a)}i=a+4256|0;b:{if(q[a+4244|0]){if(!(u[i>>3]<=1)){u[i>>3]=1}break b}k=(p[a+4232>>2]&-2)!=4;e=u[i>>3];c:{if(x(e)<2147483648){h=~~e;break c}h=-2147483648}if(!(k|(h|0)<1)){Aw(a);e=u[a+4256>>3]}u[i>>3]=e- +(h|0)}p[j+8>>2]=0;p[j+12>>2]=0;e=0;h=j;d:{e:{f:{switch(p[a+4232>>2]){case 0:e=Sh(u[a+4256>>3]*6.283185307179586);break e;case 1:e=x(u[a+4256>>3]+ -.5)*-4+1;break e;case 2:e=u[a+4256>>3];e=e+e+ -1;break e;case 3:e=u[a+4256>>3]<.5?-1:1;break e;case 4:i=p[a+4276>>2];h=p[a+4272>>2];p[j+8>>2]=h;p[j+12>>2]=i;f(0,h|0);f(1,i|0);e=+g();break d;case 5:break f;default:break d}}e=u[a+4256>>3];l=e*e*e*((e*6+ -15)*e+10);e=u[a+4272>>3];e=l*(u[a+4280>>3]-e)+e}u[h+8>>3]=e}if(q[a+4241|0]){e=-e;u[j+8>>3]=e}u[j+8>>3]=e*+t[a+4220>>2]+ +t[a+4224>>2];wf(j+8|0,0,1);i=Ti(a);g:{if(!i){break g}h=p[a+4236>>2];if(q[a+4243|0]){o=i,r=h>>>8&15|176|(h&127)<<8|Ss(u[j+8>>3]*127)<<16,n=p[p[i>>2]+68>>2],m[n](o|0,r|0)|0;break g}m[p[p[i>>2]+44>>2]](i,h,w(u[j+8>>3]))}u[a+4256>>3]=u[a+4256>>3]+u[a+4264>>3]*+(d>>>0)}h=a;a=a+44|0;Zh(h,b,c,Fd(a,0),Fd(a,1),d);fb=j+16|0}function b7(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0;e=q[c+1|0];g=v((e>>>3&1)+(e>>>4&1)|0,3)+(q[c+2|0]>>>2&3)|0;h=g-((g|0)!=0)|0;g=q[c+3|0]>191?1:2;a:{if(e&8){i=Kd(a,9);g=g<<1;d=Kd(a,g+7|0);break a}i=Kd(a,g|8)>>>g|0}e=v(h,40);l=e+42688|0;m=e+43008|0;s=v(h,23)+42496|0;h=0;b:{while(1){e=q[c+3|0];j=Kd(a,12);o[b+4>>1]=j;f=Kd(a,9);o[b+6>>1]=f;if((f&65535)>>>0>288){break b}e=e>>>0>191?d<<4:d;t=b,u=Kd(a,8),n[t+10|0]=u;d=Kd(a,q[c+1|0]&8?4:9);n[b+13|0]=22;n[b+14|0]=0;p[b>>2]=s;o[b+8>>1]=d;c:{if(Kd(a,1)){d=Kd(a,2);n[b+11|0]=d;if(!(d&255)){break b}f=Kd(a,1);o[b+18>>1]=65287;n[b+12|0]=f;if(q[b+11|0]==2){d=b;d:{if(!(f&255)){p[b>>2]=l;n[b+18|0]=8;k=39;f=0;break d}p[b>>2]=m;k=30;f=q[c+1|0]&8?8:6}n[d+14|0]=k;n[b+13|0]=f;e=e&3855}d=Kd(a,10);t=b,u=Kd(a,3),n[t+21|0]=u;t=b,u=Kd(a,3),n[t+22|0]=u;t=b,u=Kd(a,3),n[t+23|0]=u;d=d<<5;break c}n[b+11|0]=0;n[b+12|0]=0;d=Kd(a,15);t=b,u=Kd(a,4),n[t+18|0]=u;f=Kd(a,3);n[b+20|0]=255;n[b+19|0]=f}n[b+17|0]=d&31;n[b+15|0]=d>>>10;n[b+16|0]=d>>>5&31;h=(j&65535)+h|0;d=b;e:{if(q[c+1|0]&8){f=Kd(a,1);break e}f=r[b+8>>1]>499}n[d+24|0]=f;t=b,u=Kd(a,1),n[t+25|0]=u;d=Kd(a,1);n[b+27|0]=e>>>12&15;n[b+26|0]=d;b=b+28|0;d=e<<4;g=g+ -1|0;if(g){continue}break}return(p[a+4>>2]+h|0)>(p[a+8>>2]+(i<<3)|0)?-1:i}return-1}function JLa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,r=0;i=fb-32|0;fb=i;n[i+12|0]=0;l=vS(i+16|0,d,i+12|0);h=p[l>>2];p[i+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){m=i;g=b+ -1|0;f=q[a|0];b:{c:{if(!(!g|(f|0)!=(e&255))){f=q[a+1|0];p[114610]=0;p[i+8>>2]=f;f=J(33,i+8|0,i+12|0)|0;g=p[114610];p[114610]=0;d:{if((g|0)!=1){k=a+2|0;g=b+ -2|0;if(!g){break d}j=p[f>>2];if(!(j&255)){break d}g=q[k|0];while(1){n[h|0]=g;f=p[i+12>>2]+ -1|0;p[i+12>>2]=f;h=h+1|0;j=j+ -1|0;if(j&255){continue}break}g=b+ -3|0;k=a+3|0;break b}a=I()|0;H()|0;Up(l);L(a|0);E()}n[h|0]=e;f=p[i+12>>2]+ -1|0;break c}k=a+1|0;n[h|0]=f;f=p[i+12>>2]+ -1|0}p[m+12>>2]=f;h=h+1|0}if(!g){break a}a=k;b=g;if(f){continue}break}}k=p[l>>2];e=d-f|0;e:{if(!e){break e}h=128;g=0;while(1){b=q[k|0];j=0;f=0;while(1){a=c+g|0;m=a;r=q[a|0];a=b&h;n[m|0]=r|(a<<8|a)>>>(f-j&7);a=g+1|0;g=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;h=(h<<8|h)>>>1&255;a=j&65535;j=j+1|0;if(a>>>0<7){continue}break}h=(h<<8|h)>>>(f&65535)&255;k=k+1|0;o=o+1|0;if((o|0)!=(e|0)){continue}break}if(!e){break e}j=0;while(1){d=c;f=d;g=j<<24>>24;b=n[d|0];d=128;f:{if((b|0)==-128){break f}a=b;d=a;if((a|0)>-1){break f}d=0-(b&127)|0}j=g-(d&255)|0;n[f|0]=j;c=c+1|0;e=e+ -1|0;if(e){continue}break}}Up(l);fb=i+32|0}function VO(a,b){var c=0;a:{b:{c:{d:{if(Sd(a,15580)){break d}if(Sd(a,15607)){break d}if(Sd(a,15612)){break d}if(Sd(a,16104)){break d}if(!Sd(a,16109)){break c}}o[b+8>>1]=4;p[b>>2]=16114;break b}e:{f:{if(Sd(a,15585)){break f}if(Sd(a,15590)){break f}if(!Sd(a,16147)){break e}}n[b+10|0]=1;o[b+8>>1]=4;p[b>>2]=16152;return 1}g:{if(!Sd(a,16165)){if(!Sd(a,16170)){break g}}o[b+8>>1]=8;p[b>>2]=16175;break b}h:{if(!Sd(a,16185)){if(!Sd(a,16190)){break h}}p[b>>2]=16195;o[b+8>>1]=n[a+2|0]+ -48;break b}i:{if(!Sd(a,15570)){if(!Sd(a,15575)){break i}}p[b+4>>2]=1;p[b>>2]=16213;o[b+8>>1]=q[a|0]==56?8:4;return 1}if(!(hd(a,16244,3)|(q[a+3|0]+ -52&255)>>>0>4)){p[b>>2]=16248;o[b+8>>1]=n[a+3|0]+ -48;break b}j:{if(hd(a,16264,3)){if(hd(a,16268,3)){break j}}if((q[a+3|0]+ -52&255)>>>0>5){break j}n[b+13|0]=1;n[b+11|0]=1;p[b>>2]=16272;o[b+8>>1]=n[a+3|0]+ -48;return 1}k:{if((q[a|0]+ -49&255)>>>0>8){break k}if(!hd(a+1|0,16284,3)){n[b+12|0]=1;p[b>>2]=16288;o[b+8>>1]=n[a|0]+ -48;return 1}if((q[a+1|0]+ -48&255)>>>0>9|((q[a+2|0]|q[a+3|0]<<8)!=20035?(q[a+2|0]|q[a+3|0]<<8)!=18499:0)){break k}n[b+12|0]=1;p[b>>2]=16288;o[b+8>>1]=(n[a+1|0]+v(n[a|0],10)|0)+ -528;return 1}if(hd(a,16319,3)|(q[a+3|0]+ -52&255)>>>0>5){break a}p[b>>2]=16323;o[b+8>>1]=n[a+3|0]+ -48}c=1}return c}function Cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=fb-144|0;fb=c;e=Pk(c+40|0,a);p[114610]=0;d=J(686,c+24|0,32261)|0;a=p[114610];p[114610]=0;a:{b:{c:{d:{if((a|0)!=1){p[114610]=0;p[c+16>>2]=19464961;p[c+20>>2]=0;N(687,e|0,d|0,c+16|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}yb(d);if(!(p[e>>2]&1073741824)){break c}break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;yb(d);break b}a=ke(b);p[114610]=0;o[c+16>>1]=a;o[c+14>>1]=65535;d=J(686,c+24|0,32267)|0;a=p[114610];p[114610]=0;e:{if((a|0)!=1){p[114610]=0;a=P(1184,e|0,c+14|0,d|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break e}yb(d);if((a|0)!=1){o[c+16>>1]=r[c+14>>1]}Lg(c+16|0,r[p[19847]+10>>1]);f:{if(r[c+16>>1]<=ke(b)>>>0){break f}p[114610]=0;K(401,b|0,r[c+16>>1]);a=p[114610];p[114610]=0;if((a|0)!=1){break f}a=I()|0;H()|0;break b}o[c+12>>1]=0;if(!r[c+16>>1]){break a}a=0;g:{while(1){h:{a=Rb(b,a&65535);p[114610]=0;K(1587,c+24|0,c+12|0);d=p[114610];p[114610]=0;if((d|0)==1){break h}p[114610]=0;U(1569,e|0,a|0,c+24|0,1588)|0;a=p[114610];p[114610]=0;if((a|0)==1){break g}yb(c+24|0);a=r[c+12>>1]+1|0;o[c+12>>1]=a;if((a&65535)>>>0<r[c+16>>1]){continue}break a}break}a=I()|0;H()|0;break b}a=I()|0;H()|0;yb(c+24|0);break b}a=I()|0;H()|0;break b}a=I()|0;H()|0;yb(d)}hg(e);L(a|0);E()}hg(e);fb=c+144|0}function oU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=fb-1072|0;fb=f;e=Hh(f+16|0);h=Tl(a,e);sb(e);p[a+1060>>2]=0;p[a+1064>>2]=0;p[a+1056>>2]=c;e=a+1068|0;p[e>>2]=0;p[e+4>>2]=0;p[a+1076>>2]=0;n[a+1080|0]=d;a:{b:{if(le(c)){i=a+1060|0;e=0;while(1){p[a+1060>>2]=0;p[a+1064>>2]=0;c:{if(!p[c>>2]){break c}while(1){p[114610]=0;d=J(258,b|0,2)|0;g=p[114610];p[114610]=0;d:{e:{f:{g:{if((g|0)!=1){if(!d){break c}p[114610]=0;d=M(357,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break g}if(!d){break d}p[114610]=0;N(341,f|0,b|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break f}d=Tl(f+16|0,f);Nd(h,d);ac(h+16|0,d+16|0,1040);sb(f+16|0);sb(f);p[a+1072>>2]=0;p[a+1076>>2]=0;g=Vp(p[a+1056>>2]);d=p[a+1056>>2];if(g>>>0>=2){d=p[d+20>>2];p[114610]=0;K(358,a|0,d+(e<<1)|0);d=p[114610];p[114610]=0;if((d|0)!=1){break d}break e}d=p[d+20>>2];p[114610]=0;K(359,a|0,d+e|0);d=p[114610];p[114610]=0;if((d|0)==1){break e}break d}d=I()|0;H()|0;break a}d=I()|0;H()|0;break a}d=I()|0;H()|0;break a}d=O(77024)|0;if((H()|0)!=($(77024)|0)){break a}T(d|0)|0;p[114610]=0;R(20);d=p[114610];p[114610]=0;if((d|0)==1){break b}}if(s[i>>2]<s[c>>2]){continue}break}}e=e+1|0;if(e>>>0<le(p[a+1056>>2])>>>0){continue}break}}fb=f+1072|0;return a|0}d=I()|0;H()|0}sb(a);L(d|0);E()}function FHa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{b:{if(!Hb(b,9)){break b}h=a+484344|0;i=a+480280|0;while(1){ln(b,c+28|0);d=Lf(b);c:{if(!((q[c+28|0]|q[c+29|0]<<8|(q[c+30|0]<<16|q[c+31|0]<<24))==1229999433|(q[c+28|0]|q[c+29|0]<<8|(q[c+30|0]<<16|q[c+31|0]<<24))==1397771593|((q[c+28|0]|q[c+29|0]<<8|(q[c+30|0]<<16|q[c+31|0]<<24))==1297110104|(q[c+28|0]|q[c+29|0]<<8|(q[c+30|0]<<16|q[c+31|0]<<24))==1297110099))){if(Hb(b,d)){break c}}jg(b,8);break b}ld(c+8|0,b,d);d=i;d:{if((q[c+28|0]|q[c+29|0]<<8|(q[c+30|0]<<16|q[c+31|0]<<24))==1481001027){while(1){p[114610]=0;e=M(390,c+8|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}n[d+8|0]=e;d=d+32|0;if((h|0)!=(d|0)){continue}break d}}e:{if(q[c+28|0]!=70){break e}d=q[c+29|0];e=(d|0)==88;if((d+ -48&255)>>>0>9?!e:0){break e}f=q[c+30|0];if((f+ -48&255)>>>0>9){break e}g=q[c+31|0];if((g+ -48&255)>>>0>9){break e}d=(v(f,10)+(e?-16:v(d,100)+48|0)|0)+g&255;if(d>>>0>249){break d}p[114610]=0;K(670,c+8|0,(v(d,160)+a|0)+906300|0);d=p[114610];p[114610]=0;if((d|0)!=1){break d}break a}if((q[c+28|0]|q[c+29|0]<<8|(q[c+30|0]<<16|q[c+31|0]<<24))!=1430540109){break d}p[a+1074304>>2]=0;j=1}sb(c+8|0);if(Hb(b,9)){continue}break}}fb=c+32|0;return j|0}a=I()|0;H()|0;sb(c+8|0);L(a|0);E()}function Xxa(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=fb-48|0;fb=b;f=b+40|0;a=f;p[a>>2]=-1;p[a+4>>2]=-1;fta();i=b,j=r5(),p[i+8>>2]=j;p[b+12>>2]=ib;a=p[b+12>>2];p[b+16>>2]=p[b+8>>2];p[b+20>>2]=a;a=fb-16|0;fb=a;c=Ysa(b+16|0);fb=a+16|0;p[b+24>>2]=c;p[b+28>>2]=ib;d=p[b+24>>2];e=d<<8&16711680|d<<24;a=p[b+28>>2];c=a<<24|d>>>8;g=c&65280;c=a<<8|d>>>24;e=c&255|g|e;c=b+32|0;a=((a&255)<<24|d>>>8)&-16777216|((a&16777215)<<8|d>>>24)&16711680|(a>>>8&65280|a>>>24)|h;n[c|0]=a;n[c+1|0]=a>>>8;n[c+2|0]=a>>>16;n[c+3|0]=a>>>24;a=e;n[c+4|0]=a;n[c+5|0]=a>>>8;n[c+6|0]=a>>>16;n[c+7|0]=a>>>24;a=p[b+36>>2];p[b+24>>2]=p[b+32>>2];p[b+28>>2]=a;MM(f,b+24|0,qb(b+24|0));i=b,j=o5(),p[i+8>>2]=j;p[b+12>>2]=ib;a=p[b+12>>2];p[b+16>>2]=p[b+8>>2];p[b+20>>2]=a;a=fb-16|0;fb=a;c=Qsa(b+16|0);fb=a+16|0;p[b+24>>2]=c;p[b+28>>2]=ib;d=p[b+24>>2];e=d<<8&16711680|d<<24;a=p[b+28>>2];c=a<<24|d>>>8;g=c&65280;c=a<<8|d>>>24;e=c&255|g|e;c=b+32|0;a=((a&255)<<24|d>>>8)&-16777216|((a&16777215)<<8|d>>>24)&16711680|(a>>>8&65280|a>>>24)|h;n[c|0]=a;n[c+1|0]=a>>>8;n[c+2|0]=a>>>16;n[c+3|0]=a>>>24;a=e;n[c+4|0]=a;n[c+5|0]=a>>>8;n[c+6|0]=a>>>16;n[c+7|0]=a>>>24;a=p[b+36>>2];p[b+24>>2]=p[b+32>>2];p[b+28>>2]=a;MM(f,b+24|0,qb(b+24|0));fb=b+48|0;ib=p[f+4>>2];return p[f>>2]}function zha(a){a=a|0;var b=0,c=0,d=0,e=0,f=w(0),g=0,h=0;c=fb-32|0;fb=c;a:{b=p[a+20>>2];b:{if(!b){break b}p[b+148>>2]=-1;g=c,h=m[p[p[a>>2]+40>>2]](a)|0,p[g+16>>2]=h;p[c+8>>2]=1073741822;e=p[Yd(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=p[a+20>>2];p[114610]=0;K(508,d+4|0,b+4|0);b=p[114610];p[114610]=0;c:{d:{e:{f:{if((b|0)!=1){b=p[a+20>>2];p[114610]=0;K(1738,c+8|0,b+4|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;p[c>>2]=0;p[c+4>>2]=0;N(1739,c+16|0,c+8|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;J(1740,c+16|0,0)|0;b=p[114610];p[114610]=0;g:{if((b|0)==1){break g}b=p[p[a>>2]+176>>2];p[114610]=0;K(b|0,a|0,-1);b=p[114610];p[114610]=0;if((b|0)==1){break g}if((e|0)>=1){b=0;while(1){d=p[p[a>>2]+48>>2];p[114610]=0;f=w(ia(d|0,a|0,b|0));d=p[114610];p[114610]=0;if((d|0)==1){break e}p[114610]=0;t[c+8>>2]=f;J(1741,c+16|0,c+8|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break e}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=p[p[a>>2]+180>>2];p[114610]=0;S(b|0,a|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(71348)|0;break c}b=O(71348)|0;break c}b=O(71348)|0;break c}b=O(71348)|0;break c}b=O(71348)|0}if((H()|0)!=($(71348)|0)){break a}T(b|0)|0;fs(p[a+20>>2]+4|0);V()}fb=c+32|0;return}L(b|0);E()}function Lo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;g=a+1074308|0;vb(e+8|0,g,96);d=b;a:{if(!tb(e+8|0)){f=p[b+660>>2];break a}p[b+660>>2]=0;f=0}p[d+660>>2]=f+c;b:{if(!(q[b+88|0]&2)|(!(p[a+480180>>2]&18)|s[b+84>>2]>c>>>0)){break b}d=p[b+84>>2];if(!d){break b}f=c;c=p[b+80>>2];c=((f-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(p[a+480180>>2]==16384?p[b+88>>2]&1:0)|0;c:{if(Sf(b+810|0)){d=p[b+656>>2];if(d){d=r[Yc(d+236|0,q[b+810|0]+ -1|0)>>1];if(!d|d>>>0>r[a+480190>>1]){break c}}if(q[a+480210|0]&32){d=c;c=p[b+660>>2];p[b+660>>2]=d+c}p[b>>2]=0;p[b+4>>2]=c;if(!(q[b+88|0]&2)|s[b+84>>2]>c>>>0?s[b+76>>2]>c>>>0:0){break c}vb(e+8|0,g,57);if(!(h=!tb(e+8|0),i=0,j=p[a+480180>>2]!=16,j?h:i)){p[b+700>>2]=0;p[b+88>>2]=p[b+88>>2]|2097152;break c}if(!(p[a+480180>>2]&1048581)){vb(e+8|0,g,27);if(tb(e+8|0)){if(q[a+480208|0]&4){d=p[b+76>>2];p[b>>2]=0;p[b+4>>2]=d;break c}p[b>>2]=0;p[b+4>>2]=0;break c}d=p[b+80>>2];p[b>>2]=0;p[b+4>>2]=d;if(!(q[a+480208|0]&4)){break c}a=p[b+76>>2];if(a>>>0<5){break c}p[b>>2]=0;p[b+4>>2]=a+ -2;break c}if(!(q[b+88|0]&2)|p[a+480180>>2]!=1){break c}a=p[b+80>>2];p[b>>2]=0;p[b+4>>2]=a;break c}if(!(p[a+480180>>2]&268582928)|c>>>0>=s[b+76>>2]){break c}p[b>>2]=0;p[b+4>>2]=c}fb=e+16|0}function $Ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;vd(b,32);e=a+4|0;e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);p[b>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=a+10|0;e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);p[b+4>>2]=e;g=e;e=a+14|0;e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);p[b+8>>2]=g+(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));e=b;if(!(d?0:c)){c=a+46|0;c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}p[e+24>>2]=c;c=q[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!(q[d|0]|q[d+1|0]<<8)|(q[d|0]|q[d+1|0]<<8)==12288){break a}e=c;c=q[d|0]|q[d+1|0]<<8;c=(e-((c<<24|c<<8&16711680)>>>9|0)|0)+6144|0}rs(b,+(c|0)*.0006510416666666666);n[f+15|0]=q[a+9|0];n[f+14|0]=64;h=b,i=q[hc(f+15|0,f+14|0)|0]<<2,o[h+30>>1]=i;if(n[a+40|0]&1){o[b+34>>1]=r[b+34>>1]|64;p[b>>2]=p[b>>2]>>>1;p[b+4>>2]=p[b+4>>2]>>>1;p[b+8>>2]=p[b+8>>2]>>>1}b:{if(q[a+41|0]<=8){a=p[b+4>>2];c=p[b+8>>2];break b}o[b+34>>1]=r[b+34>>1]|1;p[b>>2]=p[b>>2]>>>1;a=p[b+4>>2]>>>1|0;p[b+4>>2]=a;c=p[b+8>>2]>>>1|0;p[b+8>>2]=c}c:{if(c>>>0>a+1>>>0){o[b+34>>1]=r[b+34>>1]|2;break c}p[b+4>>2]=0;p[b+8>>2]=0}fb=f+16|0}function Bo(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=p[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b+ -1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=p[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(r[a+480192>>1]){break a}a=a+484344|0;f=c,g=Ub(a),p[f+8>>2]=g;f=c,g=Vb(a),p[f>>2]=g;a=1;j:{if(!Ab(c+8|0,c)){break j}while(1){b=p[c+8>>2];if(!(!Ch(b)|p[b+12>>2]==64)){a=4;break j}Qx(c+8|0);if(Ab(c+8|0,c)){continue}break}}fb=c+16|0;return a}d=32;if(r[a+480188>>1]>16){break a}if(!r[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(n[e+480281|0]&1|r[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<r[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}fb=c+16|0;return d}function TP(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{d=q[a|0];b:{if(d>>>0>21){break b}n[a|0]=q[d+14784|0];c:{switch(d+ -8|0){case 0:n[b|0]=q[b|0]<<1;break b;case 4:n[b|0]=q[b|0]+1>>>1;break b;case 5:a=q[b|0];n[b|0]=v(a>>>4|0,10)+(a&15);break b;case 6:d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=q[b|0];switch((d>>>4|0)-1|0){case 10:break e;case 9:break f;case 8:break g;case 6:break h;case 5:break i;case 3:break j;case 1:break k;case 0:break l;case 11:case 12:case 13:break b;case 14:break d;default:break m}}n[a|0]=0;break b}n[a|0]=29;n[c+15|0]=q[b|0]&15;n[c+14|0]=14;e=b,f=q[hc(c+15|0,c+14|0)|0]<<4|15,n[e|0]=f;break b}n[a|0]=29;n[c+13|0]=q[b|0]&15;n[c+12|0]=14;e=b,f=q[hc(c+13|0,c+12|0)|0]|240,n[e|0]=f;break b}n[b|0]=d&15|48;break b}n[b|0]=d&15|176;break b}n[b|0]=d&15|64;break b}n[a|0]=15;n[b|0]=q[b|0]&15;break b}n[a|0]=24;n[b|0]=(q[b|0]<<3&120)+8&240;break b}n[a|0]=24;n[b|0]=(q[b|0]&15)+1>>>1;break b}n[a|0]=10;break b;case 8:a=q[b|0];if(a>>>0<=223){n[b|0]=a>>>0>63?-16:a<<2&240;break b}if(a>>>0<=239){n[b|0]=a<<2&48|15;break b}n[b|0]=a<<4|15;break b;case 9:break c;default:break b}}a=q[b|0];if(a>>>0<=223){break a}if(a>>>0>239){break b}n[b|0]=a>>>2&3|240}fb=c+16|0;return}n[b|0]=a>>>0>63?15:a>>>2|0;fb=c+16|0}function nwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0;g=fb-16|0;fb=g;f=p[a+48>>2];l=p[a+40>>2];m=p[a+36>>2];e=p[a+44>>2];s=p[a+16>>2];j=p[a+4>>2];h=p[a>>2];p[g+8>>2]=h;p[g+12>>2]=j;b=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=b;a:{if(!d){i=l>>12;q=m>>12;break a}while(1){b=j+s|0;i=n[b+2|0];q=n[b+1|0];t=n[b|0];u=n[b+ -1|0];b=p[a+60>>2];w=b;x=b>>31;b=e;e=Pb(e,-16777216,16776704);k=p[a+64>>2];f=Pb(f,-16777216,16776704);y=p[a+72>>2];z=p[a+32>>2];j=c;A=p[c>>2];e=NNa(k,k>>31,e,e>>31);k=ib;B=e;e=p[a+68>>2];r=NNa(e,e>>31,f,f>>31);e=B+r|0;f=ib+k|0;f=e>>>0<r>>>0?f+1|0:f;k=e;e=(h>>>21&2040)+27824|0;h=(((v(t,o[e+2>>1])+v(o[e>>1],u)|0)+v(q,o[e+4>>1])|0)+v(i,o[e+6>>1])<<8)/16384<<8;e=h;i=NNa(w,x,e,e>>31);e=k+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=p[a+28>>2]+m|0;q=m>>12;p[j>>2]=v(f,q)+A;l=l+z|0;i=l>>12;p[c+4>>2]=p[c+4>>2]+v(f,i);e=e-(h&y)|0;Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;h=p[g+8>>2];j=p[g+12>>2];f=b;continue}break}h=p[g+8>>2];j=p[g+12>>2];f=b}p[a+40>>2]=l;p[a+20>>2]=q;p[a+36>>2]=m;p[a+48>>2]=f;p[a+44>>2]=e;p[a+24>>2]=i;p[a>>2]=h;p[a+4>>2]=j;fb=g+16|0}function LAa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;e=ki(c,b);p[f+12>>2]=e;a:{if((e|0)<1){break a}c=p[b+4>>2];b:{if(!c){c=p[d+4>>2];break b}c=32-c|0;p[f+8>>2]=c;e=p[Yd(f+8|0,f+12|0)>>2];p[f+12>>2]=p[f+12>>2]-e;h=p[d+4>>2];i=p[p[b>>2]>>2];j=p[b+4>>2];p[f+8>>2]=e;k=32-h|0;p[f+4>>2]=k;l=Cb(f+8|0,f+4|0);g=p[d>>2];i=i&(-1<<j&-1>>>c-e);c=p[d+4>>2];h=p[b+4>>2];j=c>>>0>h>>>0?i<<c-h:i>>>h-c|0;h=p[l>>2];p[g>>2]=j|p[g>>2]&(-1<<c&-1>>>k-h^-1);j=c+h|0;c=j&31;p[d+4>>2]=c;g=g+(j>>>3&536870908)|0;p[d>>2]=g;e=e-h|0;if((e|0)>=1){p[g>>2]=p[g>>2]&(-1>>>32-e^-1)|i>>>h+p[b+4>>2];p[d+4>>2]=e;c=e}p[b>>2]=p[b>>2]+4;e=p[f+12>>2]}h=32-c|0;if((e|0)>=32){i=-1<<c;j=i^-1;g=p[b>>2];while(1){e=p[d>>2];g=p[g>>2];p[e>>2]=j&p[e>>2]|g<<c;p[d>>2]=e+4;p[e+4>>2]=i&p[e+4>>2]|g>>>h;k=p[f+12>>2];e=k+ -32|0;p[f+12>>2]=e;g=p[b>>2]+4|0;p[b>>2]=g;if((k|0)>63){continue}break}}if((e|0)<1){break a}i=p[p[b>>2]>>2];p[f+8>>2]=h;b=Yd(f+12|0,f+8|0);c=p[d>>2];g=p[d+4>>2];b=p[b>>2];j=p[c>>2]&(-1<<g&-1>>>h-b^-1);h=i&-1>>>32-e;p[c>>2]=j|h<<g;e=b+g|0;p[d+4>>2]=e&31;c=c+(e>>>3&536870908)|0;p[d>>2]=c;e=p[f+12>>2]-b|0;p[f+12>>2]=e;if((e|0)<1){break a}p[c>>2]=p[c>>2]&(-1>>>32-e^-1)|h>>>b;p[d+4>>2]=p[f+12>>2]}Ed(a,d);fb=f+16|0}function PAa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;g=ki(c,b);p[f+12>>2]=g;a:{if((g|0)<1){break a}c=p[b+4>>2];b:{if(!c){e=p[d+4>>2];break b}e=32-c|0;p[f+8>>2]=e;c=p[Yd(f+8|0,f+12|0)>>2];p[f+12>>2]=p[f+12>>2]-c;g=p[d+4>>2];h=p[p[b>>2]>>2];j=p[b+4>>2];p[f+8>>2]=c;k=32-g|0;p[f+4>>2]=k;l=Cb(f+8|0,f+4|0);i=p[d>>2];j=h&(-1<<j&-1>>>e-c);e=p[d+4>>2];g=p[b+4>>2];h=p[l>>2];p[i>>2]=(e>>>0>g>>>0?j<<e-g:j>>>g-e|0)|p[i>>2]&(-1<<e&-1>>>k-h^-1);k=e+h|0;e=k&31;p[d+4>>2]=e;i=i+(k>>>3&536870908)|0;p[d>>2]=i;c=c-h|0;if((c|0)>=1){p[i>>2]=p[i>>2]&(-1>>>32-c^-1)|j>>>g+h;p[d+4>>2]=c;e=c}p[b>>2]=p[b>>2]+4;g=p[f+12>>2]}i=32-e|0;if((g|0)>=32){k=-1<<e;l=k^-1;h=p[b>>2];c=p[d>>2];j=p[c>>2];while(1){g=p[h>>2];p[c>>2]=j&l|g<<e;j=k&p[c+4>>2]|g>>>i;p[c+4>>2]=j;m=p[f+12>>2];g=m+ -32|0;p[f+12>>2]=g;h=h+4|0;c=c+4|0;if((m|0)>63){continue}break}p[b>>2]=h;p[d>>2]=c}if((g|0)<1){break a}h=p[p[b>>2]>>2];p[f+8>>2]=i;b=Yd(f+12|0,f+8|0);c=p[d>>2];e=p[d+4>>2];b=p[b>>2];g=h&-1>>>32-g;p[c>>2]=p[c>>2]&(-1<<e&-1>>>i-b^-1)|g<<e;e=b+e|0;p[d+4>>2]=e&31;c=c+(e>>>3&536870908)|0;p[d>>2]=c;e=p[f+12>>2]-b|0;p[f+12>>2]=e;if((e|0)<1){break a}p[c>>2]=p[c>>2]&(-1>>>32-e^-1)|g>>>b;p[d+4>>2]=p[f+12>>2]}Ed(a,d);fb=f+16|0}function lfa(a,b,c){var d=0,e=0,f=0,g=0,h=w(0),i=0,j=w(0),k=0,l=0;e=fb-144|0;fb=e;d=p[a+4>>2];if(d>>>0>=29){p[a+4>>2]=0;d=0}d=v(d,44)+82176|0;if(!(b?0:(d|0)==p[a+4112>>2])){p[a+4112>>2]=d;h=w(c>>>0);jfa(d,e+8|0,h);p[a+4124>>2]=p[e+40>>2];d=_G($G(p[e+16>>2]),h);o[a+4190>>1]=d;o[a+4188>>1]=d;d=r[e+24>>1]<<1;o[a+4198>>1]=d;o[a+4196>>1]=d;while(1){d=(g<<4)+a|0;f=(e+8|0)+v(g,12)|0;i=p[f+44>>2];p[d+4204>>2]=i;p[d+4208>>2]=i;o[d+4212>>1]=r[f+36>>1];o[d+4214>>1]=r[f+42>>1];o[d+4216>>1]=r[f+40>>1];o[d+4218>>1]=r[f+38>>1];g=g+1|0;if((g|0)!=8){continue}break}p[a+53996>>2]=p[e+32>>2];f=a+4184|0;d=p[e+12>>2];if((d|0)>-9e3){d=ZG(d)}else{d=0}p[f>>2]=d;f=a+54052|0;d=p[e+8>>2];if((d|0)>=-8999){d=ZG(d)}else{d=0}p[f>>2]=d;d=p[e+28>>2];f=a+54036|0;p[f>>2]=268464128;p[f+4>>2]=1879052288;d=d>>>0<32512?d:32512;o[a+54010>>1]=d;o[a+54008>>1]=d;o[a+54006>>1]=d;o[a+54004>>1]=d;p[e+4>>2]=p[e+20>>2];Vd(e+4|0,0,32752);d=r[e+4>>1];o[a+54018>>1]=d;f=a+54014|0;o[f>>1]=0;o[f+2>>1]=0;o[a+54012>>1]=d;j=t[e+36>>2];k=e,l=_G(w(j*j),h),p[k>>2]=l;Vd(e,256,32512);d=r[e>>1];o[a+54026>>1]=d;f=a+54022|0;o[f>>1]=0;o[f+2>>1]=0;o[a+54020>>1]=d}if(b){p[a+4120>>2]=0;bH(a)}b=v(c,5);if(s[a+4124>>2]<b>>>0){p[a+4124>>2]=b}fb=e+144|0}function gwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0;g=fb-32|0;fb=g;j=p[a+16>>2];a:{b:{c:{h=p[a+8>>2];e=p[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}k=p[a+24>>2];l=p[a+20>>2];b=p[a+4>>2];f=p[a>>2];p[g+24>>2]=f;p[g+28>>2]=b;p[g+16>>2]=h;p[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=o[b+14>>1];n=o[b+12>>1];q=o[b+10>>1];r=o[b+8>>1];s=o[b+6>>1];t=o[b+4>>1];u=o[b+2>>1];w=o[b>>1];h=0;b=1;while(1){f=h<<1;p[(g+8|0)+(h<<2)>>2]=(((((((v(o[(f|-8)+e>>1],u)+v(o[(f|-12)+e>>1],w)|0)+v(o[(f|-4)+e>>1],t)|0)+v(o[e+f>>1],s)|0)+v(o[(f|4)+e>>1],r)|0)+v(o[(f|8)+e>>1],q)|0)+v(o[(f|12)+e>>1],n)|0)+v(o[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}p[c>>2]=p[c>>2]+v(p[g+8>>2],l);p[c+4>>2]=p[c+4>>2]+v(p[g+12>>2],k);Kb(g+24|0,g+16|0);d=d+ -1|0;if(d){c=c+8|0;f=p[g+24>>2];b=p[g+28>>2];continue}break}f=p[g+24>>2];b=p[g+28>>2]}p[a>>2]=f;p[a+4>>2]=b;fb=g+32|0}function mwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;g=fb-16|0;fb=g;e=p[a+48>>2];l=p[a+40>>2];m=p[a+36>>2];f=p[a+44>>2];r=p[a+16>>2];k=p[a+4>>2];j=p[a>>2];p[g+8>>2]=j;p[g+12>>2]=k;b=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=b;a:{if(!d){i=l>>12;h=m>>12;break a}while(1){b=(k<<1)+r|0;h=o[b>>1];s=o[b+ -2>>1];t=o[b+2>>1];u=o[b+4>>1];q=p[a+60>>2];b=f;f=Pb(f,-16777216,16776704);n=p[a+64>>2];i=Pb(e,-16777216,16776704);w=p[a+72>>2];x=p[a+32>>2];k=c;y=p[c>>2];e=NNa(n,n>>31,f,f>>31);n=ib;f=e;e=(j>>>21&2040)+27824|0;j=(((v(o[e+2>>1],h)+v(o[e>>1],s)|0)+v(t,o[e+4>>1])|0)+v(u,o[e+6>>1])|0)/16384<<8;e=j;h=NNa(q,q>>31,e,e>>31);f=f+h|0;e=ib+n|0;e=f>>>0<h>>>0?e+1|0:e;h=f;f=p[a+68>>2];i=NNa(f,f>>31,i,i>>31);f=h+i|0;e=ib+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=p[a+28>>2]+m|0;h=m>>12;p[k>>2]=v(e,h)+y;l=l+x|0;i=l>>12;p[c+4>>2]=p[c+4>>2]+v(e,i);f=f-(j&w)|0;Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;j=p[g+8>>2];k=p[g+12>>2];e=b;continue}break}j=p[g+8>>2];k=p[g+12>>2];e=b}p[a+40>>2]=l;p[a+20>>2]=h;p[a+36>>2]=m;p[a+48>>2]=e;p[a+44>>2]=f;p[a+24>>2]=i;p[a>>2]=j;p[a+4>>2]=k;fb=g+16|0}function QD(a,b){var c=0,d=0,e=0,f=0;a:{b:{c:{c=p[a+4>>2];d:{if(c>>>0<s[a+104>>2]){p[a+4>>2]=c+1;c=q[c|0];break d}c=Sc(a)}switch(c+ -43|0){case 0:case 2:break b;default:break c}}b=c+ -48|0;break a}f=(c|0)==45;e=!b;b=p[a+4>>2];e:{if(b>>>0<s[a+104>>2]){p[a+4>>2]=b+1;c=q[b|0];break e}c=Sc(a)}b=c+ -48|0;if(!(e|b>>>0<10|!p[a+104>>2])){p[a+4>>2]=p[a+4>>2]+ -1}}f:{if(b>>>0<10){b=0;while(1){d=v(b,10)+c|0;b=p[a+4>>2];g:{if(b>>>0<s[a+104>>2]){p[a+4>>2]=b+1;c=q[b|0];break g}c=Sc(a)}e=c+ -48|0;b=d+ -48|0;if((b|0)<214748364?e>>>0<=9:0){continue}break}d=b;b=b>>31;h:{if(e>>>0>=10){break h}while(1){d=NNa(d,b,10,0);c=d+c|0;b=ib;b=c>>>0<d>>>0?b+1|0:b;c=c+ -48|0;b=b+ -1|0;b=c>>>0<4294967248?b+1|0:b;d=c;c=p[a+4>>2];i:{if(c>>>0<s[a+104>>2]){p[a+4>>2]=c+1;c=q[c|0];break i}c=Sc(a)}e=c+ -48|0;if(e>>>0>9){break h}if((b|0)<21474836?1:(b|0)<=21474836?d>>>0<2061584302:0){continue}break}}if(e>>>0<10){while(1){c=p[a+4>>2];j:{if(c>>>0<s[a+104>>2]){p[a+4>>2]=c+1;c=q[c|0];break j}c=Sc(a)}if(c+ -48>>>0<10){continue}break}}if(p[a+104>>2]){p[a+4>>2]=p[a+4>>2]+ -1}a=d;d=f?0-a|0:a;b=f?0-(b+(0<a>>>0)|0)|0:b;break f}b=-2147483648;if(!p[a+104>>2]){break f}p[a+4>>2]=p[a+4>>2]+ -1;ib=-2147483648;return 0}ib=b;return d}function fka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=w(0),j=w(0),k=0,l=0,m=0,n=w(0);h=fb-16|0;fb=h;a:{if(o[d>>1]>o[d+2>>1]){break a}if(!Bb(b)){break a}g=o[e>>1];if((g|0)<o[d>>1]){break a}k=o[d+2>>1];if((k|0)<(g|0)){break a}if((Bb(b)+ -1&65535)>>>0>(k-g&65535)>>>0|s[a+36>>2]>65535){break a}b:{if(!Bb(b)){break b}while(1){if(!(t[Fb(b,f)>>2]<w(0))){f=f+1|0;if(f>>>0<Bb(b)>>>0){continue}break b}break}f=0;break a}f=0;if(t[c>>2]<=w(0)){break a}o[a>>1]=1;o[a+28>>1]=r[d>>1];l=a,m=sI(Bb(b)),o[l+30>>1]=m;t[a+32>>2]=x(t[c>>2]);g=a+4|0;cl(g,(o[d+2>>1]-o[d>>1]|0)+1|0);c=Ub(b);b=Vb(b);l=h,m=Ub(g),p[l+8>>2]=m;dka(c,b,Yo(h+8|0,o[e>>1]-o[d>>1]|0));f=o[e>>1];c=o[a+28>>1];c:{if((f|0)<=(c|0)){b=f;break c}while(1){f=f+ -1|0;i=t[Fb(g,o[a+30>>1]+(f-c|0)|0)>>2];j=t[a+32>>2];l=Fb(g,f-o[a+28>>1]|0),n=w(i/j),t[l>>2]=n;b=o[e>>1];c=o[a+28>>1];if((f|0)<=(c|0)){break c}if((b|0)!=-32768){continue}break}}c=o[a+30>>1];f=c+b|0;d:{if((f|0)>o[d+2>>1]|(32767-c|0)<(b|0)){break d}while(1){i=t[a+32>>2];j=t[Fb(g,(f-c|0)-o[a+28>>1]|0)>>2];l=Fb(g,f-o[a+28>>1]|0),n=w(j*i),t[l>>2]=n;if((f|0)>=o[d+2>>1]){break d}f=f+1|0;c=o[a+30>>1];if((32767-c|0)>=o[e>>1]){continue}break}}qo(a);f=1}fb=h+16|0;return f|0}function yva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0;e=fb-48|0;fb=e;j=p[a+16>>2];f=Df(e+16|0);p[f+8>>2]=a+112;p[f+16>>2]=p[a+128>>2];n=f,q=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[n+12>>2]=q;b=p[f+16>>2];if(b){n=f,q=Cf(a+8|0,b),p[n>>2]=q;p[f+4>>2]=ib}k=p[a+24>>2];l=p[a+20>>2];b=p[a+4>>2];g=p[a>>2];p[e+8>>2]=g;p[e+12>>2]=b;h=p[a+12>>2];p[e>>2]=p[a+8>>2];p[e+4>>2]=h;if(d){while(1){h=0;i=g;p[e+40>>2]=g;p[e+44>>2]=m;g=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;a:{b=p[f+16>>2];if((b|0)<=0){break a}while(1){h=(h&2147483647)<<1|i>>>31;qd(p[f+8>>2],(o[(h<<1|2)+g>>1]+o[g+((h&2147483646)<<1)>>1]|0)/8<<16>>16);pd(p[f+8>>2],4);Kb(e+40|0,f);if((b|0)<2){break a}b=b+ -1|0;i=p[e+40>>2];h=p[e+44>>2];continue}}d=d+ -1|0;b=p[f+8>>2];Kb(b,b+8|0);b=p[f+8>>2];h=p[b+4>>2];if(h){i=b;b=(p[e+44>>2]&2147483647)<<1|p[e+40>>2]>>>31;qd(i,(o[(b<<1|2)+g>>1]+o[g+((b&2147483646)<<1)>>1]|0)/8<<16>>16);pd(p[f+8>>2],h);b=p[f+8>>2];h=p[b>>2];p[b>>2]=h;p[b+4>>2]=0}b=xf(b,p[f+12>>2]);p[c>>2]=p[c>>2]+v(b,l);p[c+4>>2]=p[c+4>>2]+v(b,k);Kb(e+8|0,e);if(d){c=c+8|0;g=p[e+8>>2];b=p[e+12>>2];continue}break}g=p[e+8>>2];b=p[e+12>>2]}p[a>>2]=g;p[a+4>>2]=b;fb=e+48|0}function T0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=fb-160|0;fb=a;p[a+144>>2]=c;p[a+152>>2]=b;p[a+20>>2]=2482;b=Hd(a+24|0,a+32|0,a+20|0);p[114610]=0;qc(a+16|0,e);h=p[114610];p[114610]=0;a:{b:{c:{d:{if((h|0)!=1){p[114610]=0;h=M(21,a+16|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break b}n[a+15|0]=0;e=p[e+4>>2];p[114610]=0;c=ma(2483,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}if(!c){break c}Me(g);if(!q[a+15|0]){break d}p[114610]=0;c=J(22,h|0,45)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}p[114610]=0;K(110,g|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){break d}break b}e=I()|0;H()|0;break a}p[114610]=0;h=J(22,h|0,48)|0;c=p[114610];p[114610]=0;if((c|0)!=1){e=p[b>>2];i=p[a+20>>2];c=i+ -1|0;d=e>>>0>c>>>0?e:c;h=h&255;while(1){e:{if(e>>>0<c>>>0){if((h|0)==q[e|0]){break e}d=e}p[114610]=0;P(2491,g|0,d|0,i|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break c}break b}e=e+1|0;continue}}break b}p[114610]=0;c=J(2423,a+152|0,a+144|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}if(c){p[f>>2]=p[f>>2]|2}c=p[a+152>>2];Gb(a+16|0);wc(b);fb=a+160|0;return c|0}e=I()|0;H()|0;Gb(a+16|0)}wc(b);L(e|0);E()}function mha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb+ -64|0;fb=c;gha(a);p[114610]=0;i=a;K(1754,a|0,11);b=p[114610];p[114610]=0;a:{if((b|0)!=1){b=80016;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{while(1){d=ug(44);l:{if(!d){p[c+60>>2]=0;break l}g=p[b>>2];f=p[b+4>>2];p[114610]=0;f=J(85,c+32|0,f|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break k}p[114610]=0;K(1755,c+48|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break j}e=p[b+8>>2];p[114610]=0;e=J(85,c|0,e|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break i}p[114610]=0;K(1755,c+16|0,e|0);h=p[114610];p[114610]=0;if((h|0)==1){break h}p[114610]=0;Z(1756,d|0,g|0,1,c+48|0,c+16|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break g}yb(c+16|0);pb(e);yb(c+48|0);pb(f);p[114610]=0;p[c+60>>2]=d;K(1757,i|0,c+60|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}d=p[c+60>>2];p[d+32>>2]=p[b+12>>2];p[d+36>>2]=p[b+16>>2];n[d+40|0]=q[b+20|0];n[d+41|0]=q[d+41|0]&253|q[b+21|0]<<1}b=b+24|0;if((b|0)!=80280){continue}break}fb=c- -64|0;return a|0}b=I()|0;H()|0;break c}b=I()|0;H()|0;break d}b=I()|0;H()|0;break e}b=I()|0;H()|0;break f}b=I()|0;H()|0;yb(c+16|0)}pb(e)}yb(c+48|0)}pb(f)}Nb(d);break a}b=I()|0;H()|0;break a}b=I()|0;H()|0}ww(i);L(b|0);E()}function hwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0;e=fb-32|0;fb=e;j=p[a+16>>2];a:{b:{c:{f=p[a+8>>2];g=p[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?f>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?f>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?f>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?f>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}k=p[a+24>>2];l=p[a+20>>2];b=p[a+4>>2];h=p[a>>2];p[e+24>>2]=h;p[e+28>>2]=b;p[e+16>>2]=f;p[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=o[a+14>>1];q=o[a+12>>1];r=o[a+10>>1];s=o[a+8>>1];t=o[a+6>>1];u=o[a+4>>1];w=o[a+2>>1];x=o[a>>1];b=0;a=1;while(1){p[(e+8|0)+(b<<2)>>2]=(((((((v(n[(b|-4)+f|0],w)+v(n[(b|-6)+f|0],x)|0)+v(n[(b|-2)+f|0],u)|0)+v(n[b+f|0],t)|0)+v(n[(b|2)+f|0],s)|0)+v(n[(b|4)+f|0],r)|0)+v(n[(b|6)+f|0],q)|0)+v(n[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],l);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],k);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;h=p[e+24>>2];b=p[e+28>>2];continue}break}h=p[e+24>>2];b=p[e+28>>2]}p[g>>2]=h;p[g+4>>2]=b;fb=e+32|0}function yqa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,r=0,s=0,t=0,w=0,y=0,z=0,B=0;j=fb-16|0;fb=j;y=j,z=v(p[a>>2],le(a)),p[y+4>>2]=z;vc(j+4|0,c);c=ub(b);l=u[e+8>>3];k=p[j+4>>2];a:{if(!k){break a}e=k;while(1){m=0;h=c;n=q[h+4|0]|q[h+5|0]<<8|(q[h+6|0]<<16|q[h+7|0]<<24);i=q[h|0]|q[h+1|0]<<8|(q[h+2|0]<<16|q[h+3|0]<<24);t=i<<24|i<<8&16711680;r=m;m=n<<24|i>>>8;h=n<<8|i>>>24;r=r|0;m=m&65280|h&255|t;h=n;f(0,((h&255)<<24|i>>>8)&-16777216|((h&16777215)<<8|i>>>24)&16711680|(h>>>8&65280|h>>>24)|r);f(1,m&2147483647);l=A(+g(),l);c=c+8|0;e=e+ -1|0;if(e){continue}break}if(!k|l==0){break a}w=1/l;c=p[a+20>>2];while(1){e=b;a=q[e+4|0]|q[e+5|0]<<8|(q[e+6|0]<<16|q[e+7|0]<<24);i=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);h=i<<24;t=0;n=i<<8&16711680|h;r=a<<24|i>>>8;h=a<<8|i>>>24;e=a;f(0,((e&255)<<24|i>>>8)&-16777216|((e&16777215)<<8|i>>>24)&16711680|(e>>>8&65280|e>>>24)|t);f(1,n|(r&65280|h&255));y=j,B=+g()*w,u[y+8>>3]=B;wf(j+8|0,-1,1);s=u[j+8>>3]*32768;u[j+8>>3]=s;a=c;s=Id(s);b:{if(x(s)<2147483648){e=~~s;break b}e=-2147483648}y=a,z=Mc(e),o[y>>1]=z;b=b+8|0;c=c+2|0;k=k+ -1|0;if(k){continue}break}}if(d){u[d>>3]=l}fb=j+16|0;return p[j+4>>2]}function VAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,t=0,u=0;d=fb+ -64|0;fb=d;t=d,u=pf(a)>>>5|0,o[t+32>>1]=u;o[d+16>>1]=3999;t=c,u=r[rf(d+32|0,d+16|0)>>1],o[t+480190>>1]=u;zy(b,r[c+480190>>1],0);a:{if(r[c+480190>>1]){h=d+62|0;k=d+58|0;l=d+56|0;n=d+52|0;m=d+60|0;i=1;j=1;while(1){f=cp(c,j&65535);Js(a,d+32|0);vd(f,0);pn(d,2,d+32|0);zc(d+16|0,d);p[114610]=0;J(369,((i<<5)+c|0)+946300|0,d+16|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}pb(d+16|0);o[f+32>>1]=64;p[f+24>>2]=8287;e=q[m|0]|q[m+1|0]<<8;o[d+16>>1]=(e<<24|e<<8&16711680)>>>16;o[d>>1]=64;t=f,u=r[rf(d+16|0,d)>>1]<<2,o[t+30>>1]=u;e=n;e=(q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))&-16777217;p[f>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=q[l|0]|q[l+1|0]<<8;g=q[k|0]|q[k+1|0]<<8;g=(g<<24|g<<8&16711680)>>>16|0;b:{if(g>>>0<2){break b}e=(e<<8&16711680|e<<24)>>>15|0;g=e+(g<<1)|0;if(g>>>0>s[f>>2]){break b}p[f+16>>2]=g;p[f+12>>2]=e;o[f+34>>1]=r[f+34>>1]|8}if(q[h|0]|q[h+1|0]<<8){e=(q[h|0]|q[h+1|0]<<8)==512}else{e=1}Wd(d+16|0,b,i+ -1|0);Zd(d+16|0,e);j=j+1|0;i=j&65535;if(i>>>0<=r[c+480190>>1]){continue}break}}fb=d- -64|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function K0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=fb-448|0;fb=a;p[a+432>>2]=c;p[a+440>>2]=b;p[a+20>>2]=2482;b=Hd(a+24|0,a+32|0,a+20|0);p[114610]=0;qc(a+16|0,e);h=p[114610];p[114610]=0;a:{b:{c:{d:{if((h|0)!=1){p[114610]=0;h=M(2449,a+16|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break b}n[a+15|0]=0;e=p[e+4>>2];p[114610]=0;c=ma(2493,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}if(!c){break c}J0(g);if(!q[a+15|0]){break d}p[114610]=0;c=J(2475,h|0,45)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}p[114610]=0;K(112,g|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){break d}break b}e=I()|0;H()|0;break a}p[114610]=0;c=J(2475,h|0,48)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}e=p[b>>2];d=p[a+20>>2];h=d+ -4|0;while(1){if(!((c|0)!=p[e>>2]|e>>>0>=h>>>0)){e=e+4|0;continue}break}p[114610]=0;P(2499,g|0,e|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break c}break b}p[114610]=0;c=J(2455,a+440|0,a+432|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}if(c){p[f>>2]=p[f>>2]|2}c=p[a+440>>2];Gb(a+16|0);wc(b);fb=a+448|0;return c|0}e=I()|0;H()|0;Gb(a+16|0)}wc(b);L(e|0);E()}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;b=fb-2144|0;fb=b;Jb(b+96|0,0,2048);a:{b:{c:{f=p[c+4>>2];if(!f){a=W(8)|0;p[114610]=0;b=J(85,b+80|0,38559)|0;c=p[114610];p[114610]=0;if((c|0)==1){break c}dc(a,b);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}c=I()|0;H()|0;pb(b);break b}g=p[c>>2];d=p[c+8>>2];e=p[c+12>>2];p[b+76>>2]=e;p[b+72>>2]=d;c=p[b+76>>2];p[b+24>>2]=p[b+72>>2];p[b+28>>2]=c;p[b+68>>2]=f;p[b+64>>2]=g;c=p[b+68>>2];p[b+16>>2]=p[b+64>>2];p[b+20>>2]=c;c=b;i=b;h=bQ(b+16|0);if(h){p[b+52>>2]=e;p[b+48>>2]=d;d=p[b+52>>2];p[b+8>>2]=p[b+48>>2];p[b+12>>2]=d;p[b+44>>2]=f;p[b+40>>2]=g;d=p[b+44>>2];p[b>>2]=p[b+40>>2];p[b+4>>2]=d;d=_P(b)}else{d=0}p[i+56>>2]=d;p[c+60>>2]=0;d=0;c=2048;while(1){if(c){e=m[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}a=Qr(a,yl(b+32|0,ub(b+96|0),d),h?b+56|0:0);if(a+1>>>0>=3){a=W(8)|0;p[114610]=0;b=J(85,b+80|0,38544)|0;c=p[114610];p[114610]=0;if((c|0)!=1){dc(a,b);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}c=I()|0;H()|0;pb(b);break b}c=I()|0;H()|0;X(a|0);break b}fb=b+2144|0;return a|0}c=I()|0;H()|0;X(a|0)}L(c|0)}E()}function gDa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;vd(b,0);f=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);a:{if(c&34){if(d){p[b+24>>2]=f;break a}g=b,h=ek(Kg(+(f+1408|0)*.0006510416666666666)*8363),p[g+24>>2]=h;break a}n[b+37|0]=(c|0)==16?f:f^128;n[b+36|0]=q[a+4|0]}n[e+15|0]=q[a+5|0];n[e+14|0]=64;g=b,h=q[hc(e+15|0,e+14|0)|0]<<2,o[g+30>>1]=h;d=a+6|0;if((q[d|0]|q[d+1|0]<<8)>>>0<=256){o[b+28>>1]=q[d|0]|q[d+1|0]<<8;o[b+34>>1]=r[b+34>>1]|32}d=a+8|0;p[b>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=a+12|0;p[b+4>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=a+16|0;p[b+8>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=a+20|0;if(q[d|0]&16){o[b+34>>1]=r[b+34>>1]|2}if(q[d|0]&32){o[b+34>>1]=r[b+34>>1]|4}if(n[d+1|0]&1){o[b+34>>1]=r[b+34>>1]|8}if(q[d+1|0]&2){o[b+34>>1]=r[b+34>>1]|16}n[b+38|0]=q[(q[a+22|0]&7)+27808|0];n[b+39|0]=q[a+23|0];n[b+40|0]=q[a+24|0];n[b+41|0]=q[a+25|0];if((c|0)==32){n[e+13|0]=q[a+26|0];n[e+12|0]=64;g=b,h=q[hc(e+13|0,e+12|0)|0],o[g+32>>1]=h}c=a+27|0;p[b+12>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);a=a+31|0;p[b+16>>2]=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);fb=e+16|0}function xm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-80|0;fb=c;g=kw(a);e=b+24|0;a:{b:{if(Ah(p[e>>2]+484360|0)){if(Ah(p[e>>2]+484360|0)){a=0;while(1){f=p[e>>2];b=jw(RO(c+40|0,1),a&255,0,0);p[114610]=0;d=p[b+12>>2];p[c+8>>2]=p[b+8>>2];p[c+12>>2]=d;d=p[b+20>>2];p[c+16>>2]=p[b+16>>2];p[c+20>>2]=d;d=p[b+4>>2];p[c>>2]=p[b>>2];p[c+4>>2]=d;Q(2129,c- -64|0,f|0,0,c|0);b=p[114610];p[114610]=0;c:{d:{if((b|0)!=1){i=c,j=Ub(c- -64|0),p[i+32>>2]=j;i=c,j=Vb(c- -64|0),p[i+24>>2]=j;if(Ab(c+32|0,c+24|0)){break d}break c}a=I()|0;H()|0;break b}while(1){e:{b=p[c+32>>2];f=r[b+24>>1];h=u[b>>3];d=p[b+16>>2];b=c+40|0;p[b+16>>2]=a;p[b+12>>2]=f;p[b+8>>2]=d;u[b>>3]=h;p[114610]=0;K(2130,g|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}Zx(c+32|0);if(Ab(c+32|0,c+24|0)){continue}break c}break}a=I()|0;H()|0;ck(c- -64|0);break b}ck(c- -64|0);a=a+1|0;if(a>>>0<Ah(p[e>>2]+484360|0)>>>0){continue}break}}fb=c+80|0;return}b=W(8)|0;p[114610]=0;c=J(85,c+40|0,38497)|0;a=p[114610];p[114610]=0;if((a|0)!=1){dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}a=I()|0;H()|0;X(b|0)}gf(g);L(a|0)}E()}function I_(a,b,c,d,e,f){var g=0,h=0;p[c>>2]=a;p[f>>2]=d;g=p[c>>2];a:{b:{while(1){if(g>>>0>=b>>>0){a=0;break a}a=2;d=r[g>>1];if(d>>>0>1114111){break a}c:{d:{if(d>>>0<=127){a=1;g=p[f>>2];if((e-g|0)<1){break a}p[f>>2]=g+1;n[g|0]=d;break d}if(d>>>0<=2047){a=p[f>>2];if((e-a|0)<2){break b}p[f>>2]=a+1;n[a|0]=d>>>6|192;a=p[f>>2];p[f>>2]=a+1;n[a|0]=d&63|128;break d}if(d>>>0<=55295){a=p[f>>2];if((e-a|0)<3){break b}p[f>>2]=a+1;n[a|0]=d>>>12|224;a=p[f>>2];p[f>>2]=a+1;n[a|0]=d>>>6&63|128;a=p[f>>2];p[f>>2]=a+1;n[a|0]=d&63|128;break d}if(d>>>0<=56319){a=1;if((b-g|0)<4){break a}h=r[g+2>>1];if((h&64512)!=56320){break c}if((e-p[f>>2]|0)<4){break a}a=d&960;if((h&1023|(d<<10&64512|a<<10))+65536>>>0>1114111){break c}p[c>>2]=g+2;g=p[f>>2];p[f>>2]=g+1;a=(a>>>6|0)+1|0;n[g|0]=a>>>2|240;g=p[f>>2];p[f>>2]=g+1;n[g|0]=a<<4&48|d>>>2&15|128;a=p[f>>2];p[f>>2]=a+1;n[a|0]=h>>>6&15|d<<4&48|128;a=p[f>>2];p[f>>2]=a+1;n[a|0]=h&63|128;break d}if(d>>>0<57344){break a}a=p[f>>2];if((e-a|0)<3){break b}p[f>>2]=a+1;n[a|0]=d>>>12|224;a=p[f>>2];p[f>>2]=a+1;n[a|0]=d>>>6&63|128;a=p[f>>2];p[f>>2]=a+1;n[a|0]=d&63|128}g=p[c>>2]+2|0;p[c>>2]=g;continue}break}return 2}return 1}return a}function oY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(Xf(a,p[b+8>>2],e)){Cu(b,c,d);return}a:{if(Xf(a,p[b>>2],e)){if(!(p[b+20>>2]!=(c|0)?p[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}p[b+32>>2]=1;return}p[b+32>>2]=d;if(p[b+44>>2]!=4){f=a+16|0;i=f+(p[a+12>>2]<<3)|0;j=b;b:{c:{while(1){d:{if(f>>>0>=i>>>0){break d}o[b+52>>1]=0;Bu(f,b,c,c,1,e);if(q[b+54|0]){break d}e:{if(!q[b+53|0]){break e}if(q[b+52|0]){d=1;if(p[b+24>>2]==1){break c}h=1;g=1;if(q[a+8|0]&2){break e}break c}h=1;d=g;if(!(n[a+8|0]&1)){break c}}f=f+8|0;continue}break}d=g;a=4;if(!h){break b}}a=3}p[j+44>>2]=a;if(d&1){break a}}p[b+20>>2]=c;p[b+40>>2]=p[b+40>>2]+1;if(p[b+36>>2]!=1|p[b+24>>2]!=2){break a}n[b+54|0]=1;return}g=p[a+12>>2];f=a+16|0;qq(f,b,c,d,e);if((g|0)<2){break a}g=f+(g<<3)|0;f=a+24|0;a=p[a+8>>2];if(!(p[b+36>>2]!=1?!(a&2):0)){while(1){if(q[b+54|0]){break a}qq(f,b,c,d,e);f=f+8|0;if(f>>>0<g>>>0){continue}break}break a}if(!(a&1)){while(1){if(q[b+54|0]|p[b+36>>2]==1){break a}qq(f,b,c,d,e);f=f+8|0;if(f>>>0<g>>>0){continue}break a}}while(1){if(q[b+54|0]|(p[b+24>>2]==1?p[b+36>>2]==1:0)){break a}qq(f,b,c,d,e);f=f+8|0;if(f>>>0<g>>>0){continue}break}}}function wva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-48|0;fb=e;l=p[a+16>>2];f=Df(e+16|0);p[f+8>>2]=a+112;p[f+16>>2]=p[a+128>>2];m=f,n=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[m+12>>2]=n;b=p[f+16>>2];if(b){m=f,n=Cf(a+8|0,b),p[m>>2]=n;p[f+4>>2]=ib}j=p[a+40>>2];k=p[a+36>>2];g=p[a+4>>2];h=p[a>>2];p[e+8>>2]=h;p[e+12>>2]=g;b=p[a+12>>2];p[e>>2]=p[a+8>>2];p[e+4>>2]=b;a:{if(!d){b=j>>12;i=k>>12;break a}while(1){b=0;i=b;p[e+40>>2]=h;p[e+44>>2]=b;g=(g<<1)+l|0;b:{b=p[f+16>>2];if((b|0)<=0){break b}while(1){qd(p[f+8>>2],o[(i<<1)+g>>1]/4<<16>>16);pd(p[f+8>>2],4);Kb(e+40|0,f);if((b|0)<2){break b}b=b+ -1|0;i=p[e+44>>2];continue}}d=d+ -1|0;b=p[f+8>>2];Kb(b,b+8|0);b=p[f+8>>2];h=p[b+4>>2];if(h){qd(b,o[g+(p[e+44>>2]<<1)>>1]/4<<16>>16);pd(p[f+8>>2],h);b=p[f+8>>2];h=p[b>>2];p[b>>2]=h;p[b+4>>2]=0}g=xf(b,p[f+12>>2]);b=p[a+32>>2];k=p[a+28>>2]+k|0;i=k>>12;p[c>>2]=p[c>>2]+v(g,i);j=b+j|0;b=j>>12;p[c+4>>2]=p[c+4>>2]+v(g,b);Kb(e+8|0,e);if(d){c=c+8|0;h=p[e+8>>2];g=p[e+12>>2];continue}break}h=p[e+8>>2];g=p[e+12>>2]}p[a+40>>2]=j;p[a+20>>2]=i;p[a+36>>2]=k;p[a+24>>2]=b;p[a>>2]=h;p[a+4>>2]=g;fb=e+48|0}function nha(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-80|0;fb=d;f=Mb(d+48|0,VJ(b));p[114610]=0;K(1603,d- -64|0,f|0);e=p[114610];p[114610]=0;a:{b:{c:{if((e|0)!=1){pb(f);k=d,l=Ub(a),p[k+40>>2]=l;k=d,l=Vb(a),p[k+32>>2]=l;if(!Ab(d+40|0,d+32|0)){a=0;break a}i=b+20|0;j=b+16|0;f=0;while(1){a=0;g=p[d+40>>2];e=j;if(p[p[g>>2]+32>>2]==(q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))){a=i;a=p[p[g>>2]+36>>2]==(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))}e=p[g>>2];p[114610]=0;K(1753,d|0,e+8|0);e=p[114610];p[114610]=0;d:{e:{f:{g:{if((e|0)!=1){p[114610]=0;K(1603,d+16|0,d|0);e=p[114610];p[114610]=0;if((e|0)==1){break g}e=hf(d+16|0,d- -64|0);pb(d+16|0);pb(d);if((a&e)!=1){break e}f=p[g>>2];h=3;break d}a=I()|0;H()|0;break f}a=I()|0;H()|0;pb(d)}f=d- -64|0;break b}if(!(a^1|(h|0)>1)){f=p[g>>2];h=2;break d}a=e&(h|0)<1;f=a?p[g>>2]:f;h=a?1:h}Rd(d+40|0);if(Ab(d+40|0,d+32|0)){continue}break}break c}a=I()|0;H()|0;break b}a=0;if(!f){break a}e=p[f+4>>2];if(!e){break a}p[114610]=0;a=P(e|0,f|0,c|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){a=(a|0)!=0;break a}f=d- -64|0;a=I()|0;H()|0}pb(f);L(a|0);E()}pb(d- -64|0);fb=d+80|0;return a}function Av(a,b,c,d){var e=0,h=0,i=0,j=0,k=0,l=0,m=0;i=fb-32|0;fb=i;e=d&2147483647;k=e;e=e+ -1006698496|0;j=c;h=c;if(c>>>0<0){e=e+1|0}l=h;h=e;e=k+ -1140785152|0;m=j;if(j>>>0<0){e=e+1|0}a:{if((e|0)==(h|0)&l>>>0<m>>>0|h>>>0<e>>>0){e=d<<4|c>>>28;c=c<<4|b>>>28;b=b&268435455;j=b;if((b|0)==134217728&a>>>0>=1|b>>>0>134217728){e=e+1073741824|0;a=c+1|0;if(a>>>0<1){e=e+1|0}h=a;break a}h=c;e=e-((c>>>0<0)+ -1073741824|0)|0;if(a|j^134217728){break a}a=h+(h&1)|0;if(a>>>0<h>>>0){e=e+1|0}h=a;break a}if(!(!j&(k|0)==2147418112?!(a|b):(k|0)==2147418112&j>>>0<0|k>>>0<2147418112)){e=d<<4|c>>>28;h=c<<4|b>>>28;e=e&524287|2146959360;break a}h=0;e=2146435072;if(k>>>0>1140785151){break a}e=0;j=k>>>16|0;if(j>>>0<15249){break a}e=d&65535|65536;ef(i+16|0,a,b,c,e,j+ -15233|0);om(i,a,b,c,e,15361-j|0);c=p[i+4>>2];a=p[i+8>>2];e=p[i+12>>2]<<4|a>>>28;h=a<<4|c>>>28;a=c&268435455;c=a;b=p[i>>2]|((p[i+16>>2]|p[i+24>>2])!=0|(p[i+20>>2]|p[i+28>>2])!=0);if((a|0)==134217728&b>>>0>=1|a>>>0>134217728){a=h+1|0;if(a>>>0<1){e=e+1|0}h=a;break a}if(b|c^134217728){break a}a=h+(h&1)|0;if(a>>>0<h>>>0){e=e+1|0}h=a}fb=i+32|0;f(0,h|0);f(1,d&-2147483648|e);return+g()}function U6(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,p=0,s=w(0),u=0,x=w(0);i=fb-48|0;fb=i;k=!q[d+13|0]+(q[d+14|0]!=0)|0;l=q[d+25|0];m=i;o=b;p=i+44|0;a:{if(q[a+1|0]&8){f=q[d+27|0];g=q[r[d+8>>1]+43424|0];h=g&3;n[i+47|0]=h;n[i+46|0]=h;h=g>>>2|0;n[i+45|0]=h;n[i+44|0]=h;b=v(k,28)+43328|0;break a}f=(q[a+3|0]&16)>>>4&(f|0)!=0;b=f?12:0;g=r[d+8>>1]>>>f|0;while(1){j=1;f=3;while(1){h=f;f=q[(f+b|0)+43440|0];n[h+(i+44|0)|0]=((g|0)/(j|0)|0)%(f|0);j=v(f,j);f=h+ -1|0;if(h){continue}break}b=b+4|0;g=g-j|0;if((g|0)>-1){continue}break}f=-16;b=(v(k,28)+43328|0)+b|0}H6(m,o,p,b,c,f);h=q[d+14|0];b:{if(h){b=2-l|0;k=q[d+23|0]<<b;f=q[d+22|0]<<b;c=q[d+21|0]<<b;b=q[d+13|0];j=0;while(1){g=(b+j|0)+i|0;n[g|0]=c+q[g|0];n[g+1|0]=f+q[g+1|0];n[g+2|0]=k+q[g+2|0];j=j+3|0;if(j>>>0<h>>>0){continue}break}break b}if(!q[d+24|0]){break b}f=0;while(1){b=f+i|0;n[b+11|0]=q[b+11|0]+q[f+43464|0];f=f+1|0;if((f|0)!=10){continue}break}}s=Pv(w(2048),((((q[a+3|0]&224)==96)<<1)-q[d+10|0]|0)+258|0);f=0;if((h|0)!=(0-q[d+13|0]|0)){a=l+1|0;while(1){u=(f<<2)+e|0,x=Pv(s,q[f+i|0]<<a),t[u>>2]=x;f=f+1|0;if(f>>>0<q[d+14|0]+q[d+13|0]>>>0){continue}break}}fb=i+48|0}function zva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0;e=fb-48|0;fb=e;j=p[a+16>>2];f=Df(e+16|0);p[f+8>>2]=a+112;p[f+16>>2]=p[a+128>>2];o=f,q=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[o+12>>2]=q;b=p[f+16>>2];if(b){o=f,q=Cf(a+8|0,b),p[o>>2]=q;p[f+4>>2]=ib}k=p[a+24>>2];l=p[a+20>>2];b=p[a+4>>2];g=p[a>>2];p[e+8>>2]=g;p[e+12>>2]=b;h=p[a+12>>2];p[e>>2]=p[a+8>>2];p[e+4>>2]=h;if(d){while(1){h=0;i=g;p[e+40>>2]=g;p[e+44>>2]=m;g=(((b&2147483647)<<1|g>>>31)&-2)+j|0;a:{b=p[f+16>>2];if((b|0)<=0){break a}while(1){h=(h&2147483647)<<1|i>>>31;qd(p[f+8>>2],n[(h|1)+g|0]+n[g+(h&-2)|0]<<5);pd(p[f+8>>2],4);Kb(e+40|0,f);if((b|0)<2){break a}b=b+ -1|0;i=p[e+40>>2];h=p[e+44>>2];continue}}d=d+ -1|0;b=p[f+8>>2];Kb(b,b+8|0);b=p[f+8>>2];h=p[b+4>>2];if(h){i=b;b=(p[e+44>>2]&2147483647)<<1|p[e+40>>2]>>>31;qd(i,n[(b|1)+g|0]+n[g+(b&-2)|0]<<5);pd(p[f+8>>2],h);b=p[f+8>>2];h=p[b>>2];p[b>>2]=h;p[b+4>>2]=0}b=xf(b,p[f+12>>2]);p[c>>2]=p[c>>2]+v(b,l);p[c+4>>2]=p[c+4>>2]+v(b,k);Kb(e+8|0,e);if(d){c=c+8|0;g=p[e+8>>2];b=p[e+12>>2];continue}break}g=p[e+8>>2];b=p[e+12>>2]}p[a>>2]=g;p[a+4>>2]=b;fb=e+48|0}function Dwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;g=fb-16|0;fb=g;f=p[a+48>>2];l=p[a+40>>2];m=p[a+36>>2];e=p[a+44>>2];r=p[a+16>>2];j=p[a+4>>2];h=p[a>>2];p[g+8>>2]=h;p[g+12>>2]=j;b=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=b;a:{if(!d){i=l>>12;o=m>>12;break a}while(1){b=j+r|0;i=n[b+1|0];o=n[b|0];b=p[a+60>>2];s=b;t=b>>31;b=e;e=Pb(e,-16777216,16776704);k=p[a+64>>2];f=Pb(f,-16777216,16776704);u=p[a+72>>2];w=p[a+32>>2];j=c;x=p[c>>2];e=NNa(k,k>>31,e,e>>31);k=ib;y=e;e=p[a+68>>2];q=NNa(e,e>>31,f,f>>31);e=y+q|0;f=ib+k|0;f=e>>>0<q>>>0?f+1|0:f;k=e;e=o<<8;h=((v((i<<8)-e|0,h>>>18|0)|0)/16384|0)+e<<8;e=h;i=NNa(s,t,e,e>>31);e=k+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=p[a+28>>2]+m|0;o=m>>12;p[j>>2]=v(f,o)+x;l=l+w|0;i=l>>12;p[c+4>>2]=p[c+4>>2]+v(f,i);e=e-(h&u)|0;Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;h=p[g+8>>2];j=p[g+12>>2];f=b;continue}break}h=p[g+8>>2];j=p[g+12>>2];f=b}p[a+40>>2]=l;p[a+20>>2]=o;p[a+36>>2]=m;p[a+48>>2]=f;p[a+44>>2]=e;p[a+24>>2]=i;p[a>>2]=h;p[a+4>>2]=j;fb=g+16|0}function qo(a){a=a|0;var b=0,c=0,d=0,e=0,f=w(0),g=0,h=w(0),i=0,j=0,k=0,l=w(0);c=p[a+36>>2];if(!c){bi(a+16|0);return}a:{b:{c:{switch(r[a>>1]){case 3:d=a+16|0;if(c>>>0>=1001){bi(d);return}cl(d,c);c=r[a+28>>1];b=a+4|0;Bb(b);f=dl(a,(c<<16)+65536>>16);c=o[a+28>>1];Bb(b);b=1;f=fe(w(f/dl(a,c)),w(w(1)/w(p[a+36>>2]+1>>>0)));if(!p[a+36>>2]){break b}while(1){h=fe(f,w(b>>>0));k=Fb(d,b+ -1|0),l=h,t[k>>2]=l;b=b+1|0;if(b>>>0<=s[a+36>>2]){continue}break}break b;case 1:d=a+16|0;g=r[a+30>>1];if(1e3/(c>>>0)>>>0<g>>>0){bi(d);return}cl(d,v(c,g));c=o[a+28>>1];Bb(a+4|0);b=r[a+30>>1];if((c|0)>=0){c=(c|0)%(b|0)|0}else{c=((c^-1)%(b|0)^-1)+b|0}if(!g){break b}while(1){b=b&65535;e=c+i<<16>>16;d:{if((e|0)>=0){b=(e|0)%(b|0)|0;break d}b=b+((e^-1)%(b|0)^-1)|0}e=1;b=b<<16;j=b>>16;f=fe(w(dl(a,b+65536>>16)/dl(a,j)),w(w(1)/w(p[a+36>>2]+1>>>0)));b=1;if(p[a+36>>2]){while(1){h=fe(f,w((b&65535)>>>0));k=Fb(d,(v(p[a+36>>2],j)+e|0)+ -1|0),l=h,t[k>>2]=l;b=b+1|0;e=b&65535;if(s[a+36>>2]>=e>>>0){continue}break}}i=i+1|0;if((i&65535)>>>0>=g>>>0){break b}b=r[a+30>>1];continue};case 0:break a;default:break c}}bi(a+16|0);p[a+36>>2]=0}return}bi(a+16|0)}function Iqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;p[f+8>>2]=c>>>4;p[f+4>>2]=p[a>>2];d=p[Cb(f+8|0,f+4|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){e=b;g=q[e+4|0]|q[e+5|0]<<8|(q[e+6|0]<<16|q[e+7|0]<<24);h=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);e=g;j=h<<8&16711680|h<<24;k=e<<24|h>>>8;g=e<<8|h>>>24;j=k&65280|g&255|j;p[f+8>>2]=((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|l;p[f+12>>2]=j;wf(f+8|0,-1,1);i=u[f+8>>3]*32768;u[f+8>>3]=i;e=a;i=Id(i);a:{if(x(i)<2147483648){g=~~i;break a}g=-2147483648}m=e,n=Mc(g),o[m>>1]=n;e=b;g=q[e+12|0]|q[e+13|0]<<8|(q[e+14|0]<<16|q[e+15|0]<<24);h=q[e+8|0]|q[e+9|0]<<8|(q[e+10|0]<<16|q[e+11|0]<<24);e=g;j=h<<8&16711680|h<<24;k=e<<24|h>>>8;g=e<<8|h>>>24;j=k&65280|g&255|j;p[f+8>>2]=((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|l;p[f+12>>2]=j;wf(f+8|0,-1,1);i=u[f+8>>3]*32768;u[f+8>>3]=i;e=a;i=Id(i);b:{if(x(i)<2147483648){g=~~i;break b}g=-2147483648}m=e,n=Mc(g),o[m+2>>1]=n;a=a+4|0;b=b+16|0;c=c+ -1|0;if(c){continue}break}}fb=f+16|0;return d<<4}function Cwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;g=fb-16|0;fb=g;f=p[a+48>>2];l=p[a+40>>2];m=p[a+36>>2];e=p[a+44>>2];r=p[a+16>>2];j=p[a+4>>2];i=p[a>>2];p[g+8>>2]=i;p[g+12>>2]=j;b=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=b;a:{if(!d){h=l>>12;n=m>>12;break a}while(1){b=(j<<1)+r|0;n=o[b+2>>1];h=o[b>>1];b=p[a+60>>2];s=b;t=b>>31;b=e;e=Pb(e,-16777216,16776704);k=p[a+64>>2];f=Pb(f,-16777216,16776704);u=p[a+72>>2];w=p[a+32>>2];j=c;x=p[c>>2];e=NNa(k,k>>31,e,e>>31);k=ib;y=e;e=p[a+68>>2];q=NNa(e,e>>31,f,f>>31);e=y+q|0;f=ib+k|0;f=e>>>0<q>>>0?f+1|0:f;k=e;i=h+((v(n-h|0,i>>>18|0)|0)/16384|0)<<8;e=i;h=NNa(s,t,e,e>>31);e=k+h|0;f=ib+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=p[a+28>>2]+m|0;n=m>>12;p[j>>2]=v(f,n)+x;l=l+w|0;h=l>>12;p[c+4>>2]=p[c+4>>2]+v(f,h);e=e-(i&u)|0;Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;i=p[g+8>>2];j=p[g+12>>2];f=b;continue}break}i=p[g+8>>2];j=p[g+12>>2];f=b}p[a+40>>2]=l;p[a+20>>2]=n;p[a+36>>2]=m;p[a+48>>2]=f;p[a+44>>2]=e;p[a+24>>2]=h;p[a>>2]=i;p[a+4>>2]=j;fb=g+16|0}function ac(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){Ja(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if((c|0)<1){c=a;break b}if(!(a&3)){c=a;break b}c=a;while(1){n[c|0]=q[b|0];b=b+1|0;c=c+1|0;if(c>>>0>=e>>>0){break b}if(c&3){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+ -64|0;if(c>>>0>f>>>0){break c}while(1){p[c>>2]=p[b>>2];p[c+4>>2]=p[b+4>>2];p[c+8>>2]=p[b+8>>2];p[c+12>>2]=p[b+12>>2];p[c+16>>2]=p[b+16>>2];p[c+20>>2]=p[b+20>>2];p[c+24>>2]=p[b+24>>2];p[c+28>>2]=p[b+28>>2];p[c+32>>2]=p[b+32>>2];p[c+36>>2]=p[b+36>>2];p[c+40>>2]=p[b+40>>2];p[c+44>>2]=p[b+44>>2];p[c+48>>2]=p[b+48>>2];p[c+52>>2]=p[b+52>>2];p[c+56>>2]=p[b+56>>2];p[c+60>>2]=p[b+60>>2];b=b- -64|0;c=c- -64|0;if(c>>>0<=f>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){p[c>>2]=p[b>>2];b=b+4|0;c=c+4|0;if(c>>>0<d>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e+ -4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){n[c|0]=q[b|0];n[c+1|0]=q[b+1|0];n[c+2|0]=q[b+2|0];n[c+3|0]=q[b+3|0];b=b+4|0;c=c+4|0;if(c>>>0<=d>>>0){continue}break}}if(c>>>0<e>>>0){while(1){n[c|0]=q[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function A_(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;p[c>>2]=a;p[f>>2]=d;a:{b:{while(1){c:{g=p[c>>2];if(g>>>0>=b>>>0){break c}j=p[f>>2];if(j>>>0>=e>>>0){break c}a=n[g|0];d=a&255;d:{if((a|0)>=0){if(d>>>0<=1114111){a=1;break d}return 2}k=2;if(d>>>0<194){break b}if(d>>>0<=223){if((b-g|0)<2){break a}h=q[g+1|0];if((h&192)!=128){break b}a=2;d=h&63|d<<6&1984;if(d>>>0<=1114111){break d}break b}if(d>>>0<=239){if((b-g|0)<3){break a}i=q[g+2|0];h=q[g+1|0];e:{f:{if((d|0)!=237){if((d|0)!=224){break f}if((h&224)==160){break e}break b}if((h&224)==128){break e}break b}if((h&192)!=128){break b}}if((i&192)!=128){break b}a=3;d=i&63|(d<<12&61440|(h&63)<<6);if(d>>>0<=1114111){break d}break b}if(d>>>0>244){break b}if((b-g|0)<4){break a}i=q[g+3|0];l=q[g+2|0];h=q[g+1|0];g:{h:{switch(d+ -240|0){case 0:if((h+112&255)>>>0<48){break g}break b;case 4:if((h&240)==128){break g}break b;default:break h}}if((h&192)!=128){break b}}if((l&192)!=128|(i&192)!=128){break b}a=4;d=i&63|(l<<6&4032|(d<<18&1835008|(h&63)<<12));if(d>>>0>1114111){break b}}p[j>>2]=d;p[c>>2]=a+g;p[f>>2]=p[f>>2]+4;continue}break}k=g>>>0<b>>>0}return k}return 1}function Tk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;p[a+4>>2]=0;if(q[Qi(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=p[p[a>>2]+ -12>>2];p[114610]=0;b=p[(a+b|0)+24>>2];d=p[114610];p[114610]=0;if((d|0)==1){break c}p[114610]=0;b=M(2323,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}if(me(b,-1)){break b}p[a+4>>2]=p[a+4>>2]+1;if(!me(b,c)){continue}break}d=0;break a}while(1){if(p[a+4>>2]>=(b|0)){break a}e=p[p[a>>2]+ -12>>2];p[114610]=0;e=p[(a+e|0)+24>>2];g=p[114610];p[114610]=0;d:{if((g|0)==1){break d}p[114610]=0;e=M(2323,e|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break d}if(me(e,-1)){break b}p[a+4>>2]=p[a+4>>2]+1;if(!me(e,c)){continue}break a}break}}b=O(0)|0;H()|0;T(b|0)|0;Oi(p[p[a>>2]+ -12>>2]+a|0,1);b=p[p[a>>2]+ -12>>2];p[114610]=0;b=p[(a+b|0)+20>>2];c=p[114610];p[114610]=0;e:{f:{g:{if((c|0)!=1){if(!(b&1)){break g}p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)!=1){break e}}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break f}L(a|0);E()}V();d=1;break a}a=O(0)|0;H()|0;rb(a)}E()}d=2}mg(p[p[a>>2]+ -12>>2]+a|0,d)}fb=f+16|0;return a|0}function xva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0;e=fb-48|0;fb=e;l=p[a+16>>2];f=Df(e+16|0);p[f+8>>2]=a+112;p[f+16>>2]=p[a+128>>2];m=f,o=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[m+12>>2]=o;b=p[f+16>>2];if(b){m=f,o=Cf(a+8|0,b),p[m>>2]=o;p[f+4>>2]=ib}j=p[a+40>>2];k=p[a+36>>2];g=p[a+4>>2];h=p[a>>2];p[e+8>>2]=h;p[e+12>>2]=g;b=p[a+12>>2];p[e>>2]=p[a+8>>2];p[e+4>>2]=b;a:{if(!d){b=j>>12;i=k>>12;break a}while(1){b=0;i=b;p[e+40>>2]=h;p[e+44>>2]=b;g=g+l|0;b:{b=p[f+16>>2];if((b|0)<=0){break b}while(1){qd(p[f+8>>2],n[g+i|0]<<6);pd(p[f+8>>2],4);Kb(e+40|0,f);if((b|0)<2){break b}b=b+ -1|0;i=p[e+44>>2];continue}}d=d+ -1|0;b=p[f+8>>2];Kb(b,b+8|0);b=p[f+8>>2];h=p[b+4>>2];if(h){qd(b,n[g+p[e+44>>2]|0]<<6);pd(p[f+8>>2],h);b=p[f+8>>2];h=p[b>>2];p[b>>2]=h;p[b+4>>2]=0}g=xf(b,p[f+12>>2]);b=p[a+32>>2];k=p[a+28>>2]+k|0;i=k>>12;p[c>>2]=p[c>>2]+v(g,i);j=b+j|0;b=j>>12;p[c+4>>2]=p[c+4>>2]+v(g,b);Kb(e+8|0,e);if(d){c=c+8|0;h=p[e+8>>2];g=p[e+12>>2];continue}break}h=p[e+8>>2];g=p[e+12>>2]}p[a+40>>2]=j;p[a+20>>2]=i;p[a+36>>2]=k;p[a+24>>2]=b;p[a>>2]=h;p[a+4>>2]=g;fb=e+48|0}function Nga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=w(0),g=w(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=w(0),s=0,u=0,v=0,y=w(0);a:{if(!p[a+4272>>2]){break a}h=a+44|0;if(!fh(h)){break a}k=Fd(h,0);l=Fd(h,1);m=_c(h,0);n=_c(h,1);if(d){j=a+4256|0;e=p[a+4268>>2];o=d;while(1){f=t[l>>2];g=t[k>>2];v=Fb(j,e<<1),y=g,t[v>>2]=y;v=Fb(j,p[a+4268>>2]<<1|1),y=f,t[v>>2]=y;f=w(x(qH(w(w(w(x(g))+w(x(f)))*w(536870912)),31,5)));g=t[a+4276>>2];f=w(f*w(4.656612873077393e-10));f=w(w(w(g-f)*t[(g>f?4240:4236)+a>>2])+f);t[a+4276>>2]=f;q=m;r=w(t[a+4232>>2]*w(4.656612873077393e-10));g=t[a+4244>>2];f=w(w(w(t[a+4248>>2]*w(2147483648))*w(g-w(A(f,g))))+w(2147483392));b:{if(f<w(4294967296)&f>=w(0)){i=~~f>>>0;break b}i=0}e=i<<5;s=e|-2147483648;u=e;e=i>>>26|0;f=w(r*w((e?s:u)>>>(e?32-e|0:31)>>>0));e=p[a+4272>>2];e=(((e+(p[a+4252>>2]+(p[a+4268>>2]<<12)|0)|0)+ -1|0)/4096|0)%(e|0)<<1;v=q,y=w(f*t[Fb(j,e)>>2]),t[v>>2]=y;v=n,y=w(f*t[Fb(j,e|1)>>2]),t[v>>2]=y;i=p[a+4268>>2];e=i+ -1|0;p[a+4268>>2]=e;if(!i){e=p[a+4272>>2]+e|0;p[a+4268>>2]=e}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o+ -1|0;if(o){continue}break}}Zh(a,b,c,_c(h,0),_c(h,1),d)}}function dwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;m=p[a+16>>2];a:{b:{c:{g=p[a+8>>2];e=p[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}i=p[a+40>>2];j=p[a+36>>2];b=p[a+4>>2];k=p[a>>2];p[f+8>>2]=k;p[f+12>>2]=b;p[f>>2]=g;p[f+4>>2]=e;e:{if(!d){g=i>>12;e=j>>12;break e}while(1){g=p[a+32>>2];j=p[a+28>>2]+j|0;e=j>>12;h=(b<<1)+m|0;b=(k>>>16&65520)+l|0;b=(((((((v(o[h+ -4>>1],o[b+2>>1])+v(o[h+ -6>>1],o[b>>1])|0)+v(o[h+ -2>>1],o[b+4>>1])|0)+v(o[h>>1],o[b+6>>1])|0)+v(o[h+2>>1],o[b+8>>1])|0)+v(o[h+4>>1],o[b+10>>1])|0)+v(o[h+6>>1],o[b+12>>1])|0)+v(o[h+8>>1],o[b+14>>1])|0)/32768|0;p[c>>2]=p[c>>2]+v(e,b);i=g+i|0;g=i>>12;p[c+4>>2]=p[c+4>>2]+v(b,g);Kb(f+8|0,f);d=d+ -1|0;if(d){c=c+8|0;k=p[f+8>>2];b=p[f+12>>2];continue}break}k=p[f+8>>2];b=p[f+12>>2]}p[a+40>>2]=i;p[a+20>>2]=e;p[a+36>>2]=j;p[a+24>>2]=g;p[a>>2]=k;p[a+4>>2]=b;fb=f+16|0}function l6(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,r=0,t=0;a:{if(q[a+23|0]){d=p[a+2092>>2];if((d|0)<1){break a}while(1){f=e<<2;r=f+p[a+2084>>2]|0,t=Yk(p[f+p[a+32>>2]>>2]),p[r>>2]=t;e=e+1|0;d=p[a+2092>>2];if((e|0)<(d|0)){continue}break}break a}if(p[a+4>>2]>=1){while(1){if(XE(a,q[b+e|0])){r=p[a+2084>>2]+(d<<2)|0,t=Yk(p[p[a+32>>2]+(e<<2)>>2]),p[r>>2]=t;d=d+1|0}e=e+1|0;if((e|0)<p[a+4>>2]){continue}break}}if(p[a+2092>>2]==(d|0)){break a}aa(52033,50416,1185,52056);E()}KE(p[a+2084>>2],d,2302);p[p[a+2084>>2]+(p[a+2092>>2]<<2)>>2]=-1;b:{c:{d=q[a+23|0];i=p[(d?2092:4)+a>>2];if((i|0)<1){break c}f=0;while(1){e=f;g=a;if(d&255){e=p[(f<<2)+c>>2]}j=q[b+e|0];d:{if(!XE(g,j)){break d}k=f<<2;g=Yk(p[k+p[a+32>>2]>>2]);l=p[a+2084>>2];e=0;d=p[a+2092>>2];if((d|0)>=2){while(1){h=d>>>1|0;m=h+e|0;o=s[(m<<2)+l>>2]>g>>>0;e=o?e:m;d=o?h:d-h|0;if((d|0)>1){continue}break}}d=g;g=e<<2;if((d|0)!=p[g+l>>2]){break b}if(q[a+23|0]){p[g+p[a+2088>>2]>>2]=p[c+k>>2];n[p[a+8>>2]+e|0]=j;break d}p[g+p[a+2088>>2]>>2]=f}f=f+1|0;if((i|0)==(f|0)){break c}d=q[a+23|0];continue}}return}aa(52079,50416,1215,52056);E()}function Mva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0;f=fb-32|0;fb=f;k=p[a+40>>2];l=p[a+36>>2];m=p[a+16>>2];e=p[a+4>>2];g=e;h=p[a>>2];p[f+24>>2]=h;p[f+28>>2]=e;e=p[a+12>>2];p[f+16>>2]=p[a+8>>2];p[f+20>>2]=e;a:{if(!d){e=k>>12;j=l>>12;break a}while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=o[e+38>>1];n=o[e+36>>1];q=o[e+34>>1];r=o[e+32>>1];s=o[e+30>>1];t=o[e+28>>1];u=o[e+26>>1];w=o[e+24>>1];j=0;e=1;while(1){g=j<<1;p[(f+8|0)+(j<<2)>>2]=(((((v(o[(g|8)+i>>1],q)+v(o[(g|4)+i>>1],r)|0)+v(o[(g|12)+i>>1],n)|0)+v(o[(g|16)+i>>1],h)|0)/2|0)+((((v(o[(g|-8)+i>>1],u)+v(o[(g|-12)+i>>1],w)|0)+v(o[(g|-4)+i>>1],t)|0)+v(o[g+i>>1],s)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=p[a+32>>2];l=p[a+28>>2]+l|0;j=l>>12;p[c>>2]=p[c>>2]+v(j,p[f+8>>2]);k=e+k|0;e=k>>12;p[c+4>>2]=p[c+4>>2]+v(e,p[f+12>>2]);Kb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;h=p[f+24>>2];g=p[f+28>>2];continue}break}h=p[f+24>>2];g=p[f+28>>2]}p[a+40>>2]=k;p[a+20>>2]=j;p[a+36>>2]=l;p[a+24>>2]=e;p[a>>2]=h;p[a+4>>2]=g;fb=f+32|0}function fwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;m=p[a+16>>2];a:{b:{c:{g=p[a+8>>2];e=p[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}i=p[a+40>>2];j=p[a+36>>2];b=p[a+4>>2];k=p[a>>2];p[f+8>>2]=k;p[f+12>>2]=b;p[f>>2]=g;p[f+4>>2]=e;e:{if(!d){g=i>>12;e=j>>12;break e}while(1){g=p[a+32>>2];j=p[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((v(n[h+ -2|0],o[b+2>>1])+v(n[h+ -3|0],o[b>>1])|0)+v(n[h+ -1|0],o[b+4>>1])|0)+v(n[h|0],o[b+6>>1])|0)+v(n[h+1|0],o[b+8>>1])|0)+v(n[h+2|0],o[b+10>>1])|0)+v(n[h+3|0],o[b+12>>1])|0)+v(n[h+4|0],o[b+14>>1])<<8)/32768|0;p[c>>2]=p[c>>2]+v(e,b);i=g+i|0;g=i>>12;p[c+4>>2]=p[c+4>>2]+v(b,g);Kb(f+8|0,f);d=d+ -1|0;if(d){c=c+8|0;k=p[f+8>>2];b=p[f+12>>2];continue}break}k=p[f+8>>2];b=p[f+12>>2]}p[a+40>>2]=i;p[a+20>>2]=e;p[a+36>>2]=j;p[a+24>>2]=g;p[a>>2]=k;p[a+4>>2]=b;fb=f+16|0}function aF(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=w(0),r=0,s=0;a:{if(q[b+21|0]){l=p[f>>2];j=p[e>>2];r=1;b:{if((h|0)>=1){m=p[b>>2];s=v(d,g);while(1){if(p[a+1396>>2]<=9){Kj(a)}k=p[a+1392>>2];g=o[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=q[g+p[b+8>>2]|0];p[a+1392>>2]=i>>>k;i=p[a+1396>>2]-k|0;k=(i|0)<0;p[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=Zk(a,b)}if((g|0)>=p[b+2092>>2]?q[b+23|0]:0){break a}if((g|0)<=-1){if(!q[a+1376|0]){r=0;if(p[a+1384>>2]){break b}}Wb(a,21);return 0}k=v(d,l);m=((k+m|0)+j|0)>(s|0)?(s-k|0)+j|0:m;k=v(g,p[b>>2]);d:{if(q[b+22|0]){g=0;n=w(0);if((m|0)<=0){break d}while(1){n=w(t[p[b+28>>2]+(g+k<<2)>>2]+n);i=p[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;t[i>>2]=t[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=p[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;t[i>>2]=t[i>>2]+t[p[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}p[e>>2]=j;p[f>>2]=l}return r}Wb(a,21);return 0}aa(50672,50416,1872,50708);E()}function rwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;g=fb-16|0;fb=g;f=p[a+48>>2];l=p[a+24>>2];m=p[a+20>>2];b=p[a+44>>2];q=p[a+16>>2];h=p[a+4>>2];i=p[a>>2];p[g+8>>2]=i;p[g+12>>2]=h;e=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=h+q|0;h=n[e+2|0];r=n[e+1|0];s=n[e|0];t=n[e+ -1|0];e=p[a+60>>2];u=e;w=e>>31;e=Pb(b,-16777216,16776704);j=p[a+64>>2];f=Pb(f,-16777216,16776704);x=p[a+72>>2];y=p[c>>2];e=NNa(j,j>>31,e,e>>31);j=ib;z=e;e=p[a+68>>2];k=NNa(e,e>>31,f,f>>31);e=z+k|0;f=ib+j|0;f=e>>>0<k>>>0?f+1|0:f;j=e;e=(i>>>21&2040)+27824|0;h=(((v(o[e+2>>1],s)+v(t,o[e>>1])|0)+v(o[e+4>>1],r)|0)+v(h,o[e+6>>1])<<8)/16384<<8;e=h;i=NNa(u,w,e,e>>31);e=j+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;p[c>>2]=v(e,m)+y;p[c+4>>2]=p[c+4>>2]+v(e,l);e=f-(h&x)|0;Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;i=p[g+8>>2];h=p[g+12>>2];f=b;b=e;continue}break}i=p[g+8>>2];h=p[g+12>>2]}p[a+48>>2]=b;p[a+44>>2]=e;p[a>>2]=i;p[a+4>>2]=h;fb=g+16|0}function qwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0;g=fb-16|0;fb=g;f=p[a+48>>2];m=p[a+24>>2];n=p[a+20>>2];b=p[a+44>>2];q=p[a+16>>2];h=p[a+4>>2];i=p[a>>2];p[g+8>>2]=i;p[g+12>>2]=h;e=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(h<<1)+q|0;j=o[e>>1];r=o[e+ -2>>1];s=o[e+2>>1];t=o[e+4>>1];l=p[a+60>>2];e=Pb(b,-16777216,16776704);k=p[a+64>>2];h=Pb(f,-16777216,16776704);u=p[a+72>>2];f=p[c>>2];e=NNa(k,k>>31,e,e>>31);k=ib;w=c;x=f;f=(i>>>21&2040)+27824|0;i=(((v(j,o[f+2>>1])+v(o[f>>1],r)|0)+v(o[f+4>>1],s)|0)+v(t,o[f+6>>1])|0)/16384<<8;f=i;j=NNa(l,l>>31,f,f>>31);e=j+e|0;f=ib+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=p[a+68>>2];h=NNa(e,e>>31,h,h>>31);e=j+h|0;f=ib+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;p[w>>2]=x+v(e,n);p[c+4>>2]=p[c+4>>2]+v(e,m);e=f-(i&u)|0;Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;i=p[g+8>>2];h=p[g+12>>2];f=b;b=e;continue}break}i=p[g+8>>2];h=p[g+12>>2]}p[a+48>>2]=b;p[a+44>>2]=e;p[a>>2]=i;p[a+4>>2]=h;fb=g+16|0}function lla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb+ -64|0;fb=e;g=Em(a);a:{if(b+ -1>>>0>1023){break a}f=p[a+12>>2];if((f|0)==(b|0)){break a}if(c){c=p[g+8>>2];if(s[c+40>>2]<b>>>0|s[c+36>>2]>b>>>0){break a}f=p[a+12>>2]}f=v(Qj(a),f>>>0<b>>>0?b-f|0:f-b|0);b:{c:{if(s[a+12>>2]<b>>>0){c=e;d:{if(d){d=Vb(a);break d}d=Ub(a)}p[c+48>>2]=d;c=Ld(e+56|0,e+48|0);ch(e+40|0);c=p[c>>2];p[114610]=0;U(1563,a|0,c|0,f|0,e+40|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}a=O(71348)|0;break c}if(d){i=e,j=Vb(a),p[i+48>>2]=j;i=e,j=MI(e+48|0,0-f|0),p[i+40>>2]=j;c=Ld(e+32|0,e+40|0);i=e,j=Vb(a),p[i+16>>2]=j;d=p[Ld(e+24|0,e+16|0)>>2];c=p[c>>2];p[114610]=0;P(1564,a|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}a=O(71348)|0;break c}i=e,j=Ub(a),p[i+40>>2]=j;c=Ld(e+8|0,e+40|0);i=e,j=Ub(a),p[i+16>>2]=j;i=e,j=MI(e+16|0,f),p[i+48>>2]=j;d=p[Ld(e,e+48|0)>>2];c=p[c>>2];p[114610]=0;P(1564,a|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}a=O(71348)|0}if((H()|0)==($(71348)|0)){T(a|0)|0;V();break a}L(a|0);E()}p[a+12>>2]=b;h=1}fb=e- -64|0;return h|0}function $E(a,b,c,d,e){var f=w(0),g=w(0),h=0,i=w(0),j=w(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d+ -4|0;g=t[b>>2];i=t[d>>2];j=t[a>>2];t[a>>2]=i+j;c=a+ -4|0;f=t[c>>2];t[c>>2]=t[b>>2]+f;i=w(j-i);f=w(f-g);t[d>>2]=w(t[e>>2]*i)-w(t[e+4>>2]*f);t[b>>2]=w(t[e+4>>2]*i)+w(t[e>>2]*f);b=d+ -12|0;i=t[b>>2];c=a+ -8|0;f=t[c>>2];h=c;c=d+ -8|0;j=t[c>>2];t[h>>2]=j+f;h=a+ -12|0;g=t[h>>2];t[h>>2]=t[b>>2]+g;f=w(f-j);g=w(g-i);t[c>>2]=w(t[e+32>>2]*f)-w(t[e+36>>2]*g);t[b>>2]=w(t[e+36>>2]*f)+w(t[e+32>>2]*g);b=d+ -20|0;i=t[b>>2];c=a+ -16|0;f=t[c>>2];h=c;c=d+ -16|0;j=t[c>>2];t[h>>2]=j+f;h=a+ -20|0;g=t[h>>2];t[h>>2]=t[b>>2]+g;f=w(f-j);g=w(g-i);t[c>>2]=w(t[e+64>>2]*f)-w(t[e+68>>2]*g);t[b>>2]=w(t[e+68>>2]*f)+w(t[e+64>>2]*g);b=d+ -28|0;i=t[b>>2];c=a+ -24|0;f=t[c>>2];h=c;c=d+ -24|0;j=t[c>>2];t[h>>2]=j+f;h=a+ -28|0;g=t[h>>2];t[h>>2]=t[b>>2]+g;f=w(f-j);g=w(g-i);t[c>>2]=w(t[e+96>>2]*f)-w(t[e+100>>2]*g);t[b>>2]=w(t[e+100>>2]*f)+w(t[e+96>>2]*g);d=d+ -32|0;a=a+ -32|0;e=e+128|0;b=(k|0)>1;k=k+ -1|0;if(b){continue}break}}return}aa(51824,50416,2408,51837);E()}function Nva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0;f=fb-32|0;fb=f;k=p[a+40>>2];l=p[a+36>>2];m=p[a+16>>2];e=p[a+4>>2];h=e;i=p[a>>2];p[f+24>>2]=i;p[f+28>>2]=e;e=p[a+12>>2];p[f+16>>2]=p[a+8>>2];p[f+20>>2]=e;a:{if(!d){g=k>>12;e=l>>12;break a}while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=o[e+38>>1];q=o[e+36>>1];r=o[e+34>>1];s=o[e+32>>1];t=o[e+30>>1];u=o[e+28>>1];w=o[e+26>>1];x=o[e+24>>1];g=0;e=1;while(1){p[(f+8|0)+(g<<2)>>2]=(((((v(n[(g|4)+j|0],r)+v(n[(g|2)+j|0],s)|0)+v(n[(g|6)+j|0],q)|0)+v(n[(g|8)+j|0],i)<<8)/2|0)+((((v(n[(g|-4)+j|0],w)+v(n[(g|-6)+j|0],x)|0)+v(n[(g|-2)+j|0],u)|0)+v(n[g+j|0],t)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=p[a+32>>2];l=p[a+28>>2]+l|0;e=l>>12;p[c>>2]=p[c>>2]+v(e,p[f+8>>2]);k=h+k|0;g=k>>12;p[c+4>>2]=p[c+4>>2]+v(g,p[f+12>>2]);Kb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;i=p[f+24>>2];h=p[f+28>>2];continue}break}i=p[f+24>>2];h=p[f+28>>2]}p[a+40>>2]=k;p[a+20>>2]=e;p[a+36>>2]=l;p[a+24>>2]=g;p[a>>2]=i;p[a+4>>2]=h;fb=f+32|0}function B4(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-32|0;fb=c;p[114610]=0;h=J(15,c+24|0,a|0)|0;d=p[114610];p[114610]=0;a:{b:{c:{if((d|0)!=1){d:{if(!q[h|0]){break d}d=p[(p[p[a>>2]+ -12>>2]+a|0)+4>>2];qc(c+16|0,p[p[a>>2]+ -12>>2]+a|0);p[114610]=0;f=M(2331,c+16|0)|0;e=p[114610];p[114610]=0;e:{f:{if((e|0)!=1){Gb(c+16|0);e=Dk(c+8|0,a);g=p[p[a>>2]+ -12>>2];p[114610]=0;g=a+g|0;j=M(16,g|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break f}e=p[e>>2];p[114610]=0;i=f;f=b&65535;k=b;b=d&74;b=Z(2332,i|0,e|0,g|0,j|0,((b|0)==64?f:(b|0)==8?f:k)|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}p[c+16>>2]=b;if(!Ck(c+16|0)){break d}b=p[p[a>>2]+ -12>>2];p[114610]=0;K(18,a+b|0,5);b=p[114610];p[114610]=0;if((b|0)!=1){break d}b=O(0)|0;H()|0;break e}b=O(0)|0;H()|0;Gb(c+16|0);break e}b=O(0)|0;H()|0}uf(h);break c}uf(h);break b}b=O(0)|0;H()|0}T(b|0)|0;b=p[p[a>>2]+ -12>>2];p[114610]=0;S(19,a+b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=c+32|0;return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function X5(a,b,c,d,e,f,g){var h=w(0),i=w(0),j=w(0),k=w(0),l=0,m=w(0),n=0,o=w(0),p=w(0),q=w(0),r=w(0),s=w(0),u=w(0),x=w(0);if((a|0)>=1){l=v(f,12)+e|0;m=t[l>>2];n=f<<3;o=t[n+e>>2];f=(f<<2)+e|0;p=t[f>>2];q=t[l+4>>2];r=t[(n|4)+e>>2];s=t[f+4>>2];u=t[e+4>>2];x=t[e>>2];e=(c<<2)+b|0;f=e+(d<<2)|0;b=0-g<<2;while(1){c=f+ -4|0;i=t[c>>2];k=t[f>>2];j=t[e>>2];t[e>>2]=k+j;d=e+ -4|0;h=t[d>>2];t[d>>2]=t[c>>2]+h;h=w(h-i);i=w(j-k);t[c>>2]=w(h*x)+w(i*u);t[f>>2]=w(i*x)-w(h*u);c=f+ -12|0;k=t[c>>2];d=e+ -8|0;h=t[d>>2];g=d;d=f+ -8|0;j=t[d>>2];t[g>>2]=j+h;g=e+ -12|0;i=t[g>>2];t[g>>2]=t[c>>2]+i;i=w(i-k);h=w(h-j);t[c>>2]=w(i*p)+w(h*s);t[d>>2]=w(h*p)-w(i*s);c=f+ -20|0;k=t[c>>2];d=e+ -16|0;h=t[d>>2];g=d;d=f+ -16|0;j=t[d>>2];t[g>>2]=j+h;g=e+ -20|0;i=t[g>>2];t[g>>2]=t[c>>2]+i;i=w(i-k);h=w(h-j);t[c>>2]=w(i*o)+w(h*r);t[d>>2]=w(h*o)-w(i*r);c=f+ -28|0;k=t[c>>2];d=e+ -24|0;h=t[d>>2];g=d;d=f+ -24|0;j=t[d>>2];t[g>>2]=j+h;g=e+ -28|0;i=t[g>>2];t[g>>2]=t[c>>2]+i;i=w(i-k);h=w(h-j);t[c>>2]=w(i*m)+w(h*q);t[d>>2]=w(h*m)-w(i*q);f=b+f|0;e=b+e|0;c=(a|0)>1;a=a+ -1|0;if(c){continue}break}}}function m6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-128|0;fb=e;j=Jb(e,0,128);a:{b:{c:{d:{if((c|0)<1){break d}while(1){if(q[b+h|0]!=255){break d}h=h+1|0;if((h|0)!=(c|0)){continue}break}break c}if((c|0)!=(h|0)){break b}}f=1;if(!p[a+2092>>2]){break a}aa(51930,50416,1088,51953);E()}e=b+h|0;YE(a,0,h,0,q[e|0],d);e=q[e|0];if(e){g=e>>>0>1?e:1;f=1;while(1){p[(f<<2)+j>>2]=1<<32-f;e=(f|0)==(g|0);f=f+1|0;if(!e){continue}break}}k=1;i=h+1|0;if((i|0)>=(c|0)){f=1;break a}e:{f:{g:{while(1){h:{h=b+i|0;e=q[h|0];i:{if((e|0)==255){break i}f=e;if(!e){break e}while(1){g=(f<<2)+j|0;l=p[g>>2];if(!l){g=(f|0)>1;f=f+ -1|0;if(g){continue}break e}break}if(f>>>0>=32){break h}p[g>>2]=0;YE(a,Yk(l),i,k,e,d);k=k+1|0;g=q[h|0];if((g|0)==(f|0)){break i}if(g>>>0>31){break g}if((f|0)>=(g|0)){break i}while(1){e=(g<<2)+j|0;if(p[e>>2]){break f}p[e>>2]=(1<<32-g)+l;g=g+ -1|0;if((g|0)>(f|0)){continue}break}}f=1;i=i+1|0;if((i|0)!=(c|0)){continue}break a}break}aa(51971,50416,1111,51953);E()}aa(51988,50416,1116,51953);E()}aa(52015,50416,1118,51953);E()}f=0}fb=j+128|0;return f}function k6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;a=Hv(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((_q(b,c,0)|0)!=-1){while(1){f=_q(b,c,e);p[114610]=0;Q(199,d|0,b|0,e|0,f-e|0);f=p[114610];p[114610]=0;if((f|0)==1){break j}p[114610]=0;K(200,d+16|0,d|0);f=p[114610];p[114610]=0;if((f|0)==1){break i}p[114610]=0;K(201,a|0,d+16|0);f=p[114610];p[114610]=0;if((f|0)==1){break h}pb(d+16|0);pb(d);e=_q(b,c,e)+wb(c)|0;if((_q(b,c,e)|0)!=-1){continue}break}}k:{if(cd(a)){p[114610]=0;Q(199,d+16|0,b|0,e|0,-1);c=p[114610];p[114610]=0;if((c|0)==1){break f}c=wb(d+16|0);pb(d+16|0);if(!c){break k}}p[114610]=0;Q(199,d|0,b|0,e|0,-1);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;K(200,d+16|0,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;K(201,a|0,d+16|0);b=p[114610];p[114610]=0;if((b|0)==1){break c}pb(d+16|0);pb(d)}fb=d+32|0;return}e=I()|0;H()|0;break a}e=I()|0;H()|0;break g}e=I()|0;H()|0;pb(d+16|0)}pb(d);break a}e=I()|0;H()|0;break a}e=I()|0;H()|0;break a}e=I()|0;H()|0;break b}e=I()|0;H()|0;pb(d+16|0)}pb(d)}Xk(a);L(e|0);E()}function LH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,g=0,h=w(0);c=fb+ -64|0;fb=c;d=Ln(c+48|0,Ed(c+40|0,b));p[114610]=0;b=M(548,d|0)|0;e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}p[114610]=0;b=P(1701,d|0,c|0,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}b:{if(!b|p[c>>2]!=542066252){break b}b=c|4;if(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24)){break b}b=c+8|0;g=a,h=Rm((f(2,q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24)),j()),w(0),w(1)),t[g+4220>>2]=h;b=c+12|0;g=a,h=Rm((f(2,q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24)),j()),w(0),w(1)),t[g+4224>>2]=h;b=c+16|0;g=a,h=Rm((f(2,q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24)),j()),w(0),w(1)),t[g+4228>>2]=h;b=c+20|0;if((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))>>>0<=5){p[a+4232>>2]=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24)}b=c+24|0;p[a+4236>>2]=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);n[a+4240|0]=q[c+28|0]!=0;n[a+4241|0]=q[c+29|0]!=0;n[a+4242|0]=q[c+30|0]!=0;n[a+4243|0]=q[c+31|0]!=0;n[a+4244|0]=q[c+32|0]!=0}sb(d);fb=c- -64|0;return}a=I()|0;H()|0;sb(d);L(a|0);E()}function V_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;k=fb-16|0;fb=k;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!p[i>>2]){break a}i=i+4|0;continue}break}p[h>>2]=f;p[e>>2]=c;while(1){b:{c:{if(!((f|0)==(g|0)|(c|0)==(d|0))){j=p[b+4>>2];p[k+8>>2]=p[b>>2];p[k+12>>2]=j;j=1;d:{e:{f:{g:{h:{l=U_(f,e,i-c>>2,g-f|0,b,p[a+8>>2]);switch(l+1|0){case 0:break h;case 1:break c;default:break g}}p[h>>2]=f;while(1){i:{if(p[e>>2]==(c|0)){break i}b=Su(f,p[c>>2],k+8|0,p[a+8>>2]);if((b|0)==-1){break i}f=b+p[h>>2]|0;p[h>>2]=f;c=c+4|0;continue}break}p[e>>2]=c;break f}f=p[h>>2]+l|0;p[h>>2]=f;if((f|0)==(g|0)){break d}if((d|0)==(i|0)){c=p[e>>2];i=d;continue}i=Su(k+4|0,0,b,p[a+8>>2]);if((i|0)!=-1){break e}}j=2;break c}c=k+4|0;if(i>>>0>g-p[h>>2]>>>0){break c}while(1){if(i){f=q[c|0];j=p[h>>2];p[h>>2]=j+1;n[j|0]=f;i=i+ -1|0;c=c+1|0;continue}break}c=p[e>>2]+4|0;p[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!p[i>>2]){break b}i=i+4|0;continue}}c=p[e>>2]}j=(c|0)!=(d|0)}fb=k+16|0;return j|0}f=p[h>>2];continue}}function hfa(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{if(!p[a+4116>>2]){if(!p[a+4120>>2]){break a}an(a+8|0,c,a+4104|0,a+4108|0)}f=p[a>>2];g=p[a+4184>>2];d=v(f,g)>>>4|0;d=d>>>0<32767?d:32767;o[a+4202>>1]=d;o[a+4200>>1]=d;e=p[a+54052>>2];d=v(e,f)>>>4|0;d=d>>>0<65536?d:65536;j=d+127>>>3|0;o[a+54050>>1]=j;d=d+255>>>4|0;o[a+54048>>1]=d;o[a+54046>>1]=d;o[a+54044>>1]=j;d=a+8|0;g=(g|0)>(e|0)?g:e;f=36-f>>>1|0;f=f>>>0>8?f:8;gfa(b,d,16-(v((g|0)<32768?g:32768,(f|0)<16?16-f|0:0)>>15)|0,c);j=a+4172|0;c=ffa(a,d,c);b:{if(!c){i=p[j>>2];break b}l=a+53996|0;efa(j,d,c);h=p[a+4180>>2];k=a+37612|0;f=d;g=c;while(1){i=h&4095;h=h-p[a+53996>>2]&4095;e=4096-(h>>>0<i>>>0?i:h)|0;e=g>>>0>e>>>0?e:g;e=e>>>0<64?e:64;dfa(j,(i<<2)+k|0,f,e);cfa(l,(h<<2)+k|0,f,e);h=e+p[a+4180>>2]&4095;p[a+4180>>2]=h;i=e+p[a+4172>>2]&8191;p[a+4172>>2]=i;f=(e<<3)+f|0;g=g-e|0;if(g){continue}break}}p[a+4172>>2]=i&8191;bfa(a,d,b,c);c:{if(p[a+4116>>2]){p[a+4120>>2]=p[a+4124>>2];break c}b=p[a+4120>>2];if(b>>>0>c>>>0){p[a+4120>>2]=b-c;break c}bH(a);p[a+4120>>2]=0}p[a+4116>>2]=0}}function fxa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=ub(b);a:{b:{c:{d:{e:{while(1){b=c;if(!c){break e}c=b+ -1|0;if(!q[h+c|0]){continue}break}if((d|0)!=4){break c}d=0;c=0;while(1){f:{g:{h:{e=q[c+h|0];switch(e+ -10|0){case 3:break h;case 0:break g;default:break f}}f=f+1|0;break f}g=g+1|0}i=((d&255)==13&(c|0)!=0&(e|0)==10)+i|0;d=e;c=c+1|0;if((c|0)!=(b|0)){continue}break}break d}b=0;if((d|0)!=4){break b}}i:{if((f|0)==(g|0)){d=2;if((f|0)==(i|0)){break i}}if(f){d=0;if(!g){break i}}d=f?3:g?1:3}if(!b){break b}}c=0;f=(d|0)!=2;e=0;while(1){e=(f|q[c+h|0]!=10)+e|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}ym(a,e);f=(d|0)==1?32:13;g=(d|0)==2;i=d&-3;c=0;e=0;while(1){j:{k:{l:{m:{n:{o:{d=n[c+h|0];switch(d+ -10|0){case 1:case 2:break l;case 0:break n;case 3:break o;default:break m}}j=Xl(a,e),k=f,n[j|0]=k;c=c+g|0;break j}d=Xl(a,e);if(i){n[d|0]=13;break j}n[d|0]=32;break j}if(!d){break k}}j=Xl(a,e),k=d,n[j|0]=k;break j}j=Xl(a,e),k=32,n[j|0]=k}e=e+1|0;c=c+1|0;if(c>>>0<b>>>0){continue}break}break a}ym(a,0)}return 1}function oS(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{if((q[a|0]+ -1&255)>>>0>14){break a}g=a+1954|0;d=a+1698|0;while(1){if(n[d|0]<=-2){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}d=0;while(1){g=f;f=0;c=v(d,13)+a|0;if(q[c+14|0]){break a}e=(d<<4)+a|0;b=e+418|0;if(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24)){break a}b=e+422|0;if(q[c+942|0]|(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))>>>0>1048575){break a}c=v(d,11)+a|0;h=c+1346|0;if(q[h|0]>15|q[c+1351|0]>3|q[c+1356|0]>3){break a}b:{if(!(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))){break b}c=e+430|0;if((q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))>>>0>1048574){break b}if((q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))>>>0>(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))>>>0){break a}e=e+426|0;if((q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))>>>0>(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))>>>0){break a}}f=1;c:{if(g&1|(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))){break c}if(hd(h,12323,11)){break c}f=0}d=d+1|0;if((d|0)!=32){continue}break}}return f}function io(a,b,c,d,e,f){var g=w(0),h=w(0),i=0,j=w(0),k=w(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d+ -4|0;h=t[c>>2];j=t[d>>2];k=t[a>>2];t[a>>2]=j+k;f=a+ -4|0;g=t[f>>2];t[f>>2]=t[c>>2]+g;j=w(k-j);g=w(g-h);t[d>>2]=w(t[e>>2]*j)-w(t[e+4>>2]*g);t[c>>2]=w(t[e+4>>2]*j)+w(t[e>>2]*g);f=d+ -12|0;j=t[f>>2];c=a+ -8|0;g=t[c>>2];i=c;c=d+ -8|0;k=t[c>>2];t[i>>2]=k+g;i=a+ -12|0;h=t[i>>2];t[i>>2]=t[f>>2]+h;i=c;c=b+e|0;g=w(g-k);h=w(h-j);t[i>>2]=w(t[c>>2]*g)-w(t[c+4>>2]*h);t[f>>2]=w(t[c+4>>2]*g)+w(t[c>>2]*h);e=d+ -20|0;j=t[e>>2];f=a+ -16|0;g=t[f>>2];i=f;f=d+ -16|0;k=t[f>>2];t[i>>2]=k+g;i=a+ -20|0;h=t[i>>2];t[i>>2]=t[e>>2]+h;c=b+c|0;g=w(g-k);h=w(h-j);t[f>>2]=w(t[c>>2]*g)-w(t[c+4>>2]*h);t[e>>2]=w(t[c+4>>2]*g)+w(t[c>>2]*h);e=d+ -28|0;j=t[e>>2];f=a+ -24|0;g=t[f>>2];i=f;f=d+ -24|0;k=t[f>>2];t[i>>2]=k+g;i=a+ -28|0;h=t[i>>2];t[i>>2]=t[e>>2]+h;c=b+c|0;g=w(g-k);h=w(h-j);t[f>>2]=w(t[c>>2]*g)-w(t[c+4>>2]*h);t[e>>2]=w(t[c+4>>2]*g)+w(t[c>>2]*h);e=b+c|0;d=d+ -32|0;a=a+ -32|0;c=(l|0)>1;l=l+ -1|0;if(c){continue}break}}}function KG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=w(0);d=fb-48|0;fb=d;a:{b:{c:{d:{e:{switch(b+ -1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==p[p[a>>2]+24604>>2]){break d}ac(d+8|0,p[a>>2]+24604|0,40);p[d+8>>2]=b;hx(p[a>>2],d+8|0);break d;case 2:b=a+24|0;a=p[b>>2];e=a+24664|0;f=p[e+4>>2];p[d+24>>2]=p[e>>2];p[d+28>>2]=f;e=a+24656|0;f=p[e+4>>2];p[d+16>>2]=p[e>>2];p[d+20>>2]=f;e=p[a+24652>>2];p[d+8>>2]=p[a+24648>>2];p[d+12>>2]=e;g=d,h=Mba(c),n[g+8|0]=h;if(!lw(d+8|0,p[b>>2]+24648|0)){break d}gx(p[b>>2],d+8|0);break d;case 3:a=a+24|0;ac(d+8|0,p[a>>2]+24604|0,40);Lba(d+8|0,c);if(p[p[a>>2]+24640>>2]==p[d+44>>2]?p[p[a>>2]+24636>>2]==p[d+40>>2]:0){break d}hx(p[a>>2],d+8|0);break d;default:a=W(8)|0;p[114610]=0;c=J(85,d+8|0,38580)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(c);break b;case 0:break e}}g=a,i=fe(w(10),w(w(c|0)*w(.0005000000237487257))),t[g+48>>2]=i}fb=d+48|0;return}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function Uw(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;d=a+2|0;if(!(q[d|0]==255|!q[d|0])){p[f+12>>2]=q[d|0]+1;p[f+8>>2]=10;Vf(b,p[Yd(f+12|0,f+8|0)>>2]);d=q[a+3|0];n[b+15|0]=d;n[b+16|0]=d;n[b+13|0]=q[a+4|0];n[b+14|0]=q[a+5|0];if(Bb(b)){h=c+ -1|0;while(1){g=(e<<2)+a|0;c=g+6|0;c=q[c|0]|q[c+1|0]<<8;j=Fb(b,e),k=c>>>4|0,o[j>>1]=k;i=b;a:{b:{if(!e){d=0;c=0;break b}d=e+ -1|0;if(r[Fb(b,e)>>1]>=r[Fb(b,d)>>1]){break a}d=r[Fb(b,d)>>1]+1|0;c=e}j=Fb(i,c),k=d,o[j>>1]=k}c=g+8|0;d=q[c|0]|q[c+1|0]<<8;g=Fb(b,e);c:{d:{switch(h|0){default:d=d+1|0;c=9;break c;case 1:d=d+4097|0;c=7;break c;case 0:break d}}d=(d<<16>>16)+32769|0;c=10}n[g+2|0]=d>>>c;$I(Fb(b,e)+2|0,0,64);e=e+1|0;if(e>>>0<Bb(b)>>>0){continue}break}}n[b+12|0]=q[b+12|0]&254|n[a|0]&1;c=b;e:{f:{if(!(q[a|0]&2)){break f}e=q[b+15|0];if(Bb(b)>>>0<e>>>0){break f}e=q[b+12|0]|4;break e}e=q[b+12|0]&-5}n[c+12|0]=e;c=b;g:{h:{if(!(q[a|0]&4)){break h}a=q[b+13|0];if(a>>>0>q[b+14|0]){break h}if(Bb(b)>>>0<a>>>0){break h}a=q[b+12|0]|2;break g}a=q[b+12|0]&-3}n[c+12|0]=a}fb=f+16|0}function Swa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0;h=fb-16|0;fb=h;e=p[a+48>>2];l=p[a+40>>2];m=p[a+36>>2];f=p[a+44>>2];r=p[a+16>>2];j=p[a+4>>2];i=p[a>>2];p[h+8>>2]=i;p[h+12>>2]=j;b=p[a+12>>2];p[h>>2]=p[a+8>>2];p[h+4>>2]=b;a:{if(!d){k=l>>12;g=m>>12;break a}while(1){k=o[(j<<1)+r>>1];g=p[a+60>>2];b=f;f=Pb(f,-16777216,16776704);n=p[a+64>>2];i=Pb(e,-16777216,16776704);s=p[a+72>>2];t=p[a+32>>2];j=c;u=p[c>>2];q=k<<8;e=q;e=NNa(g,g>>31,e,e>>31);k=ib;g=NNa(n,n>>31,f,f>>31);f=g+e|0;e=ib+k|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=p[a+68>>2];i=NNa(f,f>>31,i,i>>31);f=g+i|0;e=ib+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=p[a+28>>2]+m|0;g=m>>12;p[j>>2]=v(e,g)+u;l=l+t|0;k=l>>12;p[c+4>>2]=p[c+4>>2]+v(e,k);f=f-(q&s)|0;Kb(h+8|0,h);d=d+ -1|0;if(d){c=c+8|0;j=p[h+12>>2];e=b;continue}break}i=p[h+8>>2];j=p[h+12>>2];e=b}p[a+40>>2]=l;p[a+20>>2]=g;p[a+36>>2]=m;p[a+48>>2]=e;p[a+44>>2]=f;p[a+24>>2]=k;p[a>>2]=i;p[a+4>>2]=j;fb=h+16|0}function H2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;p[g+24>>2]=b;a:{b:{if(!(p[d+4>>2]&1)){p[g>>2]=-1;b=m[p[p[a>>2]+16>>2]](a,b,c,d,e,g)|0;p[g+24>>2]=b;c:{switch(p[g>>2]){case 1:n[f|0]=1;break a;case 0:break b;default:break c}}n[f|0]=1;p[e>>2]=4;break a}qc(g,d);p[114610]=0;b=M(2449,g|0)|0;a=p[114610];p[114610]=0;d:{e:{f:{g:{if((a|0)!=1){Gb(g);qc(g,d);p[114610]=0;a=M(2450,g|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}Gb(g);p[114610]=0;K(2451,g|0,a|0);d=p[114610];p[114610]=0;if((d|0)==1){b=I()|0;H()|0;break d}p[114610]=0;K(2452,g|12,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break f}p[114610]=0;d=g+24|0;a=na(2453,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}n[f|0]=(a|0)==(g|0);b=p[g+24>>2];while(1){d=yc(d+ -12|0);if((g|0)!=(d|0)){continue}break}break a}b=I()|0;H()|0;Gb(g);break d}b=I()|0;H()|0;Gb(g);break d}b=I()|0;H()|0;yc(g);break d}b=I()|0;H()|0;while(1){d=yc(d+ -12|0);if((g|0)!=(d|0)){continue}break}}L(b|0);E()}n[f|0]=0}fb=g+32|0;return b|0}function Bq(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=fb-16|0;fb=m;p[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!q[b|0]){break b}a=0;n[b|0]=0;b=p[e>>2];p[e>>2]=b+1;n[b|0]=46;if(!wb(h)){break a}b=p[j>>2];if((b-i|0)>159){break a}c=p[k>>2];p[j>>2]=b+4;p[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!wb(h)){break c}if(!q[b|0]){break b}a=0;b=p[j>>2];if((b-i|0)>159){break a}a=p[k>>2];p[j>>2]=b+4;p[b>>2]=a;a=0;p[k>>2]=0;break a}a=-1;f=Wu(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=q[(f>>2)+62096|0];d:{e:{switch(SNa(f+ -88|0,30)|0){case 2:case 3:b=p[e>>2];if((q[b+ -1|0]&95)!=(q[c|0]&127)?(b|0)!=(d|0):0){break a}p[e>>2]=b+1;n[b|0]=g;a=0;break a;case 0:case 1:n[c|0]=80;break d;default:break e}}a=n[c|0];if((a|0)!=(g&95)){break d}n[c|0]=a|128;if(!q[b|0]){break d}n[b|0]=0;if(!wb(h)){break d}a=p[j>>2];if((a-i|0)>159){break d}b=p[k>>2];p[j>>2]=a+4;p[a>>2]=b}a=p[e>>2];p[e>>2]=a+1;n[a|0]=g;a=0;if((f|0)>84){break a}p[k>>2]=p[k>>2]+1;break a}a=-1}fb=m+16|0;return a|0}function Yya(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-48|0;fb=b;a:{b:{c:{f=a+24|0;d:{if(kd(f)){break d}e=a+4|0;c=wb(e);d=Xxa();a=ib;if(c){c=bn(b+32|0);p[114610]=0;p[b+16>>2]=a;K(87,c|0,b+16|0);a=p[114610];p[114610]=0;e:{f:{g:{if((a|0)!=1){p[114610]=0;p[b+16>>2]=d;K(87,c|0,b+16|0);a=p[114610];p[114610]=0;if((a|0)==1){break g}if(wb(e)){a=0;while(1){d=q[cc(e,a)|0];p[114610]=0;p[b+16>>2]=d;K(87,c|0,b+16|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}a=a+1|0;if(a>>>0<wb(e)>>>0){continue}break}}a=Ub(c);d=Vb(c);p[114610]=0;d=P(88,b+16|0,a|0,d|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break f}p[114610]=0;K(89,b+8|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break e}vs(f,b+8|0);gg(b+8|0);be(d);be(c);break d}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;be(d);break a}p[b+20>>2]=d;p[b+16>>2]=a;c=Twa(b+32|0,b+16|0,b+24|0);p[114610]=0;K(89,b+8|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}vs(f,b+8|0);gg(b+8|0);be(c)}fb=b+48|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0}be(c);L(a|0);E()}function KJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{switch(p[a+480224>>2]+ -1|0){default:c=p[a+24620>>2];p[d+12>>2]=1;p[d+8>>2]=p[b+44>>2]<<1;c=NNa(c,c>>31,5e4,0);f=ib;b=p[Uc(d+12|0,d+8|0)>>2];c=rc(ONa(c,f,b,b>>31),ib);break a;case 0:c=p[a+24620>>2];p[d+12>>2]=1;p[d+8>>2]=p[b+44>>2];c=NNa(c,c>>31,1e4,0);f=ib;b=p[Uc(d+12|0,d+8|0)>>2];c=rc(ONa(c,f,b,b>>31),ib);break a;case 1:break b}}e=+s[a+24620>>2]*60/(+s[b+44>>2]*1e-4*(+(NNa(p[b+32>>2],0,p[b+40>>2],0)>>>0)+4294967296*+(ib>>>0)));c:{d:{c=a+484344|0;if(!Cg(c,r[b+60>>1])){break d}if(!(cd(Rb(c,r[b+60>>1])+24|0)^1)){break d}c=Rb(c,r[b+60>>1])+24|0;break c}c=a+480248|0}if(!cd(c)){e=e*5.960464477539063e-8*+s[Fb(c,s[b+48>>2]%(Bb(c)>>>0)|0)>>2]}e:{if(x(e)<2147483648){c=~~e;break e}c=-2147483648}e=e- +(c>>>0)+u[b+8>>3];u[b+8>>3]=e;if(!(e<1)){u[b+8>>3]=e+ -1;c=c+1|0;break a}if(u[a+1074384>>3]>-1){break a}u[b+8>>3]=e+1;c=c+ -1|0}b=NNa(p[a+480244>>2],0,c,0)+32768|0;a=ib;a=b>>>0<32768?a+1|0:a;a=dd((a&65535)<<16|b>>>16,a>>>16|0);fb=d+16|0;return(a?a:1)|0}function j3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;p[g+24>>2]=b;a:{b:{if(!(p[d+4>>2]&1)){p[g>>2]=-1;b=m[p[p[a>>2]+16>>2]](a,b,c,d,e,g)|0;p[g+24>>2]=b;c:{switch(p[g>>2]){case 1:n[f|0]=1;break a;case 0:break b;default:break c}}n[f|0]=1;p[e>>2]=4;break a}qc(g,d);p[114610]=0;b=M(21,g|0)|0;a=p[114610];p[114610]=0;d:{e:{f:{g:{if((a|0)!=1){Gb(g);qc(g,d);p[114610]=0;a=M(2416,g|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}Gb(g);p[114610]=0;K(2417,g|0,a|0);d=p[114610];p[114610]=0;if((d|0)==1){b=I()|0;H()|0;break d}p[114610]=0;K(2418,g|12,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break f}p[114610]=0;d=g+24|0;a=na(2419,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}n[f|0]=(a|0)==(g|0);b=p[g+24>>2];while(1){d=pb(d+ -12|0);if((g|0)!=(d|0)){continue}break}break a}b=I()|0;H()|0;Gb(g);break d}b=I()|0;H()|0;Gb(g);break d}b=I()|0;H()|0;pb(g);break d}b=I()|0;H()|0;while(1){d=pb(d+ -12|0);if((g|0)!=(d|0)){continue}break}}L(b|0);E()}n[f|0]=0}fb=g+32|0;return b|0}function Uwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0;h=fb-16|0;fb=h;e=p[a+48>>2];l=p[a+40>>2];m=p[a+36>>2];f=p[a+44>>2];r=p[a+16>>2];j=p[a+4>>2];i=p[a>>2];p[h+8>>2]=i;p[h+12>>2]=j;b=p[a+12>>2];p[h>>2]=p[a+8>>2];p[h+4>>2]=b;a:{if(!d){k=l>>12;g=m>>12;break a}while(1){k=n[j+r|0];g=p[a+60>>2];b=f;f=Pb(f,-16777216,16776704);o=p[a+64>>2];i=Pb(e,-16777216,16776704);s=p[a+72>>2];t=p[a+32>>2];j=c;u=p[c>>2];q=k<<16;e=q;e=NNa(g,g>>31,e,e>>31);k=ib;g=NNa(o,o>>31,f,f>>31);f=g+e|0;e=ib+k|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=p[a+68>>2];i=NNa(f,f>>31,i,i>>31);f=g+i|0;e=ib+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=p[a+28>>2]+m|0;g=m>>12;p[j>>2]=v(e,g)+u;l=l+t|0;k=l>>12;p[c+4>>2]=p[c+4>>2]+v(e,k);f=f-(q&s)|0;Kb(h+8|0,h);d=d+ -1|0;if(d){c=c+8|0;j=p[h+12>>2];e=b;continue}break}i=p[h+8>>2];j=p[h+12>>2];e=b}p[a+40>>2]=l;p[a+20>>2]=g;p[a+36>>2]=m;p[a+48>>2]=e;p[a+44>>2]=f;p[a+24>>2]=k;p[a>>2]=i;p[a+4>>2]=j;fb=h+16|0}function pH(a){var b=w(0),c=0,d=0,e=0,f=0,g=w(0),h=w(0),i=0,j=w(0);c=fb-16|0;fb=c;i=c,j=w(tw(t[a+4216>>2])/w(He(p[a+16>>2])>>>0)),t[i+12>>2]=j;p[c+8>>2]=1056964608;b=w(D(w(w(ho(w(t[bl(c+12|0,c+8|0)>>2]*w(6.2831854820251465)))*w(.4000000059604645))+w(.6000000238418579))));t[a+4236>>2]=b;t[a+4240>>2]=D(w(w(1)-w(b*b)));f=a;b=w(w(t[a+4212>>2]*w(29))+w(2));a:{if(b<w(4294967296)&b>=w(0)){d=~~b>>>0;break a}d=0}n[f+4272|0]=d;f=a;e=2;b:{if(d>>>0<4){break b}e=3;if(d>>>0<8){break b}e=d>>>0<16?4:5}n[f+4273|0]=e;g=fe(w(10),w(w(w(t[a+4208>>2]*w(60))+w(-60))*w(.05000000074505806)));i=c,j=w(tw(t[a+4220>>2])/w(He(p[a+16>>2])>>>0)),t[i+12>>2]=j;p[c+8>>2]=1056964608;h=t[bl(c+12|0,c+8|0)>>2];i=c,j=w(tw(t[a+4224>>2])/w(He(p[a+16>>2])>>>0)),t[i+12>>2]=j;p[c+8>>2]=1056964608;b=H5(w(t[bl(c+12|0,c+8|0)>>2]*w(3.1415927410125732)));t[a+4268>>2]=w(w(1)-b)/w(b+w(1));b=ho(w(h*w(6.2831854820251465)));t[a+4264>>2]=-b;g=w(g*w(D(w(w(1)-w(b*b)))));b=t[a+4268>>2];t[a+4260>>2]=w(g*w(D(w(w(1)-w(b*b)))))*t[(q[a+4272|0]<<2)+33280>>2];fb=c+16|0}function P4(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;p[c+28>>2]=0;a:{b:{if(q[Qi(c+24|0,a,0)|0]){qc(c+16|0,p[p[a>>2]+ -12>>2]+a|0);p[114610]=0;d=M(2316,c+16|0)|0;e=p[114610];p[114610]=0;c:{d:{e:{f:{g:{if((e|0)==1){break g}e=mm(c+8|0,a);f=lk(c);g=p[p[a>>2]+ -12>>2];f=p[f>>2];e=p[e>>2];p[114610]=0;da(2319,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break g}Gb(c+16|0);if(p[c+20>>2]>=-2147483648){break f}p[c+28>>2]=p[c+28>>2]|4;d=-2147483648;break e}b=O(0)|0;H()|0;Gb(c+16|0);T(b|0)|0;b=p[c+28>>2]|1;p[c+28>>2]=b;Oi(p[p[a>>2]+ -12>>2]+a|0,b);b=p[p[a>>2]+ -12>>2];p[114610]=0;b=p[(a+b|0)+20>>2];d=p[114610];p[114610]=0;if((d|0)!=1){if(!(b&1)){break d}p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}if(p[c+20>>2]>2147483647){p[c+28>>2]=p[c+28>>2]|4;d=2147483647;break e}d=p[c+20>>2]}p[b>>2]=d;break c}V()}mg(p[p[a>>2]+ -12>>2]+a|0,p[c+28>>2])}fb=c+32|0;return a}a=O(0)|0;H()|0;rb(a)}E()}function _O(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;g=r[c>>1];a:{if(q[d|0]<=4){while(1){d=g<<1;o[c>>1]=d;n[b|0]=(d&65534)>>>0>255;d=q[c|0];o[c>>1]=d;if(!d){if(!Ae(a,f+15|0)){break a}d=q[f+15|0];o[c>>1]=d<<1|1;n[b|0]=d>>>7;o[c>>1]=q[c|0]}o[e>>1]=n[b|0]+(r[e>>1]<<1);d=r[c>>1]<<1;o[c>>1]=d;n[b|0]=(d&65534)>>>0>255;d=q[c|0];o[c>>1]=d;if(!d){if(!Ae(a,f+14|0)){break a}d=q[f+14|0];o[c>>1]=d<<1|1;n[b|0]=d>>>7;o[c>>1]=q[c|0]}o[e>>1]=n[b|0]+(r[e>>1]<<1);d=r[c>>1]<<1;o[c>>1]=d;n[b|0]=(d&65534)>>>0>255;g=q[c|0];o[c>>1]=g;if(!g){if(!Ae(a,f+13|0)){break a}d=q[f+13|0];o[c>>1]=d<<1|1;n[b|0]=d>>>7;g=q[c|0];o[c>>1]=g}if(q[b|0]){continue}break a}}while(1){d=g<<1;o[c>>1]=d;n[b|0]=(d&65534)>>>0>255;d=q[c|0];o[c>>1]=d;if(!d){if(!Ae(a,f+12|0)){break a}d=q[f+12|0];o[c>>1]=d<<1|1;n[b|0]=d>>>7;o[c>>1]=q[c|0]}o[e>>1]=n[b|0]+(r[e>>1]<<1);d=r[c>>1]<<1;o[c>>1]=d;n[b|0]=(d&65534)>>>0>255;g=q[c|0];o[c>>1]=g;if(!g){if(!Ae(a,f+11|0)){break a}d=q[f+11|0];o[c>>1]=d<<1|1;n[b|0]=d>>>7;g=q[c|0];o[c>>1]=g}if(q[b|0]){continue}break}}fb=f+16|0}function OD(a,b,c,d){var e=0,g=0,h=0,i=0,k=0,l=0,m=0;i=fb-32|0;fb=i;g=d&2147483647;h=g;e=g+ -1065418752|0;g=c;k=g;if(g>>>0<0){e=e+1|0}m=k;l=h+ -1082064896|0;k=g;if(g>>>0<0){l=l+1|0}a:{if((e|0)==(l|0)&m>>>0<k>>>0|e>>>0<l>>>0){h=(d&33554431)<<7|c>>>25;g=0;l=g;k=c&33554431;if(!(!g&(k|0)==16777216?!(a|b):!g&k>>>0<16777216|g>>>0<0)){e=h+1073741825|0;break a}e=h+1073741824|0;if(k^16777216|a|(b|l)){break a}e=(e&1)+e|0;break a}if(!(!g&(h|0)==2147418112?!(a|b):(h|0)==2147418112&g>>>0<0|h>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(h>>>0>1082064895){break a}e=0;h=h>>>16|0;if(h>>>0<16145){break a}e=d&65535|65536;ef(i+16|0,a,b,c,e,h+ -16129|0);om(i,a,b,g,e,16257-h|0);b=p[i+8>>2];e=(p[i+12>>2]&33554431)<<7|b>>>25;g=p[i+4>>2];h=g;a=0;k=a;l=p[i>>2]|((p[i+16>>2]|p[i+24>>2])!=0|(p[i+20>>2]|p[i+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(g|l):!a&b>>>0<16777216|a>>>0<0)){e=e+1|0;break a}if(b^16777216|l|(h|k)){break a}e=(e&1)+e|0}fb=i+32|0;return f(2,d&-2147483648|e),j()}function Dq(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=fb-16|0;fb=m;n[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!q[b|0]){break b}a=0;n[b|0]=0;b=p[e>>2];p[e>>2]=b+1;n[b|0]=46;if(!wb(h)){break a}b=p[j>>2];if((b-i|0)>159){break a}c=p[k>>2];p[j>>2]=b+4;p[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!wb(h)){break c}if(!q[b|0]){break b}a=0;b=p[j>>2];if((b-i|0)>159){break a}a=p[k>>2];p[j>>2]=b+4;p[b>>2]=a;a=0;p[k>>2]=0;break a}a=-1;f=Gm(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=q[f+62096|0];d:{e:{switch(f+ -22|0){case 2:case 3:b=p[e>>2];if((q[b+ -1|0]&95)!=(q[c|0]&127)?(b|0)!=(d|0):0){break a}p[e>>2]=b+1;n[b|0]=g;a=0;break a;case 0:case 1:n[c|0]=80;break d;default:break e}}a=n[c|0];if((a|0)!=(g&95)){break d}n[c|0]=a|128;if(!q[b|0]){break d}n[b|0]=0;if(!wb(h)){break d}a=p[j>>2];if((a-i|0)>159){break d}b=p[k>>2];p[j>>2]=a+4;p[a>>2]=b}a=p[e>>2];p[e>>2]=a+1;n[a|0]=g;a=0;if((f|0)>21){break a}p[k>>2]=p[k>>2]+1;break a}a=-1}fb=m+16|0;return a|0}function eLa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=fb-144|0;fb=g;k=zp(a);if(k){u=g+8|4;v=g+8|6;w=g+8|5;i=g+8|2;l=g+8|3;while(1){LKa(a,g+8|0);e=q[g+8|0]|q[g+9|0]<<8;a:{if(!e){break a}e=(e<<24|e<<8)>>>16|0;if(e>>>0>r[c+480192>>1]){break a}e=p[((e<<2)+c|0)+900380>>2];if(!e){break a}e=Jt(e,b);b:{if(!q[l|0]){break b}if(n[i|0]&1){n[e+12|0]=q[e+12|0]|1}if(q[i|0]&2){n[e+12|0]=q[e+12|0]|4}if(!(q[i|0]&4)){break b}n[e+12|0]=q[e+12|0]|2}n[g+4|0]=q[l|0];n[g+7|0]=31;f=q[hc(g+4|0,g+7|0)|0]+1|0;j=f&255;Vf(e,j);n[e+13|0]=q[w|0];n[e+14|0]=q[v|0];h=q[u|0];n[e+15|0]=h;n[e+16|0]=h;h=0;if((f|0)!=(j|0)){break a}while(1){m=g+16|0;s=h<<2;f=m+s|0;f=q[f|0]|q[f+1|0]<<8;x=Fb(e,h),y=(f<<8&16711680|f<<24)>>>16|0,o[x>>1]=y;f=(s|2)+m|0;f=q[f|0]|q[f+1|0]<<8;f=(f<<24|f<<8&16711680)>>>16|0;o[g+4>>1]=d?f+128>>>2|0:f;Lg(g+4|0,64);f=q[g+4|0];x=Fb(e,h),y=f,n[x+2|0]=y;h=h+1|0;if((j|0)!=(h|0)){continue}break}}t=t+1|0;if((t&65535)>>>0<k>>>0){continue}break}}fb=g+144|0}function Ava(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-48|0;fb=e;i=p[a+16>>2];f=Df(e+16|0);p[f+8>>2]=a+112;p[f+16>>2]=p[a+128>>2];m=f,n=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[m+12>>2]=n;b=p[f+16>>2];if(b){m=f,n=Cf(a+8|0,b),p[m>>2]=n;p[f+4>>2]=ib}j=p[a+24>>2];k=p[a+20>>2];b=p[a+4>>2];h=p[a>>2];p[e+8>>2]=h;p[e+12>>2]=b;g=p[a+12>>2];p[e>>2]=p[a+8>>2];p[e+4>>2]=g;if(d){while(1){g=0;p[e+40>>2]=h;p[e+44>>2]=l;h=(b<<1)+i|0;a:{b=p[f+16>>2];if((b|0)<=0){break a}while(1){qd(p[f+8>>2],o[(g<<1)+h>>1]/4<<16>>16);pd(p[f+8>>2],4);Kb(e+40|0,f);if((b|0)<2){break a}b=b+ -1|0;g=p[e+44>>2];continue}}d=d+ -1|0;b=p[f+8>>2];Kb(b,b+8|0);b=p[f+8>>2];g=p[b+4>>2];if(g){qd(b,o[h+(p[e+44>>2]<<1)>>1]/4<<16>>16);pd(p[f+8>>2],g);b=p[f+8>>2];g=p[b>>2];p[b>>2]=g;p[b+4>>2]=0}b=xf(b,p[f+12>>2]);p[c>>2]=p[c>>2]+v(b,k);p[c+4>>2]=p[c+4>>2]+v(b,j);Kb(e+8|0,e);if(d){c=c+8|0;h=p[e+8>>2];b=p[e+12>>2];continue}break}h=p[e+8>>2];b=p[e+12>>2]}p[a>>2]=h;p[a+4>>2]=b;fb=e+48|0}function qG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;a:{b:{c:{d:{e:{f:{g:{if(Xh(a)){mo(d+24|0);break g}xm(d+8|0,a);p[114610]=0;K(2175,d+24|0,d+8|0);c=p[114610];p[114610]=0;if((c|0)==1){break f}gf(d+8|0)}c=a+36|0;h:{if(Xh(a)){break h}c=p[d+24>>2]}if((b|0)==-1){e=4194304;break d}if((b|0)>=0){f=b;if((Dd(c)|0)>(b|0)){break d}}b=W(8)|0;p[114610]=0;c=J(85,d+8|0,38614)|0;a=p[114610];p[114610]=0;if((a|0)==1){break e}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break c}a=I()|0;H()|0;gf(d+8|0);break b}a=I()|0;H()|0;X(b|0);break c}p[a+8>>2]=b;b=a+24|0;g=p[b>>2];p[g+480208>>2]=p[g+480208>>2]&-4194305|e;b=p[b>>2];e=q[Gc(c,f)+16|0];p[114610]=0;K(489,b+484360|0,e|0);b=p[114610];p[114610]=0;i:{if((b|0)==1){break i}b=p[Gc(c,f)+12>>2];c=p[Gc(c,f)+8>>2];p[114610]=0;+ha(2025,a|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break i}p[a+16>>2]=0;p[a+20>>2]=0;Nj(d+24|0);fb=d+32|0;return}a=I()|0;H()|0}Nj(d+24|0)}L(a|0)}E()}function DW(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb+ -64|0;fb=c;a=Xc(a);p[114610]=0;b=Y(228)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}p[114610]=0;d=J(2,c+32|0,10984)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}p[114610]=0;b=Y(228)|0;e=p[114610];p[114610]=0;e:{f:{g:{h:{if((e|0)==1){break h}p[114610]=0;p[c+12>>2]=b;K(234,c+16|0,c+12|0);b=p[114610];p[114610]=0;if((b|0)==1){break h}p[114610]=0;N(3,c+48|0,d|0,c+16|0);b=p[114610];p[114610]=0;if((b|0)==1){break g}xb(a,c+48|0);pb(c+48|0);pb(c+16|0);pb(d);p[114610]=0;b=Y(230)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}if(!b){break e}p[114610]=0;J(235,a|0,10987)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break e}break b}b=I()|0;H()|0;break f}b=I()|0;H()|0;pb(c+16|0)}pb(d);break a}p[114610]=0;b=Y(229)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}if(!b){break d}p[114610]=0;J(235,a|0,10989)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}}fb=c- -64|0;return}b=I()|0;H()|0;break a}b=I()|0;H()|0}pb(a);L(b|0);E()}function IK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;g=v(b,896)+a|0;a:{if(c){vb(e+8|0,a+1074308|0,90);if(!tb(e+8|0)){n[(v(b,896)+a|0)+1075815|0]=c}n[(v(b,896)+a|0)+1075816|0]=c;break a}c=q[g+1075816|0]}f=g+1074984|0;h=c&255;j=0-h|0;i=d?i:!(p[a+480180>>2]&204473357);DK(a,b,j,i);b:{c:{if(p[a+480180>>2]!=16777216){break c}g=p[(v(b,896)+a|0)+1075640>>2];if(!g|!p[g+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){CK(a,f,240-h|0);break b}if(!(b>>>0<224|d)){BK(f,224-h|0);break b}AK(f,j);break b}if(p[a+480180>>2]==268435456){p[(v(b,896)+a|0)+1075692>>2]=65535}if(!(i^1|(c&255)>>>0<224)){d:{d=h&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}xK(a,f,d);break b}if(p[a+480180>>2]==524288){break d}FK(a,f,d);break b}if(p[a+480180>>2]!=524288){break b}}e:{if(!(n[(v(b,896)+a|0)+1075856|0]&1)){break e}if(p[a+1074416>>2]==1){vb(e+8|0,a+1074308|0,6);if(tb(e+8|0)){break e}}if(p[a+480180>>2]==64){break e}if(!(p[a+480208>>2]&2)|p[a+480180>>2]!=8){break b}}yK(a,f,h<<2)}fb=e+16|0}function tta(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;if(!q[a+40|0]){o[c>>1]=0;o[b>>1]=0;return}f=p[a+16>>2];e=r[f+3840>>1];d=0;a:{if(!(e&3)){break a}d=(r[a+20>>1]>>>7&7)>>>(q[f+3844|0]^1)>>>(e&1)|0;d=(e&4?0-d|0:d)<<16>>16}d=d<<r[a+22>>1];h=b;e=p[a+36>>2];b:{if(e){i=r[e+32>>1];g=r[a+32>>1];e=Af(p[a>>2],p[a+24>>2],d<<16>>16,0,o[a+30>>1]);f=p[a+24>>2];b=p[a+4>>2];if(!i){if(!g){d=d<<16>>16;e=Af(b,f,d,e,0);e=Af(p[a+8>>2],p[a+24>>2],d,e,0);d=Af(p[a+12>>2],p[a+24>>2],d,e,0);break b}d=d<<16>>16;f=Af(b,f,d,0,0);f=Af(p[a+8>>2],p[a+24>>2],d,f,0);d=Af(p[a+12>>2],p[a+24>>2],d,f,0)+e|0;break b}if(!g){d=d<<16>>16;e=Af(b,f,d,e,0);f=Af(p[a+8>>2],p[a+24>>2],d,0,0);d=Af(p[a+12>>2],p[a+24>>2],d,f,0)+e|0;break b}d=d<<16>>16;f=Af(b,f,d,0,0);d=(Af(p[a+8>>2],p[a+24>>2],d,f,0)+e|0)+Af(p[a+12>>2],p[a+24>>2],d,0,0)|0;break b}g=r[a+32>>1];d=d<<16>>16;e=Af(p[a>>2],p[a+24>>2],d,0,o[a+30>>1]);f=p[a+24>>2];b=p[a+4>>2];if(!g){d=Af(b,f,d,e,0);break b}d=Af(b,f,d,0,0)+e|0}o[h>>1]=q[a+41|0]?d:0;o[c>>1]=q[a+42|0]?d:0}function NJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-2608|0;fb=f;d=f+8|0;Tl(d,a);p[d+1056>>2]=0;p[d+1060>>2]=0;Jb(d+1064|0,0,1536);p[114610]=0;S(566,d|0);a=p[114610];p[114610]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!c){break d}f:{while(1){p[114610]=0;j=J(260,d|0,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break f}a=0;g:{while(1){p[114610]=0;e=J(260,d|0,1)|0;k=p[114610];p[114610]=0;if((k|0)==1){break g}a=v(a,6)+d|0;a=o[(e?a+1066|0:a+1064|0)>>1];h:{if((a|0)>255){break h}e=v(a,6)+d|0;g=q[e+1068|0];if(o[e+1064>>1]<0){break h}if(o[e+1066>>1]>-1){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;n[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break d}break}b=O(77024)|0;break e}b=O(77024)|0;break e}b=O(77024)|0}if((H()|0)!=($(77024)|0)){break a}T(b|0)|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break c}}p[114610]=0;a=M(567,d|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}sb(d);fb=f+2608|0;return a|0}b=I()|0;H()|0;break a}b=I()|0;H()|0}sb(d);L(b|0);E()}function y_(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a;while(1){a:{if(i>>>0>=c>>>0|d>>>0>=b>>>0){break a}g=n[d|0];f=g&255;b:{if((g|0)>=0){g=1;if(f>>>0<=1114111){break b}break a}if(f>>>0<194){break a}if(f>>>0<=223){if((b-d|0)<2){break a}e=q[d+1|0];if((e&192)!=128){break a}g=2;if((e&63|f<<6&1984)>>>0<=1114111){break b}break a}c:{d:{if(f>>>0<=239){if((b-d|0)<3){break a}h=q[d+2|0];e=q[d+1|0];if((f|0)==237){break d}if((f|0)==224){if((e&224)==160){break c}break a}if((e&192)!=128){break a}break c}if((b-d|0)<4|f>>>0>244){break a}h=q[d+3|0];j=q[d+2|0];e=q[d+1|0];e:{f:{switch(f+ -240|0){case 0:if((e+112&255)>>>0<48){break e}break a;case 4:if((e&240)==128){break e}break a;default:break f}}if((e&192)!=128){break a}}if((j&192)!=128|(h&192)!=128){break a}g=4;if((h&63|(j<<6&4032|(f<<18&1835008|(e&63)<<12)))>>>0>1114111){break a}break b}if((e&224)!=128){break a}}if((h&192)!=128){break a}g=3;if((h&63|(f<<12&61440|(e&63)<<6))>>>0>1114111){break a}}i=i+1|0;d=d+g|0;continue}break}return d-a|0}function Hwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;g=fb-16|0;fb=g;f=p[a+48>>2];l=p[a+24>>2];m=p[a+20>>2];b=p[a+44>>2];o=p[a+16>>2];h=p[a+4>>2];i=p[a>>2];p[g+8>>2]=i;p[g+12>>2]=h;e=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=h+o|0;h=n[e+1|0];q=n[e|0];e=p[a+60>>2];r=e;s=e>>31;e=Pb(b,-16777216,16776704);j=p[a+64>>2];f=Pb(f,-16777216,16776704);t=p[a+72>>2];u=p[c>>2];e=NNa(j,j>>31,e,e>>31);j=ib;w=e;e=p[a+68>>2];k=NNa(e,e>>31,f,f>>31);e=w+k|0;f=ib+j|0;f=e>>>0<k>>>0?f+1|0:f;j=e;e=q<<8;h=((v((h<<8)-e|0,i>>>18|0)|0)/16384|0)+e<<8;e=h;i=NNa(r,s,e,e>>31);e=j+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;p[c>>2]=v(e,m)+u;p[c+4>>2]=p[c+4>>2]+v(e,l);e=f-(h&t)|0;Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;i=p[g+8>>2];h=p[g+12>>2];f=b;b=e;continue}break}i=p[g+8>>2];h=p[g+12>>2]}p[a+48>>2]=b;p[a+44>>2]=e;p[a>>2]=i;p[a+4>>2]=h;fb=g+16|0}function aya(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;vd(b,0);mk(d,2,a+32|0);zc(d+16|0,d);p[114610]=0;J(370,b+43|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(d+16|0);e=a+56|0;c=a+52|0;a:{if((q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))>>>0<=(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))>>>0){break a}p[b>>2]=(q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24))-(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24));c=a+44|0;p[b+12>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+48|0;p[d+16>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);f=b,g=p[Cb(d+16|0,b)>>2],p[f+16>>2]=g;o[b+30>>1]=q[a+60|0];c=a+62|0;p[b+24>>2]=q[c|0]|q[c+1|0]<<8;c=a- -64|0;if(q[c|0]|q[c+1|0]<<8){rs(b,+((q[c|0]|q[c+1|0]<<8)<<16>>16)*25431315104166665e-22)}a=a+61|0;if(q[a|0]&8){o[b+34>>1]=r[b+34>>1]|8}if(q[a|0]&16){o[b+34>>1]=r[b+34>>1]|16}if(!(q[a|0]&4)){break a}o[b+34>>1]=r[b+34>>1]|1;p[b+12>>2]=p[b+12>>2]>>>1;p[b+16>>2]=p[b+16>>2]>>>1}fb=d+32|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function JK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;h=v(b,896)+a|0;a:{if(c){vb(e+8|0,a+1074308|0,90);if(!tb(e+8|0)){n[(v(b,896)+a|0)+1075816|0]=c}n[(v(b,896)+a|0)+1075815|0]=c;break a}c=q[h+1075815|0]}f=h+1074984|0;g=c&255;i=d?i:!(p[a+480180>>2]&204473357);DK(a,b,g,i);b:{c:{if(p[a+480180>>2]!=16777216){break c}h=p[(v(b,896)+a|0)+1075640>>2];if(!h|!p[h+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){CK(a,f,g+ -240|0);break b}if(!(b>>>0<224|d)){BK(f,g+ -224|0);break b}AK(f,g);break b}if(p[a+480180>>2]==268435456){p[(v(b,896)+a|0)+1075692>>2]=1}if(!(i^1|(c&255)>>>0<224)){d:{d=g&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}zK(a,f,d);break b}if(p[a+480180>>2]==524288){break d}EK(a,f,d);break b}if(p[a+480180>>2]!=524288){break b}}e:{if(!(n[(v(b,896)+a|0)+1075856|0]&1)){break e}if(p[a+1074416>>2]==1){vb(e+8|0,a+1074308|0,6);if(tb(e+8|0)){break e}}if(p[a+480180>>2]==64){break e}if(!(p[a+480208>>2]&2)|p[a+480180>>2]!=8){break b}}yK(a,f,0-(g<<2)|0)}fb=e+16|0}function Gwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0;h=fb-16|0;fb=h;g=p[a+48>>2];m=p[a+24>>2];n=p[a+20>>2];b=p[a+44>>2];q=p[a+16>>2];f=p[a+4>>2];i=p[a>>2];p[h+8>>2]=i;p[h+12>>2]=f;e=p[a+12>>2];p[h>>2]=p[a+8>>2];p[h+4>>2]=e;a:{if(!d){e=b;b=g;break a}while(1){e=(f<<1)+q|0;r=o[e+2>>1];e=o[e>>1];f=p[a+60>>2];s=f;t=f>>31;f=Pb(b,-16777216,16776704);j=p[a+64>>2];g=Pb(g,-16777216,16776704);u=p[a+72>>2];w=p[c>>2];f=NNa(j,j>>31,f,f>>31);j=ib;k=f;f=p[a+68>>2];l=NNa(f,f>>31,g,g>>31);f=k+l|0;g=ib+j|0;g=f>>>0<l>>>0?g+1|0:g;k=f;f=e+((v(r-e|0,i>>>18|0)|0)/16384|0)<<8;e=f;i=NNa(s,t,e,e>>31);e=k+i|0;g=ib+g|0;g=e>>>0<i>>>0?g+1|0:g;e=e+8388608|0;if(e>>>0<8388608){g=g+1|0}g=(g&16777215)<<8|e>>>24;e=(g|0)/256|0;p[c>>2]=v(e,n)+w;p[c+4>>2]=p[c+4>>2]+v(e,m);e=g-(f&u)|0;Kb(h+8|0,h);d=d+ -1|0;if(d){c=c+8|0;i=p[h+8>>2];f=p[h+12>>2];g=b;b=e;continue}break}i=p[h+8>>2];f=p[h+12>>2]}p[a+48>>2]=b;p[a+44>>2]=e;p[a>>2]=i;p[a+4>>2]=f;fb=h+16|0}function KE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-208|0;fb=d;p[d+8>>2]=1;p[d+12>>2]=0;a:{h=b<<2;if(!h){break a}p[d+16>>2]=4;p[d+20>>2]=4;b=4;g=4;e=2;while(1){f=b;b=(g+4|0)+b|0;p[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;g=f;if(b>>>0<h>>>0){continue}break}f=(a+h|0)+ -4|0;b:{if(f>>>0<=a>>>0){e=1;b=1;break b}e=1;b=1;while(1){c:{if((e&3)==3){Cv(a,c,b,d+16|0);Xq(d+8|0,2);b=b+2|0;break c}g=b+ -1|0;d:{if(s[(d+16|0)+(g<<2)>>2]>=f-a>>>0){Wq(a,c,d+8|0,b,0,d+16|0);break d}Cv(a,c,b,d+16|0)}if((b|0)==1){Vq(d+8|0,1);b=0;break c}Vq(d+8|0,g);b=1}e=p[d+8>>2]|1;p[d+8>>2]=e;a=a+4|0;if(a>>>0<f>>>0){continue}break}}Wq(a,c,d+8|0,b,0,d+16|0);while(1){e:{f:{g:{if(!((b|0)!=1|(e|0)!=1)){if(p[d+12>>2]){break g}break a}if((b|0)>1){break f}}f=JE(d+8|0);Xq(d+8|0,f);e=p[d+8>>2];b=b+f|0;break e}Vq(d+8|0,2);p[d+8>>2]=p[d+8>>2]^7;Xq(d+8|0,1);g=a+ -4|0;f=b+ -2|0;Wq(g-p[(d+16|0)+(f<<2)>>2]|0,c,d+8|0,b+ -1|0,1,d+16|0);Vq(d+8|0,1);e=p[d+8>>2]|1;p[d+8>>2]=e;Wq(g,c,d+8|0,f,1,d+16|0);b=f}a=a+ -4|0;continue}}fb=d+208|0}function rj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-80|0;fb=d;c=p[a+28>>2];tn(p[p[c>>2]+ -12>>2]+c|0,0);if(!od(a,4)){Nu(a)}a:{if(!p[a+4>>2]){break a}if(od(a,6)){break a}if(od(a,7)){break a}h=p[a+28>>2];c=d- -64|0;e=p[a+84>>2];f=v(p[a+20>>2],p[a+4>>2]);g=f+p[a+80>>2]|0;if(g>>>0<f>>>0){e=e+1|0}e=Bg(c,g,e);f=p[e+12>>2];p[d+24>>2]=p[e+8>>2];p[d+28>>2]=f;c=p[e+4>>2];p[d+16>>2]=p[e>>2];p[d+20>>2]=c;Ni(h,d+16|0)}c=0;b:{if(!od(a,5)){break b}e=a+44|0;f=gd(e);if(!f){break b}g=a+32|0;while(1){c:{h=(p[a+96>>2]+c>>>0)%(f>>>0)|0;if(s[jc(e,h)>>2]>=Cc(g)>>>0){break c}i=_l(d+48|0,oc(g,p[jc(e,h)>>2]),r[jc(e,h)+12>>1]);j=Ru(b,i);yb(i);if(!j){break c}p[a+96>>2]=(h+1>>>0)%(f>>>0);if(p[jc(e,h)+4>>2]){f=p[a+28>>2];b=d+32|0;c=p[a+12>>2];g=p[a+8>>2];a=p[jc(e,h)+4>>2];g=g+a|0;if(g>>>0<a>>>0){c=c+1|0}a=Bg(b,g,c);c=p[a+12>>2];p[d+8>>2]=p[a+8>>2];p[d+12>>2]=c;b=p[a+4>>2];p[d>>2]=p[a>>2];p[d+4>>2]=b;Ni(f,d)}c=jc(e,h);break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}c=0}fb=d+80|0;return c}function S_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;j=fb-16|0;fb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!q[i|0]){break a}i=i+1|0;continue}break}p[h>>2]=f;p[e>>2]=c;while(1){b:{c:{d:{if((f|0)==(g|0)|(c|0)==(d|0)){break d}k=p[b+4>>2];p[j+8>>2]=p[b>>2];p[j+12>>2]=k;e:{f:{g:{k=R_(f,e,i-c|0,g-f>>2,b,p[a+8>>2]);h:{if((k|0)==-1){while(1){i:{p[h>>2]=f;if(p[e>>2]==(c|0)){break i}g=1;j:{k:{l:{b=BC(f,c,i-c|0,j+8|0,p[a+8>>2]);switch(b+2|0){case 2:break j;case 1:break l;case 0:break f;default:break k}}p[e>>2]=c;break h}g=b}c=c+g|0;f=p[h>>2]+4|0;continue}break}p[e>>2]=c;break d}f=p[h>>2]+(k<<2)|0;p[h>>2]=f;if((f|0)==(g|0)){break e}c=p[e>>2];if((d|0)==(i|0)){i=d;continue}if(!BC(f,c,1,b,p[a+8>>2])){break g}}a=2;break c}p[h>>2]=p[h>>2]+4;c=p[e>>2]+1|0;p[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!q[i|0]){break b}i=i+1|0;continue}}p[e>>2]=c;a=1;break c}c=p[e>>2]}a=(c|0)!=(d|0)}fb=j+16|0;return a|0}f=p[h>>2];continue}}function x4(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;p[114610]=0;g=J(15,d+24|0,a|0)|0;h=p[114610];p[114610]=0;a:{b:{c:{if((h|0)!=1){d:{if(!q[g|0]){break d}qc(d+16|0,p[p[a>>2]+ -12>>2]+a|0);p[114610]=0;h=M(2331,d+16|0)|0;e=p[114610];p[114610]=0;e:{f:{if((e|0)!=1){Gb(d+16|0);e=Dk(d+8|0,a);f=p[p[a>>2]+ -12>>2];p[114610]=0;f=a+f|0;i=M(16,f|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break f}e=p[e>>2];p[114610]=0;b=xa(2334,h|0,e|0,f|0,i|0,b|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break f}p[d+16>>2]=b;if(!Ck(d+16|0)){break d}b=p[p[a>>2]+ -12>>2];p[114610]=0;K(18,a+b|0,5);b=p[114610];p[114610]=0;if((b|0)!=1){break d}b=O(0)|0;H()|0;break e}b=O(0)|0;H()|0;Gb(d+16|0);break e}b=O(0)|0;H()|0}uf(g);break c}uf(g);break b}b=O(0)|0;H()|0}T(b|0)|0;b=p[p[a>>2]+ -12>>2];p[114610]=0;S(19,a+b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=d+32|0;return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function vEa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-432|0;fb=c;Ac(a);Ty(a,c+376|0,c+296|0,c+8|0);g=1;g=q[c+408|0]|q[c+409|0]<<8|(q[c+410|0]<<16|q[c+411|0]<<24)?q[c+427|0]+1|0:g;o[c+6>>1]=4;j=c+291|0;a:{while(1){e=q[c+8|0]|q[c+9|0]<<8;d=e<<8&16711680|e<<24;if(d>>16<0|q[j|0]>63){break a}if(e){d=(d|(e>>>8&65280|e>>>24))>>>16|0;e=d>>>0>1?d:1;f=0;while(1){d=q[c+392|0]|q[c+393|0]<<8|(q[c+394|0]<<16|q[c+395|0]<<24);b:{if(!Jc(a,(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))+(f<<2)|0)){break b}if(!Jc(a,Pz(a))){break b}d=c;c:{if(!b){h=td(a);break c}h=zp(a)}o[d+4>>1]=h;l=c,m=r[Bi(c+6|0,c+4|0)>>1],o[l+6>>1]=m}f=f+1|0;if((e|0)!=(f|0)){continue}break}}d:{if(!(q[c+296|0]|q[c+297|0]<<8|(q[c+298|0]<<16|q[c+299|0]<<24))){break d}d=q[c+296|0]|q[c+297|0]<<8|(q[c+298|0]<<16|q[c+299|0]<<24);if(!Jc(a,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))){break d}Ty(a,c+376|0,c+296|0,c+8|0);i=i+1|0;if((g|0)>(i&255)){continue}}break}k=r[c+6>>1]}fb=c+432|0;return k|0}function E_(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=a;while(1){a:{if(g>>>0>=c>>>0|e>>>0>=b>>>0){break a}f=q[e|0];if(f>>>0>1114111){break a}d=e+1|0;b:{if(f<<24>>24>=0){break b}if(f>>>0<194){break a}if(f>>>0<=223){if((b-e|0)<2){break a}d=q[e+1|0];if((d&192)!=128|(d&63|f<<6&1984)>>>0>1114111){break a}d=e+2|0;break b}c:{d:{if(f>>>0<=239){if((b-e|0)<3){break a}h=q[e+2|0];d=q[e+1|0];if((f|0)==237){break d}if((f|0)==224){if((d&224)==160){break c}break a}if((d&192)!=128){break a}break c}if(c-g>>>0<2|f>>>0>244|(b-e|0)<4){break a}h=q[e+3|0];i=q[e+2|0];d=q[e+1|0];e:{f:{switch(f+ -240|0){case 0:if((d+112&255)>>>0<48){break e}break a;case 4:if((d&240)==128){break e}break a;default:break f}}if((d&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(h&63|(i<<6&4032|(f<<18&1835008|(d&63)<<12)))>>>0>1114111){break a}g=g+1|0;d=e+4|0;break b}if((d&224)!=128){break a}}if((h&192)!=128|(h&63|(f<<12&61440|(d&63)<<6))>>>0>1114111){break a}d=e+3|0}e=d;g=g+1|0;continue}break}return e-a|0}function eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb+ -64|0;fb=c;d=Xg(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{if(Xh(b)){mo(c+56|0);break i}p[114610]=0;K(2189,c+40|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break h}p[114610]=0;K(2175,c+56|0,c+40|0);a=p[114610];p[114610]=0;if((a|0)==1){break g}gf(c+40|0)}e=c;a=b+36|0;j:{if(Xh(b)){break j}a=p[c+56>>2]}f=e,g=Ub(a),p[f+32>>2]=g;f=c,g=Vb(a),p[f+24>>2]=g;if(Ab(c+32|0,c+24|0)){a=b+24|0;while(1){b=li(p[a>>2]+484360|0,q[p[c+32>>2]+16|0]);p[114610]=0;K(2190,c+8|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;N(9,c+40|0,0,c+8|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;K(1534,d|0,c+40|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}pb(c+40|0);pb(c+8|0);ok(c+32|0);if(Ab(c+32|0,c+24|0)){continue}break}}Nj(c+56|0);fb=c- -64|0;return}b=I()|0;H()|0;break a}b=I()|0;H()|0;gf(c+40|0);break a}b=I()|0;H()|0;break b}b=I()|0;H()|0;break c}b=I()|0;H()|0;pb(c+40|0)}pb(c+8|0)}Nj(c+56|0)}bd(d);L(b|0);E()}function Mla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;vd(c,0);d=a+36|0;o[e+14>>1]=q[d|0]|q[d+1|0]<<8;o[e+12>>1]=32767;f=c,g=(r[rf(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,o[f+28>>1]=g;d=a+38|0;o[e+10>>1]=q[d|0]|q[d+1|0]<<8;o[e+8>>1]=32767;f=c,g=(r[rf(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,o[f+30>>1]=g;o[c+32>>1]=64;d=a+44|0;p[c>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=a+48|0;p[c+4>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=a+52|0;p[c+8>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=a+56|0;p[c+24>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=b+166|0;if(q[d|0]<=4){n[c+38|0]=q[q[d|0]+31786|0]}n[c+39|0]=q[b+167|0];d=b+171|0;n[c+41|0]=(q[d|0]|q[d+1|0]<<8)>>>4;b=b+169|0;b=(q[b|0]|q[b+1|0]<<8)>>>2|0;n[c+40|0]=b;if(q[c+41|0]|b&255){n[c+39|0]=q[c+39|0]^-1}a=a+40|0;if(q[a|0]&4){o[c+34>>1]=r[c+34>>1]|1}if(q[a|0]&8){o[c+34>>1]=r[c+34>>1]|2}if(q[a|0]&16){o[c+34>>1]=r[c+34>>1]|4}if(q[a|0]&32){o[c+34>>1]=r[c+34>>1]|32}fb=e+16|0}function y4(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-32|0;fb=c;p[114610]=0;g=J(15,c+24|0,a|0)|0;d=p[114610];p[114610]=0;a:{b:{c:{if((d|0)!=1){d:{if(!q[g|0]){break d}qc(c+16|0,p[p[a>>2]+ -12>>2]+a|0);p[114610]=0;d=M(2331,c+16|0)|0;e=p[114610];p[114610]=0;e:{f:{if((e|0)!=1){Gb(c+16|0);e=Dk(c+8|0,a);f=p[p[a>>2]+ -12>>2];p[114610]=0;f=a+f|0;h=M(16,f|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break f}e=p[e>>2];p[114610]=0;b=Z(2332,d|0,e|0,f|0,h|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}p[c+16>>2]=b;if(!Ck(c+16|0)){break d}b=p[p[a>>2]+ -12>>2];p[114610]=0;K(18,a+b|0,5);b=p[114610];p[114610]=0;if((b|0)!=1){break d}b=O(0)|0;H()|0;break e}b=O(0)|0;H()|0;Gb(c+16|0);break e}b=O(0)|0;H()|0}uf(g);break c}uf(g);break b}b=O(0)|0;H()|0}T(b|0)|0;b=p[p[a>>2]+ -12>>2];p[114610]=0;S(19,a+b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=c+32|0;return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function u4(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;p[114610]=0;g=J(15,d+24|0,a|0)|0;c=p[114610];p[114610]=0;a:{b:{c:{if((c|0)!=1){d:{if(!q[g|0]){break d}qc(d+16|0,p[p[a>>2]+ -12>>2]+a|0);p[114610]=0;c=M(2331,d+16|0)|0;e=p[114610];p[114610]=0;e:{f:{if((e|0)!=1){Gb(d+16|0);e=Dk(d+8|0,a);f=p[p[a>>2]+ -12>>2];p[114610]=0;f=a+f|0;h=M(16,f|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break f}e=p[e>>2];p[114610]=0;c=Ua(2335,c|0,e|0,f|0,h|0,+b)|0;e=p[114610];p[114610]=0;if((e|0)==1){break f}p[d+16>>2]=c;if(!Ck(d+16|0)){break d}c=p[p[a>>2]+ -12>>2];p[114610]=0;K(18,a+c|0,5);c=p[114610];p[114610]=0;if((c|0)!=1){break d}c=O(0)|0;H()|0;break e}c=O(0)|0;H()|0;Gb(d+16|0);break e}c=O(0)|0;H()|0}uf(g);break c}uf(g);break b}c=O(0)|0;H()|0}T(c|0)|0;c=p[p[a>>2]+ -12>>2];p[114610]=0;S(19,a+c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=d+32|0;return}a=I()|0;H()|0;p[114610]=0;R(20);d=p[114610];p[114610]=0;if((d|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function pv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-32|0;fb=c;p[114610]=0;g=J(15,c+24|0,a|0)|0;d=p[114610];p[114610]=0;a:{b:{c:{if((d|0)!=1){d:{if(!q[g|0]){break d}qc(c+16|0,p[p[a>>2]+ -12>>2]+a|0);p[114610]=0;d=M(2331,c+16|0)|0;e=p[114610];p[114610]=0;e:{f:{if((e|0)!=1){Gb(c+16|0);e=Dk(c+8|0,a);f=p[p[a>>2]+ -12>>2];p[114610]=0;f=a+f|0;h=M(16,f|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break f}e=p[e>>2];p[114610]=0;b=Z(2333,d|0,e|0,f|0,h|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break f}p[c+16>>2]=b;if(!Ck(c+16|0)){break d}b=p[p[a>>2]+ -12>>2];p[114610]=0;K(18,a+b|0,5);b=p[114610];p[114610]=0;if((b|0)!=1){break d}b=O(0)|0;H()|0;break e}b=O(0)|0;H()|0;Gb(c+16|0);break e}b=O(0)|0;H()|0}uf(g);break c}uf(g);break b}b=O(0)|0;H()|0}T(b|0)|0;b=p[p[a>>2]+ -12>>2];p[114610]=0;S(19,a+b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=c+32|0;return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Cva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0;e=fb-48|0;fb=e;i=p[a+16>>2];f=Df(e+16|0);p[f+8>>2]=a+112;p[f+16>>2]=p[a+128>>2];m=f,o=yf(b+327720|0,p[b+20>>2],(p[a+88>>2]&16384)>>>14|0),p[m+12>>2]=o;b=p[f+16>>2];if(b){m=f,o=Cf(a+8|0,b),p[m>>2]=o;p[f+4>>2]=ib}j=p[a+24>>2];k=p[a+20>>2];b=p[a+4>>2];h=p[a>>2];p[e+8>>2]=h;p[e+12>>2]=b;g=p[a+12>>2];p[e>>2]=p[a+8>>2];p[e+4>>2]=g;if(d){while(1){g=0;p[e+40>>2]=h;p[e+44>>2]=l;h=b+i|0;a:{b=p[f+16>>2];if((b|0)<=0){break a}while(1){qd(p[f+8>>2],n[h+g|0]<<6);pd(p[f+8>>2],4);Kb(e+40|0,f);if((b|0)<2){break a}b=b+ -1|0;g=p[e+44>>2];continue}}d=d+ -1|0;b=p[f+8>>2];Kb(b,b+8|0);b=p[f+8>>2];g=p[b+4>>2];if(g){qd(b,n[h+p[e+44>>2]|0]<<6);pd(p[f+8>>2],g);b=p[f+8>>2];g=p[b>>2];p[b>>2]=g;p[b+4>>2]=0}b=xf(b,p[f+12>>2]);p[c>>2]=p[c>>2]+v(b,k);p[c+4>>2]=p[c+4>>2]+v(b,j);Kb(e+8|0,e);if(d){c=c+8|0;h=p[e+8>>2];b=p[e+12>>2];continue}break}h=p[e+8>>2];b=p[e+12>>2]}p[a>>2]=h;p[a+4>>2]=b;fb=e+48|0}function iwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;j=p[a+16>>2];a:{b:{c:{h=p[a+8>>2];g=p[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}k=p[a+24>>2];l=p[a+20>>2];b=p[a+4>>2];e=p[a>>2];p[f+8>>2]=e;p[f+12>>2]=b;p[f>>2]=h;p[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((v(o[b+ -4>>1],o[e+2>>1])+v(o[b+ -6>>1],o[e>>1])|0)+v(o[b+ -2>>1],o[e+4>>1])|0)+v(o[b>>1],o[e+6>>1])|0)+v(o[b+2>>1],o[e+8>>1])|0)+v(o[b+4>>1],o[e+10>>1])|0)+v(o[b+6>>1],o[e+12>>1])|0)+v(o[b+8>>1],o[e+14>>1])|0)/32768|0;p[c>>2]=p[c>>2]+v(b,l);p[c+4>>2]=p[c+4>>2]+v(b,k);Kb(f+8|0,f);d=d+ -1|0;if(d){c=c+8|0;e=p[f+8>>2];b=p[f+12>>2];continue}break}e=p[f+8>>2];b=p[f+12>>2]}p[a>>2]=e;p[a+4>>2]=b;fb=f+16|0}function Li(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,n=0;i=fb-32|0;fb=i;p[i+16>>2]=c;p[i+24>>2]=b;qc(i+8|0,d);p[114610]=0;j=M(2449,i+8|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){Gb(i+8|0);p[e>>2]=0;c=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(Fj(i+24|0,i+16|0)){break b}c:{if((bm(j,p[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}k=0;b=bm(j,p[c>>2]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=bm(j,p[g+8>>2])}l=i,n=m[p[p[a>>2]+36>>2]](a,p[i+24>>2],p[i+16>>2],d,e,f,b,k)|0,p[l+24>>2]=n;g=c+8|0;break c}if(Gj(j,8192,p[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(Gj(j,8192,p[g>>2])){continue}}break}while(1){if(!Pq(i+24|0,i+16|0)){break c}if(!Gj(j,8192,Rk(i+24|0))){break c}lm(i+24|0);continue}}if((Bk(j,Rk(i+24|0))|0)==(Bk(j,p[g>>2])|0)){g=g+4|0;lm(i+24|0);break c}p[e>>2]=4}c=p[e>>2];continue}break}p[e>>2]=4}if(Fj(i+24|0,i+16|0)){p[e>>2]=p[e>>2]|2}fb=i+32|0;return p[i+24>>2]}a=I()|0;H()|0;Gb(i+8|0);L(a|0);E()}function Qva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,w=0;f=fb-32|0;fb=f;j=p[a+24>>2];k=p[a+20>>2];l=p[a+16>>2];i=p[a+4>>2];e=i;g=p[a>>2];p[f+24>>2]=g;p[f+28>>2]=e;i=p[a+12>>2];p[f+16>>2]=p[a+8>>2];p[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=o[a+38>>1];n=o[a+36>>1];q=o[a+34>>1];r=o[a+32>>1];s=o[a+30>>1];t=o[a+28>>1];u=o[a+26>>1];w=o[a+24>>1];g=0;a=1;while(1){e=g<<1;p[(f+8|0)+(g<<2)>>2]=(((((v(o[(e|8)+h>>1],q)+v(o[(e|4)+h>>1],r)|0)+v(o[(e|12)+h>>1],n)|0)+v(o[(e|16)+h>>1],m)|0)/2|0)+((((v(o[(e|-8)+h>>1],u)+v(o[(e|-12)+h>>1],w)|0)+v(o[(e|-4)+h>>1],t)|0)+v(o[e+h>>1],s)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}p[c>>2]=p[c>>2]+v(p[f+8>>2],k);p[c+4>>2]=p[c+4>>2]+v(p[f+12>>2],j);Kb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;g=p[f+24>>2];e=p[f+28>>2];continue}break}g=p[f+24>>2];e=p[f+28>>2]}p[i>>2]=g;p[i+4>>2]=e;fb=f+32|0}function py(a,b){a=a|0;b=b|0;a:{b:{switch((q[a+3|0]|64)+ -64|0){case 0:n[a+3|0]=q[a+5|0]?42:0;return;case 1:n[a+3|0]=16;return;case 2:n[a+3|0]=12;return;case 3:n[a+3|0]=14;if(b){break a}b=a;a=q[a+5|0];n[b+5|0]=v(a>>>4|0,10)+(a&15);return;case 4:n[a+3|0]=11;return;case 5:n[a+3|0]=3;return;case 6:n[a+3|0]=2;return;case 7:n[a+3|0]=4;return;case 8:n[a+3|0]=5;return;case 9:n[a+3|0]=18;return;case 10:n[a+3|0]=1;return;case 11:n[a+3|0]=7;return;case 12:n[a+3|0]=6;return;case 13:n[a+3|0]=21;return;case 14:n[a+3|0]=22;return;case 15:n[a+3|0]=10;return;case 16:n[a+3|0]=29;return;case 17:n[a+3|0]=15;return;case 18:n[a+3|0]=8;return;case 19:n[a+3|0]=20;return;case 20:n[a+3|0]=17;return;case 21:n[a+3|0]=26;return;case 22:n[a+3|0]=23;return;case 23:n[a+3|0]=24;return;case 24:n[a+3|0]=9;return;case 25:n[a+3|0]=27;return;case 26:n[a+3|0]=31;return;case 28:n[a+3|0]=b?32:31;return;case 29:n[a+3|0]=33;return;case 27:n[a+3|0]=34;return;default:break b}}n[a+3|0]=0}}function cDa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0;e=fb-16|0;fb=e;n[e+15|0]=8;o[e+12>>1]=0;p[e+8>>2]=0;o[e+6>>1]=0;if(d){k=v(c,d);while(1){if((k|0)>=1){h=(j<<1)+b|0;s=h+(k<<1)|0;while(1){o[e+6>>1]=0;_O(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{b:{g=q[e+15|0];if(!g){break b}c=r[e+12>>1];while(1){f=c<<1;c=f&254;o[e+12>>1]=c;f=(f&65534)>>>0>255;n[e+14|0]=f;if(!c){if(!Ae(a,e+5|0)){break b}c=q[e+5|0];f=c>>>7|0;n[e+14|0]=f;c=c<<1&254|1;o[e+12>>1]=c}i=r[e+6>>1]<<1|f;o[e+6>>1]=i;g=g+ -1|0;if(g&255){continue}break}break a}i=r[e+6>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;l=c&255;if(l>>>0<2){break c}f=c+ -1|0;if(!(g&1<<l)){continue}break}}n[e+15|0]=(q[e+15|0]+c&254)>>>1;c=i&1;n[e+14|0]=c;c=c+ -1^(i&65534)>>>1;f=c+r[e+8>>1]|0;o[e+6>>1]=f;o[h>>1]=f;c=(c>>1)-m|0;m=o[e+6>>1];p[e+8>>2]=c+(m<<1);Vd(e+8|0,-32768,32767);h=(d<<1)+h|0;if(h>>>0<s>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}fb=e+16|0}function s7(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=a;j=a>>31;g=NNa(a,j,1e4,0)+14780|0;a=ib;h=g;a=g>>>0<14780?a+1|0:a;g=a;e=i;f=ONa(h,a,-14609700,-1)+e|0;a=j+ib|0;a=f>>>0<e>>>0?a+1|0:a;e=f;f=ONa(h,g,365242500,0);e=e+f|0;a=ib+a|0;a=e>>>0<f>>>0?a+1|0:a;f=ONa(h,g,-146097e4,-1);e=f+e|0;a=ib+a|0;a=e>>>0<f>>>0?a+1|0:a;h=ONa(h,g,3652425,0);f=ib;g=f;k=NNa(h,f,-365,-1);f=k+e|0;e=ib+a|0;e=f>>>0<k>>>0?e+1|0:e;a=e;if((a|0)<-1?1:(a|0)<=-1){a=g+ -1|0;g=h+ -1|0;if((g|0)!=-1){a=a+1|0}h=g;g=a;e=ONa(h,a,-4,-1)+i|0;a=j+ib|0;a=e>>>0<i>>>0?a+1|0:a;f=NNa(h,g,-365,-1);i=f+e|0;e=ib+a|0;e=i>>>0<f>>>0?e+1|0:e;f=ONa(h,g,100,0);i=f+i|0;a=ib+e|0;a=i>>>0<f>>>0?a+1|0:a;e=ONa(h,g,-400,-1);i=e+i|0;a=ib+a|0;f=i;a=f>>>0<e>>>0?a+1|0:a}i=b;b=NNa(f,a,100,0)+52|0;a=ib;g=ONa(b,b>>>0<52?a+1|0:a,3060,0);a=ib;e=a;b=g+2|0;if(b>>>0<2){a=a+1|0}a=ONa(b,a,12,0);h=a+h|0;p[i>>2]=h;a=NNa(a,ib,12,0);p[c>>2]=(b-a|0)+1;b=NNa(g,e,306,0)+5|0;a=ib;a=ONa(b,b>>>0<5?a+1|0:a,-10,-1)+f|0;p[d>>2]=a+1}function Mi(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,o=0;i=fb-32|0;fb=i;p[i+16>>2]=c;p[i+24>>2]=b;qc(i+8|0,d);p[114610]=0;j=M(21,i+8|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){Gb(i+8|0);p[e>>2]=0;c=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(Pi(i+24|0,i+16|0)){break b}c:{if((cm(j,n[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}k=0;b=cm(j,n[c|0]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=cm(j,n[g+2|0])}l=i,o=m[p[p[a>>2]+36>>2]](a,p[i+24>>2],p[i+16>>2],d,e,f,b,k)|0,p[l+24>>2]=o;g=c+2|0;break c}if(wg(j,8192,n[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(wg(j,8192,n[g|0])){continue}}break}while(1){if(!ao(i+24|0,i+16|0)){break c}if(!wg(j,8192,Ij(i+24|0))){break c}Uk(i+24|0);continue}}if((_u(j,Ij(i+24|0))|0)==(_u(j,n[g|0])|0)){g=g+1|0;Uk(i+24|0);break c}p[e>>2]=4}c=p[e>>2];continue}break}p[e>>2]=4}if(Pi(i+24|0,i+16|0)){p[e>>2]=p[e>>2]|2}fb=i+32|0;return p[i+24>>2]}a=I()|0;H()|0;Gb(i+8|0);L(a|0);E()}function jwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;j=p[a+16>>2];a:{b:{c:{h=p[a+8>>2];g=p[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}k=p[a+24>>2];l=p[a+20>>2];b=p[a+4>>2];e=p[a>>2];p[f+8>>2]=e;p[f+12>>2]=b;p[f>>2]=h;p[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((v(n[b+ -2|0],o[e+2>>1])+v(n[b+ -3|0],o[e>>1])|0)+v(n[b+ -1|0],o[e+4>>1])|0)+v(n[b|0],o[e+6>>1])|0)+v(n[b+1|0],o[e+8>>1])|0)+v(n[b+2|0],o[e+10>>1])|0)+v(n[b+3|0],o[e+12>>1])|0)+v(n[b+4|0],o[e+14>>1])<<8)/32768|0;p[c>>2]=p[c>>2]+v(b,l);p[c+4>>2]=p[c+4>>2]+v(b,k);Kb(f+8|0,f);d=d+ -1|0;if(d){c=c+8|0;e=p[f+8>>2];b=p[f+12>>2];continue}break}e=p[f+8>>2];b=p[f+12>>2]}p[a>>2]=e;p[a+4>>2]=b;fb=f+16|0}function CU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-80|0;fb=d;Ac(b);hq(a);a:{if(!au(b,d+40|0)){break a}if(!RA(d+40|0)){break a}b:{if(!c){break b}c=d+40|4;e=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);if(!Hb(b,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+ -28|0)){break a}vu(a);uu(d+24|0);tu(qg(a)+28|0,d+24|0);gq(d+24|0);e=p[qg(a)+28>>2];p[114610]=0;f=M(350,b|0)|0;b=p[114610];p[114610]=0;c:{if((b|0)==1){break c}c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);b=q[d+52|0]|q[d+53|0]<<8|(q[d+54|0]<<16|q[d+55|0]<<24);p[114610]=0;c=U(351,f|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+ -28|0,e|0,b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}f=0;if(!c){break a}Ei(d+8|0,e);qu(d+16|0,d+8|0);b=Ln(d+24|0,d+16|0);Nd(qg(a)+12|0,b);sb(b);break b}b=wa(71348,77368)|0;a=H()|0;d:{if(($(71348)|0)==(a|0)){break d}if(($(77368)|0)==(a|0)){break d}L(b|0);E()}T(b|0)|0;V();f=0;break a}f=1}fb=d+80|0;return f|0}function _m(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;n[a+861|0]=0;p[a+708>>2]=0;p[a+656>>2]=0;p[a+104>>2]=0;n[a+819|0]=0;p[a+804>>2]=0;p[a+824>>2]=0;p[a+696>>2]=0;p[a+668>>2]=0;p[a+88>>2]=p[a+88>>2]|6144;vb(e+8|0,b+1074308|0,23);if(tb(e+8|0)){o[a+798>>1]=65536;o[a+800>>1]=1}n[a+866|0]=0;n[a+859|0]=0;n[a+871|0]=255;p[a+660>>2]=0;n[a+872|0]=q[a+872|0]&252;Gs(a+810|0);p[a+84>>2]=0;p[a+76>>2]=0;p[a+80>>2]=0;p[a+700>>2]=0;p[a+656>>2]=0;p[a+104>>2]=0;p[a+92>>2]=0;p[a+96>>2]=0;p[a>>2]=0;p[a+4>>2]=0;n[a+865|0]=0;n[a+858|0]=0;p[a+688>>2]=0;p[a+672>>2]=0;p[a+676>>2]=0;o[a+840>>1]=0;n[a+839|0]=0;o[a+856>>1]=32512;o[a+862>>1]=0;p[a+20>>2]=0;p[a+24>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;p[a+28>>2]=0;p[a+32>>2]=0;p[a+876>>2]=0;p[a+880>>2]=0;n[a+872|0]=q[a+872|0]&243;a:{if(c>>>0>126){c=64;b=128;d=0;break a}d=(c<<5)+b|0;c=r[d+480286>>1];b=r[d+480284>>1];d=p[d+480280>>2]}o[a+796>>1]=0;p[a+760>>2]=c;p[a+692>>2]=b;p[a+88>>2]=d;n[a+817|0]=0;n[a+818|0]=0;fb=e+16|0}function iF(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=p[a+32>>2];a:{b:{c:{c=p[a+1380>>2];d:{if((c|0)==-1){h=1;c=-1;break d}d=p[a+1116>>2];e:{if((c|0)>=(d|0)){break e}while(1){e=q[(a+c|0)+1120|0];b=e+b|0;if((e|0)!=255){break e}c=c+1|0;if((c|0)<(d|0)){continue}break}}if(b>>>0>s[a+40>>2]){break c}c=(c|0)==(d|0)?-1:c}while(1){if((c|0)!=-1){return 1}g=p[a+40>>2];if(b+26>>>0>=g>>>0){Wb(a,1);break a}if((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))!=(q[84608]|q[84609]<<8|(q[84610]<<16|q[84611]<<24))){Wb(a,21);break a}if(q[b+4|0]){Wb(a,21);break a}f:{if(h){if(!p[a+992>>2]|!(n[b+5|0]&1)){break f}Wb(a,21);break a}if(n[b+5|0]&1){break f}Wb(a,21);break a}d=b+27|0;e=q[b+26|0];b=d+e|0;if(b>>>0>g>>>0){break b}h=0;c=0;f=0;g:{if(!e){break g}while(1){i=q[c+d|0];b=i+b|0;f=c;if((i|0)!=255){break g}c=c+1|0;if((e|0)!=(c|0)){continue}break}f=e}d=f;c=(d|0)==(e|0)?-1:d;if(b>>>0<=g>>>0){continue}break}Wb(a,1);break a}Wb(a,1);break a}Wb(a,1)}return 0}function uL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-96|0;fb=e;n[e+95|0]=d;d=0;h=Po(a);i=bj(h);o[b>>1]=0;a:{if(i){while(1){j=r[kc(h,d&65535)>>1];b:{if(!Cg(p[a+24>>2]+484344|0,j)){break b}d=r[b>>1];if(nc(a)>>>0<=d>>>0){p[c>>2]=0;a=1;break a}f=id(a,r[b>>1]);ej(e+72|0,f);bk(e- -64|0,f);d=p[e+76>>2];p[e+32>>2]=p[e+72>>2];p[e+36>>2]=d;d=p[e+68>>2];p[e+24>>2]=p[e+64>>2];p[e+28>>2]=d;lsa(e+80|0,e+32|0,e+24|0,e+95|0);d=c;c:{if(q[e+95|0]){bk(e+56|0,f);g=0;if(tL(e+80|0,e+56|0)){break c}if(q[e+95|0]){break b}}bk(e+56|0,f);if(tL(e+80|0,e+56|0)^1){ej(e+48|0,f);a=p[e+84>>2];b=p[e+80>>2];p[e+40>>2]=b;p[e+44>>2]=a;c=p[e+52>>2];p[e+16>>2]=p[e+48>>2];p[e+20>>2]=c;p[e+8>>2]=b;p[e+12>>2]=a;g=GN(e+16|0,e+8|0);break c}if(s[f+4>>2]>=s[Rb(p[a+24>>2]+484344|0,j)+12>>2]){break b}g=p[f+4>>2]}p[d>>2]=g;a=1;break a}d=r[b>>1]+1|0;o[b>>1]=d;if((d&65535)>>>0<i>>>0){continue}break}}o[b>>1]=65535;p[c>>2]=-1;a=0}fb=e+96|0;return a|0}function Ni(a,b){var c=0,d=0,e=0,f=0;c=fb+ -64|0;fb=c;d=p[(p[p[a>>2]+ -12>>2]+a|0)+16>>2]&-3;tn(p[p[a>>2]+ -12>>2]+a|0,d);a:{b:{if(q[Qi(c+56|0,a,1)|0]){e=p[p[a>>2]+ -12>>2];p[114610]=0;e=p[(a+e|0)+24>>2];f=p[114610];p[114610]=0;c:{d:{if((f|0)==1){break d}p[114610]=0;f=p[b+12>>2];p[c+16>>2]=p[b+8>>2];p[c+20>>2]=f;f=p[b+4>>2];p[c+8>>2]=p[b>>2];p[c+12>>2]=f;Q(2326,c+40|0,e|0,c+8|0,8);b=p[114610];p[114610]=0;if((b|0)==1){break d}b=Bg(c+24|0,-1,-1);p[114610]=0;b=hS(c+40|0,b);e=p[114610];p[114610]=0;if((e|0)==1){break d}b=b?d|4:d;break c}b=O(0)|0;H()|0;T(b|0)|0;b=d|1;Oi(p[p[a>>2]+ -12>>2]+a|0,b);d=p[p[a>>2]+ -12>>2];p[114610]=0;d=p[(a+d|0)+20>>2];e=p[114610];p[114610]=0;e:{if((e|0)!=1){if(!(d&1)){break e}p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}V()}mg(p[p[a>>2]+ -12>>2]+a|0,b)}fb=c- -64|0;return}a=O(0)|0;H()|0;rb(a)}E()}function ija(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-48|0;fb=e;p[e+44>>2]=0;ni(b,e+44|0);a:{b:{if(p[e+44>>2]!=(xk(32481)|0)){break b}p[e+40>>2]=0;ni(b,e+40|0);i=-1;f=p[e+40>>2];if(f+ -1>>>0>1){break b}c:{d:{e:{if((f|0)<=1){f=Lb(e+24|0);p[114610]=0;g=P(724,b|0,f|0,256)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}if(!g){break d}p[114610]=0;N(13,e+8|0,d|0,f|0);g=p[114610];p[114610]=0;if((g|0)!=1){break e}break a}f=Lb(e+24|0);p[114610]=0;g=P(726,b|0,f|0,255)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}if(!g){break c}p[114610]=0;N(13,e+8|0,d|0,f|0);g=p[114610];p[114610]=0;if((g|0)==1){break a}}xb(c,e+8|0);pb(e+8|0);pb(f);c=0;o[e+8>>1]=0;mf(b,e+8|0);p[e+24>>2]=0;ni(b,e+24|0);f=p[e+24>>2];if(f>>>0>50){break b}if(f){while(1){if(!gI(a,b,d)){break b}c=c+1|0;if(c>>>0<s[e+24>>2]){continue}break}}p[e+24>>2]=0;ni(b,e+24|0);i=p[e+24>>2]==(xk(32486)|0)?1:-1;break b}pb(f);break b}pb(f)}fb=e+48|0;return i}a=I()|0;H()|0;pb(f);L(a|0);E()}function Rva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0;f=fb-32|0;fb=f;j=p[a+24>>2];k=p[a+20>>2];l=p[a+16>>2];h=p[a+4>>2];i=h;e=p[a>>2];p[f+24>>2]=e;p[f+28>>2]=h;h=p[a+12>>2];p[f+16>>2]=p[a+8>>2];p[f+20>>2]=h;h=a;if(d){while(1){g=(((i&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=o[a+38>>1];q=o[a+36>>1];r=o[a+34>>1];s=o[a+32>>1];t=o[a+30>>1];u=o[a+28>>1];w=o[a+26>>1];x=o[a+24>>1];e=0;a=1;while(1){p[(f+8|0)+(e<<2)>>2]=(((((v(n[(e|4)+g|0],r)+v(n[(e|2)+g|0],s)|0)+v(n[(e|6)+g|0],q)|0)+v(n[(e|8)+g|0],m)<<8)/2|0)+((((v(n[(e|-4)+g|0],w)+v(n[(e|-6)+g|0],x)|0)+v(n[(e|-2)+g|0],u)|0)+v(n[e+g|0],t)<<8)/2|0)|0)/16384;i=a;a=0;e=1;if(i){continue}break}p[c>>2]=p[c>>2]+v(p[f+8>>2],k);p[c+4>>2]=p[c+4>>2]+v(p[f+12>>2],j);Kb(f+24|0,f+16|0);d=d+ -1|0;if(d){c=c+8|0;e=p[f+24>>2];i=p[f+28>>2];continue}break}e=p[f+24>>2];i=p[f+28>>2]}p[h>>2]=e;p[h+4>>2]=i;fb=f+32|0}function Mfa(a){var b=w(0),c=w(0),d=w(0),e=0,f=w(0),g=w(0),h=w(0),i=w(0),j=w(0),k=w(0),l=w(0),m=0,o=w(0);e=fb-16|0;fb=e;c=zg(a,5);f=zg(a,11);d=w(c*zg(a,4));i=w(w(d*w(.03999999910593033))+w(c*w(.02250000089406967)));c=w(f*zg(a,10));f=w(w(c*w(.03999999910593033))+w(f*w(.02250000089406967)));if(n[a+4264|0]&1){b=zg(a,3);g=zg(a,9);b=w(b*d);d=w(zg(a,2)*b);i=w(w(w(b*w(.12250000238418579))+i)+w(d*w(.1444000005722046)));b=w(g*c);c=w(zg(a,8)*b);f=w(w(w(b*w(.12250000238418579))+f)+w(c*w(.1444000005722046)))}zg(a,12);b=t[a+4496>>2];g=zg(a,1);h=zg(a,7);k=zg(a,0);l=zg(a,6);m=e,o=fe(w(10),w(w(iH(a)+w(w(t[a+4236>>2]*w(12e3))+w(-1e4)))*w(.0005000000237487257))),t[m+12>>2]=o;p[e+8>>2]=1065353216;j=t[bl(e+12|0,e+8|0)>>2];b=w(b*b);c=w(h*w(b*c));h=w(l*c);d=w(g*w(b*d));b=w(k*d);g=w(w(w(h+b)*w(-.5))+w(1));t[a+4284>>2]=j*w(D(w(g/w(w(w(b+c)*w(.1444000005722046))+i))));t[a+4288>>2]=j*w(D(w(g/w(w(w(h+d)*w(.1444000005722046))+f))));fb=e+16|0}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=w(0),h=0,i=0,j=0,k=0,l=0,m=0,n=w(0),o=w(0),q=w(0),r=w(0),s=w(0),u=w(0),v=w(0),y=w(0),z=0,A=0,B=w(0);if(p[a+4220>>2]){f=a+44|0;i=Fd(f,0);j=Fd(f,1);k=_c(f,0);l=_c(f,1);if(d){h=a+4208|0;e=p[a+4224>>2];m=d;while(1){n=t[j>>2];o=t[i>>2];z=h;e=e-p[a+4228>>2]|0;if((e|0)<=-1){e=e+p[a+4220>>2]|0}e=e<<1;q=t[Fb(z,e)>>2];e=Fb(h,e|1);s=t[a+4248>>2];u=t[a+4256>>2];v=t[a+4252>>2];y=t[a+4244>>2];r=t[e>>2];g=w(w(w(w(n*s)+w(o*u))+w(q*v))+w(y*r));A=Fb(h,p[a+4224>>2]<<1),B=w(x(g))<w(1.0000000195414814e-24)?w(0):g,t[A>>2]=B;g=w(w(w(w(s*o)+w(u*n))+w(v*r))+w(y*q));A=Fb(h,p[a+4224>>2]<<1|1),B=w(x(g))<w(1.0000000195414814e-24)?w(0):g,t[A>>2]=B;e=p[a+4224>>2]+1|0;e=(e|0)==p[a+4220>>2]?0:e;p[a+4224>>2]=e;t[k>>2]=w(q*t[a+4236>>2])+w(o*t[a+4240>>2]);t[l>>2]=w(r*t[a+4236>>2])+w(n*t[a+4240>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m+ -1|0;if(m){continue}break}}Zh(a,b,c,_c(f,0),_c(f,1),d)}}function aDa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,s=0,t=0;e=fb-16|0;fb=e;n[e+15|0]=4;o[e+12>>1]=0;p[e+8>>2]=0;n[e+7|0]=0;if(d){k=v(c,d);s=(k|0)<1;while(1){if(!s){h=b+j|0;t=k+h|0;while(1){n[e+7|0]=0;ZO(a,e+14|0,e+12|0,e+7|0);a:{b:{g=q[e+15|0];if(!g){break b}c=r[e+12>>1];while(1){f=c<<1;c=f&254;o[e+12>>1]=c;f=(f&65534)>>>0>255;n[e+14|0]=f;if(!c){if(!Ae(a,e+6|0)){break b}c=q[e+6|0];f=c>>>7|0;n[e+14|0]=f;c=c<<1&254|1;o[e+12>>1]=c}i=q[e+7|0]<<1|f;n[e+7|0]=i;g=g+ -1|0;if(g&255){continue}break}break a}i=q[e+7|0]}c=1;g=i&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;l=c&255;if(l>>>0<2){break c}f=c+ -1|0;if(!(g&1<<l)){continue}break}}n[e+15|0]=(q[e+15|0]+c&254)>>>1;c=i&1;n[e+14|0]=c;c=c+ -1^(i&254)>>>1;f=c+q[e+8|0]|0;n[e+7|0]=f;n[h|0]=f;c=(c>>1)-m|0;m=n[e+7|0];p[e+8>>2]=c+(m<<1);Vd(e+8|0,-128,127);h=d+h|0;if(h>>>0<t>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}fb=e+16|0}function sda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-48|0;fb=b;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){d=Lb(b+32|0);c=p[a+24>>2];p[114610]=0;K(2075,b+16|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break h}e=b,f=Ub(b+16|0),p[e+8>>2]=f;e=b,f=Vb(b+16|0),p[e>>2]=f;if(!Ab(b+8|0,b)){break f}break g}c=O(0)|0;H()|0;break c}c=O(0)|0;H()|0;break d}while(1){c=p[b+8>>2];p[114610]=0;J(1251,d|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}kn(b+8|0);e=b,f=Vb(b+16|0),p[e>>2]=f;if(!Ab(b+8|0,b)){break f}p[114610]=0;J(1995,d|0,34105)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}break e}c=Pd(Ib(d));bd(b+16|0);pb(d);break b}c=O(0)|0;H()|0;bd(b+16|0)}pb(d)}T(c|0)|0;c=0;p[114610]=0;Q(1989,36809,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=b+48|0;return c|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Zda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-48|0;fb=b;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((c|0)!=1){d=Lb(b+32|0);c=p[a+24>>2];p[114610]=0;K(2040,b+16|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break h}e=b,f=Ub(b+16|0),p[e+8>>2]=f;e=b,f=Vb(b+16|0),p[e>>2]=f;if(!Ab(b+8|0,b)){break f}break g}c=O(0)|0;H()|0;break c}c=O(0)|0;H()|0;break d}while(1){c=p[b+8>>2];p[114610]=0;J(1251,d|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break e}kn(b+8|0);e=b,f=Vb(b+16|0),p[e>>2]=f;if(!Ab(b+8|0,b)){break f}p[114610]=0;J(1995,d|0,34105)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}break e}c=Pd(Ib(d));bd(b+16|0);pb(d);break b}c=O(0)|0;H()|0;bd(b+16|0)}pb(d)}T(c|0)|0;c=0;p[114610]=0;Q(1989,35566,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=b+48|0;return c|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function sma(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;g=Xg(a);a=c+16|0;a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);p[114610]=0;a=J(256,b|0,a|0)|0;d=p[114610];p[114610]=0;a:{b:{c:{if((d|0)==1){break c}d:{e:{f:{if(!a){break f}a=c+12|0;d=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);p[114610]=0;K(1532,g|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break c}if(!(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))){break f}d=c+4|0;c=0;while(1){p[114610]=0;e=J(258,b|0,4)|0;h=p[114610];p[114610]=0;if((h|0)==1){break b}if(!e){break f}e=q[d|0]|q[d+1|0]<<8;p[114610]=0;N(1533,f|0,b|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break e}p[114610]=0;K(1534,g|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break d}pb(f);c=c+1|0;if(c>>>0<(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))>>>0){continue}break}}fb=f+16|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(f);break a}a=I()|0;H()|0;break a}a=I()|0;H()|0}bd(g);L(a|0);E()}function fj(a){a=a|0;var b=0;a:{b:{switch(q[a+3|0]){case 0:if(!q[a+5|0]){break a}n[a+3|0]=1;return;case 1:n[a+3|0]=2;return;case 2:n[a+3|0]=3;return;case 3:n[a+3|0]=4;return;case 4:n[a+3|0]=5;return;case 5:n[a+3|0]=6;return;case 6:n[a+3|0]=7;return;case 7:n[a+3|0]=8;return;case 8:n[a+3|0]=9;return;case 9:n[a+3|0]=10;return;case 10:n[a+3|0]=11;return;case 11:n[a+3|0]=12;return;case 12:n[a+3|0]=13;return;case 13:n[a+3|0]=14;b=a;a=q[a+5|0];n[b+5|0]=v(a>>>4|0,10)+(a&15);return;case 14:n[a+3|0]=19;return;case 15:if(q[a+5|0]<=31){n[a+3|0]=16;return}n[a+3|0]=17;return;case 16:n[a+3|0]=23;return;case 17:n[a+3|0]=24;return;case 20:n[a+3|0]=25;return;case 21:n[a+3|0]=30;return;case 25:n[a+3|0]=29;return;case 27:n[a+3|0]=15;return;case 29:n[a+3|0]=18;return;case 33:n[a+3|0]=28;return;case 34:n[a+3|0]=27;return;case 35:n[a+3|0]=31;return;case 36:n[a+3|0]=32;return;case 38:n[a+3|0]=34;return;default:break b}}n[a+3|0]=0}}function Xwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0;h=fb-16|0;fb=h;f=p[a+48>>2];n=p[a+24>>2];q=p[a+20>>2];b=p[a+44>>2];r=p[a+16>>2];i=p[a+4>>2];j=p[a>>2];p[h+8>>2]=j;p[h+12>>2]=i;e=p[a+12>>2];p[h>>2]=p[a+8>>2];p[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){j=o[(i<<1)+r>>1];g=p[a+60>>2];k=g;e=Pb(b,-16777216,16776704);m=p[a+64>>2];i=Pb(f,-16777216,16776704);s=p[a+72>>2];f=p[c>>2];l=g>>31;j=j<<8;g=j;g=NNa(k,l,g,g>>31);k=ib;l=c;t=f;f=g;g=NNa(m,m>>31,e,e>>31);e=f+g|0;f=ib+k|0;f=e>>>0<g>>>0?f+1|0:f;g=e;e=p[a+68>>2];i=NNa(e,e>>31,i,i>>31);e=g+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;p[l>>2]=t+v(e,q);p[c+4>>2]=p[c+4>>2]+v(e,n);e=f-(j&s)|0;Kb(h+8|0,h);d=d+ -1|0;if(d){c=c+8|0;i=p[h+12>>2];f=b;b=e;continue}break}j=p[h+8>>2];i=p[h+12>>2]}p[a+48>>2]=b;p[a+44>>2]=e;p[a>>2]=j;p[a+4>>2]=i;fb=h+16|0}function Ywa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,q=0,r=0,s=0,t=0;h=fb-16|0;fb=h;f=p[a+48>>2];o=p[a+24>>2];q=p[a+20>>2];b=p[a+44>>2];r=p[a+16>>2];i=p[a+4>>2];j=p[a>>2];p[h+8>>2]=j;p[h+12>>2]=i;e=p[a+12>>2];p[h>>2]=p[a+8>>2];p[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){j=n[i+r|0];g=p[a+60>>2];k=g;e=Pb(b,-16777216,16776704);m=p[a+64>>2];i=Pb(f,-16777216,16776704);s=p[a+72>>2];f=p[c>>2];l=g>>31;j=j<<16;g=j;g=NNa(k,l,g,g>>31);k=ib;l=c;t=f;f=g;g=NNa(m,m>>31,e,e>>31);e=f+g|0;f=ib+k|0;f=e>>>0<g>>>0?f+1|0:f;g=e;e=p[a+68>>2];i=NNa(e,e>>31,i,i>>31);e=g+i|0;f=ib+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;p[l>>2]=t+v(e,q);p[c+4>>2]=p[c+4>>2]+v(e,o);e=f-(j&s)|0;Kb(h+8|0,h);d=d+ -1|0;if(d){c=c+8|0;i=p[h+12>>2];f=b;b=e;continue}break}j=p[h+8>>2];i=p[h+12>>2]}p[a+48>>2]=b;p[a+44>>2]=e;p[a>>2]=j;p[a+4>>2]=i;fb=h+16|0}function aJ(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,p=0,s=0;k=fb-16|0;fb=k;n[k+15|0]=c;n[k+14|0]=12;Vf(b,q[hc(k+15|0,k+14|0)|0]);if(Bb(b)){c=0;l=a+96|0;a=a+144|0;while(1){a:{b:{c:{switch(h|0){case 0:i=c<<2;j=i+l|0;j=q[j|0]|q[j+1|0]<<8;p=Fb(b,c),s=j,o[p>>1]=s;i=(i|2)+l|0;break b;case 1:break c;default:break a}}i=c<<2;j=i+a|0;j=q[j|0]|q[j+1|0]<<8;p=Fb(b,c),s=j,o[p>>1]=s;i=a+(i|2)|0}i=q[i|0];p=Fb(b,c),s=i,n[p+2|0]=s}d:{if(!c){break d}i=c+ -1|0;if(r[Fb(b,c)>>1]>=r[Fb(b,i)>>1]){break d}if(r[Fb(b,c)>>1]>255){break d}j=q[Fb(b,i)+1|0];m=Fb(b,c);o[m>>1]=r[m>>1]|j<<8;if(r[Fb(b,c)>>1]>=r[Fb(b,i)>>1]){break d}i=Fb(b,c);o[i>>1]=r[i>>1]+256}c=c+1|0;if(c>>>0<Bb(b)>>>0){continue}break}}n[b+12|0]=0;e:{if(!(d&1)){break e}if(cd(b)){break e}n[b+12|0]=q[b+12|0]|1}if(e>>>0<=11){if(d&2){n[b+12|0]=q[b+12|0]|4}n[b+15|0]=e;n[b+16|0]=e}if(!(g>>>0<f>>>0|g>>>0>11)){if(d&4){n[b+12|0]=q[b+12|0]|2}n[b+14|0]=g;n[b+13|0]=f}fb=k+16|0}function rK(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;p[e+12>>2]=b;f=0;a:{if(!b){break a}if(p[a+480180>>2]&20){b=a+1074308|0;vb(e,b,73);if(tb(e)){p[e+12>>2]=r[e+12>>1]}if(q[a+480208|0]&16){vb(e,b,73);b=tb(e);a=p[e+12>>2];c=p[((a>>>0)%768<<2)+22048>>2]<<6;if(b){a=14-((9983-a>>>0)/768|0)&31}else{a=((a>>>0)/768|0)+2|0}f=c>>>a|0;break a}a=p[e+12>>2];if(!a){p[e+12>>2]=1;a=1}f=229079296/(a>>>0)|0;break a}f=227001280/(b>>>0)|0;if(dt(a)){break a}f=(b+c<<4)+ -133808|0;if(p[a+480180>>2]==64){break a}b=p[a+480180>>2];vc(e+12|0,16777215);if(b&17408){f=dd(QNa(NNa(c?c:8363,0,3506176,0),ib,(p[e+12>>2]<<8)+d|0,0),ib);break a}if(q[a+480208|0]&16){vb(e,a+1074308|0,7);if(tb(e)){c=d>>31;b=d;a=p[e+12>>2];d=a>>>24|0;f=a<<8;b=b+f|0;a=c+d|0;a=b>>>0<f>>>0?a+1|0:a;f=(a&15)<<28|b>>>4;break a}f=dd(QNa(NNa(c?c:8363,0,7012352,0),ib,(p[e+12>>2]<<8)+d|0,0),ib);break a}f=dd(QNa(-1485242368,13,(p[e+12>>2]<<8)+d|0,0),ib)}fb=e+16|0;return f}function cN(a,b,c){var d=0;d=q[a|0]&15;n[a|0]=q[d+17456|0];a:{b:{c:{switch(d|0){case 0:if(q[b|0]?c>>>0>=51:0){break b}n[a|0]=0;return;case 5:d=q[b|0];if(!((d&240)!=32?(d&15)!=2:0)){n[a|0]=20;n[b|0]=159;d=159}if(!((d&15)==12|(d&240)==192)|c>>>0<51){break b}n[a|0]=25;n[b|0]=0;return;case 7:if(c>>>0>51){break b}n[a|0]=0;return;case 10:a=q[b|0]&240;if(!a){break b}n[b|0]=a;return;case 11:n[b|0]=v(q[b|0]&15,17);return;case 12:n[b|0]=q[b|0]>>>2;return;case 13:a=q[b|0];n[b|0]=v(a>>>4|0,10)+(a&15);return;case 14:d:{switch((q[b|0]>>>4|0)+ -1|0){case 0:n[a|0]=2;break a;case 1:n[a|0]=3;break a;case 7:if(c>>>0<52){break b}n[a|0]=20;n[b|0]=q[b|0]&15|96;return;case 8:n[a|0]=15;n[b|0]=q[b|0]&15;return;case 9:n[a|0]=11;n[b|0]=q[b|0]<<4|15;return;case 10:n[a|0]=11;break a;case 11:case 12:break d;default:break b}}n[a|0]=20;return;case 15:break c;default:break b}}if(q[b|0]<48){break b}n[a|0]=17}return}n[b|0]=q[b|0]|240}function y6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-16|0;fb=g;a:{if(p[a+1420>>2]>=0){p[f>>2]=0;a=x6(a,b,c);break a}p[a+100>>2]=0;p[a+32>>2]=b;p[a+40>>2]=b+c;if(!iF(a)){p[f>>2]=0;a=0;break a}if(!w6(a,g+12|0,g+4|0,g+8|0)){b:{c:{d:{c=p[a+100>>2];switch(c+ -32|0){case 0:break c;case 3:break d;default:break b}}p[a+100>>2]=0;while(1){if(l=0,m=(yg(a)|0)!=-1,n=p[a+96>>2],n?l:m){continue}break}p[f>>2]=0;a=p[a+32>>2]-b|0;break a}if(p[a+992>>2]){break b}p[a+100>>2]=0;while(1){if(l=0,m=(yg(a)|0)!=-1,n=p[a+96>>2],n?l:m){continue}break}p[f>>2]=0;a=p[a+32>>2]-b|0;break a}z6(a);p[a+100>>2]=c;p[f>>2]=0;a=1;break a}i=p[g+4>>2];j=v6(a,p[g+12>>2],i,p[g+8>>2]);p[g+12>>2]=j;h=p[a+4>>2];if((h|0)>=1){c=0;while(1){k=(c<<2)+a|0;p[k+864>>2]=p[k+800>>2]+(i<<2);c=c+1|0;if((h|0)!=(c|0)){continue}break}}if(d){p[d>>2]=h}p[f>>2]=j;p[e>>2]=a+864;a=p[a+32>>2]-b|0}fb=g+16|0;return a|0}function Jya(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=fb-112|0;fb=j;a:{b:{if(!ue(a)){break b}if(nc(b)>>>0<2){break b}f=ky(j+8|0,a);p[f+20>>2]=0;p[f>>2]=0;c:{d=nc(b);if(d){d:{while(1){c=id(b,g);e=p[a>>2];h=p[c>>2];if(e>>>0<=h>>>0){break d}c=p[c+4>>2];if(e-h>>>0<c>>>0){break d}e=p[f>>2];if(e>>>0>268435456-c>>>0){break d}p[f>>2]=c+e;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(!Wo(f)){break b}if(!g){break c}d=0;c=0;while(1){e=id(b,d);h=p[f+20>>2];p[114610]=0;h=M(466,h|0)|0;i=p[114610];p[114610]=0;if((i|0)==1){break a}i=p[a+20>>2];p[114610]=0;i=M(466,i|0)|0;k=p[114610];p[114610]=0;if((k|0)==1){break a}ac(c+h|0,i+p[e>>2]|0,p[e+4>>2]);p[e>>2]=c;if(!(!d|d>>>0>9)){p[((d<<2)+f|0)- -64>>2]=c}c=p[e+4>>2]+c|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}break c}if(Wo(f)){break c}break b}Zm(a);ky(a,f);p[a+4>>2]=0;p[a+8>>2]=p[a>>2];o[a+34>>1]=r[a+34>>1]|2}fb=j+112|0;return}a=O(0)|0;H()|0;rb(a);E()}function fma(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;f=Xc(a);a:{if(wb(b)){while(1){e=p[Ui(b,i)>>2];b:{if(e>>>0>=2097152){p[114610]=0;K(118,f|0,63);a=p[114610];p[114610]=0;if((a|0)!=1){break b}break a}a=0;c:{d:{while(1){h=e&63;n[(d+10|0)+a|0]=h;c=a+1|0;e=e>>>6|0;if(!e){break d}a=c;if((a|0)!=6){continue}break}c=7;a=6;break c}e:{if(!a){p[114610]=0;K(118,f|0,n[d+10|0]);break e}if((c|0)!=2){break c}a=1;c=2;if((h|0)!=1){break c}p[114610]=0;K(118,f|0,n[d+10|0]|64)}a=p[114610];p[114610]=0;if((a|0)!=1){break b}break a}e=(-1<<c^-1)<<7-a;h=c+d|0;a=c;while(1){f:{if((a|0)==(c|0)){g=q[h+9|0];p[114610]=0;K(118,f|0,(e|g)<<24>>24);g=p[114610];p[114610]=0;if((g|0)==1){break a}a=a+ -1|0;break f}p[114610]=0;a=a+ -1|0;K(118,f|0,n[a+(d+10|0)|0]|-128);g=p[114610];p[114610]=0;if((g|0)==1){break a}}if(a){continue}break}}i=i+1|0;if(i>>>0<wb(b)>>>0){continue}break}}fb=d+16|0;return}a=I()|0;H()|0;pb(f);L(a|0);E()}function Zoa(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;f=Lb(a);a:{if(wb(b)){while(1){e=p[Ui(b,i)>>2];b:{if(e>>>0>=2097152){p[114610]=0;K(110,f|0,63);a=p[114610];p[114610]=0;if((a|0)!=1){break b}break a}a=0;c:{d:{while(1){h=e&63;n[(d+10|0)+a|0]=h;c=a+1|0;e=e>>>6|0;if(!e){break d}a=c;if((a|0)!=6){continue}break}c=7;a=6;break c}e:{if(!a){p[114610]=0;K(110,f|0,n[d+10|0]);break e}if((c|0)!=2){break c}a=1;c=2;if((h|0)!=1){break c}p[114610]=0;K(110,f|0,n[d+10|0]|64)}a=p[114610];p[114610]=0;if((a|0)!=1){break b}break a}e=(-1<<c^-1)<<7-a;h=c+d|0;a=c;while(1){f:{if((a|0)==(c|0)){g=q[h+9|0];p[114610]=0;K(110,f|0,(e|g)<<24>>24);g=p[114610];p[114610]=0;if((g|0)==1){break a}a=a+ -1|0;break f}p[114610]=0;a=a+ -1|0;K(110,f|0,n[a+(d+10|0)|0]|-128);g=p[114610];p[114610]=0;if((g|0)==1){break a}}if(a){continue}break}}i=i+1|0;if(i>>>0<wb(b)>>>0){continue}break}}fb=d+16|0;return}a=I()|0;H()|0;pb(f);L(a|0);E()}function xd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb+ -64|0;fb=c;p[a+480180>>2]=b;b=Bo(a);WJ(c,b);e=p[c+12>>2];d=a+1074316|0;p[d>>2]=p[c+8>>2];p[d+4>>2]=e;d=p[c+4>>2];p[a+1074308>>2]=p[c>>2];p[a+1074312>>2]=d;Rr(a+8|0,b);d=r[a+480192>>1];if(d){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=p[e>>2];if(f){Nb(Us(f));d=r[a+480192>>1]}p[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=d>>>0){continue}break}}p[a+480184>>2]=0;p[a+480188>>2]=0;p[a+480236>>2]=65536;p[a+480228>>2]=48;p[a+480232>>2]=48;n[a+480268|0]=5;p[a+480260>>2]=16;p[a+480264>>2]=32767;p[a+480204>>2]=125e4;p[a+480208>>2]=0;p[a+480196>>2]=6;p[a+480200>>2]=256;p[a+1074300>>2]=0;p[a+1074304>>2]=0;o[a+480192>>1]=0;qx(a,4);Mka(a+484344|0);mM(a+484360|0);Me(a+1304400|0);Me(a+1304412|0);Me(a+1304424|0);b=Jb(c,0,64);c=dK(b);Foa(a+1304436|0,c);Ur(c);Kz(a+1304500|0);ks(a+480248|0);if(p[a+480180>>2]&738230281){p[a+480208>>2]=p[a+480208>>2]|8388608}fb=b- -64|0}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;p[114610]=0;S(2088,a|0);e=p[114610];p[114610]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}p[114610]=0;S(2041,b|0);e=p[114610];p[114610]=0;if((e|0)==1){break e}e=0;p[114610]=0;S(2089,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break e}a=Jb(c,0,d);if(!q[b|0]){break b}if(Th(b,37554)|(d|0)!=8){break d}p[a+4>>2]=2090;p[a>>2]=2091;break c}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37578,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();return 0}if(Th(b,37566)|(d|0)!=64){break b}p[a+60>>2]=2092;p[a+56>>2]=2093;p[a+52>>2]=2094;p[a+48>>2]=2095;p[a+44>>2]=2096;p[a+40>>2]=2097;p[a+36>>2]=2098;p[a+32>>2]=2099;p[a+28>>2]=2100;p[a+24>>2]=2101;p[a+20>>2]=2102;p[a+16>>2]=2103;p[a+12>>2]=2104;p[a+8>>2]=2105;p[a+4>>2]=2106;p[a>>2]=2107}e=1}return e|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function dfa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0;j=fb-32|0;fb=j;g=p[a>>2];while(1){p[(e<<2)+j>>2]=g+(p[((e<<4)+a|0)+32>>2]^-1);e=e+1|0;if((e|0)!=7){continue}break}if(d){n=o[a+28>>1]/8<<16>>16;while(1){g=0;f=0;e=0;while(1){h=(e<<2)+j|0;i=p[h>>2]+1&8191;p[h>>2]=i;m=f;f=(i<<2)+a|0;i=o[f+160>>1];h=(e<<4)+a|0;l=o[f+162>>1];f=(m+v(i,o[h+44>>1])|0)+v(l,o[h+46>>1])|0;g=(v(i,o[h+40>>1])+g|0)+v(l,o[h+42>>1])|0;e=e+1|0;if((e|0)!=4){continue}break}h=0;e=4;i=Mc((g|0)/32768|0);l=Mc((f|0)/32768|0);g=0;while(1){k=(e<<2)+j|0;f=p[k>>2]+1&8191;p[k>>2]=f;m=g;g=(f<<2)+a|0;k=o[g+160>>1];f=(e<<4)+a|0;q=o[g+162>>1];g=(m+v(k,o[f+44>>1])|0)+v(q,o[f+46>>1])|0;h=(v(o[f+40>>1],k)+h|0)+v(o[f+42>>1],q)|0;e=e+1|0;if((e|0)!=7){continue}break}e=Mc(i+((h|0)/32768|0)|0);o[b>>1]=e;p[c>>2]=v(e,n);e=Mc(l+((g|0)/32768|0)|0);o[b+2>>1]=e;p[c+4>>2]=v(e,n);c=c+8|0;b=b+4|0;d=d+ -1|0;if(d){continue}break}}fb=j+32|0}function ZD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-32|0;fb=c;a:{if(q[a+52|0]){d=p[a+48>>2];if(!b){break a}n[a+52|0]=0;p[a+48>>2]=-1;break a}p[c+24>>2]=1;e=p[Gf(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;b:{while(1){if((d|0)!=(h|0)){f=Lq(p[a+32>>2]);if((f|0)==-1){break b}n[(c+24|0)+d|0]=f;d=d+1|0;continue}break}c:{if(q[a+53|0]){n[c+23|0]=q[c+24|0];break c}h=c+24|0;while(1){d:{d=p[a+40>>2];f=p[d>>2];i=p[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(YD(p[a+36>>2],g,c+24|0,d,c+16|0,c+23|0,h,c+12|0)+ -1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=p[a+40>>2];p[g>>2]=f;p[g+4>>2]=i;if((e|0)==8){break b}f=Lq(p[a+32>>2]);if((f|0)==-1){break b}n[d|0]=f;e=e+1|0;continue}break}n[c+23|0]=q[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e+ -1|0;if((Mq(og(n[e+(c+24|0)|0]),p[a+32>>2])|0)!=-1){continue}break b}}j=a,k=og(n[c+23|0]),p[j+48>>2]=k}d=og(n[c+23|0]);break a}d=-1}fb=c+32|0;return d}function sga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=w(0),m=0,n=0,o=0,r=0,s=0,u=w(0),v=w(0),y=w(0),z=0,A=0,B=w(0);f=fb-16|0;fb=f;a:{if(!p[a+4240>>2]){break a}g=a+44|0;if(!fh(g)){break a}y=t[a+4220>>2];z=f,A=Fd(g,0),p[z+8>>2]=A;z=f,A=Fd(g,1),p[z+12>>2]=A;z=f,A=_c(g,0),p[z>>2]=A;z=f,A=_c(g,1),p[z+4>>2]=A;if(d){m=a+4208|0;j=d;while(1){h=0;i=1;k=0;while(1){n=(q[a+4264|0]?1-k|0:h)&255;e=p[a+4244>>2]-p[((n<<2)+a|0)+4248>>2]|0;if((e|0)<=-1){e=p[a+4240>>2]+e|0}o=h<<2;r=o+(f+8|0)|0;s=p[r>>2];p[r>>2]=s+4;l=t[s>>2];u=t[Fb(m,(e<<1)+n|0)>>2];v=w(w(t[a+4224>>2]*u)+w(l*t[a+4260>>2]));z=Fb(m,p[a+4244>>2]<<1|h),B=w(x(v))<w(1.0000000195414814e-24)?w(0):v,t[z>>2]=B;h=f+o|0;e=p[h>>2];p[h>>2]=e+4;t[e>>2]=l+w(w(u-l)*y);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=p[a+4244>>2]+1|0;p[a+4244>>2]=(i|0)==p[a+4240>>2]?0:i;j=j+ -1|0;if(j){continue}break}}Zh(a,b,c,_c(g,0),_c(g,1),d)}fb=f+16|0}function XG(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,n=0;j=fb-48|0;fb=j;p[j+44>>2]=0;if(!(i?0:!(d|g|h))){k=Jca(g?j+44|0:0)}if(d){l=m[d|0](k,e)|0}else{l=3}if(!(!(l&2)|!g)){p[g+16>>2]=k;n=g;g=p[j+44>>2];a:{if(g){g=Pd(g);break a}g=Pd(34085)}p[n+20>>2]=g}if(h){p[h>>2]=k}if(i){g=p[j+44>>2];b:{if(g){g=Pd(g);break b}g=Pd(34085)}p[i>>2]=g}g=p[j+44>>2];if(g){Nb(g);p[j+44>>2]=0}c:{if(!(l&1)){break c}p[114610]=0;K(1990,j+32|0,a|0);g=p[114610];p[114610]=0;d:{e:{if((g|0)!=1){f:{if(f){p[114610]=0;K(1991,f|0,j+32|0);g=p[114610];p[114610]=0;if((g|0)!=1){break f}break e}g=Ib(j+32|0);if(b){p[114610]=0;K(b|0,g|0,c|0);g=p[114610];p[114610]=0;if((g|0)==1){break e}break f}sr(g,j)}pb(j+32|0);break c}g=O(0)|0;H()|0;break d}g=O(0)|0;H()|0;pb(j+32|0)}T(g|0)|0;p[j+28>>2]=f;p[j+24>>2]=e;p[j+20>>2]=d;p[j+16>>2]=c;p[j+12>>2]=b;p[j+4>>2]=248;p[j>>2]=37741;p[j+8>>2]=a?a:34085;a=p[13902];LE(a,37611,j);Yq(a);V()}fb=j+48|0}function XJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=Ue(a);f=d,g=wd(b),p[f+8>>2]=g;f=d,g=jf(b),p[f>>2]=g;a:{b:{if(!Ab(d+8|0,d)){break b}a=0;b=0;while(1){c=q[p[d+8>>2]];c:{if(!a){if(!(c&128)){a=0;p[114610]=0;K(112,e|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){break c}break a}if((c&224)==192){b=c&31;a=1;break c}if((c&240)==224){b=c&15;a=2;break c}if((c&248)==240){b=c&7;a=3;break c}b=0;p[114610]=0;K(112,e|0,65533);c=p[114610];p[114610]=0;a=0;if((c|0)==1){break a}break c}if((c&192)!=128){p[114610]=0;K(112,e|0,65533);a=p[114610];p[114610]=0;if((a|0)==1){break a}b=c&63;a=-1;break c}c=c&63|b<<6;a=a+ -1|0;if(a){b=c;break c}b=0;p[114610]=0;K(112,e|0,c|0);c=p[114610];p[114610]=0;a=0;if((c|0)==1){break a}}bg(d+8|0);if(Ab(d+8|0,d)){continue}break}if(!a){break b}p[114610]=0;K(112,e|0,65533);a=p[114610];p[114610]=0;if((a|0)!=1){break b}break a}fb=d+16|0;return}a=I()|0;H()|0;yc(e);L(a|0);E()}function swa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0;e=fb-32|0;fb=e;i=p[a+40>>2];j=p[a+36>>2];l=p[a+16>>2];b=p[a+4>>2];f=b;g=p[a>>2];p[e+24>>2]=g;p[e+28>>2]=b;b=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=b;a:{if(!d){b=i>>12;h=j>>12;break a}while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=(g>>>21&2040)+27824|0;g=o[b+6>>1];m=o[b+4>>1];n=o[b+2>>1];q=o[b>>1];h=0;b=1;while(1){f=h<<1;p[(e+8|0)+(h<<2)>>2]=(((v(o[f+k>>1],n)+v(o[(f|-4)+k>>1],q)|0)+v(o[(f|4)+k>>1],m)|0)+v(o[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=p[a+32>>2];j=p[a+28>>2]+j|0;h=j>>12;p[c>>2]=p[c>>2]+v(h,p[e+8>>2]);i=b+i|0;b=i>>12;p[c+4>>2]=p[c+4>>2]+v(b,p[e+12>>2]);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;g=p[e+24>>2];f=p[e+28>>2];continue}break}g=p[e+24>>2];f=p[e+28>>2]}p[a+40>>2]=i;p[a+20>>2]=h;p[a+36>>2]=j;p[a+24>>2]=b;p[a>>2]=g;p[a+4>>2]=f;fb=e+32|0}function CM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;n[a+15|0]=0;n[a+16|0]=0;n[a+17|0]=0;n[a+18|0]=0;n[a+19|0]=0;n[a+20|0]=0;n[a+21|0]=0;n[a+22|0]=0;n[a+14|0]=5;o[a+12>>1]=0;p[a+8>>2]=128;p[a>>2]=256;p[a+4>>2]=64;p[a+28>>2]=0;n[a+27|0]=60;p[a+40>>2]=0;p[a+44>>2]=0;n[a+33|0]=33554434;n[a+34|0]=131072;n[a+35|0]=512;n[a+36|0]=2;n[a+23|0]=16711680;n[a+24|0]=65280;n[a+25|0]=255;n[a+26|0]=0;n[a+32|0]=0;d=ay(a+48|0);e=ay(a+68|0);f=ay(a+88|0);p[114610]=0;M(1163,a+492|0)|0;c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;M(1163,a+524|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}p[114610]=0;N(910,a|0,0,0);c=p[114610];p[114610]=0;if((c|0)==1){break a}p[114610]=0;N(911,a|0,0,0);c=p[114610];p[114610]=0;if((c|0)==1){break a}p[a+40>>2]=0;p[a+44>>2]=0;p[114610]=0;K(780,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}Uua(a);return a|0}a=I()|0;H()|0;dn(f);dn(e);dn(d);L(a|0);E()}function eDa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,p=0;e=fb-16|0;fb=e;n[e+15|0]=8;n[e+14|0]=0;o[e+12>>1]=0;if(d){k=v(c,d);while(1){if((k|0)>=1){h=(j<<1)+b|0;m=h+(k<<1)|0;while(1){o[e+10>>1]=0;_O(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{g=q[e+15|0];if(!g){break b}c=r[e+12>>1];while(1){f=c<<1;c=f&254;o[e+12>>1]=c;f=(f&65534)>>>0>255;n[e+14|0]=f;if(!c){if(!Ae(a,e+9|0)){break b}c=q[e+9|0];f=c>>>7|0;n[e+14|0]=f;c=c<<1&254|1;o[e+12>>1]=c}i=r[e+10>>1]<<1|f;o[e+10>>1]=i;g=g+ -1|0;if(g&255){continue}break}break a}i=r[e+10>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;l=c&255;if(l>>>0<2){break c}f=c+ -1|0;if(!(g&1<<l)){continue}break}}n[e+15|0]=(q[e+15|0]+c&254)>>>1;c=i&1;n[e+14|0]=c;c=(c+ -1^(i&65534)>>>1)+p|0;o[e+10>>1]=c;o[h>>1]=c;p=r[e+10>>1];h=(d<<1)+h|0;if(h>>>0<m>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}fb=e+16|0}function SW(){var a=0,b=0,c=0,d=0;c=fb-32|0;fb=c;a:{a=Mb(c+16|0,10940);if(!wb(a)){break a}b:{if((Nf(a,10946)|0)!=-1){b=Nf(a,10946);p[114610]=0;Q(232,c|0,a|0,b+1|0,-1);b=p[114610];p[114610]=0;if((b|0)==1){break b}xb(a,c);pb(c)}if((Nf(a,10948)|0)!=-1){b=Nf(a,10948);p[114610]=0;Q(232,c|0,a|0,b+1|0,-1);b=p[114610];p[114610]=0;if((b|0)==1){break b}xb(a,c);pb(c)}if((Nf(a,10950)|0)!=-1){b=Nf(a,10950);p[114610]=0;Q(232,c|0,a|0,0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}xb(a,c);pb(c)}if((Nf(a,10952)|0)!=-1){b=Nf(a,10952);p[114610]=0;Q(232,c|0,a|0,0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}xb(a,c);pb(c)}if((Nf(a,10954)|0)!=-1){b=Nf(a,10954);p[114610]=0;Q(232,c|0,a|0,0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}xb(a,c);pb(c)}p[114610]=0;b=M(233,a|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break a}}c=I()|0;H()|0;pb(a);L(c|0);E()}pb(a);fb=c+32|0;return b|0}function WD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-32|0;fb=c;a:{if(q[a+52|0]){d=p[a+48>>2];if(!b){break a}n[a+52|0]=0;p[a+48>>2]=-1;break a}p[c+24>>2]=1;e=p[Gf(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;b:{while(1){if((d|0)!=(h|0)){f=Lq(p[a+32>>2]);if((f|0)==-1){break b}n[(c+24|0)+d|0]=f;d=d+1|0;continue}break}c:{if(q[a+53|0]){p[c+20>>2]=n[c+24|0];break c}h=c+24|0;while(1){d:{d=p[a+40>>2];f=p[d>>2];i=p[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(YD(p[a+36>>2],g,c+24|0,d,c+16|0,c+20|0,h,c+12|0)+ -1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=p[a+40>>2];p[g>>2]=f;p[g+4>>2]=i;if((e|0)==8){break b}f=Lq(p[a+32>>2]);if((f|0)==-1){break b}n[d|0]=f;e=e+1|0;continue}break}p[c+20>>2]=n[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e+ -1|0;if((Mq(n[e+(c+24|0)|0],p[a+32>>2])|0)!=-1){continue}break b}}p[a+48>>2]=p[c+20>>2]}d=p[c+20>>2];break a}d=-1}fb=c+32|0;return d}function PIa(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-80|0;fb=d;Me(b);a:{if(Hb(a,1)){b:{c:{d:{e:{f:{g:{while(1){p[114610]=0;e=P(605,a|0,d+16|0,64)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}p[d+8>>2]=e;e=wb(b);p[114610]=0;p[d+4>>2]=c-e;e=J(33,d+8|0,d+4|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break g}e=p[e>>2];if(!e){break b}n[d+8|0]=0;f=e+(d+16|0)|0;e=Gm(d+16|0,f,d+8|0);h=d,i=jf(b),p[h+8>>2]=i;Ld(d,d+8|0);p[114610]=0;U(606,b|0,p[d>>2],d+16|0,e|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break f}p[114610]=0;J(338,a|0,e-(d+16|0)|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}if(e>>>0>=f>>>0){continue}break}p[114610]=0;J(338,a|0,1)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break b}a=O(71348)|0;break c}a=O(71348)|0;break c}a=O(71348)|0;break c}a=O(71348)|0;break c}a=O(71348)|0}if((H()|0)!=($(71348)|0)){break a}T(a|0)|0;V()}e=(wb(b)|0)!=0}fb=d+80|0;return e}L(a|0);E()}function Zk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Kj(a);a:{b:{c:{g=p[b+32>>2];d:{if(!g){d=p[b+2084>>2];if(d){break d}break b}f=p[b+4>>2];if((f|0)<9){break c}d=p[b+2084>>2];if(!d){break c}}h=p[a+1392>>2];j=Yk(h);e=p[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;i=f+c|0;g=s[(i<<2)+d>>2]>j>>>0;c=g?c:i;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=p[a+1396>>2];c=q[b+23|0]?c:p[p[b+2088>>2]+(c<<2)>>2];b=q[c+p[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}p[a+1392>>2]=h>>>b;a=d-b|0}p[e+1396>>2]=a;return c}if(q[b+23|0]){break a}if((f|0)>=1){d=p[b+8>>2];while(1){f:{e=q[c+d|0];if((e|0)==255){break f}h=p[a+1392>>2];if(p[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=p[a+1396>>2];if((d|0)>=(e|0)){p[a+1392>>2]=h>>>e;p[a+1396>>2]=d-q[p[b+8>>2]+c|0];return c}p[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}Wb(a,21);p[a+1396>>2]=0}return-1}aa(50634,50416,1690,50645);E()}function twa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0;e=fb-32|0;fb=e;i=p[a+40>>2];j=p[a+36>>2];l=p[a+16>>2];b=p[a+4>>2];g=b;h=p[a>>2];p[e+24>>2]=h;p[e+28>>2]=b;b=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=b;a:{if(!d){f=i>>12;b=j>>12;break a}while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=(h>>>21&2040)+27824|0;h=o[b+6>>1];m=o[b+4>>1];q=o[b+2>>1];r=o[b>>1];f=0;b=1;while(1){p[(e+8|0)+(f<<2)>>2]=(((v(n[f+k|0],q)+v(n[(f|-2)+k|0],r)|0)+v(n[(f|2)+k|0],m)|0)+v(n[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=p[a+32>>2];j=p[a+28>>2]+j|0;b=j>>12;p[c>>2]=p[c>>2]+v(b,p[e+8>>2]);i=g+i|0;f=i>>12;p[c+4>>2]=p[c+4>>2]+v(f,p[e+12>>2]);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;h=p[e+24>>2];g=p[e+28>>2];continue}break}h=p[e+24>>2];g=p[e+28>>2]}p[a+40>>2]=i;p[a+20>>2]=b;p[a+36>>2]=j;p[a+24>>2]=f;p[a>>2]=h;p[a+4>>2]=g;fb=e+32|0}function Qq(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;c=p[p[a>>2]+ -12>>2];p[114610]=0;c=p[(a+c|0)+24>>2];b=p[114610];p[114610]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}p[114610]=0;c=J(15,d+8|0,a|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}if(!q[c|0]){break e}b=p[p[a>>2]+ -12>>2];p[114610]=0;b=p[(a+b|0)+24>>2];e=p[114610];p[114610]=0;f:{if((e|0)==1){break f}p[114610]=0;b=M(2315,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=p[p[a>>2]+ -12>>2];p[114610]=0;K(18,a+b|0,1);b=p[114610];p[114610]=0;if((b|0)!=1){break e}}b=O(0)|0;H()|0;uf(c);break c}b=O(0)|0;H()|0;break c}uf(c);break b}b=O(0)|0;H()|0}T(b|0)|0;c=p[p[a>>2]+ -12>>2];p[114610]=0;S(19,a+c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}V()}fb=d+16|0;return a|0}a=I()|0;H()|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;if((c|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function uI(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;p[114610]=0;g=J(15,d+24|0,a|0)|0;e=p[114610];p[114610]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!q[g|0]){break e}e=Dk(d+8|0,a);h=p[(p[p[a>>2]+ -12>>2]+a|0)+4>>2];f=p[p[a>>2]+ -12>>2];p[114610]=0;f=a+f|0;i=M(16,f|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break d}e=p[e>>2];p[114610]=0;c=b+c|0;b=da(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break d}p[d+16>>2]=b;if(!Ck(d+16|0)){break e}b=p[p[a>>2]+ -12>>2];p[114610]=0;K(18,a+b|0,5);b=p[114610];p[114610]=0;if((b|0)!=1){break e}break d}uf(g);break b}b=O(0)|0;H()|0;uf(g);break c}b=O(0)|0;H()|0}T(b|0)|0;b=p[p[a>>2]+ -12>>2];p[114610]=0;S(19,a+b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}V()}fb=d+32|0;return a}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){a=O(0)|0;H()|0;rb(a);E()}L(a|0);E()}function nla(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,t=0,u=0,v=0;k=fb-16|0;fb=k;if(ue(a)){d=r[a+34>>1];l=p[a+4>>2];h=p[a+8>>2];j=p[a>>2];o=!(d&2)|(l>>>0>=h>>>0|h>>>0>j>>>0);m=p[a+12>>2];i=p[a+16>>2];q=!(d&8)|(m>>>0>=i>>>0|i>>>0>j>>>0);t=b+1304360|0;b=b+1074984|0;u=d&4;v=d&16;while(1){a:{if(p[b+104>>2]!=(a|0)){break a}d=p[b+76>>2];if(!d){break a}b:{c:{d:{e=b;e:{f:{if(q){break f}c=p[b+88>>2];if(c&2048){break f}p[b+84>>2]=i;p[b+80>>2]=m;g=v;d=i;break e}if(o){break d}p[b+84>>2]=h;p[b+80>>2]=l;c=p[b+88>>2];g=u;d=h}p[e+76>>2]=d;f=c|2;p[b+88>>2]=f;n=b+88|0;e=1;if(!g){break c}c=c|6;e=1;g=1;break b}f=p[b+88>>2]&-3;p[b+88>>2]=f;n=b+88|0;e=0}c=f&-5;g=0}p[b+88>>2]=c;if(d>>>0<s[b+4>>2]){c=c&-129;p[b+88>>2]=c;f=p[b+80>>2];p[b>>2]=0;p[b+4>>2]=f}if(!g){p[n>>2]=c&-129}if(e){break a}p[b+76>>2]=j}b=b+896|0;if((t|0)!=(b|0)){continue}break}}fb=k+16|0}function Jca(a){var b=0,c=0,d=0,e=0;a:{if(!a){break a}c=p[a>>2];if(!c){break a}Nb(c);p[a>>2]=0}p[114610]=0;R(81);c=p[114610];p[114610]=0;e=a;b:{c:{d:{if((c|0)==1){d=Ya(71348,83452,83464,83568,71504,71608,71556,71448,71436,71752,71720,71688,71676,71324,0)|0;a=277;b=H()|0;if((b|0)==($(71348)|0)){break d}a=358;if(($(83452)|0)==(b|0)){break d}a=359;if(($(83464)|0)==(b|0)){break d}a=357;if(($(83568)|0)==(b|0)){break d}a=300;if(($(71504)|0)==(b|0)){break d}a=299;if(($(71608)|0)==(b|0)){break d}a=298;if(($(71556)|0)==(b|0)){break d}a=297;if(($(71448)|0)==(b|0)){break d}a=296;if(($(71436)|0)==(b|0)){break d}a=289;if(($(71752)|0)==(b|0)){break d}a=288;if(($(71720)|0)==(b|0)){break d}a=287;if(($(71688)|0)==(b|0)){break d}a=286;if(($(71676)|0)==(b|0)){break d}c=257;a=267;b=($(71324)|0)==(b|0);d=T(d|0)|0;if(b){break c}break b}E()}d=T(d|0)|0}Hca(e,d);c=a}V();return c}function PK(a,b){var c=0,d=0,e=0,f=0,g=0;d=r[a+480188>>1];a:{if(d>>>0<=255){f=a+1304392|0;while(1){e=v(d,896)+a|0;c=e+1075060|0;b:{if(p[c>>2]){break b}if(!Zi(e+1074984|0)){break a}if(p[c>>2]){break b}if(q[e+1075073|0]&24){break a}}if(q[e+1075073|0]&2){if(!kd(f)){break a}if(!OK(p[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=v(b,896)+a|0;if(!p[b+1075680>>2]){d=65535;if(p[b+1075060>>2]){break a}}g=p[b+1075672>>2]|p[b+1075664>>2]<<9}d=65535;b=r[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=v(b,896)+a|0;if(!(p[c+1075680>>2]?0:p[c+1075060>>2])){f=(p[c+1075672>>2]|p[c+1075664>>2]<<9)>>>(p[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=p[c+1075712>>2];break d}if((f|0)!=(g|0)){break c}c=p[c+1075712>>2];if(c>>>0<=e>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function dDa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,p=0,s=0;e=fb-16|0;fb=e;n[e+15|0]=4;n[e+14|0]=0;o[e+12>>1]=0;if(d){k=v(c,d);m=(k|0)<1;while(1){if(!m){h=b+j|0;p=k+h|0;while(1){n[e+11|0]=0;ZO(a,e+14|0,e+12|0,e+11|0);a:{b:{g=q[e+15|0];if(!g){break b}c=r[e+12>>1];while(1){f=c<<1;c=f&254;o[e+12>>1]=c;f=(f&65534)>>>0>255;n[e+14|0]=f;if(!c){if(!Ae(a,e+10|0)){break b}c=q[e+10|0];f=c>>>7|0;n[e+14|0]=f;c=c<<1&254|1;o[e+12>>1]=c}i=q[e+11|0]<<1|f;n[e+11|0]=i;g=g+ -1|0;if(g&255){continue}break}break a}i=q[e+11|0]}c=1;g=i&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;l=c&255;if(l>>>0<2){break c}f=c+ -1|0;if(!(g&1<<l)){continue}break}}n[e+15|0]=(q[e+15|0]+c&254)>>>1;c=i&1;n[e+14|0]=c;c=(c+ -1^(i&254)>>>1)+s|0;n[e+11|0]=c;n[h|0]=c;s=q[e+11|0];h=d+h|0;if(h>>>0<p>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}fb=e+16|0}function $xa(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;g=1;f=a;e=td(b);if((e|0)==252){g=td(b);e=td(b)}n[f|0]=(e+ -1&255)>>>0<60?e+36|0:0;Dl(d+8|0,b);b=Zc(d+8|0);f=Tf(d+8|0);e=vi(d+8|0);n[a+1|0]=q[d+8|0];n[d+7|0]=q[b|0]&15;n[d+6|0]=q[b|0]>>>4;n[d+5|0]=q[f|0];n[d+4|0]=q[e|0];cN(d+7|0,d+5|0,c);cN(d+6|0,d+4|0,c);a:{b:{c:{d:{e=q[d+7|0];c=(e|0)!=10;b=q[d+6|0];if(!(c|(b|0)!=10)){n[d+7|0]=0;h=d,i=en((q[d+4|0]|q[d+5|0]<<8)>>>6|0),n[h+5|0]=i;break d}if(!c){h=d,i=en(q[d+5|0]<<2),n[h+5|0]=i;break d}if((b|0)==10){h=d,i=en(q[d+4|0]<<2),n[h+4|0]=i;break d}if((b|0)!=(e|0)){break d}n[d+6|0]=0;break c}b=q[d+6|0];if((b|0)==13){break b}if(b){break a}e=q[d+7|0]}if((e&255)==13){break a}}bh(d+7|0,d+6|0);bh(d+5|0,d+4|0)}Qw(d+6|0,d+4|0,d+7|0,d+5|0);Pw(d,d+7|0,d+5|0,d+6|0,d+4|0);n[a+2|0]=q[d+7|0];n[a+4|0]=q[d+5|0];n[a+3|0]=q[d+6|0];n[a+5|0]=q[d+4|0];fb=d+16|0;return g}function mda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;p[114610]=0;S(2015,a|0);d=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}p[114610]=0;S(2041,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break g}p[114610]=0;S(2041,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break g}d=p[a+24>>2];p[114610]=0;b=J(85,e+16|0,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break g}p[114610]=0;c=J(85,e|0,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break f}p[114610]=0;Q(2081,d|0,b|0,c|0,1);d=p[114610];p[114610]=0;if((d|0)==1){break e}pb(c);pb(b);b=1;break b}d=O(0)|0;H()|0;break c}d=O(0)|0;H()|0;break d}d=O(0)|0;H()|0;pb(c)}pb(b)}T(d|0)|0;b=0;p[114610]=0;Q(1989,36983,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=e+32|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Fda(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;K(2061,d|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}if(nc(d)>>>0<2147483647){break h}c=W(8)|0;p[114610]=0;J(2062,c|0,36296)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;N(2009,c|0,71676,265);b=p[114610];p[114610]=0;if((b|0)!=1){break b}b=O(0)|0;H()|0;break f}b=O(0)|0;H()|0;break e}b=O(0)|0;H()|0;break e}a=34085;j:{if((b|0)<0){break j}a=34085;if((nc(d)|0)<=(b|0)){break j}a=Ib(id(d,b))}b=Pd(a);bd(d);break d}b=O(0)|0;H()|0;X(c|0)}bd(d)}T(b|0)|0;b=0;p[114610]=0;Q(1989,36311,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break c}V()}fb=d+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break a}a=O(0)|0;H()|0;rb(a)}E()}L(a|0);E()}function Eda(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;K(2063,d|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}if(nc(d)>>>0<2147483647){break h}c=W(8)|0;p[114610]=0;J(2062,c|0,36296)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;N(2009,c|0,71676,265);b=p[114610];p[114610]=0;if((b|0)!=1){break b}b=O(0)|0;H()|0;break f}b=O(0)|0;H()|0;break e}b=O(0)|0;H()|0;break e}a=34085;j:{if((b|0)<0){break j}a=34085;if((nc(d)|0)<=(b|0)){break j}a=Ib(id(d,b))}b=Pd(a);bd(d);break d}b=O(0)|0;H()|0;X(c|0)}bd(d)}T(b|0)|0;b=0;p[114610]=0;Q(1989,36343,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break c}V()}fb=d+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break a}a=O(0)|0;H()|0;rb(a)}E()}L(a|0);E()}function Dda(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;K(2064,d|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}if(nc(d)>>>0<2147483647){break h}c=W(8)|0;p[114610]=0;J(2062,c|0,36296)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;N(2009,c|0,71676,265);b=p[114610];p[114610]=0;if((b|0)!=1){break b}b=O(0)|0;H()|0;break f}b=O(0)|0;H()|0;break e}b=O(0)|0;H()|0;break e}a=34085;j:{if((b|0)<0){break j}a=34085;if((nc(d)|0)<=(b|0)){break j}a=Ib(id(d,b))}b=Pd(a);bd(d);break d}b=O(0)|0;H()|0;X(c|0)}bd(d)}T(b|0)|0;b=0;p[114610]=0;Q(1989,36375,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break c}V()}fb=d+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break a}a=O(0)|0;H()|0;rb(a)}E()}L(a|0);E()}function Cda(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;K(2065,d|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}if(nc(d)>>>0<2147483647){break h}c=W(8)|0;p[114610]=0;J(2062,c|0,36296)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;N(2009,c|0,71676,265);b=p[114610];p[114610]=0;if((b|0)!=1){break b}b=O(0)|0;H()|0;break f}b=O(0)|0;H()|0;break e}b=O(0)|0;H()|0;break e}a=34085;j:{if((b|0)<0){break j}a=34085;if((nc(d)|0)<=(b|0)){break j}a=Ib(id(d,b))}b=Pd(a);bd(d);break d}b=O(0)|0;H()|0;X(c|0)}bd(d)}T(b|0)|0;b=0;p[114610]=0;Q(1989,36405,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break c}V()}fb=d+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break a}a=O(0)|0;H()|0;rb(a)}E()}L(a|0);E()}function Bda(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;K(2066,d|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}if(nc(d)>>>0<2147483647){break h}c=W(8)|0;p[114610]=0;J(2062,c|0,36296)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;N(2009,c|0,71676,265);b=p[114610];p[114610]=0;if((b|0)!=1){break b}b=O(0)|0;H()|0;break f}b=O(0)|0;H()|0;break e}b=O(0)|0;H()|0;break e}a=34085;j:{if((b|0)<0){break j}a=34085;if((nc(d)|0)<=(b|0)){break j}a=Ib(id(d,b))}b=Pd(a);bd(d);break d}b=O(0)|0;H()|0;X(c|0)}bd(d)}T(b|0)|0;b=0;p[114610]=0;Q(1989,36437,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break c}V()}fb=d+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break a}a=O(0)|0;H()|0;rb(a)}E()}L(a|0);E()}function Ada(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;K(2067,d|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break i}if(nc(d)>>>0<2147483647){break h}c=W(8)|0;p[114610]=0;J(2062,c|0,36296)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;N(2009,c|0,71676,265);b=p[114610];p[114610]=0;if((b|0)!=1){break b}b=O(0)|0;H()|0;break f}b=O(0)|0;H()|0;break e}b=O(0)|0;H()|0;break e}a=34085;j:{if((b|0)<0){break j}a=34085;if((nc(d)|0)<=(b|0)){break j}a=Ib(id(d,b))}b=Pd(a);bd(d);break d}b=O(0)|0;H()|0;X(c|0)}bd(d)}T(b|0)|0;b=0;p[114610]=0;Q(1989,36472,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break c}V()}fb=d+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break a}a=O(0)|0;H()|0;rb(a)}E()}L(a|0);E()}function nF(a,b,c,d){var e=0,f=0,g=0,h=w(0),i=0,j=w(0),k=0,l=w(0),m=w(0),n=w(0),o=0;e=fb-96|0;fb=e;if((d|0)>=1){while(1){t[e+48>>2]=-t[a>>2];p[e>>2]=p[a+68>>2];f=0;while(1){g=f<<3;i=f<<4;j=t[(i|8)+a>>2];h=t[(i|4)+a>>2];t[(e+48|0)+(g|4)>>2]=j+h;k=f<<1;t[(8-k<<2)+e>>2]=h-j;j=t[(a+i|0)+16>>2];h=t[(i|12)+a>>2];t[(7-k<<2)+e>>2]=j-h;t[(e+g|0)+56>>2]=-w(h+j);f=f+1|0;if((f|0)!=4){continue}break}mF(e+48|0);mF(e);t[e+4>>2]=-t[e+4>>2];t[e+12>>2]=-t[e+12>>2];t[e+20>>2]=-t[e+20>>2];t[e+28>>2]=-t[e+28>>2];i=0;while(1){f=i<<2;g=f+b|0;j=t[g>>2];k=g;h=t[f+48848>>2];l=t[f+(e+48|0)>>2];m=t[e+f>>2];g=f+36|0;n=t[g+48848>>2];t[k>>2]=w(h*l)-w(m*n);k=a+f|0;f=c+f|0;g=c+g|0;h=w(w(h*m)+w(n*l));t[k>>2]=w(j*t[f>>2])-w(t[g>>2]*h);t[(17-i<<2)+a>>2]=w(t[f>>2]*h)+w(j*t[g>>2]);i=i+1|0;if((i|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}fb=e+96|0}function XU(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;n[e+24|0]=q[a|0];n[e+25|0]=q[a+1|0];n[e+26|0]=q[a+2|0];n[e+27|0]=q[a+3|0];f=XA(e+8|0);b=a+b|0;p[f+12>>2]=b+ -4;p[f+8>>2]=a;Ci(f,q[b+ -1|0]);a:{if(!d){break a}a=d;while(1){if(!Ci(f,1)){p[e+4>>2]=1;while(1){b=Ci(f,2);p[e+4>>2]=b+p[e+4>>2];if((b|0)==3){continue}break}vc(e+4|0,a);b=0;if(p[e+4>>2]){while(1){a=a+ -1|0;k=c+a|0,l=Ci(f,8),n[k|0]=l;b=b+1|0;if(b>>>0<s[e+4>>2]){continue}break}}if(!a){break a}}b=Ci(f,2);p[e+4>>2]=b+2;b:{if((b|0)==3){b=f;h=b;g=7;c:{if(!Ci(b,1)){break c}g=q[Yb(e+24|0,3)|0]}g=Ci(h,g);while(1){b=Ci(f,3);p[e+4>>2]=b+p[e+4>>2];if((b|0)==7){continue}break}break b}g=Ci(f,q[Yb(e+24|0,b)|0])}vc(e+4|0,a);h=0;i=p[e+4>>2];if(i){while(1){b=0;j=a+g|0;if(j>>>0<d>>>0){b=q[c+j|0]}a=a+ -1|0;n[c+a|0]=b;h=h+1|0;if((i|0)!=(h|0)){continue}break}}if(a){continue}break}}fb=e+32|0}function DH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=w(0);b=fb-32|0;fb=b;e=p[a+20>>2];a:{if(!e){break a}if(Cc(e+4|0)>>>0<4){break a}Ei(b+8|0,p[a+20>>2]+4|0);e=vha(b+16|0,b+8|0);p[114610]=0;d=M(390,e|0)|0;c=p[114610];p[114610]=0;b:{if((c|0)!=1){if(d){break b}d=p[p[a>>2]+40>>2];p[114610]=0;d=M(d|0,a|0)|0;c=p[114610];p[114610]=0;c:{if((c|0)==1){break c}if(Cc(p[a+20>>2]+4|0)+ -4>>>0<d<<2>>>0){break b}c=p[p[a>>2]+168>>2];p[114610]=0;K(c|0,a|0,-1);c=p[114610];p[114610]=0;if((c|0)==1){break c}if(d){c=0;while(1){p[114610]=0;g=w(ua(703,e|0));f=p[114610];p[114610]=0;if((f|0)==1){break c}f=p[p[a>>2]+44>>2];p[114610]=0;sa(f|0,a|0,c|0,w(g));f=p[114610];p[114610]=0;if((f|0)==1){break c}c=c+1|0;if((d|0)!=(c|0)){continue}break}}d=p[p[a>>2]+172>>2];p[114610]=0;S(d|0,a|0);a=p[114610];p[114610]=0;if((a|0)!=1){break b}}}a=I()|0;H()|0;sb(e);L(a|0);E()}sb(e)}fb=b+32|0}function _la(a,b,c,d){var e=0;e=fb-48|0;fb=e;a=Lb(a);a:{b:{b=b+ -1|0;switch(b|0){case 0:case 3:break b;default:break a}}d=d?d+ -1|0:0}c:{d:{e:{f:{g:{h:{i:{j:{switch(b|0){case 0:case 1:n[e+32|0]=0;b=Gm(c,c+d|0,e+32|0);p[114610]=0;P(119,a|0,c|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break i}b=I()|0;H()|0;break c;case 2:case 3:break j;default:break i}}p[114610]=0;P(119,a|0,c|0,c+d|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break h}Bla(wd(a),jf(a),wd(a));p[114610]=0;c=J(120,e+16|0,a|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break g}p[114610]=0;d=J(85,e|0,6640)|0;b=p[114610];p[114610]=0;if((b|0)==1){break f}p[114610]=0;N(121,e+32|0,c|0,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}xb(a,e+32|0);pb(e+32|0);pb(d);pb(c)}fb=e+48|0;return}b=I()|0;H()|0;break c}b=I()|0;H()|0;break c}b=I()|0;H()|0;break d}b=I()|0;H()|0;pb(d)}pb(c)}pb(a);L(b|0);E()}function zK(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{if(p[a+480180>>2]==4){d=q[b+833|0];if(c){n[b+833|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(p[a+480180>>2]!=1048576){break a}if(c){n[b+833|0]=c;break a}c=q[b+833|0]}b:{if(!(n[b+872|0]&1)|!(c&255)){break b}d=p[b+700>>2];if(!d){break b}c:{if(!(q[a+480208|0]&16)){break c}d=p[b+700>>2];if(p[a+480180>>2]==4){break c}c=xx(a,c&15);f=NNa(c,c>>31,d,d>>31)+32768|0;c=ib;c=rc(ONa(f,f>>>0<32768?c+1|0:c,65536,0),ib);p[b+700>>2]=c;if((c|0)!=(d|0)){break b}a=a+1074308|0;vb(e+8|0,a,7);if(!(!tb(e+8|0)|p[b+700>>2]>=2147483647)){p[b+700>>2]=p[b+700>>2]+1;break b}vb(e+8|0,a,7);if(tb(e+8|0)){break b}a=p[b+700>>2];if((a|0)<2){break b}p[b+700>>2]=a+ -1;break b}c=d-((c&255)<<2)|0;p[b+700>>2]=c;if((c|0)>0){break b}p[b+700>>2]=1;if(p[a+480180>>2]!=2){break b}p[b+696>>2]=0;p[b+88>>2]=p[b+88>>2]|2101248}fb=e+16|0}function Ova(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;i=p[a+40>>2];j=p[a+36>>2];l=p[a+16>>2];h=p[a+4>>2];e=h;f=p[a>>2];p[g+8>>2]=f;p[g+12>>2]=e;h=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=h;a:{if(!d){h=i>>12;k=j>>12;break a}while(1){h=p[a+32>>2];j=p[a+28>>2]+j|0;k=j>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((v(o[e+4>>1],o[f+34>>1])+v(o[e+2>>1],o[f+32>>1])|0)+v(o[e+6>>1],o[f+36>>1])|0)+v(o[e+8>>1],o[f+38>>1])|0)/2|0)+((((v(o[e+ -4>>1],o[f+26>>1])+v(o[e+ -6>>1],o[f+24>>1])|0)+v(o[e+ -2>>1],o[f+28>>1])|0)+v(o[e>>1],o[f+30>>1])|0)/2|0)|0)/16384|0;p[c>>2]=p[c>>2]+v(k,e);i=h+i|0;h=i>>12;p[c+4>>2]=p[c+4>>2]+v(e,h);Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;f=p[g+8>>2];e=p[g+12>>2];continue}break}f=p[g+8>>2];e=p[g+12>>2]}p[a+40>>2]=i;p[a+20>>2]=k;p[a+36>>2]=j;p[a+24>>2]=h;p[a>>2]=f;p[a+4>>2]=e;fb=g+16|0}function WJ(a,b){var c=0;c=fb-16|0;fb=c;a=tx(a);a:{b:{c:{switch(b+ -1|0){default:if((b|0)!=16777216){break b}Eb(a,7,1);Eb(a,9,1);Eb(a,10,1);Eb(a,13,1);Eb(a,15,1);Eb(a,16,1);Eb(a,17,1);Eb(a,18,1);Eb(a,20,1);Eb(a,21,1);Eb(a,24,1);Eb(a,25,1);Eb(a,26,1);Eb(a,28,1);Eb(a,30,1);Eb(a,31,1);Eb(a,33,1);Eb(a,34,1);Eb(a,39,1);Eb(a,41,1);Eb(a,44,1);Eb(a,46,1);Eb(a,45,1);Eb(a,47,1);Eb(a,48,1);Eb(a,50,1);Eb(a,99,1);Eb(a,102,1);Eb(a,104,1);Eb(a,105,1);Eb(a,108,1);break a;case 1:px(c,2);b=p[c+12>>2];p[a+8>>2]=p[c+8>>2];p[a+12>>2]=b;b=p[c+4>>2];p[a>>2]=p[c>>2];p[a+4>>2]=b;Ag(a,107);break a;case 3:px(c,4);b=p[c+12>>2];p[a+8>>2]=p[c+8>>2];p[a+12>>2]=b;b=p[c+4>>2];p[a>>2]=p[c>>2];p[a+4>>2]=b;Ag(a,4);break a;case 2:break b;case 0:break c}}Eb(a,88,1);break a}px(c,b);b=p[c+12>>2];p[a+8>>2]=p[c+8>>2];p[a+12>>2]=b;b=p[c+4>>2];p[a>>2]=p[c>>2];p[a+4>>2]=b}fb=c+16|0}function Gv(a){var b=0,c=0,d=0,f=0,g=0,i=0;h(+a);f=e(1)|0;e(0)|0;b=f;f=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){h(+a);b=e(1)|0;b=b&2147483647;if((b|0)==2146435072&e(0)>>>0>0|b>>>0>2146435072){return a}if(!(a>709.782712893384^1)){return a*8.98846567431158e+307}if(!(a<-745.1332191019411)|a<-708.3964185322641^1){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+u[(f<<3)+52176>>3];if(x(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=(f^1)-f|0}c=+(b|0);a=d+c*-.6931471803691238;g=c*1.9082149292705877e-10;d=a-g;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;i=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+ -16533902205465252e-22)+6613756321437934e-20)+ -.0027777777777015593)+.16666666666666602);c=i+(d*a/(2-a)-g)+1;if(!b){break b}c=Jh(c,b)}return c}return a+1}function Pva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;i=p[a+40>>2];j=p[a+36>>2];l=p[a+16>>2];h=p[a+4>>2];e=h;f=p[a>>2];p[g+8>>2]=f;p[g+12>>2]=e;h=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=h;a:{if(!d){h=i>>12;k=j>>12;break a}while(1){h=p[a+32>>2];j=p[a+28>>2]+j|0;k=j>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((v(n[e+2|0],o[f+34>>1])+v(n[e+1|0],o[f+32>>1])|0)+v(n[e+3|0],o[f+36>>1])|0)+v(n[e+4|0],o[f+38>>1])<<8)/2|0)+((((v(n[e+ -2|0],o[f+26>>1])+v(n[e+ -3|0],o[f+24>>1])|0)+v(n[e+ -1|0],o[f+28>>1])|0)+v(n[e|0],o[f+30>>1])<<8)/2|0)|0)/16384|0;p[c>>2]=p[c>>2]+v(k,e);i=h+i|0;h=i>>12;p[c+4>>2]=p[c+4>>2]+v(e,h);Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;f=p[g+8>>2];e=p[g+12>>2];continue}break}f=p[g+8>>2];e=p[g+12>>2]}p[a+40>>2]=i;p[a+20>>2]=k;p[a+36>>2]=j;p[a+24>>2]=h;p[a>>2]=f;p[a+4>>2]=e;fb=g+16|0}function zy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;a:{b:{e=p[a+4>>2];if(e>>>0<b>>>0){h=Df(d+72|0);g=Fs(a);f=b-e|0;if(!(g>>>0<f>>>0|e>>>0>g-f>>>0)){bk(d+56|0,a);b=p[d+60>>2];p[d+72>>2]=p[d+56>>2];p[d+76>>2]=b;p[a+4>>2]=p[a+4>>2]+f;break b}qb(a);b=yy(d+56|0);e=p[a+4>>2];p[114610]=0;e=J(933,a|0,e+f|0)|0;g=p[114610];p[114610]=0;c:{if((g|0)==1){break c}p[114610]=0;K(934,b|0,e|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[b+4>>2]=p[a+4>>2]+f;ej(d+40|0,a);bk(d+32|0,a);ej(d+24|0,b);p[114610]=0;e=p[d+44>>2];p[d+8>>2]=p[d+40>>2];p[d+12>>2]=e;e=p[d+36>>2];p[d>>2]=p[d+32>>2];p[d+4>>2]=e;Q(935,d+48|0,d+8|0,d|0,d+24|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}e=p[d+52>>2];p[d+72>>2]=p[d+48>>2];p[d+76>>2]=e;xy(a,b);ce(b);break b}a=I()|0;H()|0;ce(b);L(a|0);E()}p[a+4>>2]=b;break a}Mp(Ed(d+16|0,h),f,c)}fb=d+80|0}function UG(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=fb+ -64|0;fb=j;p[j+60>>2]=e;e=p[a+4>>2];k=p[a>>2];a=p[a+8>>2];p[114610]=0;p[j+40>>2]=b;p[j+52>>2]=a;p[j+44>>2]=k;p[j+48>>2]=e;p[j+20>>2]=d?d:1997;N(1998,j+24|0,j+20|0,j+60|0);a=p[114610];p[114610]=0;a:{b:{c:{d:{if((a|0)!=1){b=oo(j+32|0,j+24|0);p[114610]=0;a=p[j+52>>2];p[j+8>>2]=p[j+48>>2];p[j+12>>2]=a;a=p[j+44>>2];p[j>>2]=p[j+40>>2];p[j+4>>2]=a;c=+ra(1999,j|0,+c,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}Nc(b);Nc(j+24|0);break b}a=O(0)|0;H()|0;break c}a=O(0)|0;H()|0;Nc(b);Nc(j+24|0)}T(a|0)|0;p[114610]=0;ca(2e3,34440,d|0,p[j+60>>2],f|0,g|0,h|0,i|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();c=0}fb=j- -64|0;return+c}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;e=Xg(a);f=b+24|0;a=p[f>>2];p[114610]=0;a=M(2194,a+484344|0)|0;c=p[114610];p[114610]=0;a:{b:{c:{if((c|0)==1){break c}p[114610]=0;K(1532,e|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=p[f>>2];p[114610]=0;c=M(2194,c+484344|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=Rb(p[f>>2]+484344|0,a);p[114610]=0;K(2193,d|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){p[114610]=0;N(2185,d+16|0,b|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break g}p[114610]=0;K(1534,e|0,d+16|0);c=p[114610];p[114610]=0;if((c|0)==1){break f}a=a+1|0;pb(d+16|0);pb(d);continue}break}a=I()|0;H()|0;break a}a=I()|0;H()|0;break e}a=I()|0;H()|0;pb(d+16|0)}pb(d);break a}fb=d+32|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0}bd(e);L(a|0);E()}function T4(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;p[c+28>>2]=0;a:{b:{if(q[Qi(c+24|0,a,0)|0]){qc(c+16|0,p[p[a>>2]+ -12>>2]+a|0);p[114610]=0;e=M(2316,c+16|0)|0;d=p[114610];p[114610]=0;c:{d:{if((d|0)==1){break d}d=mm(c+8|0,a);f=lk(c);g=p[p[a>>2]+ -12>>2];f=p[f>>2];d=p[d>>2];p[114610]=0;da(2317,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}Gb(c+16|0);break c}b=O(0)|0;H()|0;Gb(c+16|0);T(b|0)|0;b=p[c+28>>2]|1;p[c+28>>2]=b;Oi(p[p[a>>2]+ -12>>2]+a|0,b);b=p[p[a>>2]+ -12>>2];p[114610]=0;b=p[(a+b|0)+20>>2];e=p[114610];p[114610]=0;e:{if((e|0)!=1){if(!(b&1)){break e}p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}V()}mg(p[p[a>>2]+ -12>>2]+a|0,p[c+28>>2])}fb=c+32|0;return a}a=O(0)|0;H()|0;rb(a)}E()}function N4(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;p[c+28>>2]=0;a:{b:{if(q[Qi(c+24|0,a,0)|0]){qc(c+16|0,p[p[a>>2]+ -12>>2]+a|0);p[114610]=0;e=M(2316,c+16|0)|0;d=p[114610];p[114610]=0;c:{d:{if((d|0)==1){break d}d=mm(c+8|0,a);f=lk(c);g=p[p[a>>2]+ -12>>2];f=p[f>>2];d=p[d>>2];p[114610]=0;da(2320,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}Gb(c+16|0);break c}b=O(0)|0;H()|0;Gb(c+16|0);T(b|0)|0;b=p[c+28>>2]|1;p[c+28>>2]=b;Oi(p[p[a>>2]+ -12>>2]+a|0,b);b=p[p[a>>2]+ -12>>2];p[114610]=0;b=p[(a+b|0)+20>>2];e=p[114610];p[114610]=0;e:{if((e|0)!=1){if(!(b&1)){break e}p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}V()}mg(p[p[a>>2]+ -12>>2]+a|0,p[c+28>>2])}fb=c+32|0;return a}a=O(0)|0;H()|0;rb(a)}E()}function K4(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;p[c+28>>2]=0;a:{b:{if(q[Qi(c+24|0,a,0)|0]){qc(c+16|0,p[p[a>>2]+ -12>>2]+a|0);p[114610]=0;e=M(2316,c+16|0)|0;d=p[114610];p[114610]=0;c:{d:{if((d|0)==1){break d}d=mm(c+8|0,a);f=lk(c);g=p[p[a>>2]+ -12>>2];f=p[f>>2];d=p[d>>2];p[114610]=0;da(2321,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}Gb(c+16|0);break c}b=O(0)|0;H()|0;Gb(c+16|0);T(b|0)|0;b=p[c+28>>2]|1;p[c+28>>2]=b;Oi(p[p[a>>2]+ -12>>2]+a|0,b);b=p[p[a>>2]+ -12>>2];p[114610]=0;b=p[(a+b|0)+20>>2];e=p[114610];p[114610]=0;e:{if((e|0)!=1){if(!(b&1)){break e}p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}V()}mg(p[p[a>>2]+ -12>>2]+a|0,p[c+28>>2])}fb=c+32|0;return a}a=O(0)|0;H()|0;rb(a)}E()}function H4(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;p[c+28>>2]=0;a:{b:{if(q[Qi(c+24|0,a,0)|0]){qc(c+16|0,p[p[a>>2]+ -12>>2]+a|0);p[114610]=0;e=M(2316,c+16|0)|0;d=p[114610];p[114610]=0;c:{d:{if((d|0)==1){break d}d=mm(c+8|0,a);f=lk(c);g=p[p[a>>2]+ -12>>2];f=p[f>>2];d=p[d>>2];p[114610]=0;da(2322,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}Gb(c+16|0);break c}b=O(0)|0;H()|0;Gb(c+16|0);T(b|0)|0;b=p[c+28>>2]|1;p[c+28>>2]=b;Oi(p[p[a>>2]+ -12>>2]+a|0,b);b=p[p[a>>2]+ -12>>2];p[114610]=0;b=p[(a+b|0)+20>>2];e=p[114610];p[114610]=0;e:{if((e|0)!=1){if(!(b&1)){break e}p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}V()}mg(p[p[a>>2]+ -12>>2]+a|0,p[c+28>>2])}fb=c+32|0;return a}a=O(0)|0;H()|0;rb(a)}E()}function Afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=w(0),m=0,n=w(0),o=w(0),q=w(0),r=w(0),s=w(0),u=w(0),v=w(0),x=w(0),y=w(0);i=fb-16|0;fb=i;j=a+44|0;if(fh(j)){h=Fd(j,0);p[i+8>>2]=h;k=Fd(j,1);p[i+12>>2]=k;e=_c(j,0);p[i>>2]=e;f=_c(j,1);p[i+4>>2]=f;a:{if(t[a+4216>>2]!=w(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=p[e>>2];p[e>>2]=g+4;e=a+f|0;m=e+4248|0;q=t[m>>2];l=t[g>>2];r=t[a+4228>>2];s=t[a+4224>>2];u=t[a+4220>>2];v=t[a+4236>>2];x=t[a+4232>>2];g=e+4240|0;n=t[g>>2];t[m>>2]=n;t[g>>2]=l;g=e+4264|0;y=t[g>>2];e=e+4256|0;o=t[e>>2];t[g>>2]=o;l=w(w(w(w(n*s)+w(u*l))+w(q*r))-w(w(y*v)+w(o*x)));t[e>>2]=l;f=f+i|0;e=p[f>>2];p[f>>2]=e+4;t[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h+ -1|0;if(h){continue}break}break a}g=h;h=d<<2;ac(e,g,h);ac(f,k,h)}Zh(a,b,c,_c(j,0),_c(j,1),d)}fb=i+16|0}function u3(a,b,c){var d=0,e=0,f=0,g=0,h=0;h=fb-16|0;fb=h;a:{b:{c:{d:{if(a){if(c>>>0>=4){break d}d=c;break c}c=0;a=p[b>>2];d=p[a>>2];if(!d){break a}while(1){f=1;if(d>>>0>=128){g=-1;f=Jj(h+12|0,d,0);if((f|0)==-1){break a}}d=p[a+4>>2];a=a+4|0;c=c+f|0;g=c;if(d){continue}break}break a}f=p[b>>2];d=c;while(1){e=p[f>>2];e:{if(e+ -1>>>0>=127){if(!e){n[a|0]=0;p[b>>2]=0;break b}g=-1;e=Jj(a,e,0);if((e|0)==-1){break a}d=d-e|0;a=a+e|0;break e}n[a|0]=e;d=d+ -1|0;f=p[b>>2];a=a+1|0}f=f+4|0;p[b>>2]=f;if(d>>>0>3){continue}break}}if(d){f=p[b>>2];while(1){e=p[f>>2];f:{if(e+ -1>>>0>=127){if(!e){n[a|0]=0;p[b>>2]=0;break b}g=-1;e=Jj(h+12|0,e,0);if((e|0)==-1){break a}if(d>>>0<e>>>0){break b}Jj(a,p[f>>2],0);d=d-e|0;a=a+e|0;break f}n[a|0]=e;d=d+ -1|0;f=p[b>>2];a=a+1|0}f=f+4|0;p[b>>2]=f;if(d){continue}break}}g=c;break a}g=c-d|0}fb=h+16|0;return g}function nna(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a:{if(!(q[b+90|0]&4)|(p[a+480208>>2]&2101248)==2101248){break a}b:{if(p[c>>2]<=0){vb(d+8|0,a+1074308|0,21);if(!tb(d+8|0)){break b}}g=5;if(!(p[a+480180>>2]&5)){vb(d+8|0,a+1074308|0,21);g=tb(d+8|0)?5:6}f=ex(a,q[b+845|0],q[b+840|0]);c:{if((q[b+845|0]&3)!=1){break c}vb(d+8|0,a+1074308|0,89);if(!tb(d+8|0)){break c}f=q[b+839|0];h=q[b+840|0];e=h<<2&124;e=(!(q[b+90|0]&2)|q[a+480209|0]&16?f:q[b+843|0]+f|0)&32?e^127:e;f=h&32?0-e|0:e}e=c;if(p[a+480180>>2]!=131072){c=p[c>>2]+((v(q[b+847|0],f)|0)/(1<<g)|0)|0}else{c=p[c>>2];c=((v(q[b+847|0],v(c,64-f|0))|0)/-8192|0)+c|0}p[e>>2]=c}if(!(p[a+480180>>2]&16777248)|q[a+480208|0]&4?q[a+480209|0]&16:0){break a}vb(d+8|0,a+1074308|0,21);c=tb(d+8|0);a=q[b+846|0];if(c){n[b+840|0]=q[b+840|0]+(a<<2);break a}n[b+840|0]=a+q[b+840|0]}fb=d+16|0}function aS(a,b){var c=0,d=0;d=q[a|0];if(d>>>0>=36){n[a|0]=0;return}c=q[d+12560|0];n[a|0]=c;a:{b:{c:{d:{e:{f:{if((c|0)<=16){if(c+ -6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=q[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}n[b|0]=a;return}switch(c+ -17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(q[b|0]){break a}n[a|0]=0;return}a=q[b|0];if(a>>>0<=64){n[b|0]=a<<1;return}n[b|0]=128;return}g:{h:{i:{j:{c=q[b|0];switch((c&240)+ -48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}n[a|0]=20;n[b|0]=159;return}n[a|0]=20;n[b|0]=192;return}if(c&14){break a}n[a|0]=21;n[b|0]=(q[b|0]!=80)<<6;return}n[a|0]=20;n[b|0]=q[b|0]&15|160;return}if(q[b|0]>31){break a}n[a|0]=16;return}if((c|0)!=31){break a}n[b|0]=(d<<5|q[b|0]>>>3)^128}}function VW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-96|0;fb=g;p[114610]=0;N(224,g+48|0,g+40|0,c|0);c=p[114610];p[114610]=0;a:{b:{h=g+48|0;c:{d:{e:{f:{if((c|0)!=1){p[114610]=0;N(224,g+60|0,g+32|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break f}p[114610]=0;N(224,g+72|0,g+24|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break e}p[114610]=0;N(224,g+84|0,g+16|0,f|0);c=p[114610];p[114610]=0;if((c|0)==1){break d}p[114610]=0;K(225,g+8|0,g+48|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(72,a|0,b|0,g+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}LB(g+48|0);fb=g+96|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;b=1;break c}a=I()|0;H()|0;b=2;break c}a=I()|0;H()|0;b=3}b=h+v(b,12)|0;while(1){b=pb(b+ -12|0);if((b|0)!=(g+48|0)){continue}break}break a}a=I()|0;H()|0;LB(g+48|0)}L(a|0);E()}function SM(a){a=a|0;var b=0;Jb(a,0,288);gy(a+288|0);$o(a+800|0);n[a+2|0]=q[18114];b=q[18112]|q[18113]<<8;n[a|0]=b;n[a+1|0]=b>>>8;n[a+34|0]=q[18117];b=q[18115]|q[18116]<<8;n[a+32|0]=b;n[a+33|0]=b>>>8;b=q[18121]|q[18122]<<8|(q[18123]<<16|q[18124]<<24);n[a+99|0]=b;n[a+100|0]=b>>>8;n[a+101|0]=b>>>16;n[a+102|0]=b>>>24;b=q[18118]|q[18119]<<8|(q[18120]<<16|q[18121]<<24);n[a+96|0]=b;n[a+97|0]=b>>>8;n[a+98|0]=b>>>16;n[a+99|0]=b>>>24;b=q[18125]|q[18126]<<8|(q[18127]<<16|q[18128]<<24);n[a+128|0]=b;n[a+129|0]=b>>>8;n[a+130|0]=b>>>16;n[a+131|0]=b>>>24;b=q[18128]|q[18129]<<8|(q[18130]<<16|q[18131]<<24);n[a+131|0]=b;n[a+132|0]=b>>>8;n[a+133|0]=b>>>16;n[a+134|0]=b>>>24;n[a+260|0]=q[18136];b=q[18132]|q[18133]<<8|(q[18134]<<16|q[18135]<<24);n[a+256|0]=b;n[a+257|0]=b>>>8;n[a+258|0]=b>>>16;n[a+259|0]=b>>>24;rxa(a+288|0);qxa(a+800|0)}function Pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if(($e(a)|0)==(b|0)){if(($e(a+12|0)|0)==(c|0)){break b}}p[114610]=0;K(1641,a|0,b|0);d=p[114610];p[114610]=0;c:{d:{if((d|0)==1){break d}p[114610]=0;e=a+12|0;K(1641,e|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}p[114610]=0;f=a+24|0;K(1642,f|0,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}p[114610]=0;g=a+36|0;K(1642,g|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=Hl(a,d);i=Fb(f,d),j=h,p[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=O(71348)|0;if((H()|0)!=($(71348)|0)){break a}T(b|0)|0;bI(a);aI(a);b=a+12|0;bI(b);aI(b);b=a+24|0;$H(b);_H(b);a=a+36|0;$H(a);_H(a);V();return 0}a=0;while(1){b=Hl(e,a);i=Fb(g,a),j=b,p[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}L(b|0);E()}function RJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b:{d=a+484360|0;if(fc(Ob(d))>>>0<=b>>>0){break b}if(Vo(Ob(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(fc(Ob(d))>>>0<=c>>>0){break a}if(!Vo(Ob(d),b&65535)){continue}break}break a}c=b}if(fc(Ob(d))>>>0>c>>>0){d=a+1074308|0;f=a+1304360|0;c=a+1074984|0;while(1){n[c+819|0]=0;p[c+700>>2]=0;n[c+861|0]=0;n[c+827|0]=0;p[c+708>>2]=0;n[c+841|0]=0;p[c+804>>2]=0;n[c+839|0]=0;n[c+840|0]=0;vb(e+8|0,d,23);if(tb(e+8|0)){o[c+798>>1]=65536;o[c+800>>1]=1}n[c+859|0]=0;c=c+896|0;if((f|0)!=(c|0)){continue}break}QJ(a);c:{if(!(b&65535)){moa(a);break c}o[a+1074440>>1]=b;o[a+1074436>>1]=0;b=a+1074424|0;p[b>>2]=0;p[b+4>>2]=0;p[a+1074432>>2]=0;b=a+1074396|0;p[b>>2]=0;p[b+4>>2]=0;p[a+1074380>>2]=0;p[a+1074392>>2]=p[a+1074416>>2]}p[a+480208>>2]=p[a+480208>>2]&-769}fb=e+16|0}function oza(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;vd(c,2);n[d+16|0]=q[b+13|0];n[d|0]=64;f=c,g=q[hc(d+16|0,d)|0]<<2,o[f+30>>1]=g;e=b+14|0;p[c+24>>2]=(q[e|0]|q[e+1|0]<<8)<<1;mk(d,2,b+1|0);zc(d+16|0,d);p[114610]=0;J(370,c+43|0,d+16|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){pb(d+16|0);e=Tc(a,8,1,0,2);a:{if((q[b|0]&3)!=1){break a}a=b+22|0;p[c>>2]=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);a=b+26|0;p[c+4>>2]=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);a=b+30|0;a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);p[c+8>>2]=a;if(a>>>0>s[c+4>>2]){p[c+8>>2]=a+ -1}if(q[b|0]&4){o[c+34>>1]=r[c+34>>1]|2}if(q[b|0]&8){o[c+34>>1]=r[c+34>>1]|4}if(!(q[b|0]&16)){break a}Az(e);lj(e,9);p[c>>2]=p[c>>2]>>>1;p[c+4>>2]=p[c+4>>2]>>>1;p[c+8>>2]=p[c+8>>2]>>>1}fb=d+32|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function OLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;vd(b,0);p[b>>2]=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);c=At(a+4|0,a);p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=At(a+8|0,a);p[b+8>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+15|0;p[b+24>>2]=(q[c|0]|q[c+1|0]<<8)<<1;if(!(q[c|0]|q[c+1|0]<<8)){p[b+24>>2]=16726}c=a+14|0;e=b,f=(v(ss(n[a+17|0],q[c|0]<<28>>24),p[b+24>>2])>>>0)/8363|0,p[e+24>>2]=f;n[d+15|0]=q[a+18|0];n[d+14|0]=127;e=b,f=(((q[hc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,o[e+30>>1]=f;if(q[c|0]>=16){c=q[c|0];o[b+34>>1]=32;o[b+28>>1]=c&240}a=a+19|0;if(q[a|0]&4){o[b+34>>1]=r[b+34>>1]|1}a:{if(!(q[a|0]&8)|s[b+4>>2]>=s[b+8>>2]){break a}o[b+34>>1]=r[b+34>>1]|2;if(q[a|0]&16){o[b+34>>1]=r[b+34>>1]|4}if(!(q[a|0]&64)){break a}o[b+34>>1]=r[b+34>>1]|128}fb=d+16|0}function $ta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=fb+ -64|0;fb=c;mf(a,c+62|0);a:{b:{c:{d:{e:{f:{g:{e=p[19847];if(r[c+62>>1]>r[e+12>>1]){f=p[b+12>>2];Rz(c+16|0,18469);p[114610]=0;Q(1182,c+32|0,c+16|0,c+62|0,e+12|0);d=p[114610];p[114610]=0;if((d|0)==1){break g}p[114610]=0;d=J(653,c+48|0,c+32|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break f}p[114610]=0;K(627,f|0,d|0);f=p[114610];p[114610]=0;if((f|0)==1){break e}pb(d);pb(c+32|0);yb(c+16|0);o[c+62>>1]=r[e+12>>1]}ig(li(b,0),r[c+62>>1]);b=li(b,0);h=c,i=Ub(b),p[h+48>>2]=i;h=c,i=Vb(b),p[h+16>>2]=i;if(Ab(c+48|0,c+16|0)){break b}break a}b=I()|0;H()|0;break c}b=I()|0;H()|0;break d}b=I()|0;H()|0;pb(d)}pb(c+32|0)}yb(c+16|0);L(b|0);E()}while(1){b=p[c+48>>2];mf(a,c+14|0);o[b>>1]=r[c+14>>1];te(c+48|0);if(Ab(c+48|0,c+16|0)){continue}break}}fb=c- -64|0}function bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;vd(b,4);o[b+30>>1]=q[a+12|0]<<2;Lg(b+30|0,256);c=q[a+15|0];o[b+34>>1]=32;o[b+28>>1]=c;n[b+37|0]=q[a+13|0];n[b+36|0]=q[a+16|0];p[b>>2]=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);c=a+4|0;e=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[b+4>>2]=e;c=a+8|0;p[b+8>>2]=e+(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24));a=a+14|0;if(q[a|0]&16){p[b>>2]=p[b>>2]>>>1;p[b+4>>2]=p[b+4>>2]>>>1;p[b+8>>2]=p[b+8>>2]>>>1}if(q[a|0]&32){p[b>>2]=p[b>>2]>>>1;p[b+4>>2]=p[b+4>>2]>>>1;p[b+8>>2]=p[b+8>>2]>>>1}a:{if(!(q[a|0]&3)|s[b+8>>2]<=s[b+4>>2]){break a}o[b+34>>1]=r[b+34>>1]|2;if(!(q[a|0]&2)){break a}o[b+34>>1]=r[b+34>>1]|4}a=Mb(d,31616);p[114610]=0;J(370,b+43|0,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){pb(a);fb=d+16|0;return}b=I()|0;H()|0;pb(a);L(b|0);E()}function hxa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-48|0;fb=e;o[a>>1]=0;o[a+2>>1]=0;o[a+4>>1]=0;ln(b,e+44|0);a:{if(!QM(e+44|0)){break a}d=q[e+46|0];g=q[e+47|0];f=q[e+45|0];n[a+4|0]=1;h=f>>>3&3;c=(h|0)!=3;i=f>>>1&3;f=i^3;g=g>>>0<192;o[a+2>>1]=r[(v(c,6)+18360|0)+(f<<1)>>1]<<g;f=v(v(q[f+(v(c,3)+18137|0)|0],r[((v(c,90)+18144|0)+v(f,30)|0)+(d>>>3&30)>>1]),1e3);d=d>>>1|0;d=v(((f>>>0)/r[(v(h,6)+18336|0)+(d&6)>>1]|0)+(d&1)|0,(i|0)==3?4:1);o[a>>1]=d;c=q[g+((c<<1)+18372|0)|0];if(c+8>>>0>(d&65535)>>>0){break a}gxa(b,e,c+4|0);b=2;if(c>>>0>2){while(1){if(q[b+e|0]){break a}b=b+1|0;if((c|0)!=(b|0)){continue}break}}b=a;c=c+e|0;d=1;b:{if((q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))==1868983881){break b}d=(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))==1735289176}n[b+5|0]=d}fb=e+48|0;return a|0}function Cqa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var g=0,h=0,i=w(0),k=w(0),l=w(0),m=0,n=0;g=fb-16|0;fb=g;m=g,n=v(p[a>>2],le(a)),p[m+8>>2]=n;vc(g+8|0,c);c=ub(b);i=t[e+4>>2];e=p[g+8>>2];if(e){while(1){h=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);i=w(A(w(x((f(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),j()))),i));c=c+4|0;e=e+ -1|0;if(e){continue}break}}c=i==w(0);a:{if(c){break a}e=p[g+8>>2];if(!e){break a}l=c?w(1):w(w(1)/i);c=p[a+20>>2];while(1){a=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);t[g+12>>2]=l*(f(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),j());Td(g+12|0,w(-1));k=w(t[g+12>>2]*w(32768));t[g+12>>2]=k;a=c;k=$d(k);b:{if(w(x(k))<w(2147483648)){h=~~k;break b}h=-2147483648}m=a,n=Mc(h),o[m>>1]=n;b=b+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){t[d>>2]=i}fb=g+16|0;return p[g+8>>2]}function _aa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-48|0;fb=e;h=no(a,c);i=tG(a+4|0);j=sG(a+24|0);k=rG(a+32|0);l=kw(a+36|0);p[a+56>>2]=3;m=Xg(a+68|0);p[114610]=0;K(2165,a|0,d|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{if((c|0)!=1){c=p[b>>2];f=p[b+4>>2];g=p[b+12>>2];b=p[b+8>>2];p[e+8>>2]=b;p[e+12>>2]=g;p[114610]=0;p[e+16>>2]=c;p[e+20>>2]=f;p[e>>2]=c;p[e+4>>2]=f;p[e+24>>2]=b;p[e+28>>2]=g;K(2166,e+32|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;N(2167,a|0,e+32|0,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break c}sb(e+32|0);p[114610]=0;S(2168,a|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}fb=e+48|0;return a|0}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;sb(e+32|0);break a}a=I()|0;H()|0}bd(m);gf(l);gg(k);th(j);Nc(i);Nc(h);L(a|0);E()}function zqa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,r=0,s=0;h=fb-16|0;fb=h;n=h,r=v(p[a>>2],le(a)),p[n+4>>2]=r;vc(h+4|0,c);c=ub(b);j=u[e+8>>3];i=p[h+4>>2];a:{if(!i){break a}e=i;while(1){l=(q[c+4|0]|q[c+5|0]<<8|(q[c+6|0]<<16|q[c+7|0]<<24))&2147483647;f(0,q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24));f(1,l|0);j=A(+g(),j);c=c+8|0;e=e+ -1|0;if(e){continue}break}if(!i|j==0){break a}m=1/j;c=p[a+20>>2];while(1){a=b;e=q[a+4|0]|q[a+5|0]<<8|(q[a+6|0]<<16|q[a+7|0]<<24);f(0,q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24));f(1,e|0);n=h,s=+g()*m,u[n+8>>3]=s;wf(h+8|0,-1,1);k=u[h+8>>3]*32768;u[h+8>>3]=k;a=c;k=Id(k);b:{if(x(k)<2147483648){e=~~k;break b}e=-2147483648}n=a,r=Mc(e),o[n>>1]=r;b=b+8|0;c=c+2|0;i=i+ -1|0;if(i){continue}break}}if(d){u[d>>3]=j}fb=h+16|0;return p[h+4>>2]}function tqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,g=w(0),h=0,i=0,k=w(0),l=0,m=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>3;p[e+8>>2]=p[a>>2];i=p[Cb(e+12|0,e+8|0)>>2];k=t[d>>2];b=ub(b);if(i){a=p[a+20>>2];c=i;while(1){d=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);t[e+12>>2]=k*(f(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),j());Td(e+12|0,w(-1));g=w(t[e+12>>2]*w(32768));t[e+12>>2]=g;d=a;g=$d(g);a:{if(w(x(g))<w(2147483648)){h=~~g;break a}h=-2147483648}l=d,m=Mc(h),o[l>>1]=m;d=q[b+4|0]|q[b+5|0]<<8|(q[b+6|0]<<16|q[b+7|0]<<24);t[e+12>>2]=k*(f(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),j());Td(e+12|0,w(-1));g=w(t[e+12>>2]*w(32768));t[e+12>>2]=g;d=a;g=$d(g);b:{if(w(x(g))<w(2147483648)){h=~~g;break b}h=-2147483648}l=d,m=Mc(h),o[l+2>>1]=m;a=a+4|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return i<<3}function gqa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;spa(a+8|0);p[a+32>>2]=0;p[a+36>>2]=0;c=a+4|0;p[p[c>>2]>>2]=0;p[p[c>>2]+40>>2]=p[p[a>>2]+480196>>2];p[p[c>>2]+44>>2]=p[p[a>>2]+480204>>2];p[p[c>>2]+68>>2]=p[p[a>>2]+480200>>2];f=r[p[a>>2]+480188>>1];b=e;p[b+24>>2]=0;p[b+28>>2]=0;p[b+16>>2]=0;p[b+20>>2]=0;p[b+8>>2]=0;p[b+12>>2]=0;b=b+8|0;p[b>>2]=0;p[b+4>>2]=0;n[b+21|0]=255;n[b+13|0]=0;n[b+14|0]=0;n[b+15|0]=0;n[b+16|0]=0;n[b+17|0]=0;n[b+18|0]=0;n[b+19|0]=0;n[b+20|0]=0;p[b+8>>2]=0;p[b+12>>2]=0;Vpa(a+20|0,f,b);if(r[p[a>>2]+480188>>1]){while(1){b=v(d,896);_m((b+p[c>>2]|0)+608|0,p[a>>2],d&65535);n[(b+p[c>>2]|0)+1445|0]=0;n[(b+p[c>>2]|0)+1444|0]=0;n[(b+p[c>>2]|0)+1429|0]=0;n[(b+p[c>>2]|0)+1432|0]=0;n[(b+p[c>>2]|0)+1427|0]=0;d=d+1|0;if(d>>>0<r[p[a>>2]+480188>>1]){continue}break}}fb=e+32|0}function Yea(){var a=0,b=0,c=0,d=0,e=0;a=fb-48|0;fb=a;c=Lb(a+32|0);p[114610]=0;S(1994,a+16|0);b=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{if((b|0)!=1){d=a,e=Ub(a+16|0),p[d+8>>2]=e;d=a,e=Vb(a+16|0),p[d>>2]=e;if(!Ab(a+8|0,a)){break e}break f}b=O(0)|0;H()|0;break c}while(1){b=p[a+8>>2];p[114610]=0;J(1251,c|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break d}kn(a+8|0);d=a,e=Vb(a+16|0),p[d>>2]=e;if(!Ab(a+8|0,a)){break e}p[114610]=0;J(1995,c|0,34105)|0;b=p[114610];p[114610]=0;if((b|0)!=1){continue}break}break d}b=Pd(Ib(c));bd(a+16|0);pb(c);break b}b=O(0)|0;H()|0;bd(a+16|0)}pb(c);T(b|0)|0;b=0;p[114610]=0;Q(1989,34107,0,0,0);c=p[114610];p[114610]=0;if((c|0)==1){break a}V()}fb=a+48|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;if((c|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Ar(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-176|0;fb=d;e=Vg(d+40|0);f=p[p[e>>2]+ -12>>2];p[114610]=0;g=Y(122)|0;h=p[114610];p[114610]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}p[114610]=0;N(123,d+32|0,f+(d+40|0)|0,g|0);f=p[114610];p[114610]=0;if((f|0)==1){break e}Gb(d+32|0);p[114610]=0;K(142,e|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break e}p[114610]=0;K(133,e|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;K(125,d|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;N(140,d+16|0,d|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;N(141,a|0,d+16|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}pb(d+16|0);pb(d);Qd(e);fb=d+176|0;return}c=I()|0;H()|0;break a}c=I()|0;H()|0;break b}c=I()|0;H()|0;pb(d+16|0)}pb(d)}Qd(e);L(c|0);E()}function sH(a){var b=0,c=w(0),d=0,e=0,f=w(0);b=fb-16|0;fb=b;d=He(p[a+16>>2]);e=a,f=fe(w(10),w(w(w(t[a+4208>>2]*w(120))+w(-60))*w(.05000000074505806))),t[e+4232>>2]=f;c=w(w(d>>>0)*w(.0010000000474974513));e=a,f=fe(w(10),w(w(-1)/w(w(w(t[a+4212>>2]*w(499.989990234375))+w(.009999999776482582))*c))),t[e+4236>>2]=f;e=a,f=fe(w(10),w(w(-1)/w(w(w(t[a+4216>>2]*w(2950))+w(50))*c))),t[e+4240>>2]=f;p[b+12>>2]=1325400064;e=b,f=w(w(M5(w(fe(w(10),w(w(w(t[a+4220>>2]*w(60))+w(-60))*w(.05000000074505806)))*w(2147483648)))*w(96817624))+w(67108864)),t[e+8>>2]=f;e=a,f=w(t[bl(b+12|0,b+8|0)>>2]*w(4.656612873077393e-10)),t[e+4244>>2]=f;t[a+4248>>2]=w(w(-1)/w(w(t[a+4224>>2]*w(99))+w(1)))+w(1);d=a;c=w(w(w(t[a+4228>>2]*w(4))*c)+w(2));a:{if(w(x(c))<w(2147483648)){a=~~c;break a}a=-2147483648}p[d+4252>>2]=a;fb=b+16|0}function sFa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;n[g+14|0]=d;n[g+15|0]=c;n[g+13|0]=e;n[g+12|0]=f;if((d+ -1&255)>>>0<=5){n[g+14|0]=d+15}TP(g+15|0,g+13|0);TP(g+14|0,g+12|0);a:{if(q[g+15|0]==10){n[g+13|0]=q[g+13|0]&15?-1:q[g+12|0];if(q[g+14|0]!=10){break a}n[g+14|0]=0;break a}if(q[g+14|0]!=10){break a}n[g+12|0]=q[g+12|0]&15?-1:0}if(b){n[a+2|0]=1;n[a+4|0]=b+2>>>2}Qw(g+15|0,g+13|0,g+14|0,g+12|0);c=q[g+15|0];b:{if(!c){break b}d=q[g+14|0];if(!d){n[g+14|0]=c;n[g+12|0]=q[g+13|0];n[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){n[g+15|0]=0;break b}if(!b){Pw(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);n[a+2|0]=q[g+15|0];n[a+4|0]=q[g+13|0];break b}if(Fm(c)>>>0<=Fm(q[g+14|0])>>>0){break b}bh(g+15|0,g+14|0);bh(g+13|0,g+12|0)}n[a+3|0]=q[g+14|0];n[a+5|0]=q[g+12|0];fb=g+16|0}function rZ(a,b){var c=0;while(1){if(p[a>>2]==1){continue}break}a:{b:{if(!p[a>>2]){c:{sf(a,1);p[114610]=0;c=p[114610];p[114610]=0;d:{if((c|0)==1){break d}p[114610]=0;S(2567,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;b=p[114610];p[114610]=0;if((b|0)==1){break d}p[a>>2]=-1;p[114610]=0;b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;b=p[114610];p[114610]=0;if((b|0)!=1){break c}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;b=p[114610];p[114610]=0;e:{if((b|0)==1){break e}sf(a,0);p[114610]=0;a=p[114610];p[114610]=0;if((a|0)==1){break e}p[114610]=0;a=p[114610];p[114610]=0;if((a|0)==1){break e}p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}}return}a=O(0)|0;H()|0;rb(a)}E()}function FD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;g=fb-1040|0;fb=g;h=p[b>>2];p[g+12>>2]=h;i=a?a:g+16|0;d=a?d:256;a:{if(!d|!h){break a}f=c>>>2|0;k=f>>>0<d>>>0;if(f>>>0<d>>>0?c>>>0<=131:0){break a}while(1){f=k?f:d;c=c-f|0;f=dv(i,g+12|0,f,e);if((f|0)==-1){d=0;h=p[g+12>>2];j=-1;break a}h=(g+16|0)==(i|0);i=h?i:(f<<2)+i|0;j=f+j|0;d=d-(h?0:f)|0;h=p[g+12>>2];if(!d|!h){break a}f=c>>>2|0;k=f>>>0<d>>>0;if(c>>>0>131|f>>>0>=d>>>0){continue}break}}b:{c:{if(!c|(!h|!d)){break c}while(1){f=Zn(i,h,c,e);if(f+2>>>0<=2){d:{switch(f+1|0){case 1:p[g+12>>2]=0;break c;case 0:break b;default:break d}}p[e>>2]=0;break c}h=p[g+12>>2]+f|0;p[g+12>>2]=h;j=j+1|0;d=d+ -1|0;if(!d){break c}i=i+4|0;c=c-f|0;f=j;if(c){continue}break}break b}f=j}if(a){p[b>>2]=p[g+12>>2]}fb=g+1040|0;return f|0}function Yaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-32|0;fb=f;d=no(a,d);h=tG(a+4|0);i=sG(a+24|0);j=rG(a+32|0);k=kw(a+36|0);p[a+56>>2]=3;l=Xg(a+68|0);p[114610]=0;K(2165,a|0,e|0);g=p[114610];p[114610]=0;a:{b:{c:{d:{if((g|0)!=1){p[114610]=0;b=M(2172,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break d}p[114610]=0;N(2173,f+8|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;K(2174,f+16|0,f+8|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;N(2167,a|0,f+16|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break c}sb(f+16|0);p[114610]=0;S(2168,a|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;break b}a=I()|0;H()|0;break b}a=I()|0;H()|0;sb(f+16|0)}bd(l);gf(k);gg(j);th(i);Nc(h);Nc(d);L(a|0);E()}fb=f+32|0;return a|0}function W5(a,b,c,d,e){var f=w(0),g=w(0),h=0,i=w(0),j=w(0),k=w(0),l=0;if((0-(a<<4)|0)<=-1){b=(c<<2)+b|0;c=b-(a<<6)|0;k=t[(e>>3<<2)+d>>2];while(1){a=b+ -32|0;f=t[a>>2];i=t[b>>2];t[b>>2]=f+i;d=b+ -4|0;g=t[d>>2];e=d;d=b+ -36|0;j=t[d>>2];t[e>>2]=j+g;t[a>>2]=i-f;t[d>>2]=g-j;d=b+ -8|0;g=t[d>>2];e=d;d=b+ -40|0;i=t[d>>2];t[e>>2]=i+g;e=b+ -12|0;f=t[e>>2];h=e;e=b+ -44|0;j=t[e>>2];t[h>>2]=j+f;f=w(f-j);g=w(g-i);t[d>>2]=w(f+g)*k;t[e>>2]=w(f-g)*k;d=b+ -20|0;g=t[d>>2];e=b+ -52|0;f=t[e>>2];h=b+ -16|0;i=t[h>>2];l=h;h=b+ -48|0;j=t[h>>2];t[l>>2]=i+j;t[d>>2]=f+g;t[h>>2]=g-f;t[e>>2]=j-i;d=b+ -60|0;g=t[d>>2];e=b+ -28|0;f=t[e>>2];h=b+ -24|0;i=t[h>>2];l=h;h=b+ -56|0;j=t[h>>2];t[l>>2]=i+j;t[e>>2]=g+f;g=w(f-g);f=w(j-i);t[h>>2]=w(g+f)*k;t[d>>2]=w(f-g)*k;ZE(b);ZE(a);b=b+ -64|0;if(b>>>0>c>>>0){continue}break}}}function dY(a){var b=0,c=w(0),d=w(0),g=w(0),h=w(0),k=0,l=w(0),m=w(0);b=(i(a),e(2));a:{b:{if(!((b|0)>-1?b>>>0>=8388608:0)){if(!(b&2147483647)){return w(w(-1)/w(a*a))}if((b|0)<=-1){return w(w(a-a)/w(0))}b=(i(w(a*w(33554432))),e(2));k=-152;break b}if(b>>>0>2139095039){break a}k=-127;a=w(0);if((b|0)==1065353216){break a}}b=b+4913933|0;l=w((b>>>23|0)+k|0);a=w((f(2,(b&8388607)+1060439283|0),j())+w(-1));c=w(a*w(a*w(.5)));d=w(a/w(a+w(2)));g=w(d*d);h=w(g*g);m=a;a=(f(2,(i(w(a-c)),e(2))&-4096),j());c=w(w(w(m-a)-c)+w(d*w(c+w(w(g*w(w(h*w(.2849878668785095))+w(.6666666269302368)))+w(h*w(w(h*w(.24279078841209412))+w(.40000972151756287)))))));a=w(w(l*w(.3010292053222656))+w(w(a*w(.434326171875))+w(w(c*w(.434326171875))+w(w(l*w(7.903415166765626e-7))+w(w(c+a)*w(-3168997136526741e-20))))))}return a}function zo(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;a:{b:{switch(p[a+480224>>2]+ -1|0){default:b=p[a+24620>>2];d=b>>31;p[c+8>>2]=1;p[c>>2]=p[a+1074420>>2]<<1;d=NNa(b,d,5e4,0);e=ib;b=p[Uc(c+8|0,c)>>2];b=rc(ONa(d,e,b,b>>31),ib);p[a+1074404>>2]=b;break a;case 1:b=p[a+24620>>2];p[c+8>>2]=1;p[c+12>>2]=0;f=c,g=NNa(p[a+1074420>>2],0,NNa(p[a+1074408>>2],0,p[a+1074416>>2],0),ib),p[f>>2]=g;p[c+4>>2]=ib;d=NNa(b,0,6e5,0);e=ib;b=Una(c+8|0,c);b=QNa(d,e,p[b>>2],p[b+4>>2]);p[a+1074404>>2]=b;break a;case 0:break b}}b=p[a+24620>>2];d=b>>31;p[c+8>>2]=1;p[c>>2]=p[a+1074420>>2];d=NNa(b,d,1e4,0);e=ib;b=p[Uc(c+8|0,c)>>2];b=rc(ONa(d,e,b,b>>31),ib);p[a+1074404>>2]=b}d=a+1074404|0;a=p[a+480244>>2];b=NNa(a,a>>31,b,b>>31)+32768|0;a=ib;a=rc(ONa(b,b>>>0<32768?a+1|0:a,65536,0),ib);p[d>>2]=a?a:1;fb=c+16|0}function yK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;a:{if(!p[b+700>>2]){break a}f=p[a+480180>>2]==64?v(c,-20):c;b:{if(!(!(q[a+480208|0]&16)|p[a+480180>>2]==4)){g=p[b+700>>2];c=f>>31;p[e+12>>2]=(c+f^c)>>>2;vc(e+12|0,255);d=p[e+12>>2];c:{if(!d){break c}h=b;c=p[b+700>>2];i=c;c=c>>31;d:{if((f|0)<=-1){d=xx(a,d);break d}d=wx(a,d)}d=NNa(i,c,d,d>>31)+32768|0;c=ib;c=rc(ONa(d,d>>>0<32768?c+1|0:c,65536,0),ib);p[h+700>>2]=c;if((c|0)!=(g|0)){break c}vb(e,a+1074308|0,7);d=tb(e);c=p[b+700>>2];if((d|0)==(f>>>31|0)){if((c|0)>=2147483647){break c}p[b+700>>2]=p[b+700>>2]+1;break c}if((c|0)<2){break c}p[b+700>>2]=c+ -1}c=p[b+700>>2];break b}c=f+p[b+700>>2]|0;p[b+700>>2]=c}if((c|0)>0){break a}p[b+700>>2]=1;if(p[a+480180>>2]!=2){break a}p[b+696>>2]=0;p[b+88>>2]=p[b+88>>2]|2101248}fb=e+16|0}function vCa(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;vd(b,1);d=a+22|0;d=q[d|0]|q[d+1|0]<<8;p[b>>2]=(d<<24|d<<8&16711680)>>>15;n[b+37|0]=q[a+24|0]<<4;n[f+15|0]=q[a+25|0];n[f+14|0]=64;h=b,i=q[hc(f+15|0,f+14|0)|0]<<2,o[h+30>>1]=i;d=a+26|0;d=q[d|0]|q[d+1|0]<<8;g=(d<<24|d<<8&16711680)>>>16|0;d=g<<1;a=a+28|0;a=q[a|0]|q[a+1|0]<<8;a=(a<<24|a<<8&16711680)>>>16|0;e=a<<1;a:{if(a>>>0<=1){a=p[b>>2];break a}a=p[b>>2];d=d+e>>>0<=a>>>0?d:e+g>>>0>a>>>0?d:g}b:{c:{switch(a|0){case 2:p[b>>2]=0;break b;case 0:break b;default:break c}}p[b+4>>2]=d;e=d+e|0;p[b+8>>2]=e;if(d>>>0>=a>>>0){d=a+ -1|0;p[b+4>>2]=d}if(!(e-d>>>0>3?!(e>>>0<4|e>>>0<d>>>0):0)){p[b+4>>2]=0;p[b+8>>2]=0;e=0;d=0}if(!(a>>>0<=e>>>0|e>>>0>8|(!c|d))){p[b+8>>2]=0;break b}if(e>>>0<=d>>>0){break b}o[b+34>>1]=r[b+34>>1]|2}fb=f+16|0}function uf(a){var b=0,c=0;b=p[a+4>>2];c=p[p[b>>2]+ -12>>2];p[114610]=0;b=p[(b+c|0)+24>>2];c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=p[a+4>>2];c=p[p[b>>2]+ -12>>2];p[114610]=0;b=tf(b+c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}if(!b){break b}b=p[a+4>>2];if(!(p[(p[p[b>>2]+ -12>>2]+b|0)+4>>2]&8192)){break b}if(wv()){break b}b=p[a+4>>2];c=p[p[b>>2]+ -12>>2];p[114610]=0;b=p[(b+c|0)+24>>2];c=p[114610];p[114610]=0;c:{if((c|0)==1){break c}p[114610]=0;b=M(2315,b|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=p[a+4>>2];b=p[p[a>>2]+ -12>>2];p[114610]=0;K(18,a+b|0,1);a=p[114610];p[114610]=0;if((a|0)!=1){break b}}a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break a}}return}a=O(0)|0;H()|0;rb(a);E()}function jH(a){var b=w(0),c=0,d=w(0),e=w(0),f=w(0),g=0,h=0,i=0,j=w(0);c=fb-16|0;fb=c;h=a,i=ji(w(t[a+4256>>2]*w(3))),p[h+4264>>2]=i;h=a,j=w(He(p[a+16>>2])>>>((p[a+4264>>2]>>>1^-1)&1)>>>0),t[h+4268>>2]=j;t[a+4272>>2]=w(t[a+4244>>2]*w(100))*w(.0061803399585187435);h=c,j=fe(w(10),w(w(iH(a)+w(w(t[a+4228>>2]*w(11e3))+w(-1e4)))*w(.0005000000237487257))),t[h+12>>2]=j;p[c+8>>2]=1065353216;h=a,j=w(t[bl(c+12|0,c+8|0)>>2]*w(.7609999775886536)),t[h+4280>>2]=j;g=a;b=fe(w(10),w(w(w(t[a+4212>>2]*w(1e4))+w(-1e4))*w(.0010000000474974513)));if(b!=w(1)){d=ho(w(w(hH(a)*w(6.2831854820251465))/t[a+4268>>2]));e=w(b+b);f=w(b*b);b=w(b*w(8));b=Rm(w(w(w(w(d*e)+w(-2))+w(D(w(w(w(f*w(-4))+b)+w(w(w(w(f*w(4))*d)-b)*d)))))/w(e+w(-2))),w(0),w(1))}else{b=w(0)}t[g+4276>>2]=b;Nfa(a);Mfa(a);n[a+5046|0]=0;fb=c+16|0}function Iwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-32|0;fb=e;i=p[a+40>>2];j=p[a+36>>2];l=p[a+16>>2];b=p[a+4>>2];g=b;f=p[a>>2];p[e+24>>2]=f;p[e+28>>2]=b;b=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=b;a:{if(!d){h=i>>12;b=j>>12;break a}while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=o[k+g>>1];p[(e+8|0)+(h<<2)>>2]=f+((v(o[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=p[a+32>>2];j=p[a+28>>2]+j|0;b=j>>12;p[c>>2]=p[c>>2]+v(b,p[e+8>>2]);i=f+i|0;h=i>>12;p[c+4>>2]=p[c+4>>2]+v(h,p[e+12>>2]);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;f=p[e+24>>2];g=p[e+28>>2];continue}break}f=p[e+24>>2];g=p[e+28>>2]}p[a+40>>2]=i;p[a+20>>2]=b;p[a+36>>2]=j;p[a+24>>2]=h;p[a>>2]=f;p[a+4>>2]=g;fb=e+32|0}function EM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-32|0;fb=e;d=c&4;a:{if(!(b&4)){if(!d){break a}n[a+15|0]=q[a+16|0];b=q[a+12|0];n[a+12|0]=b&247;if(!(b&2)){break a}b=q[a+14|0];if(b>>>0<=q[a+13|0]){break a}if(Bb(a)>>>0<=b>>>0){break a}while(1){d=sc(a,b);o[d>>1]=r[d>>1]+1;b=b+1|0;if(b>>>0<Bb(a)>>>0){continue}break}break a}if(d){break a}b=q[a+14|0];b:{if(q[a+15|0]<=b>>>0){break b}d=q[a+12|0];if(!(d&2)){break b}n[a+12|0]=d&251}if(!(q[a+12|0]&2)|b>>>0<=q[a+13|0]){break a}d=r[sc(a,b)>>1];f=sc(a,q[a+14|0]+ -1|0);b=q[a+14|0];if((d+ -1|0)>r[f>>1]){b=r[sc(a,b)>>1]+ -1&65535;d=Zo(a,b,64,64);g=e,h=Ub(a),p[g+8>>2]=h;g=e,h=Yo(e+8|0,q[a+14|0]),p[g+16>>2]=h;f=Ld(e+24|0,e+16|0);b=kp(e,b,d&255);Zua(a,p[f>>2],b);break a}n[a+14|0]=b+ -1}if((c|0)!=16777216){n[a+17|0]=255}fb=e+32|0}function Lga(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-176|0;fb=d;e=Vg(d+40|0);f=p[p[e>>2]+ -12>>2];p[114610]=0;g=Y(122)|0;h=p[114610];p[114610]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}p[114610]=0;N(123,d+32|0,f+(d+40|0)|0,g|0);f=p[114610];p[114610]=0;if((f|0)==1){break e}Gb(d+32|0);p[114610]=0;K(148,e|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break e}p[114610]=0;K(132,e|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;K(125,d|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;N(140,d+16|0,d|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;N(141,a|0,d+16|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}pb(d+16|0);pb(d);Qd(e);fb=d+176|0;return}c=I()|0;H()|0;break a}c=I()|0;H()|0;break b}c=I()|0;H()|0;pb(d+16|0)}pb(d)}Qd(e);L(c|0);E()}function wH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-176|0;fb=d;e=Vg(d+40|0);f=p[p[e>>2]+ -12>>2];p[114610]=0;g=Y(122)|0;h=p[114610];p[114610]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}p[114610]=0;N(123,d+32|0,f+(d+40|0)|0,g|0);f=p[114610];p[114610]=0;if((f|0)==1){break e}Gb(d+32|0);p[114610]=0;K(147,e|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break e}p[114610]=0;K(130,e|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;K(125,d|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;N(140,d+16|0,d|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}p[114610]=0;N(141,a|0,d+16|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}pb(d+16|0);pb(d);Qd(e);fb=d+176|0;return}c=I()|0;H()|0;break a}c=I()|0;H()|0;break b}c=I()|0;H()|0;pb(d+16|0)}pb(d)}Qd(e);L(c|0);E()}function Qya(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);p[b>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);n[e+15|0]=q[a+4|0];n[e+14|0]=64;f=b,g=q[hc(e+15|0,e+14|0)|0]<<2,o[f+30>>1]=g;c=a+6|0;d=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[b+4>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);a=a+10|0;a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);d=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24);a=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);a=d+(a<<8&16711680|a<<24|(a>>>8&65280|a>>>24))|0;p[b+8>>2]=a;d=p[b+4>>2];c=p[b>>2];if(d>>>0>=c>>>0){d=c+ -1|0;p[b+4>>2]=d}if(a>>>0>c>>>0){p[b+8>>2]=c;a=c}a:{if(d>>>0>a>>>0){p[b+4>>2]=0;p[b+8>>2]=0;break a}if(a>>>0<=d>>>0){break a}p[b+68>>2]=d;o[b+34>>1]=r[b+34>>1]|2}fb=e+16|0}function L5(a){var b=0,c=w(0),d=w(0),f=0,g=0,h=w(0),j=w(0);f=(i(a),e(2));g=f>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=f&2147483647;g:{if(b>>>0>=1118743632){if(b>>>0>2139095040){return a}if(!((f|0)<0|b>>>0<1118925336)){return w(a*w(1.7014118346046923e+38))}if(b>>>0<=1120924084|(f|0)>-1){break g}break b}if(b>>>0<1051816473){break d}if(b>>>0<1065686419){break f}}a=w(w(a*w(1.4426950216293335))+t[(g<<2)+52192>>2]);if(w(x(a))<w(2147483648)){b=~~a;break e}b=-2147483648;break e}b=(g^1)-g|0}c=w(b|0);a=w(d+w(c*w(-.693145751953125)));h=w(c*w(1428606765330187e-21));d=w(a-h);break c}if(b>>>0<=956301312){break a}b=0;d=a}c=d;j=a;c=w(c*c);a=w(d-w(c*w(w(c*w(-.0027667332906275988))+w(.16666625440120697))));c=w(w(j+w(w(w(d*a)/w(w(2)-a))-h))+w(1));if(!b){break b}c=WE(c,b)}return c}return w(a+w(1))}function Ej(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;n[k+15|0]=a;a:{b:{c:{if(p[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=q[j+24|0]){l=45;if(q[j+25|0]!=(m|0)){break c}}p[d>>2]=c+1;n[c|0]=l;break b}if(!(!wb(g)|(a|0)!=(f|0))){a=0;b=p[i>>2];if((b-h|0)>159){break a}a=p[e>>2];p[i>>2]=b+4;p[b>>2]=a;break b}a=-1;f=Gm(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b+ -8|0){case 0:case 2:if((f|0)<(b|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=p[d>>2];if((b|0)==(c|0)|(b-c|0)>2|q[b+ -1|0]!=48){break a}a=0;p[e>>2]=0;p[d>>2]=b+1;n[b|0]=q[f+62096|0];break a}a=p[d>>2];p[d>>2]=a+1;n[a|0]=q[f+62096|0];p[e>>2]=p[e>>2]+1;a=0;break a}a=0;p[e>>2]=0}fb=k+16|0;return a|0}function Dj(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=fb-16|0;fb=k;p[k+12>>2]=a;a:{b:{c:{if(p[d>>2]!=(c|0)){break c}l=43;if(p[j+96>>2]!=(a|0)){l=45;if(p[j+100>>2]!=(a|0)){break c}}p[d>>2]=c+1;n[c|0]=l;break b}if(!(!wb(g)|(a|0)!=(f|0))){a=0;b=p[i>>2];if((b-h|0)>159){break a}a=p[e>>2];p[i>>2]=b+4;p[b>>2]=a;break b}a=-1;g=Wu(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b+ -8|0){case 0:case 2:if((f|0)<(b|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=p[d>>2];if((b|0)==(c|0)|(b-c|0)>2|q[b+ -1|0]!=48){break a}a=0;p[e>>2]=0;p[d>>2]=b+1;n[b|0]=q[f+62096|0];break a}a=p[d>>2];p[d>>2]=a+1;n[a|0]=q[f+62096|0];p[e>>2]=p[e>>2]+1;a=0;break a}a=0;p[e>>2]=0}fb=k+16|0;return a|0}function ho(a){var b=w(0),c=0,d=0,f=0,g=0;c=fb-16|0;fb=c;f=(i(a),e(2));d=f&2147483647;a:{if(d>>>0<=1061752794){b=w(1);if(d>>>0<964689920){break a}b=ph(+a);break a}if(d>>>0<=1081824209){g=+a;if(d>>>0>=1075235812){b=w(-ph(((f|0)>-1?-3.141592653589793:3.141592653589793)+g));break a}if((f|0)<=-1){b=qh(g+1.5707963267948966);break a}b=qh(1.5707963267948966-g);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=ph(((f|0)>-1?-6.283185307179586:6.283185307179586)+ +a);break a}if((f|0)<=-1){b=qh(-4.71238898038469- +a);break a}b=qh(+a+ -4.71238898038469);break a}b=w(a-a);if(d>>>0>=2139095040){break a}b:{switch(Fv(a,c+8|0)&3){case 0:b=ph(u[c+8>>3]);break a;case 1:b=qh(-u[c+8>>3]);break a;case 2:b=w(-ph(u[c+8>>3]));break a;default:break b}}b=qh(u[c+8>>3])}a=b;fb=c+16|0;return a}function Fqa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;m=i,n=v(p[a>>2],le(a)),p[m+12>>2]=n;vc(i+12|0,c);c=ub(b);h=p[e+4>>2];f=p[i+12>>2];a:{if(!f){g=h;break a}while(1){e=ub(q[c|0])|ub(q[c+1|0])<<8|ub(q[c+2|0])<<16|ub(q[c+3|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+4|0;h=g;f=f+ -1|0;if(f){continue}break}}c:{if(!g){break c}e=p[i+12>>2];if(!e){break c}j=g+ -1|0;k=g>>>1|0;l=g;c=p[a+20>>2];while(1){a=ub(q[b|0])|ub(q[b+1|0])<<8|ub(q[b+2|0])<<16|ub(q[b+3|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=k|f<<31;a=j&a>>31;m=c,n=rc(ONa(f-a|0,h-(f>>>0<a>>>0)|0,l,0),ib)>>>16|0,o[m>>1]=n;b=b+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){p[d>>2]=g}fb=i+16|0;return p[i+12>>2]}function Eqa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;m=i,n=v(p[a>>2],le(a)),p[m+12>>2]=n;vc(i+12|0,c);c=ub(b);h=p[e+4>>2];f=p[i+12>>2];a:{if(!f){g=h;break a}while(1){e=ub(q[c+3|0])|ub(q[c+2|0])<<8|ub(q[c+1|0])<<16|ub(q[c|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+4|0;h=g;f=f+ -1|0;if(f){continue}break}}c:{if(!g){break c}e=p[i+12>>2];if(!e){break c}j=g+ -1|0;k=g>>>1|0;l=g;c=p[a+20>>2];while(1){a=ub(q[b+3|0])|ub(q[b+2|0])<<8|ub(q[b+1|0])<<16|ub(q[b|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=k|f<<31;a=j&a>>31;m=c,n=rc(ONa(f-a|0,h-(f>>>0<a>>>0)|0,l,0),ib)>>>16|0,o[m>>1]=n;b=b+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){p[d>>2]=g}fb=i+16|0;return p[i+12>>2]}function df(a,b){var c=0,d=0,e=0;d=fb-32|0;fb=d;a=Bg(a,-1,-1);a:{b:{if(q[Qi(d+24|0,b,1)|0]){c=p[p[b>>2]+ -12>>2];p[114610]=0;c=p[(b+c|0)+24>>2];e=p[114610];p[114610]=0;c:{d:{if((e|0)==1){break d}p[114610]=0;Ia(2325,d+8|0,c|0,0,0,1,8);c=p[114610];p[114610]=0;if((c|0)==1){break d}c=p[d+12>>2];p[a>>2]=p[d+8>>2];p[a+4>>2]=c;c=p[d+20>>2];p[a+8>>2]=p[d+16>>2];p[a+12>>2]=c;a=0;break c}a=O(0)|0;H()|0;T(a|0)|0;Oi(p[p[b>>2]+ -12>>2]+b|0,1);a=p[p[b>>2]+ -12>>2];p[114610]=0;a=p[(a+b|0)+20>>2];c=p[114610];p[114610]=0;e:{if((c|0)!=1){if(!(a&1)){break e}p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}V();a=1}mg(p[p[b>>2]+ -12>>2]+b|0,a)}fb=d+32|0;return}a=O(0)|0;H()|0;rb(a)}E()}function jq(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a=Xc(a);a:{b:{c:{switch(b|0){case 0:p[114610]=0;b=J(2,d|0,7167)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}xb(a,b);pb(b);break b;case 1:p[114610]=0;b=J(2,d|0,7192)|0;c=p[114610];p[114610]=0;if((c|0)!=1){xb(a,b);pb(b);break b}break a;case 2:p[114610]=0;b=J(2,d|0,7237)|0;c=p[114610];p[114610]=0;if((c|0)!=1){xb(a,b);pb(b);break b}break a;case 3:p[114610]=0;b=J(2,d|0,7264)|0;c=p[114610];p[114610]=0;if((c|0)!=1){xb(a,b);pb(b);break b}break a;case 4:p[114610]=0;b=J(2,d|0,7290)|0;c=p[114610];p[114610]=0;if((c|0)!=1){xb(a,b);pb(b);break b}break a;case 5:break c;default:break b}}p[114610]=0;b=J(2,d|0,7319)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}xb(a,b);pb(b)}fb=d+16|0;return}b=I()|0;H()|0;pb(a);L(b|0);E()}function C_(a,b,c,d,e,f){var g=0;p[c>>2]=a;p[f>>2]=d;d=p[c>>2];a:{while(1){if(d>>>0>=b>>>0){g=0;break a}g=2;a=p[d>>2];if(a>>>0>1114111|(a&-2048)==55296){break a}b:{c:{if(a>>>0<=127){g=1;d=p[f>>2];if((e-d|0)<1){break a}p[f>>2]=d+1;n[d|0]=a;break c}if(a>>>0<=2047){d=p[f>>2];if((e-d|0)<2){break b}p[f>>2]=d+1;n[d|0]=a>>>6|192;d=p[f>>2];p[f>>2]=d+1;n[d|0]=a&63|128;break c}d=p[f>>2];g=e-d|0;if(a>>>0<=65535){if((g|0)<3){break b}p[f>>2]=d+1;n[d|0]=a>>>12|224;d=p[f>>2];p[f>>2]=d+1;n[d|0]=a>>>6&63|128;d=p[f>>2];p[f>>2]=d+1;n[d|0]=a&63|128;break c}if((g|0)<4){break b}p[f>>2]=d+1;n[d|0]=a>>>18|240;d=p[f>>2];p[f>>2]=d+1;n[d|0]=a>>>12&63|128;d=p[f>>2];p[f>>2]=d+1;n[d|0]=a>>>6&63|128;d=p[f>>2];p[f>>2]=d+1;n[d|0]=a&63|128}d=p[c>>2]+4|0;p[c>>2]=d;continue}break}return 1}return g}function Aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=w(0),j=0,k=0,l=0,m=0,n=w(0),o=w(0),r=0,s=0,u=0,v=0;g=fb-16|0;fb=g;j=a+44|0;if(fh(j)){u=g,v=Fd(j,0),p[u+8>>2]=v;u=g,v=Fd(j,1),p[u+12>>2]=v;u=g,v=_c(j,0),p[u>>2]=v;u=g,v=_c(j,1),p[u+4>>2]=v;if(d){r=q[a+4273|0];s=q[a+4272|0];k=d;while(1){e=0;l=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=p[f>>2];p[f>>2]=e+4;f=a+h|0;m=f+4228|0;i=w(w(t[a+4236>>2]*t[m>>2])+w(t[a+4240>>2]*t[e>>2]));t[m>>2]=i;i=w(t[a+4260>>2]*qH(w(i*w(1073741824)),s,r));e=f+4244|0;n=t[a+4264>>2];f=f+4252|0;o=t[f>>2];i=w(i-w(w(t[a+4268>>2]*t[e>>2])+w(n*o)));t[f>>2]=i;t[e>>2]=o+w(i*n);e=g+h|0;h=p[e>>2];p[e>>2]=h+4;t[h>>2]=i*w(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k+ -1|0;if(k){continue}break}}Zh(a,b,c,_c(j,0),_c(j,1),d)}fb=g+16|0}function waa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;h=Lb(a);a=Lb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!r[p[f>>2]+480192>>1]){break d}b=1;while(1){c=p[f>>2];p[114610]=0;c=J(2183,c|0,b&65535)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}p[114610]=0;c=J(85,e|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}d=Pc(c);p[114610]=0;J(1251,a|0,c|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}p[114610]=0;J(1995,a|0,38756)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}i=d^1|i;pb(c);b=b+1|0;if((b&65535)>>>0<=r[p[f>>2]+480192>>1]){continue}break}if(!(i&1)){break d}p[114610]=0;J(448,h|0,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break d}b=I()|0;H()|0;break a}pb(a);fb=e+32|0;return}b=I()|0;H()|0;break a}b=I()|0;H()|0;pb(c)}pb(a);pb(h);L(b|0);E()}function vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;h=Lb(a);a=Lb(e+16|0);a:{b:{c:{d:{f=b+24|0;if(!r[p[f>>2]+480190>>1]){break d}b=1;while(1){c=p[f>>2];p[114610]=0;c=J(2184,c|0,b&65535)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}p[114610]=0;c=J(85,e|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}d=Pc(c);p[114610]=0;J(1251,a|0,c|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}p[114610]=0;J(1995,a|0,38756)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}i=d^1|i;pb(c);b=b+1|0;if((b&65535)>>>0<=r[p[f>>2]+480190>>1]){continue}break}if(!(i&1)){break d}p[114610]=0;J(448,h|0,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break d}b=I()|0;H()|0;break a}pb(a);fb=e+32|0;return}b=I()|0;H()|0;break a}b=I()|0;H()|0;pb(c)}pb(a);pb(h);L(b|0);E()}function u0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;b=fb-32|0;fb=b;d=Lb(b+16|0);p[114610]=0;c=YC(b+8|0);e=p[114610];p[114610]=0;a:{b:{c:{if((e|0)!=1){p[114610]=0;e=Ze(d);g=p[114610];p[114610]=0;if((g|0)==1){break c}g=Ib(f);h=Ib(f);f=wb(f);p[114610]=0;U(2510,c|0,e|0,g|0,(f<<2)+h|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break c}c=Ib(d);p[114610]=0;e=p[114610];p[114610]=0;if((e|0)!=1){break b}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}e=Ue(a);p[114610]=0;a=XC(b+8|0);f=p[114610];p[114610]=0;if((f|0)!=1){d:{p[114610]=0;f=Ze(e);g=p[114610];p[114610]=0;if((g|0)==1){break d}g=ve(c);p[114610]=0;U(2513,a|0,f|0,c|0,c+g|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break d}pb(d);fb=b+32|0;return}}a=I()|0;H()|0;yc(e)}pb(d);L(a|0);E()}function v6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{h=p[a+992>>2];b:{if(!h){e=p[a+4>>2];i=0;break b}m=s6(a,h);if(!m){break a}e=p[a+4>>2];if((e|0)>=1){l=(h|0)<1;while(1){if(!l){g=(f<<2)+a|0;j=g;e=0;while(1){k=p[g+800>>2]+(c+e<<2)|0;i=e<<2;t[k>>2]=w(t[m+(h+(e^-1)<<2)>>2]*t[i+p[j+928>>2]>>2])+w(t[i+m>>2]*t[k>>2]);e=e+1|0;if((h|0)!=(e|0)){continue}break}e=p[a+4>>2]}f=f+1|0;if((f|0)<(e|0)){continue}break}}i=p[a+992>>2]}l=b-d|0;p[a+992>>2]=l;if((e|0)>=1){f=0;while(1){if((b|0)>(d|0)){g=(f<<2)+a|0;j=g;e=0;k=d;while(1){p[p[j+928>>2]+(e<<2)>>2]=p[p[g+800>>2]+(k<<2)>>2];e=e+1|0;k=e+d|0;if((e|0)!=(l|0)){continue}break}e=p[a+4>>2]}f=f+1|0;if((f|0)<(e|0)){continue}break}}if(!i){break a}g=a;j=p[a+1416>>2];a=((b|0)<(d|0)?b:d)-c|0;p[g+1416>>2]=j+a;return a}return 0}function _da(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(s[b+44>>2]<s[b+24>>2]){p[b+44>>2]=p[b+24>>2]}k=-1;l=-1;h=f&24;a:{if(!h|((h|0)==24?(e|0)==1:0)){break a}h=p[b+44>>2];if(h){g=h-Ib(b+32|0)|0;m=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=p[b+12>>2]-p[b+8>>2]|0;i=e;j=e>>31;break b}e=p[b+24>>2]-p[b+20>>2]|0;i=e;j=e>>31;break b;case 0:break b;case 2:break c;default:break a}}i=m;j=g}d=d+j|0;c=c+i|0;if(c>>>0<i>>>0){d=d+1|0}e=c;c=d;if(((d|0)<0?1:(d|0)<=0?e>>>0<0:0)|((g|0)<(d|0)?1:(g|0)<=(d|0)?m>>>0<e>>>0:0)){break a}d=f&8;d:{if(!(c|e)){break d}if(p[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!p[b+24>>2]){break a}}if(d){Bm(b,p[b+8>>2],e+p[b+8>>2]|0,p[b+44>>2])}if(f&16){ow(b,p[b+20>>2],p[b+28>>2]);qr(b,e)}k=e;l=c}Bg(a,k,l)}function VI(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;n[h+15|0]=b;n[h+14|0]=10;Vf(g,q[hc(h+15|0,h+14|0)|0]);n[g+15|0]=c;n[g+16|0]=c;n[g+14|0]=e;n[g+13|0]=d;if(Bb(g)){c=0;while(1){b=v(c,3)+f|0;d=q[b|0]|q[b+1|0]<<8;i=Fb(g,c),j=d>>>4|0,o[i>>1]=j;a:{b:{if(!c){e=0;d=0;break b}d=c+ -1|0;if(r[Fb(g,c)>>1]>=r[Fb(g,d)>>1]){break a}e=c;d=r[Fb(g,d)>>1]+1|0}i=Fb(g,e),j=d,o[i>>1]=j}b=sd(q[b+2|0],0,64);i=Fb(g,c),j=b,n[i+2|0]=j;c=c+1|0;if(c>>>0<Bb(g)>>>0){continue}break}}c=q[g+12|0]&-2|a&1;n[g+12|0]=c;b=g;c:{d:{if(!(a&2)){break d}d=q[g+15|0];e=Bb(g);c=q[g+12|0];if(e>>>0<d>>>0){break d}c=c|4;break c}c=c&251}n[b+12|0]=c;b=g;e:{f:{if(!(a&4)){break f}a=q[g+13|0];if(a>>>0>q[g+14|0]){break f}d=Bb(g);c=q[g+12|0];if(d>>>0<a>>>0){break f}a=c|2;break e}a=c&253}n[b+12|0]=a;fb=h+16|0}function Jqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;p[e+8>>2]=c>>>4;p[e+4>>2]=p[a>>2];d=p[Cb(e+8|0,e+4|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){g=q[b+4|0]|q[b+5|0]<<8|(q[b+6|0]<<16|q[b+7|0]<<24);p[e+8>>2]=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);p[e+12>>2]=g;wf(e+8|0,-1,1);f=u[e+8>>3]*32768;u[e+8>>3]=f;g=a;f=Id(f);a:{if(x(f)<2147483648){h=~~f;break a}h=-2147483648}i=g,j=Mc(h),o[i>>1]=j;g=q[b+12|0]|q[b+13|0]<<8|(q[b+14|0]<<16|q[b+15|0]<<24);p[e+8>>2]=q[b+8|0]|q[b+9|0]<<8|(q[b+10|0]<<16|q[b+11|0]<<24);p[e+12>>2]=g;wf(e+8|0,-1,1);f=u[e+8>>3]*32768;u[e+8>>3]=f;g=a;f=Id(f);b:{if(x(f)<2147483648){h=~~f;break b}h=-2147483648}i=g,j=Mc(h),o[i+2>>1]=j;a=a+4|0;b=b+16|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<4}function Qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=_h(a,b,c,d);p[a+4260>>2]=0;p[a>>2]=81568;c=a+4960|0;e=a+4504|0;b=e;while(1){Pj(b);b=b+24|0;if((c|0)!=(b|0)){continue}break}n[a+5046|0]=1;o[a+5044>>1]=0;p[a+4208>>2]=1063675494;p[a+4212>>2]=1065185444;p[a+4256>>2]=1059760811;b=a+4248|0;p[b>>2]=1065353216;p[b+4>>2]=1048525618;b=a+4240|0;p[b>>2]=1038174126;p[b+4>>2]=1065353216;b=a+4232|0;p[b>>2]=1047457519;p[b+4>>2]=1062836634;b=a+4224|0;p[b>>2]=1053079357;p[b+4>>2]=1059859440;b=a+4216|0;p[b>>2]=0;p[b+4>>2]=1032805417;p[114610]=0;P(1639,a+44|0,2,2)|0;b=p[114610];p[114610]=0;a:{if((b|0)!=1){p[114610]=0;S(1640,d|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;while(1){c=c+ -24|0;Ef(c);if((c|0)!=(e|0)){continue}break}Ge(d);L(a|0);E()}return a|0}function Jwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;i=p[a+40>>2];j=p[a+36>>2];k=p[a+16>>2];b=p[a+4>>2];h=b;f=p[a>>2];p[e+24>>2]=f;p[e+28>>2]=b;b=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=b;a:{if(!d){g=i>>12;b=j>>12;break a}while(1){l=f>>>18|0;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=n[h+g|0]<<8;p[(e+8|0)+(g<<2)>>2]=((v((n[(g|2)+h|0]<<8)-f|0,l)|0)/16384|0)+f;f=b;b=0;g=1;if(f){continue}break}f=p[a+32>>2];j=p[a+28>>2]+j|0;b=j>>12;p[c>>2]=p[c>>2]+v(b,p[e+8>>2]);i=f+i|0;g=i>>12;p[c+4>>2]=p[c+4>>2]+v(g,p[e+12>>2]);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;f=p[e+24>>2];h=p[e+28>>2];continue}break}f=p[e+24>>2];h=p[e+28>>2]}p[a+40>>2]=i;p[a+20>>2]=b;p[a+36>>2]=j;p[a+24>>2]=g;p[a>>2]=f;p[a+4>>2]=h;fb=e+32|0}function VE(a){var b=0,c=0,d=0,f=0;b=fb-16|0;fb=b;f=(i(a),e(2));c=f&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=qh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((f|0)<=-1){a=w(-ph(d+1.5707963267948966));break a}a=ph(d+ -1.5707963267948966);break a}a=qh(-(((f|0)>-1?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((f|0)<=-1){a=ph(d+4.71238898038469);break a}a=w(-ph(d+ -4.71238898038469));break a}a=qh(((f|0)>-1?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=w(a-a);break a}b:{switch(Fv(a,b+8|0)&3){case 0:a=qh(u[b+8>>3]);break a;case 1:a=ph(u[b+8>>3]);break a;case 2:a=qh(-u[b+8>>3]);break a;default:break b}}a=w(-ph(u[b+8>>3]))}fb=b+16|0;return a}function St(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;n[f+15|0]=d;n[b+12|0]=q[a|0]&15|q[b+12|0]&240;g=a+1|0;Vf(b,q[hc(g,f+15|0)|0]);d=q[hc(a+2|0,f+15|0)|0];n[b+13|0]=d;j=b,k=sd(q[a+3|0],d,q[f+15|0]),n[j+14|0]=k;d=q[hc(a+4|0,f+15|0)|0];n[b+15|0]=d;j=b,k=sd(q[a+5|0],d,q[f+15|0]),n[j+16|0]=k;n[f+14|0]=25;if(q[hc(f+14|0,g)|0]){d=0;while(1){e=v(d,3)+a|0;h=Pb(q[e+6|0]+c<<24>>24,0,64);j=Fb(b,d),k=h,n[j+2|0]=k;e=e+7|0;e=q[e|0]|q[e+1|0]<<8;j=Fb(b,d),k=e,o[j>>1]=k;a:{if(!d){break a}e=d+ -1|0;if(r[Fb(b,d)>>1]>=r[Fb(b,e)>>1]){break a}if(r[Fb(b,d)>>1]>255){break a}h=q[Fb(b,e)+1|0];i=Fb(b,d);o[i>>1]=r[i>>1]|h<<8;if(r[Fb(b,d)>>1]>=r[Fb(b,e)>>1]){break a}e=Fb(b,d);o[e>>1]=r[e>>1]+256}n[f+14|0]=25;d=d+1|0;if(d>>>0<q[hc(f+14|0,g)|0]){continue}break}}fb=f+16|0}function xK(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{if(p[a+480180>>2]==4){d=q[b+833|0];if(c){n[b+833|0]=d&240|c&15;break a}c=d&15;break a}if(p[a+480180>>2]!=1048576){break a}if(c){n[b+833|0]=c;break a}c=q[b+833|0]}b:{c:{if(!(n[b+872|0]&1)|!(c&255)){break c}d=p[b+700>>2];if(!d){break c}if(!(q[a+480208|0]&16)){break b}d=p[b+700>>2];if(p[a+480180>>2]==4){break b}c=wx(a,c&15);f=NNa(c,c>>31,d,d>>31)+32768|0;c=ib;c=rc(ONa(f,f>>>0<32768?c+1|0:c,65536,0),ib);p[b+700>>2]=c;if((c|0)!=(d|0)){break c}a=a+1074308|0;vb(e+8|0,a,7);if(!(tb(e+8|0)|p[b+700>>2]>=2147483647)){p[b+700>>2]=p[b+700>>2]+1;break c}vb(e+8|0,a,7);if(!tb(e+8|0)){break c}a=p[b+700>>2];if((a|0)<2){break c}p[b+700>>2]=a+ -1}fb=e+16|0;return}a=((c&255)<<2)+d|0;p[b+700>>2]=(a|0)<65535?a:65535;fb=e+16|0}function hma(a,b,c,d){var e=0,f=0;e=1;b=+(a|0)-b;f=b+ -3.5;if(!(x(f)<1e-8)){a:{b:{switch(d|0){case 0:e=.5-qe(.8975979010256552*b)*.5;break a;case 1:e=qe(.8975979010256552*b)*-.46+.54;break a;case 2:b=.8975979010256552*b;e=qe(b+b);e=qe(b)*-.5+.42+e*.08;break a;case 3:b=.8975979010256552*b;e=qe(b+b);e=qe(b)*-.49364+.44959+e*.05677;break a;case 4:b=.8975979010256552*b;e=qe(b+b);e=qe(b)*-.49755+.42323+e*.07922;break a;case 5:b=.8975979010256552*b;e=qe(b+b);e=qe(b)*-.48829+.35875+e*.14128+qe(b*3)*-.01168;break a;case 6:b=.8975979010256552*b;e=qe(b+b);e=qe(b)*-.49703+.40217+e*.09392+qe(b*3)*-.00183;break a;case 7:break b;default:break a}}b=.8975979010256552*b;e=qe(b+b);e=qe(b)*-.49804+.40243+e*.09831+qe(b*3)*-.00122}b=f*3.141592653589793;c=Sh(b*c)/b}return c*e}function _Aa(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;vd(b,0);o[d+14>>1]=q[a+35|0]<<2;o[d+12>>1]=256;e=b,f=r[rf(d+14|0,d+12|0)>>1],o[e+30>>1]=f;c=a+22|0;a:{if((q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))>>>0<3){break a}p[b>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+26|0;p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+30|0;p[d+8>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[d+4>>2]=1;e=b,f=p[Uc(d+8|0,d+4|0)>>2]+ -1|0,p[e+8>>2]=f;vc(b+8|0,p[b>>2]);b:{if(p[b+4>>2]+4>>>0>=s[b+8>>2]){p[b+4>>2]=0;p[b+8>>2]=0;break b}o[b+34>>1]=r[b+34>>1]|2}c=a+34|0;n[b+37|0]=q[c|0];e=b,f=ss(0,n[c|0]<<4),p[e+24>>2]=f;if(!(n[a+36|0]&1)){break a}o[b+34>>1]=r[b+34>>1]|1;p[b>>2]=p[b>>2]>>>1;p[b+4>>2]=p[b+4>>2]>>>1;p[b+8>>2]=p[b+8>>2]>>>1}fb=d+16|0}function wJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;g=-1;a:{if(!dx(a,b,2)){break a}h=p[b+656>>2];f=a+1074308|0;vb(e+8|0,f,31);b:{if(tb(e+8|0)){d=p[b+752>>2];if(d){break b}break a}d=p[b+752>>2]}vb(e+8|0,f,31);f=d-tb(e+8|0)|0;d=p[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=Zo(h+88|0,f,d,p[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(q[b+748|0]&16){g=Oo(a,b,!(p[b+88>>2]&32768),d);break a}if(dj(b)){if((d|0)==p[b+768>>2]){break a}p[b+768>>2]=d;n[b+872|0]=q[b+872|0]|8;break a}b=Go(a);p[e+8>>2]=d;f=c;c:{if((d|0)<=-1){p[e+8>>2]=0-d;fk(e+8|0,255);a=(p[e+8>>2]<<2)+(b?26272:25248)|0;break c}fk(e+8|0,255);a=(p[e+8>>2]<<2)+(b?25248:26272)|0}a=p[a>>2];b=a;d=a>>31;a=p[c>>2];i=f,j=rc(ONa(NNa(b,d,a,a>>31),ib,65536,0),ib),p[i>>2]=j}fb=e+16|0;return g}function mF(a){var b=w(0),c=w(0),d=w(0),e=w(0),f=w(0),g=w(0),h=w(0),i=w(0),j=w(0),k=w(0),l=w(0),m=w(0),n=w(0),o=w(0);b=t[a+32>>2];c=t[a+8>>2];e=t[a+16>>2];f=w(w(b-c)+e);i=t[a>>2];j=t[a+24>>2];k=w(i-j);t[a+16>>2]=f+k;d=t[a+4>>2];g=t[a+20>>2];h=t[a+28>>2];l=w(w(d-w(g+h))*w(.8660253882408142));k=w(k-w(f*w(.5)));t[a+4>>2]=l+k;m=w(w(g+d)*w(.9848077297210693));f=w(t[a+12>>2]*w(.8660253882408142));n=w(w(h+d)*w(-.6427876353263855));o=w(w(m-f)+n);d=w(i+w(j*w(.5)));i=w(w(b+c)*w(.7660444378852844));b=w(w(e-b)*w(.1736481785774231));j=w(w(d-i)+b);t[a+12>>2]=o+j;t[a+20>>2]=j-o;t[a+28>>2]=k-l;g=w(w(g-h)*w(.3420201539993286));h=w(g-w(f+m));c=w(w(e+c)*w(.9396926164627075));b=w(w(d+c)-b);t[a+32>>2]=h+b;e=w(w(g+f)+n);c=w(w(d-c)+i);t[a+24>>2]=e+c;t[a+8>>2]=c-e;t[a>>2]=b-h}function wwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0;e=fb-32|0;fb=e;i=p[a+24>>2];j=p[a+20>>2];k=p[a+16>>2];g=p[a+4>>2];b=g;f=p[a>>2];p[e+24>>2]=f;p[e+28>>2]=b;g=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=(f>>>21&2040)+27824|0;l=o[b+6>>1];m=o[b+4>>1];n=o[b+2>>1];q=o[b>>1];h=0;b=1;while(1){f=h<<1;p[(e+8|0)+(h<<2)>>2]=(((v(o[f+g>>1],n)+v(o[(f|-4)+g>>1],q)|0)+v(o[(f|4)+g>>1],m)|0)+v(o[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],j);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],i);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;f=p[e+24>>2];b=p[e+28>>2];continue}break}f=p[e+24>>2];b=p[e+28>>2]}p[a>>2]=f;p[a+4>>2]=b;fb=e+32|0}function _9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;g=Xg(a);f=b+24|0;a=r[p[f>>2]+480190>>1];p[114610]=0;K(1532,g|0,a|0);a=p[114610];p[114610]=0;a:{if((a|0)!=1){b:{c:{d:{e:{if(r[p[f>>2]+480190>>1]){a=1;while(1){d=p[f>>2];p[114610]=0;d=J(2184,d|0,a&65535)|0;e=p[114610];p[114610]=0;if((e|0)==1){break e}p[114610]=0;d=J(85,c|0,d|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break e}p[114610]=0;N(2185,c+16|0,b|0,d|0);e=p[114610];p[114610]=0;if((e|0)==1){break d}p[114610]=0;K(1534,g|0,c+16|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}pb(c+16|0);pb(d);a=a+1|0;if((a&65535)>>>0<=r[p[f>>2]+480190>>1]){continue}break}}fb=c+32|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;pb(c+16|0)}pb(d);break a}a=I()|0;H()|0}bd(g);L(a|0);E()}function Mqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=w(0),h=0,i=0,j=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>3;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){f=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);p[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);Td(e+12|0,w(-1));g=w(t[e+12>>2]*w(32768));t[e+12>>2]=g;f=a;g=$d(g);a:{if(w(x(g))<w(2147483648)){h=~~g;break a}h=-2147483648}i=f,j=Mc(h),o[i>>1]=j;f=q[b+4|0]|q[b+5|0]<<8|(q[b+6|0]<<16|q[b+7|0]<<24);p[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);Td(e+12|0,w(-1));g=w(t[e+12>>2]*w(32768));t[e+12>>2]=g;f=a;g=$d(g);b:{if(w(x(g))<w(2147483648)){h=~~g;break b}h=-2147483648}i=f,j=Mc(h),o[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<3}function $9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;g=Xg(a);f=b+24|0;a=r[p[f>>2]+480192>>1];p[114610]=0;K(1532,g|0,a|0);a=p[114610];p[114610]=0;a:{if((a|0)!=1){b:{c:{d:{e:{if(r[p[f>>2]+480192>>1]){a=1;while(1){d=p[f>>2];p[114610]=0;d=J(2183,d|0,a&65535)|0;e=p[114610];p[114610]=0;if((e|0)==1){break e}p[114610]=0;d=J(85,c|0,d|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break e}p[114610]=0;N(2185,c+16|0,b|0,d|0);e=p[114610];p[114610]=0;if((e|0)==1){break d}p[114610]=0;K(1534,g|0,c+16|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}pb(c+16|0);pb(d);a=a+1|0;if((a&65535)>>>0<=r[p[f>>2]+480192>>1]){continue}break}}fb=c+32|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;pb(c+16|0)}pb(d);break a}a=I()|0;H()|0}bd(g);L(a|0);E()}function y0(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=bD(c);b:{if(b){xj(k,a);b=p[k>>2];n[d|0]=b;n[d+1|0]=b>>>8;n[d+2|0]=b>>>16;n[d+3|0]=b>>>24;wj(k,a);break b}xq(k,a);b=p[k>>2];n[d|0]=b;n[d+1|0]=b>>>8;n[d+2|0]=b>>>16;n[d+3|0]=b>>>24;Pg(k,a)}Lh(i,k);yc(k);l=e,m=Ph(a),p[l>>2]=m;l=f,m=Oh(a),p[l>>2]=m;Zf(k,a);xb(g,k);pb(k);Qg(k,a);Lh(h,k);yc(k);a=vj(a);break a}a=aD(c);c:{if(b){xj(k,a);b=p[k>>2];n[d|0]=b;n[d+1|0]=b>>>8;n[d+2|0]=b>>>16;n[d+3|0]=b>>>24;wj(k,a);break c}xq(k,a);b=p[k>>2];n[d|0]=b;n[d+1|0]=b>>>8;n[d+2|0]=b>>>16;n[d+3|0]=b>>>24;Pg(k,a)}Lh(i,k);yc(k);l=e,m=Ph(a),p[l>>2]=m;l=f,m=Oh(a),p[l>>2]=m;Zf(k,a);xb(g,k);pb(k);Qg(k,a);Lh(h,k);yc(k);a=vj(a)}p[j>>2]=a;fb=k+16|0}function Hqa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;m=i,n=v(p[a>>2],le(a)),p[m+12>>2]=n;vc(i+12|0,c);c=ub(b);h=p[e+4>>2];f=p[i+12>>2];a:{if(!f){g=h;break a}while(1){e=ub(q[c|0]);e=ub(q[c+1|0])<<16|e<<8|ub(q[c+2|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+3|0;h=g;f=f+ -1|0;if(f){continue}break}}c:{if(!g){break c}e=p[i+12>>2];if(!e){break c}j=g+ -1|0;k=g>>>1|0;l=g;c=p[a+20>>2];while(1){a=ub(q[b|0]);a=ub(q[b+1|0])<<16|a<<8|ub(q[b+2|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=k|f<<31;a=j&a>>31;m=c,n=rc(ONa(f-a|0,h-(f>>>0<a>>>0)|0,l,0),ib)>>>16|0,o[m>>1]=n;b=b+3|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){p[d>>2]=g}fb=i+16|0;return p[i+12>>2]}function Gqa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;m=i,n=v(p[a>>2],le(a)),p[m+12>>2]=n;vc(i+12|0,c);c=ub(b);h=p[e+4>>2];f=p[i+12>>2];a:{if(!f){g=h;break a}while(1){e=ub(q[c+2|0]);e=ub(q[c+1|0])<<16|e<<8|ub(q[c|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+3|0;h=g;f=f+ -1|0;if(f){continue}break}}c:{if(!g){break c}e=p[i+12>>2];if(!e){break c}j=g+ -1|0;k=g>>>1|0;l=g;c=p[a+20>>2];while(1){a=ub(q[b+2|0]);a=ub(q[b+1|0])<<16|a<<8|ub(q[b|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=k|f<<31;a=j&a>>31;m=c,n=rc(ONa(f-a|0,h-(f>>>0<a>>>0)|0,l,0),ib)>>>16|0,o[m>>1]=n;b=b+3|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){p[d>>2]=g}fb=i+16|0;return p[i+12>>2]}function Tja(a,b,c){var d=0,e=0,f=w(0),g=0,h=0,i=0;a:{if(c){g=p[a+36>>2];if(g){break a}}return dl(a,b+c<<16>>16)}d=g+1|0;b:{if((c|0)>=0){e=c;c=(c|0)/(d|0)|0;e=e-v(d,c)|0;break b}e=g-((c^-1)%(d|0)|0)|0;c=((c+1|0)/(d|0)|0)+ -1|0}i=o[a+28>>1];h=a+4|0;Bb(h);f=w(1);c=b+c<<16>>16;c:{if((i|0)>(c|0)){break c}if((r[a+28>>1]+Bb(h)<<16)+ -65536>>16<(c|0)){break c}if(!e){return t[Fb(h,c-o[a+28>>1]|0)>>2]}b=r[a>>1];d:{if((b|0)==3){b=a+16|0;if(Bb(b)){f=t[Fb(b,e+ -1|0)>>2];break d}b=r[a>>1]}e:{if((b&65535)!=1){break e}b=a+16|0;if(!Bb(b)){break e}d=r[a+30>>1];if((c|0)>=0){d=(c|0)%(d|0)|0}else{d=d+((c^-1)%(d|0)^-1)|0}f=t[Fb(b,(v(d<<16>>16,g)+e|0)+ -1|0)>>2];break d}f=fe(w(dl(a,(c<<16)+65536>>16)/dl(a,c)),w(w(e|0)/w(d|0)))}f=w(t[Fb(h,c-o[a+28>>1]|0)>>2]*f)}return f}function Rma(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;c=78880;g=Qma(e+32|0);a=Xc(a);while(1){if(p[c>>2]==(b|0)){f=p[c+4>>2];p[114610]=0;f=J(2,e+16|0,f|0)|0;d=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{if((d|0)!=1){p[114610]=0;N(1520,e|0,g|0,f|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}if(!q[e+4|0]){break a}if(!Pc(a)){p[114610]=0;d=J(2,e|0,20752)|0;h=p[114610];p[114610]=0;if((h|0)==1){break f}p[114610]=0;J(192,a|0,d|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break e}pb(d)}p[114610]=0;J(192,a|0,f|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break a}c=I()|0;H()|0;break c}c=I()|0;H()|0;break b}c=I()|0;H()|0;break c}c=I()|0;H()|0;pb(d);break c}c=I()|0;H()|0}pb(f)}pb(a);lJ(g);L(c|0);E()}pb(f)}c=c+12|0;if((c|0)!=78928){continue}break}lJ(g);fb=e+48|0}function Nm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=p[b+88>>2];d=c|2048;p[b+88>>2]=d;e=p[b+656>>2];if(!(!e|n[b+724|0]&1)){d=c|6144;p[b+88>>2]=d}a:{if(!p[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=p[b+104>>2];if(!c){break b}f=r[c+34>>1];if(f&2){p[b+88>>2]=(f&4?d|4:d&-135)|2;d=p[c>>2];p[b+76>>2]=d;f=p[c+4>>2];p[b+80>>2]=f;c=p[c+8>>2];p[b+84>>2]=c;if(d>>>0>c>>>0){p[b+76>>2]=c;d=c}g=d;d=p[b+4>>2];if(g>>>0>=d>>>0){break b}p[b>>2]=0;p[b+4>>2]=f+((d-f>>>0)%(c-f>>>0)|0);break b}p[b+88>>2]=d&-135;p[b+76>>2]=p[c>>2]}if(!e){break a}if(!(!p[e>>2]|(p[a+480180>>2]&1064964?0:!(q[e+60|0]&2)))){p[b+88>>2]=p[b+88>>2]|4096}if(q[e+65|0]==255|p[b+732>>2]!=-1){break a}a=e+48|0;h=b,i=Zo(a,p[b+728>>2],256,64),p[h+732>>2]=i;h=b,i=r[Fb(a,q[e+65|0])>>1],p[h+728>>2]=i}}function eH(a){var b=0,c=0,d=0,e=0,f=0,g=w(0),h=0,i=0,j=0,k=0,l=0,m=0,n=w(0);c=He(p[a+16>>2]);g=w(w(t[a+4220>>2]*w(.9980000257492065))+w(.0010000000474974513));d=-9965.784284662086/+w(w(w(t[a+4216>>2]*w(2999.9990234375))+w(.0010000000474974513))*w(c>>>0));m=a,n=w(Kg(d*+s[a+4288>>2])),t[m+4232>>2]=n;m=a+4236|0,n=w(Kg(d*+s[a+4292>>2])),t[m>>2]=n;l=d*(1/+g+ -1);c=0;h=a+4272|0;i=a+4232|0;while(1){j=p[(c<<2)+h>>2];e=c<<1&-4;f=Kg(l*+(j+p[(e+h|0)+16>>2]>>>0));b=Kg(d*+(j>>>0));g=t[e+i>>2];e=(c<<3)+i|0;f=f*.5;t[e+12>>2]=b*(.5-f);t[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;k=b*b+k;c=c+1|0;if((c|0)!=4){continue}break}d=Kg(+dH(t[a+4208>>2])*.16609640474436813);b=Kg(+dH(t[a+4212>>2])*.33219280948873625);t[a+4228>>2]=d*4*D(b)/D(k);t[a+4224>>2]=d*D(1-b)}function Rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;vd(c,0);o[c+28>>1]=q[a+36|0]<<2;d=q[a+37|0];o[c+32>>1]=64;o[c+30>>1]=d<<2;d=a+40|0;p[c>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=a+44|0;p[c+4>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=a+48|0;p[c+8>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=a+52|0;p[c+24>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=b+151|0;if(5>q[d|0]){n[c+38|0]=q[q[d|0]+31786|0]}n[c+39|0]=q[b+152|0];d=b+156|0;n[c+41|0]=(q[d|0]|q[d+1|0]<<8)>>>4;b=b+154|0;b=(q[b|0]|q[b+1|0]<<8)>>>2|0;n[c+40|0]=b;if(q[c+41|0]|b&255){n[c+39|0]=q[c+39|0]^-1}a=a+38|0;if(q[a|0]&4){o[c+34>>1]=r[c+34>>1]|1}if(q[a|0]&8){o[c+34>>1]=r[c+34>>1]|2}if(q[a|0]&16){o[c+34>>1]=r[c+34>>1]|4}if(q[a|0]&32){o[c+34>>1]=r[c+34>>1]|32}}function C0(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=fD(c);b:{if(b){xj(k,a);b=p[k>>2];n[d|0]=b;n[d+1|0]=b>>>8;n[d+2|0]=b>>>16;n[d+3|0]=b>>>24;wj(k,a);break b}xq(k,a);b=p[k>>2];n[d|0]=b;n[d+1|0]=b>>>8;n[d+2|0]=b>>>16;n[d+3|0]=b>>>24;Pg(k,a)}xb(i,k);pb(k);l=e,m=Ph(a),n[l|0]=m;l=f,m=Oh(a),n[l|0]=m;Zf(k,a);xb(g,k);pb(k);Qg(k,a);xb(h,k);pb(k);a=vj(a);break a}a=eD(c);c:{if(b){xj(k,a);b=p[k>>2];n[d|0]=b;n[d+1|0]=b>>>8;n[d+2|0]=b>>>16;n[d+3|0]=b>>>24;wj(k,a);break c}xq(k,a);b=p[k>>2];n[d|0]=b;n[d+1|0]=b>>>8;n[d+2|0]=b>>>16;n[d+3|0]=b>>>24;Pg(k,a)}xb(i,k);pb(k);l=e,m=Ph(a),n[l|0]=m;l=f,m=Oh(a),n[l|0]=m;Zf(k,a);xb(g,k);pb(k);Qg(k,a);xb(h,k);pb(k);a=vj(a)}p[j>>2]=a;fb=k+16|0}function gw(a,b,c,d,e,f){var g=0,h=0,i=w(0),j=0;g=fb-96|0;fb=g;h=a+24|0;xo(p[h>>2]);n[p[h>>2]+1304512|0]=p[a+52>>2]!=0;p[g+92>>2]=f;p[g+88>>2]=e;p[g+84>>2]=d;p[g+80>>2]=c;c=yG(g+32|0,g+80|0,zG(g+80|0),b);d=p[a+32>>2];i=t[a+48>>2];e=p[c+12>>2];p[g+8>>2]=p[c+8>>2];p[g+12>>2]=e;e=p[c+4>>2];p[g>>2]=p[c>>2];p[g+4>>2]=e;d=uba(g+48|0,g,d,i);e=0;a:{while(1){if(b){c=p[h>>2];p[g+24>>2]=b;p[g+28>>2]=0;p[114610]=0;p[g+16>>2]=134217727;p[g+20>>2]=0;f=J(2153,g+24|0,g+16|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break a}f=p[f>>2];p[114610]=0;c=P(2154,c|0,f|0,d|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}e=c+e|0;b=b-c|0;if(c){continue}}break}if(!(p[a+52>>2]!=1|e)){a=p[h>>2];p[a+480208>>2]=p[a+480208>>2]&-513}fb=g+96|0;return e}a=I()|0;H()|0;L(a|0);E()}function fw(a,b,c,d,e,f){var g=0,h=0,i=w(0),j=0;g=fb-96|0;fb=g;h=a+24|0;xo(p[h>>2]);n[p[h>>2]+1304512|0]=p[a+52>>2]!=0;p[g+92>>2]=f;p[g+88>>2]=e;p[g+84>>2]=d;p[g+80>>2]=c;c=yG(g+32|0,g+80|0,zG(g+80|0),b);d=p[a+32>>2];i=t[a+48>>2];e=p[c+12>>2];p[g+8>>2]=p[c+8>>2];p[g+12>>2]=e;e=p[c+4>>2];p[g>>2]=p[c>>2];p[g+4>>2]=e;d=rba(g+48|0,g,d,i);e=0;a:{while(1){if(b){c=p[h>>2];p[g+24>>2]=b;p[g+28>>2]=0;p[114610]=0;p[g+16>>2]=134217727;p[g+20>>2]=0;f=J(2153,g+24|0,g+16|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break a}f=p[f>>2];p[114610]=0;c=P(2154,c|0,f|0,d|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}e=c+e|0;b=b-c|0;if(c){continue}}break}if(!(p[a+52>>2]!=1|e)){a=p[h>>2];p[a+480208>>2]=p[a+480208>>2]&-513}fb=g+96|0;return e}a=I()|0;H()|0;L(a|0);E()}function Z8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-80|0;fb=d;a=p[a+4>>2];ku(d+16|0,b);p[114610]=0;b=J(2,d|0,38541)|0;e=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){p[114610]=0;N(3,d+32|0,d+16|0,b|0);e=p[114610];p[114610]=0;if((e|0)==1){break h}p[114610]=0;N(723,d+48|0,d+32|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break g}p[114610]=0;N(9,d- -64|0,0,d+48|0);c=p[114610];p[114610]=0;if((c|0)==1){break f}c=p[p[a>>2]+8>>2];p[114610]=0;K(c|0,a|0,d- -64|0);a=p[114610];p[114610]=0;if((a|0)==1){break e}pb(d- -64|0);pb(d+48|0);pb(d+32|0);pb(b);pb(d+16|0);fb=d+80|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;break c}a=I()|0;H()|0;break d}a=I()|0;H()|0;pb(d- -64|0)}pb(d+48|0)}pb(d+32|0)}pb(b)}pb(d+16|0);L(a|0);E()}function Ux(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{g=nta(a,b);if((g|0)==255){break a}b=0;if(aj(a)){break a}e=ti(a+314|0,g);d=q[c+8|0]|q[c+9|0]<<8|(q[c+10|0]<<16|q[c+11|0]<<24);n[e+8|0]=d;n[e+9|0]=d>>>8;n[e+10|0]=d>>>16;n[e+11|0]=d>>>24;d=q[c+4|0]|q[c+5|0]<<8|(q[c+6|0]<<16|q[c+7|0]<<24);f=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);n[e|0]=f;n[e+1|0]=f>>>8;n[e+2|0]=f>>>16;n[e+3|0]=f>>>24;n[e+4|0]=d;n[e+5|0]=d>>>8;n[e+6|0]=d>>>16;n[e+7|0]=d>>>24;f=QL(g);h=f+3|0;d=1;while(1){e=d;d=d?f:h;Yg(p[a>>2],(d|32)&65535,q[Yb(c,b)|0]);Yg(p[a>>2],(d|64)&65535,q[Yb(c,b|2)|0]);Yg(p[a>>2],(d|96)&65535,q[Yb(c,b|4)|0]);Yg(p[a>>2],(d|128)&65535,q[Yb(c,b|6)|0]);Yg(p[a>>2],(d|224)&65535,q[Yb(c,b|8)|0]);d=0;b=1;if(e){continue}break}Yg(p[a>>2],ms(g)|192,q[Yb(c,10)|0])}}function Sw(a){a=a|0;var b=0;a:{b:{c:{if(q[a+3|0]!=19){break c}n[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=q[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}n[a+3|0]=2;break a}n[a+3|0]=3;break a}n[a+5|0]=b&15|16;return}n[a+5|0]=b&3|48;return}n[a+5|0]=b&15|32;return}n[a+5|0]=b&15|176;return}n[a+5|0]=b&3|64;return}n[a+3|0]=15;n[a+5|0]=b&15;return}if(b&15){n[a+3|0]=11;n[a+5|0]=b<<4|15;return}break b}if(b&15){n[a+3|0]=11;break a}break b}if((b|0)!=192){break c}n[a|0]=254;break b}if((b|0)!=208){break c}n[a+3|0]=0}return}n[a+3|0]=0;return}n[a+5|0]=b|240}function Cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-80|0;fb=c;h=GL(a,1<<b+ -1);p[a+12>>2]=b;a:{b=1<<b;f=b>>>2|0;if(f){i=1/+(b>>>0);b=f;e=1;while(1){p[114610]=0;u[c+40>>3]=+(b>>>0)*-6.283185307179586*i;N(1529,c+48|0,30808,c+40|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;K(1220,c- -64|0,c+48|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=jc(h,e);g=p[c+76>>2];p[d+8>>2]=p[c+72>>2];p[d+12>>2]=g;g=p[c+68>>2];p[d>>2]=p[c+64>>2];p[d+4>>2]=g;e=e<<1;b=b>>>1|0;if(b){continue}break}}b=ol(c+24|0,1,0);p[114610]=0;e=p[b+12>>2];p[c+16>>2]=p[b+8>>2];p[c+20>>2]=e;e=p[b+4>>2];p[c+8>>2]=p[b>>2];p[c+12>>2]=e;Q(1530,a|0,0,f|0,c+8|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}fb=c+80|0;return a|0}a=I()|0;H()|0;Qo(h);L(a|0);E()}function Uxa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;if(!(q[b+5|0]|q[b+3|0]!=4)){Wd(d+8|0,a,r[a+14>>1]);Zd(d+8|0,0);n[b+3|0]=0}c=q[b+2|0];a:{if((c|0)!=11){break a}c=11;if(q[b+4|0]){break a}Wd(d+8|0,a,r[a+14>>1]);c=0;Zd(d+8|0,0);n[b+2|0]=0}b:{c:{d:{if(!q[b|0]){Wd(d+8|0,a,r[a+14>>1]);if(tb(d+8|0)){break d}c=q[b+2|0]}e=q[b+3|0];Wd(d+8|0,a,r[a+14>>1]);Zd(d+8|0,(e|0)==4|(c|0)==11);c=q[b+3|0];break c}c=q[b+3|0];e=q[b+2|0];if(!(c|(e|0)==11)){n[b+5|0]=0;n[b+3|0]=4;break b}if(e|(c|0)==4){break c}n[b+4|0]=0;n[b+2|0]=11}e:{if(!(!q[a+16|0]|c)){n[b+5|0]=125;n[b+3|0]=17;break e}f:{switch(c+ -16|0){case 0:break f;case 1:break e;default:break b}}if(q[b+5|0]){break b}n[b+5|0]=6;n[a+16|0]=1;break b}n[a+16|0]=0}o[a+14>>1]=(r[a+14>>1]+1>>>0)%r[a+12>>1];fb=d+16|0}function eo(a){var b=0,c=0,d=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{h(+a);b=e(1)|0;d=e(0)|0;if((b|0)>0?1:(b|0)>=0?d>>>0>=0:0){j=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>-1){break c}return(a-a)/0}if(j>>>0>2146435071){break a}b=1072693248;k=-1023;if((j|0)!=1072693248){b=j;break b}if(d){break b}return 0}h(+(a*0x40000000000000));b=e(1)|0;d=e(0)|0;k=-1077}b=b+614242|0;i=+((b>>>20|0)+k|0);f(0,d|0);f(1,(b&1048575)+1072079006|0);a=+g()+ -1;c=a/(a+2);l=i*.6931471803691238;m=a;n=i*1.9082149292705877e-10;o=c;i=a*(a*.5);c=c*c;a=c*c;a=l+(m+(n+o*(i+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-i))}return a}function aIa(a,b){var c=0,d=0;d=fb-32|0;fb=d;vd(b,0);yi(d,1,a);zc(d+16|0,d);p[114610]=0;J(370,b+43|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(d+16|0);c=a+16|0;p[b>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+20|0;p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+24|0;p[b+8>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+28|0;p[b+24>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);o[b+30>>1]=q[a+32|0]<<2;o[b+28>>1]=q[a+33|0];a=a+48|0;if(n[a|0]&1){o[b+34>>1]=r[b+34>>1]|2}if(q[a|0]&2){o[b+34>>1]=r[b+34>>1]|4}if(q[a|0]&4){o[b+34>>1]=r[b+34>>1]|1;p[b>>2]=p[b>>2]>>>1;p[b+4>>2]=p[b+4>>2]>>>1;p[b+8>>2]=p[b+8>>2]>>>1}if(q[a|0]&8){o[b+34>>1]=r[b+34>>1]|32}fb=d+32|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function J5(a,b){var c=0,d=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=fb-32|0;fb=d;h(+a);k=e(1)|0;n=e(0)|0;h(+b);j=e(1)|0;o=e(0)|0;m=k&2147483647;i=m;p=j&2147483647;j=p;l=(i|0)==(j|0)&n>>>0<o>>>0|i>>>0<j>>>0;k=l?n:o;i=l?i:j;q=i;f(0,k|0);f(1,i|0);a=+g();j=i>>>20|0;c=a;a:{if((j|0)==2047){break a}m=l?p:m;i=m;f(0,(l?o:n)|0);f(1,i|0);b=+g();b:{if(!(k|q)){break b}k=i>>>20|0;if((k|0)==2047){break b}c=b+a;if((k-j|0)>=65){break a}c:{if(k>>>0>=1534){a=a*1.90109156629516e-211;b=b*1.90109156629516e-211;c=5.260135901548374e+210;break c}c=1;if(j>>>0>572){break c}a=a*5.260135901548374e+210;b=b*5.260135901548374e+210;c=1.90109156629516e-211}SE(d+24|0,d+16|0,b);SE(d+8|0,d,a);c=c*D(u[d>>3]+u[d+16>>3]+u[d+8>>3]+u[d+24>>3]);break a}c=b}a=c;fb=d+32|0;return a}function Bza(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;f=Lb(a+4|0);d=wza(a+16|0);n[a+20|0]=0;g=pza(a+24|0);p[114610]=0;S(80,c+8|0);b=p[114610];p[114610]=0;a:{b:{c:{if((b|0)!=1){fN(d,Cd(c+8|0));ny(c+8|0);n[a+20|0]=0;b=0;break c}b=wa(71348,71324)|0;e=H()|0;if((e|0)==($(71348)|0)){T(b|0)|0;p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)==1){b=I()|0;H()|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)!=1){break b}a=O(0)|0;H()|0;rb(a)}E()}if(($(71324)|0)!=(e|0)){break b}T(b|0)|0;n[a+20|0]=0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){b=I()|0;H()|0;break b}b=q[a+20|0]}if(b&255){break a}p[114610]=0;S(82,a|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}b=I()|0;H()|0}gg(g);ny(d);pb(f);L(b|0);E()}fb=c+16|0;return a|0}function Xza(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;vd(b,0);yi(d,1,a);zc(d+16|0,d);p[114610]=0;J(370,b+43|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(d+16|0);c=a+48|0;p[b>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+52|0;p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+56|0;p[b+8>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+62|0;p[b+24>>2]=q[c|0]|q[c+1|0]<<8;rs(b,+((q[a+60|0]^8)+ -120|0)*.005208333333333333);n[d+16|0]=q[a+61|0];n[d|0]=64;e=b,f=q[hc(d+16|0,d)|0]<<2,o[e+30>>1]=f;o[b+34>>1]=0;a=a+47|0;if(q[a|0]&4){o[b+34>>1]=r[b+34>>1]|1;p[b>>2]=p[b>>2]>>>1}if(q[a|0]&32){o[b+34>>1]=r[b+34>>1]|4}if(n[a|0]<=-1){o[b+34>>1]=r[b+34>>1]|2}fb=d+32|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;p[114610]=0;S(2015,a|0);e=p[114610];p[114610]=0;a:{b:{c:{if((e|0)==1){break c}p[114610]=0;S(2041,b|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;S(2041,c|0);f=p[114610];p[114610]=0;e=1;if((f|0)==1){break c}f=p[a+24>>2];b=ic(d+24|0,b);c=ic(d+16|0,c);p[114610]=0;g=p[b+4>>2];p[d+8>>2]=p[b>>2];p[d+12>>2]=g;b=p[c+4>>2];p[d>>2]=p[c>>2];p[d+4>>2]=b;Q(2085,f|0,d+8|0,d|0,1);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37105,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();e=0}fb=d+32|0;return e|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function nJ(a,b){var c=w(0),d=w(0),e=w(0);a:{b:{c:{switch(b|0){case 0:uo(a,w(1));to(a,w(3.725290298461914e-9));so(a,w(268435456));ro(a,0);break b;case 1:uo(a,w(32));to(a,w(4.656612873077393e-10));so(a,w(2147483648));ro(a,0);break b;case 2:uo(a,w(2));to(a,w(7.450580596923828e-9));so(a,w(134217728));ro(a,1);break b;default:uo(a,w(1));to(a,w(7.450580596923828e-9));so(a,w(134217728));ro(a,1);ax(a,0);gl(a,1);$w(a,1);d=w(256);c=w(128);e=w(128);b=0;break a;case 4:case 5:break c}}uo(a,w(.75));to(a,w(7.450580596923828e-9));so(a,w(134217728));ro(a,1);ax(a,0);b=(b|0)==4;gl(a,b?2:3);$w(a,1);d=w(256);c=b?w(256):w(192);e=c;b=1;break a}ax(a,1);gl(a,0);$w(a,0);d=w(128);e=w(100);c=w(256);b=4}t[a+16>>2]=c;t[a+20>>2]=e;t[a+24>>2]=d;p[a+28>>2]=b}function FP(a){var b=0,c=0;b=fb-48|0;fb=b;c=q[a+8|0]|q[a+9|0]<<8|(q[a+10|0]<<16|q[a+11|0]<<24);p[b+8>>2]=(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))+788;p[b+12>>2]=0;c=q[a+16|0]|q[a+17|0]<<8|(q[a+18|0]<<16|q[a+19|0]<<24);p[b+16>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);p[b+20>>2]=0;c=q[a+24|0]|q[a+25|0]<<8|(q[a+26|0]<<16|q[a+27|0]<<24);p[b+24>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);p[b+28>>2]=0;a=q[a+32|0]|q[a+33|0]<<8|(q[a+34|0]<<16|q[a+35|0]<<24);p[b+44>>2]=4;p[b+40>>2]=b+8;c=p[b+44>>2];p[b>>2]=p[b+40>>2];p[b+4>>2]=c;p[b+32>>2]=(a<<8&16711680|a<<24|(a>>>8&65280|a>>>24))+80;p[b+36>>2]=0;a=WDa(p[b>>2],p[b>>2]+(p[b+4>>2]<<3)|0);c=p[a>>2];fb=b+48|0;a=p[a+4>>2]+ -1|0;b=c+ -52|0;if(b>>>0<4294967244){a=a+1|0}ib=a;return b}function xwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,q=0,r=0;e=fb-32|0;fb=e;i=p[a+24>>2];j=p[a+20>>2];k=p[a+16>>2];b=p[a+4>>2];f=p[a>>2];p[e+24>>2]=f;p[e+28>>2]=b;g=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=(f>>>21&2040)+27824|0;l=o[b+6>>1];m=o[b+4>>1];q=o[b+2>>1];r=o[b>>1];g=0;b=1;while(1){p[(e+8|0)+(g<<2)>>2]=(((v(n[g+h|0],q)+v(n[(g|-2)+h|0],r)|0)+v(n[(g|2)+h|0],m)|0)+v(n[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],j);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],i);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;f=p[e+24>>2];b=p[e+28>>2];continue}break}f=p[e+24>>2];b=p[e+28>>2]}p[a>>2]=f;p[a+4>>2]=b;fb=e+32|0}function y5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;e=p[a+28>>2];p[d+16>>2]=e;f=p[a+20>>2];p[d+28>>2]=c;p[d+24>>2]=b;b=f-e|0;p[d+20>>2]=b;e=b+c|0;j=2;b=d+16|0;a:{b:{c:{if(!co(pa(p[a+60>>2],d+16|0,2,d+12|0)|0)){while(1){f=p[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<=-1){break b}g=p[b+4>>2];h=f>>>0>g>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;p[i>>2]=g+p[i>>2];i=(h?12:4)+b|0;p[i>>2]=p[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!co(pa(p[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}p[d+12>>2]=-1;if((e|0)!=-1){break b}}b=p[a+44>>2];p[a+28>>2]=b;p[a+20>>2]=b;p[a+16>>2]=b+p[a+48>>2];a=c;break a}p[a+28>>2]=0;p[a+16>>2]=0;p[a+20>>2]=0;p[a>>2]=p[a>>2]|32;a=0;if((j|0)==2){break a}a=c-p[b+4>>2]|0}fb=d+32|0;return a|0}function NKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Lb(a);g=wb(b);p[114610]=0;K(524,f|0,g|0);a=p[114610];p[114610]=0;if((a|0)!=1){a:{if(g){while(1){a=d+1|0;e=q[cc(b,d)|0];b:{c:{if((a|0)==(g|0)|(e|0)!=37){break c}e=q[cc(b,a)|0];d=e+ -49|0;if((d&255)>>>0<=8){if(d>>>0>=qKa(c)>>>0){d=a;break b}p[114610]=0;d=J(525,c|0,d|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;J(526,f|0,d|0)|0;e=p[114610];p[114610]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}p[114610]=0;P(527,f|0,1,37)|0;h=p[114610];p[114610]=0;d=a;if((h|0)==1){break a}}p[114610]=0;P(527,f|0,1,e<<24>>24)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}return}}a=I()|0;H()|0;pb(f);L(a|0);E()}function Wua(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;Ic(d+8|0,a);a:{b:{c:{f=a+16|0;d:{if(kd(f)){while(1){e:{e=p[f>>2];p[114610]=0;e=M(98,e|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}c=c|e;b=b+32|0;if(b>>>0<32){continue}break d}break}b=O(71324)|0;if((H()|0)!=($(71324)|0)){break a}T(b|0)|0;n[a+20|0]=0;p[114610]=0;S(82,a|0);b=p[114610];p[114610]=0;if((b|0)==1){break c}p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){break d}b=I()|0;H()|0;break a}n[a+20|0]=0}if(!q[a+20|0]){a=p[a+24>>2];p[114610]=0;a=M(99,a|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}c=a^c}fb=d+16|0;return c}b=I()|0;H()|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=O(0)|0;H()|0;rb(a);E()}b=I()|0;H()|0}L(b|0);E()}function Ji(a,b,c){var d=0;a:{if((a|0)==(b|0)){break a}if((b-a|0)-c>>>0<=0-(c<<1)>>>0){ac(a,b,c);return}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){break b}if(!(a&3)){break c}while(1){if(!c){break a}n[a|0]=q[b|0];b=b+1|0;c=c+ -1|0;a=a+1|0;if(a&3){continue}break}break c}d:{if(d){break d}if(a+c&3){while(1){if(!c){break a}c=c+ -1|0;d=c+a|0;n[d|0]=q[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c+ -4|0;p[c+a>>2]=p[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c+ -1|0;n[c+a|0]=q[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){p[a>>2]=p[b>>2];b=b+4|0;a=a+4|0;c=c+ -4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){n[a|0]=q[b|0];a=a+1|0;b=b+1|0;c=c+ -1|0;if(c){continue}break}}}function cR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;p[e+24>>2]=b;k=e,l=wd(a),p[k+8>>2]=l;g=Mn(e+24|0,e+8|0);b=zi(c,d);a:{b:{if(!b){break b}if(wz(c,Ib(a),Ib(a)+wb(a)|0)){b=di(e+8|0,c,d);c=p[e+24>>2];d=Ib(b);g=Ib(b);h=wb(b);p[114610]=0;c=U(613,a|0,c|0,d|0,g+h|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);break a}a=I()|0;H()|0;pb(b);L(a|0);E()}h=wb(a);f=Bc(a);c:{if(f-h>>>0>=b>>>0){f=Ib(a);i=h-g|0;if(!i){break c}j=g+f|0;Pl(b+j|0,j,i);break c}El(a,f,(b+h|0)-f|0,h,g,0,b);f=p[a>>2]}b=b+h|0;Jg(a,b);n[e+8|0]=0;ae(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){ae(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=e,l=wd(a),p[k+8>>2]=l;c=lf(e+8|0,g)}fb=e+32|0;return c|0}function WGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;p[d+28>>2]=0;ni(a,d+28|0);a:{b:{e=p[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Lb(d+16|0);p[114610]=0;o[d+14>>1]=0;f=P(724,a|0,e|0,255)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}if(!f){break d}p[114610]=0;J(715,a|0,d+14|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}p[114610]=0;N(13,d|0,c|0,e|0);f=p[114610];p[114610]=0;if((f|0)==1){break f}p[114610]=0;f=J(725,b|0,d+14|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}xb(f,d);pb(d);pb(e);h=h+1|0;if(h>>>0<s[d+28>>2]){continue}break}}tf(p[p[a>>2]+ -12>>2]+a|0);break c}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d);break a}pb(e)}fb=d+32|0;return}a=I()|0;H()|0}pb(e);L(a|0);E()}function VGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;o[d+30>>1]=0;mf(a,d+30|0);a:{b:{e=r[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Lb(d+16|0);p[114610]=0;o[d+14>>1]=0;f=P(726,a|0,e|0,255)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}if(!f){break d}p[114610]=0;J(715,a|0,d+14|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}p[114610]=0;N(13,d|0,c|0,e|0);f=p[114610];p[114610]=0;if((f|0)==1){break f}p[114610]=0;f=J(725,b|0,d+14|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break e}xb(f,d);pb(d);pb(e);h=h+1|0;if(h>>>0<r[d+30>>1]){continue}break}}tf(p[p[a>>2]+ -12>>2]+a|0);break c}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d);break a}pb(e)}fb=d+32|0;return}a=I()|0;H()|0}pb(e);L(a|0);E()}function FBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Xc(a);g=wb(b);p[114610]=0;K(73,f|0,g|0);a=p[114610];p[114610]=0;if((a|0)!=1){a:{if(g){while(1){a=d+1|0;e=q[cc(b,d)|0];b:{c:{if((a|0)==(g|0)|(e|0)!=37){break c}e=q[cc(b,a)|0];d=e+ -49|0;if((d&255)>>>0<=8){if(d>>>0>=nAa(c)>>>0){d=a;break b}p[114610]=0;d=J(74,c|0,d|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;J(75,f|0,d|0)|0;e=p[114610];p[114610]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}p[114610]=0;P(76,f|0,1,37)|0;h=p[114610];p[114610]=0;d=a;if((h|0)==1){break a}}p[114610]=0;P(76,f|0,1,e<<24>>24)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}return}}a=I()|0;H()|0;pb(f);L(a|0);E()}function AF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;a:{b:{c:{d:{if((b|0)>=0){if((al(a+8|0)|0)>(b|0)){break d}}b=W(8)|0;p[114610]=0;c=J(85,f|0,40569)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}d=a+32|0;a=(p[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;p[a>>2]=c|p[a>>2]&-134218753;a=(p[d>>2]+v(b,896)|0)+1075072|0;p[a>>2]=c|p[a>>2]&-134218753;a=r[p[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=v(a,896);if((b|0)==r[(e+p[d>>2]|0)+1075792>>1]){e=(e+p[d>>2]|0)+1075072|0;p[e>>2]=c|p[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}fb=f+16|0;return}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function doa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;a:{b:{c:{d:{e:{if(Yi(b)){break e}o[d+8>>1]=r[a+480190>>1];o[d+24>>1]=p[b+4>>2]+ -1;c=r[rf(d+8|0,d+24|0)>>1];if(!c){break e}while(1){Wd(d+8|0,b,c);if(!tb(d+8|0)){p[114610]=0;e=J(1425,a|0,c&65535)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}if(e){p[114610]=0;e=J(85,d+8|0,20461)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}p[114610]=0;J(369,((c<<5)+a|0)+946300|0,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}pb(e);g=g+1|0}if(!(r[a+480190>>1]!=(c|0)|c>>>0<2)){o[a+480190>>1]=r[a+480190>>1]+ -1}}e=c&65535;c=c+ -1|0;if((e|0)!=1){continue}break}}fb=d+32|0;return g&65535}c=I()|0;H()|0;break a}c=I()|0;H()|0;pb(e);break a}c=I()|0;H()|0}L(c|0);E()}function Jb(a,b,c){var d=0,e=0,f=0,g=0;a:{if(!c){break a}d=a+c|0;n[d+ -1|0]=b;n[a|0]=b;if(c>>>0<3){break a}n[d+ -2|0]=b;n[a+1|0]=b;n[d+ -3|0]=b;n[a+2|0]=b;if(c>>>0<7){break a}n[d+ -4|0]=b;n[a+3|0]=b;if(c>>>0<9){break a}d=0-a&3;e=d+a|0;b=v(b&255,16843009);p[e>>2]=b;c=c-d&-4;d=c+e|0;p[d+ -4>>2]=b;if(c>>>0<9){break a}p[e+8>>2]=b;p[e+4>>2]=b;p[d+ -8>>2]=b;p[d+ -12>>2]=b;if(c>>>0<25){break a}p[e+24>>2]=b;p[e+20>>2]=b;p[e+16>>2]=b;p[e+12>>2]=b;p[d+ -16>>2]=b;p[d+ -20>>2]=b;p[d+ -24>>2]=b;p[d+ -28>>2]=b;g=e&4|24;c=c-g|0;if(c>>>0<32){break a}d=b;f=b;b=e+g|0;while(1){p[b+24>>2]=f;p[b+28>>2]=d;p[b+16>>2]=f;p[b+20>>2]=d;p[b+8>>2]=f;p[b+12>>2]=d;p[b>>2]=f;p[b+4>>2]=d;b=b+32|0;c=c+ -32|0;if(c>>>0>31){continue}break}}return a}function Hj(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;p[a+4>>2]=0;a:{b:{d=4;c:{if(!q[Qi(e+8|0,a,1)|0]){break c}d=p[p[a>>2]+ -12>>2];p[114610]=0;d=p[(a+d|0)+24>>2];f=p[114610];p[114610]=0;d:{if((f|0)==1){break d}p[114610]=0;b=P(2324,d|0,b|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break d}p[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=O(0)|0;H()|0;T(b|0)|0;Oi(p[p[a>>2]+ -12>>2]+a|0,1);b=p[p[a>>2]+ -12>>2];p[114610]=0;b=p[(a+b|0)+20>>2];c=p[114610];p[114610]=0;e:{if((c|0)!=1){if(!(b&1)){break e}p[114610]=0;R(81);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)==1){break b}L(a|0);E()}V();d=1}mg(p[p[a>>2]+ -12>>2]+a|0,d);fb=e+16|0;return}a=O(0)|0;H()|0;rb(a)}E()}function Dqa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var g=0,h=w(0),i=w(0),k=0,l=w(0),m=0,n=0;g=fb-16|0;fb=g;m=g,n=v(p[a>>2],le(a)),p[m+8>>2]=n;vc(g+8|0,c);c=ub(b);h=t[e+4>>2];e=p[g+8>>2];if(e){while(1){h=w(A(w(x((f(2,q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24)),j()))),h));c=c+4|0;e=e+ -1|0;if(e){continue}break}}c=h==w(0);a:{if(c){break a}e=p[g+8>>2];if(!e){break a}l=c?w(1):w(w(1)/h);c=p[a+20>>2];while(1){t[g+12>>2]=l*(f(2,q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24)),j());Td(g+12|0,w(-1));i=w(t[g+12>>2]*w(32768));t[g+12>>2]=i;a=c;i=$d(i);b:{if(w(x(i))<w(2147483648)){k=~~i;break b}k=-2147483648}m=a,n=Mc(k),o[m>>1]=n;b=b+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}if(d){t[d>>2]=h}fb=g+16|0;return p[g+8>>2]}function TO(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;while(1){h=r[kc(b,g)>>1];m=h+1|0;n=h>>>0>127|(i&65535)>>>0>h>>>0;j=n?j:g>>>0<c>>>0?m:j;k=h>>>0<(k&65535)>>>0?k:m;i=n?i:m;g=g+1|0;if((g|0)!=128){continue}break}ig(b,c);c=d;d=p[a+8>>2];h=c+d|0;a:{if(f){if((qj(a)|0)!=(h+((i&65535)<<11)|0)){break a}o[e>>1]=8;break a}if(r[e>>1]!=4|f|(i&65535)==(j&65535)){break a}Jc(a,d+((j&65535)<<10)|0);g=0;c=0;b:{while(1){c:{Dl(l+8|0,a);if(q[Yb(l+8|0,0)|0]>=32){if((c|0)>=64){break c}c=c+1|0}g=g+1|0;if((g|0)!=256){continue}break b}break}i=j}Jc(a,d)}c=k&65535;d:{if(c>>>0>(i&65535)>>>0){if((h+(v(c,r[e>>1])<<8)|0)==(qj(a)|0)){break d}}if(c>>>0>=255){Hy(b,254,65534);Hy(b,255,65535)}k=i}fb=l+16|0;return k&65535}function rda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}p[114610]=0;S(2041,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break f}e=p[a+24>>2];p[114610]=0;c=J(85,d|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;Q(2076,d+16|0,e|0,c|0,1);b=p[114610];p[114610]=0;if((b|0)==1){break d}b=Pd(Ib(d+16|0));pb(d+16|0);pb(c);break b}b=O(0)|0;H()|0;break c}b=O(0)|0;H()|0;break c}b=O(0)|0;H()|0;pb(c)}T(b|0)|0;b=0;p[114610]=0;Q(1989,36833,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=d+32|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function uqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,g=w(0),h=0,i=0,k=w(0),l=0,m=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>3;p[e+8>>2]=p[a>>2];c=p[Cb(e+12|0,e+8|0)>>2];k=t[d>>2];b=ub(b);if(c){a=p[a+20>>2];d=c;while(1){t[e+12>>2]=k*(f(2,q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24)),j());Td(e+12|0,w(-1));g=w(t[e+12>>2]*w(32768));t[e+12>>2]=g;i=a;g=$d(g);a:{if(w(x(g))<w(2147483648)){h=~~g;break a}h=-2147483648}l=i,m=Mc(h),o[l>>1]=m;t[e+12>>2]=k*(f(2,q[b+4|0]|q[b+5|0]<<8|(q[b+6|0]<<16|q[b+7|0]<<24)),j());Td(e+12|0,w(-1));g=w(t[e+12>>2]*w(32768));t[e+12>>2]=g;i=a;g=$d(g);b:{if(w(x(g))<w(2147483648)){h=~~g;break b}h=-2147483648}l=i,m=Mc(h),o[l+2>>1]=m;a=a+4|0;b=b+8|0;d=d+ -1|0;if(d){continue}break}}fb=e+16|0;return c<<3}function hNa(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;vd(b,0);n[b+37|0]=q[a+22|0]<<4;n[e+15|0]=q[a+23|0];n[e+14|0]=64;g=b,h=q[hc(e+15|0,e+14|0)|0]<<2,o[g+30>>1]=h;n[b+36|0]=q[a+24|0];f=a+25|0;d=f;p[b>>2]=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);d=a+33|0;c=d;a:{if((q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))>>>0<3){break a}c=a+29|0;if((q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))+(q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24))>>>0>(q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24))>>>0){break a}o[b+34>>1]=r[b+34>>1]|2;p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[b+8>>2]=(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))+(q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24))}fb=e+16|0}function Yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}p[114610]=0;S(2041,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break f}e=p[a+24>>2];p[114610]=0;c=J(85,d|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break e}p[114610]=0;N(2042,d+16|0,e|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break d}b=Pd(Ib(d+16|0));pb(d+16|0);pb(c);break b}b=O(0)|0;H()|0;break c}b=O(0)|0;H()|0;break c}b=O(0)|0;H()|0;pb(c)}T(b|0)|0;b=0;p[114610]=0;Q(1989,35599,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=d+32|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function TD(a,b,c,d,e,f){var g=0;g=fb-80|0;fb=g;a:{if((f|0)>=16384){jd(g+32|0,b,c,d,e,0,0,0,2147352576);d=p[g+40>>2];e=p[g+44>>2];b=p[g+32>>2];c=p[g+36>>2];if((f|0)<32767){f=f+ -16383|0;break a}jd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)+ -32766|0;d=p[g+24>>2];e=p[g+28>>2];b=p[g+16>>2];c=p[g+20>>2];break a}if((f|0)>-16383){break a}jd(g- -64|0,b,c,d,e,0,0,0,65536);d=p[g+72>>2];e=p[g+76>>2];b=p[g+64>>2];c=p[g+68>>2];if((f|0)>-32765){f=f+16382|0;break a}jd(g+48|0,b,c,d,e,0,0,0,65536);f=((f|0)>-49146?f:-49146)+32764|0;d=p[g+56>>2];e=p[g+60>>2];b=p[g+48>>2];c=p[g+52>>2]}jd(g,b,c,d,e,0,0,0,f+16383<<16);b=p[g+12>>2];p[a+8>>2]=p[g+8>>2];p[a+12>>2]=b;b=p[g+4>>2];p[a>>2]=p[g>>2];p[a+4>>2]=b;fb=g+80|0}function Sva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;i=p[a+24>>2];j=p[a+20>>2];k=p[a+16>>2];h=p[a+4>>2];e=h;f=p[a>>2];p[g+8>>2]=f;p[g+12>>2]=e;h=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=h;if(d){while(1){e=(e<<1)+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((v(o[e+4>>1],o[f+34>>1])+v(o[e+2>>1],o[f+32>>1])|0)+v(o[e+6>>1],o[f+36>>1])|0)+v(o[e+8>>1],o[f+38>>1])|0)/2|0)+((((v(o[e+ -4>>1],o[f+26>>1])+v(o[e+ -6>>1],o[f+24>>1])|0)+v(o[e+ -2>>1],o[f+28>>1])|0)+v(o[e>>1],o[f+30>>1])|0)/2|0)|0)/16384|0;p[c>>2]=p[c>>2]+v(e,j);p[c+4>>2]=p[c+4>>2]+v(e,i);Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;f=p[g+8>>2];e=p[g+12>>2];continue}break}f=p[g+8>>2];e=p[g+12>>2]}p[a>>2]=f;p[a+4>>2]=e;fb=g+16|0}function Vea(a){a=a|0;var b=0;b=34184;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=34221;break a}switch(a+ -277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=34085;break a}b=34198;break a}b=34240;break a}b=34254;break a}b=34268;break a}b=34280;break a}b=34300;break a}b=34321;break a}b=34333;break a}b=34352;break a}b=34384;break a}b=34406;break a}if((a|0)!=357){break a}b=34423}return Pd(b)|0}function GD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;g=fb-272|0;fb=g;h=p[b>>2];p[g+12>>2]=h;i=a?a:g+16|0;e=0;d=a?d:256;a:{if(!d|!h){break a}f=d>>>0>c>>>0;if(!(d>>>0<=c>>>0|c>>>0>32)){break a}while(1){f=f?c:d;c=c-f|0;f=u3(i,g+12|0,f);if((f|0)==-1){d=0;h=p[g+12>>2];e=-1;break a}h=(g+16|0)==(i|0);i=h?i:f+i|0;e=e+f|0;d=d-(h?0:f)|0;h=p[g+12>>2];if(!d|!h){break a}f=c>>>0<d>>>0;if(c>>>0>32|c>>>0>=d>>>0){continue}break}}b:{c:{if(!c|(!h|!d)){break c}while(1){j=Jj(i,p[h>>2],0);if(j+1>>>0<=1){f=-1;if(j){break b}p[g+12>>2]=0;break c}h=p[g+12>>2]+4|0;p[g+12>>2]=h;e=e+j|0;d=d-j|0;if(!d){break c}i=i+j|0;f=e;c=c+ -1|0;if(c){continue}break}break b}f=e}if(a){p[b>>2]=p[g+12>>2]}fb=g+272|0;return f|0}function sE(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!p[(p[p[a>>2]+ -12>>2]+a|0)+24>>2]){break b}p[114610]=0;c=J(2328,d+8|0,a|0)|0;b=p[114610];p[114610]=0;c:{if((b|0)!=1){d:{if(!q[c|0]){break d}b=p[(p[p[a>>2]+ -12>>2]+a|0)+24>>2];p[114610]=0;b=M(2329,b|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=p[p[a>>2]+ -12>>2];p[114610]=0;K(2330,a+b|0,1);b=p[114610];p[114610]=0;if((b|0)!=1){break d}}b=O(0)|0;H()|0;rE(c);break c}rE(c);break b}b=O(0)|0;H()|0}T(b|0)|0;c=p[p[a>>2]+ -12>>2];p[114610]=0;S(19,a+c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}V()}fb=d+16|0;return a|0}a=I()|0;H()|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;if((c|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Om(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){n[b+829|0]=c;break a}c=q[b+829|0]}d=p[a+480180>>2]&202376205?c&240?c&-16:c&15:c;c=p[b+688>>2];b:{if(p[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){Ko(a,b,(d&240)>>>4|0,0);return}if(!(n[b+872|0]&1)){break b}c=q[a+480208|0]&2?c:c+ -60|0;break b}if((e|0)!=240){break b}if(f){Jo(a,b,f,0);return}if(!(n[b+872|0]&1)){break b}c=q[a+480208|0]&2?c:c+60|0}c:{if(p[a+1074416>>2]!=1|p[a+480180>>2]!=524288?!(!(n[b+872|0]&1)|q[a+480208|0]&2):0){break c}e=d&255;d=d&15;d:{if(d){if(p[a+480180>>2]&16777248?e&240:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(p[a+480180>>2]!=1){break c}p[b+88>>2]=p[b+88>>2]|2097152}g=b,h=Pb(c,0,256),p[g+688>>2]=h}function iza(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-80|0;fb=f;p[114610]=0;N(224,f+40|0,f+32|0,c|0);c=p[114610];p[114610]=0;a:{b:{g=f+40|0;c:{d:{e:{if((c|0)!=1){p[114610]=0;N(240,f+52|0,f+24|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break e}p[114610]=0;N(224,f- -64|0,f+16|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break d}p[114610]=0;K(241,f+8|0,f+40|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(72,a|0,b|0,f+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}Ul(f+40|0);fb=f+80|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;b=1;break c}a=I()|0;H()|0;b=2}b=g+v(b,12)|0;while(1){b=pb(b+ -12|0);if((b|0)!=(f+40|0)){continue}break}break a}a=I()|0;H()|0;Ul(f+40|0)}L(a|0);E()}function SHa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-80|0;fb=f;p[114610]=0;N(224,f+40|0,f+32|0,c|0);c=p[114610];p[114610]=0;a:{b:{g=f+40|0;c:{d:{e:{if((c|0)!=1){p[114610]=0;N(224,f+52|0,f+24|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break e}p[114610]=0;N(224,f- -64|0,f+16|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break d}p[114610]=0;K(241,f+8|0,f+40|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(72,a|0,b|0,f+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}Ul(f+40|0);fb=f+80|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;b=1;break c}a=I()|0;H()|0;b=2}b=g+v(b,12)|0;while(1){b=pb(b+ -12|0);if((b|0)!=(f+40|0)){continue}break}break a}a=I()|0;H()|0;Ul(f+40|0)}L(a|0);E()}function Kqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-16|0;fb=g;p[g+8>>2]=c>>>3;p[g+4>>2]=p[a>>2];d=p[Cb(g+8|0,g+4|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){k=0;e=b;h=q[e+4|0]|q[e+5|0]<<8|(q[e+6|0]<<16|q[e+7|0]<<24);i=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);f=h<<24|i>>>8;e=0;l=f&65280;f=e;e=h<<8|i>>>24;f=f|k;k=e&255|l|(i<<24|i<<8&16711680);e=g;p[e+8>>2]=((h&255)<<24|i>>>8)&-16777216|((h&16777215)<<8|i>>>24)&16711680|(h>>>8&65280|h>>>24)|f;p[e+12>>2]=k;wf(e+8|0,-1,1);j=u[e+8>>3]*32768;u[e+8>>3]=j;e=a;j=Id(j);a:{if(x(j)<2147483648){f=~~j;break a}f=-2147483648}m=e,n=Mc(f),o[m>>1]=n;a=a+2|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}fb=g+16|0;return d<<3}function HW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-80|0;fb=f;p[114610]=0;N(240,f+40|0,f+32|0,c|0);c=p[114610];p[114610]=0;a:{b:{g=f+40|0;c:{d:{e:{if((c|0)!=1){p[114610]=0;N(240,f+52|0,f+24|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break e}p[114610]=0;N(240,f- -64|0,f+16|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break d}p[114610]=0;K(241,f+8|0,f+40|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(72,a|0,b|0,f+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}Ul(f+40|0);fb=f+80|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;b=1;break c}a=I()|0;H()|0;b=2}b=g+v(b,12)|0;while(1){b=pb(b+ -12|0);if((b|0)!=(f+40|0)){continue}break}break a}a=I()|0;H()|0;Ul(f+40|0)}L(a|0);E()}function uwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;h=p[a+40>>2];i=p[a+36>>2];k=p[a+16>>2];g=p[a+4>>2];b=g;f=p[a>>2];p[e+8>>2]=f;p[e+12>>2]=b;g=p[a+12>>2];p[e>>2]=p[a+8>>2];p[e+4>>2]=g;a:{if(!d){g=h>>12;j=i>>12;break a}while(1){g=p[a+32>>2];i=p[a+28>>2]+i|0;j=i>>12;b=(b<<1)+k|0;f=(f>>>21&2040)+27824|0;b=(((v(o[b>>1],o[f+2>>1])+v(o[b+ -2>>1],o[f>>1])|0)+v(o[b+2>>1],o[f+4>>1])|0)+v(o[b+4>>1],o[f+6>>1])|0)/16384|0;p[c>>2]=p[c>>2]+v(j,b);h=g+h|0;g=h>>12;p[c+4>>2]=p[c+4>>2]+v(b,g);Kb(e+8|0,e);d=d+ -1|0;if(d){c=c+8|0;f=p[e+8>>2];b=p[e+12>>2];continue}break}f=p[e+8>>2];b=p[e+12>>2]}p[a+40>>2]=h;p[a+20>>2]=j;p[a+36>>2]=i;p[a+24>>2]=g;p[a>>2]=f;p[a+4>>2]=b;fb=e+16|0}function efa(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0,s=0,t=0,u=0,w=0;e=r[a+22>>1];f=r[a+20>>1];g=p[a+4>>2];if(c){k=o[a+26>>1];s=o[a+18>>1];l=o[a+24>>1];t=o[a+16>>1];j=p[a>>2]+ -1|0;m=a+32928|0;while(1){h=Kc(p[b>>2]);d=Kc(p[b+4>>2]);f=Kc((f<<16>>16)-h|0);e=Kc((e<<16>>16)-d|0);f=Mc(Kc((v(f,t)|0)/65536<<1)+h|0);e=Mc(Kc((v(e,s)|0)/65536<<1)+d|0);d=(g<<2)+m|0;h=o[d+2>>1];n=o[d>>1];d=Mc(((v(n,l)|0)/-65536|0)+f|0);g=g+1&127;i=(g<<2)+m|0;q=Mc(((v(h,k)|0)/-65536|0)+e|0);o[i+2>>1]=q;o[i>>1]=d;j=j+1&8191;i=(j<<2)+a|0;u=i,w=Mc(((v(d,l)|0)/65536|0)+n|0),o[u+160>>1]=w;u=i,w=Mc(h+((v(k,q)|0)/65536|0)|0),o[u+162>>1]=w;b=b+8|0;c=c+ -1|0;if(c){continue}break}}o[a+22>>1]=e;o[a+20>>1]=f;p[a+4>>2]=g}function _6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;if((d|0)>=1){f=b+7548|0;i=a+6152|0;while(1){g=v(e,28)+c|0;j=r[g+4>>1];h=p[b+4>>2];U6(i,(v(e,39)+b|0)+16156|0,b,g,f,e);T6((v(e,2304)+b|0)+2940|0,b,g,f,j+h|0);e=e+1|0;if((e|0)!=(d|0)){continue}break}}e=q[a+6155|0];a:{if(e&16){R6(b+2940|0,b+16195|0,c,a+6152|0);break a}if((e&224)!=96){break a}oF(b+2940|0,576)}if((d|0)>=1){j=b+7708|0;e=0;while(1){f=q[a+6153|0];f=(q[c+12|0]!=0)<<1<<((v((f>>>3&1)+(f>>>4&1)|0,3)+(q[a+6154|0]>>>2&3)|0)==2);g=(v(e,2304)+b|0)+2940|0;i=g;if(q[c+14|0]){Q6(((v(e,2304)+b|0)+v(f,72)|0)+2940|0,j,p[c>>2]+q[c+13|0]|0);h=f+ -1|0}else{h=31}P6(i,h);O6(g,v(e,1152)+a|0,q[c+11|0],f);N6(g);c=c+28|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}}function Tva(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;i=p[a+24>>2];j=p[a+20>>2];k=p[a+16>>2];h=p[a+4>>2];e=h;f=p[a>>2];p[g+8>>2]=f;p[g+12>>2]=e;h=p[a+12>>2];p[g>>2]=p[a+8>>2];p[g+4>>2]=h;if(d){while(1){e=e+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((v(n[e+2|0],o[f+34>>1])+v(n[e+1|0],o[f+32>>1])|0)+v(n[e+3|0],o[f+36>>1])|0)+v(n[e+4|0],o[f+38>>1])<<8)/2|0)+((((v(n[e+ -2|0],o[f+26>>1])+v(n[e+ -3|0],o[f+24>>1])|0)+v(n[e+ -1|0],o[f+28>>1])|0)+v(n[e|0],o[f+30>>1])<<8)/2|0)|0)/16384|0;p[c>>2]=p[c>>2]+v(e,j);p[c+4>>2]=p[c+4>>2]+v(e,i);Kb(g+8|0,g);d=d+ -1|0;if(d){c=c+8|0;f=p[g+8>>2];e=p[g+12>>2];continue}break}f=p[g+8>>2];e=p[g+12>>2]}p[a>>2]=f;p[a+4>>2]=e;fb=g+16|0}function Ly(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;if(n[a|0]&1){n[b+12|0]=q[b+12|0]|1}if(q[a|0]&2){n[b+12|0]=q[b+12|0]|4}if(q[a|0]&4){n[b+12|0]=q[b+12|0]|2}if(q[a|0]&16){n[b+12|0]=q[b+12|0]|16}if(q[a|0]&32){n[b+12|0]=q[b+12|0]|8}n[g+15|0]=q[a+1|0];n[g+14|0]=25;Vf(b,q[hc(g+15|0,g+14|0)|0]);n[b+15|0]=q[a+2|0];n[b+16|0]=q[a+3|0];n[b+13|0]=q[a+4|0];n[b+14|0]=q[a+5|0];if(Bb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=q[e|0]|q[e+1|0]<<8;h=Fb(b,d),i=e,o[h>>1]=i;a:{if(!d){break a}e=d+ -1|0;if(r[Fb(b,d)>>1]>=r[Fb(b,e)>>1]){break a}e=r[Fb(b,e)>>1];h=Fb(b,d),i=e+1|0,o[h>>1]=i}f=f+8|0;f=Pb((q[f|0]|q[f+1|0]<<8)<<16>>16>>c,0,64);h=Fb(b,d),i=f,n[h+2|0]=i;d=d+1|0;if(d>>>0<Bb(b)>>>0){continue}break}}fb=g+16|0}function GP(a){var b=0,c=0;a:{if(hd(a,15079,3)){break a}b=a+3|0;if(q[b|0]<48|q[b|0]>51){break a}b=a+8|0;c=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<52){break a}b=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>4294966507){break a}b=a+16|0;b=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}b=a+24|0;b=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}a=a+32|0;a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);return(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0<4294967216}return 0}function tma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;d=Lb(e);a:{b:{if(c>>>0>=64){p[114610]=0;c=M(339,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}if((c|0)<=0){p[114610]=0;J(85,a|0,30824)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break b}break a}p[114610]=0;K(111,d|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}}c:{while(1){d:{p[114610]=0;c=M(387,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}if(!c){break c}p[114610]=0;P(1531,d|0,1,((c+ -65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}}break}break a}p[114610]=0;J(338,b|0,4)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}Wc(a,d)}pb(d);fb=e+16|0;return}a=I()|0;H()|0;pb(d);L(a|0);E()}function fY(a,b){var c=0,d=0,e=0,f=0,g=0;c=16;d=a>>>0>16?a:16;a:{if(!(d+ -1&d)){a=d;break a}while(1){a=c;c=a<<1;if(a>>>0<d>>>0){continue}break}}if(-64-a>>>0<=b>>>0){p[114584]=48;return 0}d=b>>>0<11?16:b+11&-8;c=fd((d+a|0)+12|0);if(!c){return 0}b=c+ -8|0;b:{if(!(c&a+ -1)){a=b;break b}f=c+ -4|0;g=p[f>>2];c=((a+c|0)+ -1&0-a)+ -8|0;a=c-b>>>0>15?c:a+c|0;c=a-b|0;e=(g&-8)-c|0;if(!(g&3)){b=p[b>>2];p[a+4>>2]=e;p[a>>2]=b+c;break b}p[a+4>>2]=e|p[a+4>>2]&1|2;e=a+e|0;p[e+4>>2]=p[e+4>>2]|1;p[f>>2]=c|p[f>>2]&1|2;p[a+4>>2]=p[a+4>>2]|1;nq(b,c)}b=p[a+4>>2];c:{if(!(b&3)){break c}c=b&-8;if(c>>>0<=d+16>>>0){break c}p[a+4>>2]=d|b&1|2;b=a+d|0;d=c-d|0;p[b+4>>2]=d|3;c=a+c|0;p[c+4>>2]=p[c+4>>2]|1;nq(b,d)}return a+8|0}function Ax(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;a:{if(!d){break a}if(c){n[b+835|0]=c;break a}c=q[b+835|0]}c=p[a+480180>>2]&1048580?c&240?c&-16:c&15:c;b:{c:{d:{e:{if(!(p[a+480180>>2]&1048580)){d=c&240;c=c&15;if((c|0)==15){if(!d){d=0;break e}if(!(q[a+480209|0]&16)){break b}c=0-(d>>>2|0)|0;break d}f=!c;if(!c|(d|0)!=240){break e}if(!(q[a+480209|0]&16)){break b}c=c<<2;break c}if(q[a+480209|0]&16){break b}vb(e+8|0,a+1074308|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!tb(e+8|0)){break d}c=(a|0)/4|0;break d}if(q[a+480209|0]&16){break b}if(!f){c=c<<2;if(!d|!(p[a+480180>>2]&16777248)){break c}break b}c=0-(d>>>2|0)|0}if(!c){break b}}a=Pb(p[b+692>>2]+c|0,0,256);o[b+796>>1]=0;p[b+692>>2]=a}fb=e+16|0}function vwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;h=p[a+40>>2];i=p[a+36>>2];k=p[a+16>>2];g=p[a+4>>2];b=g;f=p[a>>2];p[e+8>>2]=f;p[e+12>>2]=b;g=p[a+12>>2];p[e>>2]=p[a+8>>2];p[e+4>>2]=g;a:{if(!d){g=h>>12;j=i>>12;break a}while(1){g=p[a+32>>2];i=p[a+28>>2]+i|0;j=i>>12;b=b+k|0;f=(f>>>21&2040)+27824|0;b=(((v(n[b|0],o[f+2>>1])+v(n[b+ -1|0],o[f>>1])|0)+v(n[b+1|0],o[f+4>>1])|0)+v(n[b+2|0],o[f+6>>1])<<8)/16384|0;p[c>>2]=p[c>>2]+v(j,b);h=g+h|0;g=h>>12;p[c+4>>2]=p[c+4>>2]+v(b,g);Kb(e+8|0,e);d=d+ -1|0;if(d){c=c+8|0;f=p[e+8>>2];b=p[e+12>>2];continue}break}f=p[e+8>>2];b=p[e+12>>2]}p[a+40>>2]=h;p[a+20>>2]=j;p[a+36>>2]=i;p[a+24>>2]=g;p[a>>2]=f;p[a+4>>2]=b;fb=e+16|0}function Y6(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=K6(a,c);a:{if(!q[c+768|0]){e=0;break a}g=50016;while(1){if((d|0)==(i|0)){g=q[e|0]+50016|0;i=q[e+2|0]+i|0;j=q[e+1|0];e=e+3|0}k=d<<1;f=q[Kd(b,j)+g|0];n[(k+c|0)+770|0]=f;h=q[c+769|0];if(d>>>0<h>>>0){f=q[Kd(b,j)+g|0];h=q[c+769|0]}n[((k|1)+c|0)+770|0]=h?f:0;d=d+1|0;f=q[c+768|0];if(d>>>0<f>>>0){continue}break}if(!f){e=f<<1;break a}d=0;while(1){g=c+d|0;b:{if(!q[g+770|0]){e=6;break b}e=2;if((q[a+1|0]&6)==6){break b}e=Kd(b,2);f=q[c+768|0]}n[g+834|0]=e;d=d+1|0;e=f<<1&510;if(d>>>0<e>>>0){continue}break}}J6(b,c+770|0,c+834|0,e,c);d=q[c+769|0];a=q[c+768|0];if(d>>>0<a>>>0){while(1){n[((d<<1|1)+c|0)+770|0]=0;d=d+1|0;if(d>>>0<a>>>0){continue}break}}}function Dpa(a,b,c){var d=0,e=0,f=0,g=0;a:{d=p[a+480208>>2];if(!(d&4096)){break a}b:{switch(c&15){case 0:p[b+88>>2]=p[b+88>>2]&-257;return;case 1:p[b+692>>2]=128;p[b+88>>2]=p[b+88>>2]|256;return;case 8:p[b+88>>2]=p[b+88>>2]&-25165825|16777216;return;case 9:p[b+88>>2]=p[b+88>>2]&-25165825|8388608;return;case 10:p[a+480208>>2]=d&-16385;return;case 11:p[a+480208>>2]=d|16384;return;case 12:p[a+480208>>2]=d&-8193;return;case 13:p[a+480208>>2]=d|8192;return;case 14:p[b+88>>2]=p[b+88>>2]&-129;return;case 15:break b;default:break a}}c:{if(!p[b+76>>2]|(p[b>>2]|p[b+4>>2])){break c}if(e=!Sf(b+810|0),f=0,g=q[b+88|0]&2,g?e:f){break c}c=p[b+76>>2]+ -1|0;p[b>>2]=-1;p[b+4>>2]=c}p[b+88>>2]=p[b+88>>2]|128}}function Faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb+ -64|0;fb=d;a:{b:{if((b|0)>=0){e=a+24|0;if((bj(Ob(p[e>>2]+484360|0))|0)>(b|0)){break b}}a=a+16|0;break a}g=r[kc(Ob(p[e>>2]+484360|0),b)>>1];c:{if(!Cp(p[e>>2]+484344|0,g)){break c}if((c|0)>=0){f=c;if(p[Rb(p[e>>2]+484344|0,g)+12>>2]>(f|0)){break c}}a=a+16|0;break a}o[p[e>>2]+1074438>>1]=b;b=b&65535;RJ(p[e>>2],b);p[p[e>>2]+1074428>>2]=f;c=p[e>>2];e=q[a+64|0];b=LJ(d+24|0,b,f);f=p[b+20>>2];p[d+16>>2]=p[b+16>>2];p[d+20>>2]=f;f=p[b+12>>2];p[d+8>>2]=p[b+8>>2];p[d+12>>2]=f;f=p[b+4>>2];p[d>>2]=p[b>>2];p[d+4>>2]=f;ds(d+48|0,c,e?7:1,d);b=qg(d+48|0);c=p[b+4>>2];p[a+16>>2]=p[b>>2];p[a+20>>2]=c;ck(d+48|0);a=a+16|0}fb=d- -64|0;return+u[a>>3]}function hMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;vd(b,0);p[b>>2]=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);c=At(a+4|0,a);p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=At(a+8|0,a);p[b+8>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);n[d+15|0]=127;n[d+14|0]=q[a+15|0];f=b,g=(((q[hc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,o[f+30>>1]=g;e=a+12|0;if(q[e|0]>=16){c=q[e|0];o[b+34>>1]=32;o[b+28>>1]=c&240}c=a+13|0;p[b+24>>2]=(q[c|0]|q[c+1|0]<<8)<<1;if(!(q[c|0]|q[c+1|0]<<8)){p[b+24>>2]=16726}f=b,g=(v(ss(0,q[e|0]<<28>>24),p[b+24>>2])>>>0)/8363|0,p[f+24>>2]=g;if(s[b+4>>2]<s[b+8>>2]){o[b+34>>1]=r[b+34>>1]|2}if(q[a+16|0]&132){o[b+34>>1]=r[b+34>>1]|1}fb=d+16|0}function gca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;a:{b:{if(!me(b,-1)){f=p[a+12>>2];g=p[a+8>>2];if(p[a+24>>2]==p[a+28>>2]){c=-1;if(!(q[a+48|0]&16)){break a}h=p[a+24>>2];i=p[a+20>>2];j=p[a+44>>2];k=p[a+20>>2];p[114610]=0;c=a+32|0;K(110,c|0,0);d=p[114610];p[114610]=0;if((d|0)==1){break b}d=Bc(c);p[114610]=0;K(149,c|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}d=Ib(c);ow(a,d,wb(c)+d|0);qr(a,h-i|0);p[a+44>>2]=p[a+20>>2]+(j-k|0)}p[e+12>>2]=p[a+24>>2]+1;l=a,m=p[Uc(e+12|0,a+44|0)>>2],p[l+44>>2]=m;if(q[a+48|0]&8){c=Ib(a+32|0);Bm(a,c,c+(f-g|0)|0,p[a+44>>2])}c=LG(a,zm(b));break a}c=pr(b);break a}a=O(0)|0;H()|0;T(a|0)|0;V();c=-1}fb=e+16|0;return c|0}function Sc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=p[a+116>>2];c=b;a:{f=p[a+112>>2];b:{if(b|f){b=p[a+124>>2];if((b|0)>(c|0)?1:(b|0)>=(c|0)?s[a+120>>2]>=f>>>0:0){break b}}f=nv(a);if((f|0)>-1){break a}}p[a+104>>2]=0;return-1}b=p[a+8>>2];c=p[a+116>>2];d=c;c:{d:{e=p[a+112>>2];if(!(c|e)){break d}c=(p[a+124>>2]^-1)+d|0;d=p[a+120>>2]^-1;e=d+e|0;if(e>>>0<d>>>0){c=c+1|0}d=e;e=p[a+4>>2];g=b-e|0;h=d>>>0>=g>>>0;g=g>>31;if((c|0)>(g|0)?1:(c|0)>=(g|0)?h:0){break d}p[a+104>>2]=d+e;break c}p[a+104>>2]=b}e:{if(!b){a=p[a+4>>2];break e}e=p[a+124>>2];c=a;d=p[a+120>>2];a=p[a+4>>2];b=(b-a|0)+1|0;g=b;d=d+b|0;b=(b>>31)+e|0;p[c+120>>2]=d;p[c+124>>2]=d>>>0<g>>>0?b+1|0:b}a=a+ -1|0;if(q[a|0]!=(f|0)){n[a|0]=f}return f}function mI(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;f=Lb(e+32|0);p[114610]=0;J(1619,a|0,e+24|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){d=p[e+28>>2];g=p[e+24>>2];Me(f);p[114610]=0;g=!d&g>>>0<255|d>>>0<0?g:255;K(149,f|0,g|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=cc(f,d);p[114610]=0;J(1620,a|0,h|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((jC(f)|0)!=-1){a=jC(f);p[114610]=0;K(149,f|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}}p[114610]=0;N(13,e+8|0,c|0,f|0);a=p[114610];p[114610]=0;if((a|0)!=1){break b}break a}break a}xb(b,e+8|0);pb(e+8|0);pb(f);fb=e+48|0;return}a=I()|0;H()|0;pb(f);L(a|0);E()}function Q9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=fb-32|0;fb=b;e=Xg(a);ud(b+24|0);p[114610]=0;a=J(2200,p[b+24>>2],p[b+28>>2])|0;c=p[114610];p[114610]=0;a:{b:{if((c|0)==1){break b}p[114610]=0;K(1532,e|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}a=0;c:{while(1){p[114610]=0;c=J(2200,p[b+24>>2],p[b+28>>2])|0;d=p[114610];p[114610]=0;d:{if((d|0)!=1){if((a|0)<(c|0)){break d}fb=b+32|0;return}a=I()|0;H()|0;break a}c=p[p[b+24>>2]+(a<<3)>>2];p[114610]=0;c=J(85,b+8|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(1534,e|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break c}pb(c);a=a+1|0;continue}break}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(c);break a}a=I()|0;H()|0}bd(e);L(a|0);E()}function MH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=fb-48|0;fb=c;p[c+8>>2]=542066252;d=c+8|4;n[d|0]=0;n[d+1|0]=0;n[d+2|0]=0;n[d+3|0]=0;d=p[b+4220>>2];n[c+16|0]=d;n[c+17|0]=d>>>8;n[c+18|0]=d>>>16;n[c+19|0]=d>>>24;d=p[b+4224>>2];n[c+20|0]=d;n[c+21|0]=d>>>8;n[c+22|0]=d>>>16;n[c+23|0]=d>>>24;d=p[b+4228>>2];n[c+24|0]=d;n[c+25|0]=d>>>8;n[c+26|0]=d>>>16;n[c+27|0]=d>>>24;d=p[b+4232>>2];n[c+28|0]=d;n[c+29|0]=d>>>8;n[c+30|0]=d>>>16;n[c+31|0]=d>>>24;d=p[b+4236>>2];n[c+32|0]=d;n[c+33|0]=d>>>8;n[c+34|0]=d>>>16;n[c+35|0]=d>>>24;n[c+36|0]=q[b+4240|0];n[c+37|0]=q[b+4241|0];n[c+38|0]=q[b+4242|0];n[c+39|0]=q[b+4243|0];n[c+40|0]=q[b+4244|0];b=b+4208|0;nk(b,33);ac(p[b>>2],c+8|0,33);Ei(c,b);Ed(a,c);fb=c+48|0}function Zn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;f=d?d:461580;d=p[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=q[b|0];d=a<<24>>24;if((d|0)>=0){p[i>>2]=a;e=(d|0)!=0;break a}a=n[b|0];if(!p[p[21199]>>2]){p[i>>2]=a&57343;e=1;break a}a=(a&255)+ -194|0;if(a>>>0>50){break c}d=p[(a<<2)+57632>>2];a=c+ -1|0;if(!a){break b}b=b+1|0}g=q[b|0];j=g>>>3|0;if((j+ -16|(d>>26)+j)>>>0>7){break c}while(1){a=a+ -1|0;d=g+ -128|d<<6;if((d|0)>=0){p[f>>2]=0;p[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=q[b|0];if((g&192)==128){continue}break}}p[f>>2]=0;p[114584]=25;e=-1;break a}p[f>>2]=d}fb=h+16|0;return e|0}function Joa(a){var b=0,c=0,d=0;p[114610]=0;M(1402,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){b=p[a+4>>2];if(b){Hoa(b);Nb(b)}p[a+4>>2]=0;sx(a+1304500|0);Ur(a+1304436|0);pb(a+1304424|0);pb(a+1304412|0);pb(a+1304400|0);Tr(a+1304396|0);Sr(a+1304392|0);Io(a+1304360|0);b=a+946300|0;c=a+906300|0;while(1){b=Im(b+ -160|0);if((c|0)!=(b|0)){continue}break}ps(a+484360|0);rx(a+484344|0);be(a+480248|0);return a}c=O(0)|0;H()|0;sx(a+1304500|0);Ur(a+1304436|0);pb(a+1304424|0);pb(a+1304412|0);pb(a+1304400|0);Tr(a+1304396|0);Sr(a+1304392|0);Io(a+1304360|0);b=a+946300|0;d=a+906300|0;while(1){b=Im(b+ -160|0);if((d|0)!=(b|0)){continue}break}ps(a+484360|0);rx(a+484344|0);be(a+480248|0);rb(c);E()}function S5(a,b,c,d){var e=0,f=0,g=0,h=w(0),i=w(0),j=0,k=0,l=0,m=0,n=0,o=w(0);a:{if((a|0)<4){break a}e=a>>2;m=(e|0)>1?e:1;i=w(a|0);h=w(w(1)/i);e=0;while(1){j=e<<2;f=+w(w(w(g<<2)*w(3.1415927410125732))*h);n=j+b|0,o=w(qe(f)),t[n>>2]=o;k=e|1;l=k<<2;n=l+b|0,o=w(-w(Sh(f))),t[n>>2]=o;f=+w(w(w(k|0)*w(1.5707963705062866))*h);n=c+j|0,o=w(w(qe(f))*w(.5)),t[n>>2]=o;n=c+l|0,o=w(w(Sh(f))*w(.5)),t[n>>2]=o;e=e+2|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}if((a|0)<8){break a}a=a>>3;a=(a|0)>1?a:1;h=w(w(1)/i);e=0;g=0;while(1){b=e|1;f=+w(w(w(b<<1)*w(3.1415927410125732))*h);n=(e<<2)+d|0,o=w(qe(f)),t[n>>2]=o;n=(b<<2)+d|0,o=w(-w(Sh(f))),t[n>>2]=o;e=e+2|0;g=g+1|0;if((a|0)!=(g|0)){continue}break}}}function Co(a,b,c){var d=0,e=0,f=0;d=Lb(a);a=wb(b);p[114610]=0;K(111,d|0,a|0);a=p[114610];p[114610]=0;if((a|0)!=1){a:{if(wb(b)){while(1){f=p[Ui(b,e)>>2];a=32;b:{c:{while(1){if(p[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}p[114610]=0;K(110,d|0,a<<24>>24);a=p[114610];p[114610]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(p[(a<<2)+c>>2]==(f|0)){p[114610]=0;K(110,d|0,a<<24>>24);a=p[114610];p[114610]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}p[114610]=0;K(110,d|0,63);a=p[114610];p[114610]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(e>>>0<wb(b)>>>0){continue}break}}return}}a=I()|0;H()|0;pb(d);L(a|0);E()}function kla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-32|0;fb=f;p[f+24>>2]=b;b=p[a>>2];j=f,k=Ub(a),p[j>>2]=k;b=b+v(Kr(f+24|0,f),6)|0;a:{b:{if(!c){break b}g=p[qb(a)>>2];h=p[a+4>>2];if((g-h|0)/6>>>0>=c>>>0){e=c;i=h-b|0;g=(i|0)/6|0;if(g>>>0<c>>>0){jz(a,c-g|0,d);e=g;if(!i){break b}}ila(a,b,h,v(c,6)+b|0);g=b;if(b>>>0<=d>>>0){d=d>>>0<s[a+4>>2]?v(c,6)+d|0:d}Qka(g,e,d);break b}e=qb(a);e=cQ(f,_y(a,Rf(a)+c|0),(b-p[a>>2]|0)/6|0,e);p[114610]=0;N(710,e|0,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}p[114610]=0;b=P(1565,a|0,e|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}Xs(e)}a=Ze(b);fb=f+32|0;return a|0}a=I()|0;H()|0;Xs(e);L(a|0);E()}function Sra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-32|0;fb=e;p[e+24>>2]=b;b=p[a>>2];j=e,k=Ub(a),p[j>>2]=k;b=b+(Ap(e+24|0,e)<<1)|0;a:{f=Lx(c,d);b:{if((f|0)<1){break b}g=p[qb(a)>>2];h=p[a+4>>2];if((f|0)<=g-h>>1){p[e>>2]=d;i=h-b|0;g=i>>1;if((f|0)>(g|0)){p[e>>2]=c;p[e>>2]=p[e>>2]+(g<<1);fM(a,p[e>>2],d,f-g|0);if((i|0)<1){break b}}Qra(a,b,h,(f<<1)+b|0);Ye(c,p[e>>2],b);break b}h=qb(a);f=fU(e,Ai(a,fc(a)+f|0),b-p[a>>2]>>1,h);p[114610]=0;N(1247,f|0,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}p[114610]=0;b=P(1248,a|0,f|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}EA(f)}a=Ze(b);fb=e+32|0;return a|0}a=I()|0;H()|0;EA(f);L(a|0);E()}function Nqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=w(0),g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>3;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){p[e+12>>2]=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);Td(e+12|0,w(-1));f=w(t[e+12>>2]*w(32768));t[e+12>>2]=f;h=a;f=$d(f);a:{if(w(x(f))<w(2147483648)){g=~~f;break a}g=-2147483648}i=h,j=Mc(g),o[i>>1]=j;p[e+12>>2]=q[b+4|0]|q[b+5|0]<<8|(q[b+6|0]<<16|q[b+7|0]<<24);Td(e+12|0,w(-1));f=w(t[e+12>>2]*w(32768));t[e+12>>2]=f;h=a;f=$d(f);b:{if(w(x(f))<w(2147483648)){g=~~f;break b}g=-2147483648}i=h,j=Mc(g),o[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<3}function Yua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-48|0;fb=d;a:{b:{if(p[a+8>>2]!=p[Xb(a)>>2]){break b}g=a+8|0;h=a+4|0;c=p[a+4>>2];e=p[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>2)+1|0)/-2<<2;i=g,j=Ye(f,p[g>>2],f+c|0),p[i>>2]=j;p[h>>2]=c+p[h>>2];break b}i=d,j=p[Xb(a)>>2]-p[a>>2]>>1,p[i+24>>2]=j;p[d+44>>2]=1;c=p[Uc(d+24|0,d+44|0)>>2];c=An(d+24|0,c,c>>>2|0,p[a+16>>2]);e=Ic(d+16|0,p[a+4>>2]);f=p[Ic(d+8|0,p[a+8>>2])>>2];e=p[e>>2];p[114610]=0;N(1162,c|0,e|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}Qb(a,c);Qb(h,c+4|0);Qb(g,c+8|0);Qb(Xb(a),Xb(c));Fh(c)}KP(p[a+16>>2],p[a+8>>2],b);p[a+8>>2]=p[a+8>>2]+4;fb=d+48|0;return}a=I()|0;H()|0;Fh(c);L(a|0);E()}function PKa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-48|0;fb=d;a:{b:{if(p[a+8>>2]!=p[Xb(a)>>2]){break b}g=a+8|0;h=a+4|0;c=p[a+4>>2];e=p[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>1)+1|0)/-2<<1;i=g,j=vKa(f,p[g>>2],f+c|0),p[i>>2]=j;p[h>>2]=c+p[h>>2];break b}i=d,j=p[Xb(a)>>2]-p[a>>2]|0,p[i+24>>2]=j;p[d+44>>2]=1;c=p[Uc(d+24|0,d+44|0)>>2];c=UR(d+24|0,c,c>>>2|0,p[a+16>>2]);e=Ic(d+16|0,p[a+4>>2]);f=p[Ic(d+8|0,p[a+8>>2])>>2];e=p[e>>2];p[114610]=0;N(523,c|0,e|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}Qb(a,c);Qb(h,c+4|0);Qb(g,c+8|0);Qb(Xb(a),Xb(c));ut(c)}Oz(p[a+16>>2],p[a+8>>2],b);p[a+8>>2]=p[a+8>>2]+2;fb=d+48|0;return}a=I()|0;H()|0;ut(c);L(a|0);E()}function cia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=_h(a,b,c,d);p[a>>2]=79620;c=xi(a+4208|0);d=a+4288|0;p[d>>2]=0;p[d+4>>2]=0;p[a+4280>>2]=0;p[a+4284>>2]=0;p[114610]=0;d=Y(1393)|0;e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}p[114610]=0;d=M(1394,d|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}p[a+4228>>2]=1049926264;p[a+4232>>2]=0;p[a+4220>>2]=1056964608;p[a+4224>>2]=1056964608;p[a+4296>>2]=d;n[a+4244|0]=0;p[a+4236>>2]=2147483647;p[a+4240>>2]=0;Bw(a);Dr(a);p[114610]=0;P(1639,a+44|0,2,2)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;S(1640,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}return a|0}a=I()|0;H()|0;Gg(c);Ge(b);L(a|0);E()}function CF(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=fb-16|0;fb=d;a:{b:{c:{d:{if((b|0)>=0){if((al(a+8|0)|0)>(b|0)){break d}}a=W(8)|0;p[114610]=0;d=J(85,d|0,40569)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}dc(a,d);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(d);break b}if(!(c<=1?!(c<0):0)){a=W(8)|0;p[114610]=0;d=J(85,d|0,40547)|0;b=p[114610];p[114610]=0;if((b|0)!=1){dc(a,d);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(d);break b}b=I()|0;H()|0;X(a|0);break b}e=Xm(c*64);p[(p[a+32>>2]+v(b,896)|0)+1075744>>2]=e;fb=d+16|0;return}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function kx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-16|0;fb=c;if(!cd(a)){l=c,m=Ub(a),p[l+8>>2]=m;l=c,m=Vb(a),p[l>>2]=m;if(Ab(c+8|0,c)){while(1){f=p[c+8>>2];En(f,4194304,67108864);b=d;d=p[f>>2];g=d+g|0;if(g>>>0<d>>>0){b=b+1|0}d=b;Rd(c+8|0);if(Ab(c+8|0,c)){continue}break}}b=Bb(a);h=Bb(a);l=c,m=Ub(a),p[l+8>>2]=m;l=c,m=Vb(a),p[l>>2]=m;b=QNa(g,d,b,0);f=ib;g=h<<24;d=0;if(Ab(c+8|0,c)){h=b;f=((f&1)<<31|b>>>1)&2147483647;while(1){b=p[c+8>>2];i=b;e=p[b>>2];b=e>>>8|0;e=f+(e<<24)|0;b=b+j|0;b=dd(QNa(e,e>>>0<f>>>0?b+1|0:b,h,k),ib);p[i>>2]=b;e=g;g=e-b|0;d=d-(e>>>0<b>>>0)|0;Rd(c+8|0);if(Ab(c+8|0,c)){continue}break}}a=sc(a,0);p[a>>2]=g+p[a>>2]}fb=c+16|0}function X6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=w(0);g=q[c+768|0];e=576;while(1){a:{if(!(g&255)){g=0;break a}h=(v(d,j)<<2)+a|0;i=0;while(1){l=e;f=q[(c+i|0)+770|0];b:{if(!f){break b}if(f>>>0<=16){if((d|0)<1){break b}k=(-1<<f+ -1)+1|0;e=0;while(1){n=(e<<2)+h|0,o=w(Kd(b,f)+k|0),t[n>>2]=o;e=e+1|0;if((e|0)!=(d|0)){continue}break}break b}e=2<<f+ -17;f=e|1;e=Kd(b,(e-(f>>>3|0)|0)+3|0);if((d|0)<1){break b}k=f>>>1|0;g=0;while(1){m=e;e=(e>>>0)/(f>>>0)|0;t[(g<<2)+h>>2]=(m-v(f,e)|0)-k|0;g=g+1|0;if((g|0)!=(d|0)){continue}break}}e=18-l|0;h=(l<<2)+h|0;i=i+1|0;g=q[c+768|0];if(i>>>0<g<<1>>>0){continue}break}}j=j+1|0;if((j|0)!=4){continue}break}return d<<2}function ME(a,b,c,d){a:{b:{if(b>>>0>20){break b}c:{switch(b+ -9|0){case 0:b=p[c>>2];p[c>>2]=b+4;p[a>>2]=p[b>>2];return;case 1:b=p[c>>2];p[c>>2]=b+4;b=p[b>>2];p[a>>2]=b;p[a+4>>2]=b>>31;return;case 2:b=p[c>>2];p[c>>2]=b+4;p[a>>2]=p[b>>2];p[a+4>>2]=0;return;case 4:b=p[c>>2];p[c>>2]=b+4;b=o[b>>1];p[a>>2]=b;p[a+4>>2]=b>>31;return;case 5:b=p[c>>2];p[c>>2]=b+4;p[a>>2]=r[b>>1];p[a+4>>2]=0;return;case 6:b=p[c>>2];p[c>>2]=b+4;b=n[b|0];p[a>>2]=b;p[a+4>>2]=b>>31;return;case 7:b=p[c>>2];p[c>>2]=b+4;p[a>>2]=q[b|0];p[a+4>>2]=0;return;case 3:case 8:break a;case 9:break c;default:break b}}m[d|0](a,c)}return}b=p[c>>2]+7&-8;p[c>>2]=b+8;c=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=c}function xG(a,b,c,d){var e=0,f=0,g=0,h=0,i=w(0),j=0;e=fb-80|0;fb=e;g=a+24|0;xo(p[g>>2]);n[p[g>>2]+1304512|0]=p[a+52>>2]!=0;c=ee(e+32|0,d,c,b);d=p[a+32>>2];i=t[a+48>>2];p[e+8>>2]=p[c+8>>2];h=p[c+4>>2];p[e>>2]=p[c>>2];p[e+4>>2]=h;h=pba(e+48|0,e,d,i);c=0;a:{while(1){if(b){d=p[g>>2];p[e+24>>2]=b;p[e+28>>2]=0;p[114610]=0;p[e+16>>2]=134217727;p[e+20>>2]=0;f=J(2153,e+24|0,e+16|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break a}f=p[f>>2];p[114610]=0;d=P(2154,d|0,f|0,h|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}c=c+d|0;b=b-d|0;if(d){continue}}break}if(!(p[a+52>>2]!=1|c)){a=p[g>>2];p[a+480208>>2]=p[a+480208>>2]&-513}fb=e+80|0;return c}a=I()|0;H()|0;L(a|0);E()}function wG(a,b,c,d){var e=0,f=0,g=0,h=0,i=w(0),j=0;e=fb-80|0;fb=e;g=a+24|0;xo(p[g>>2]);n[p[g>>2]+1304512|0]=p[a+52>>2]!=0;c=ee(e+32|0,d,c,b);d=p[a+32>>2];i=t[a+48>>2];p[e+8>>2]=p[c+8>>2];h=p[c+4>>2];p[e>>2]=p[c>>2];p[e+4>>2]=h;h=nba(e+48|0,e,d,i);c=0;a:{while(1){if(b){d=p[g>>2];p[e+24>>2]=b;p[e+28>>2]=0;p[114610]=0;p[e+16>>2]=134217727;p[e+20>>2]=0;f=J(2153,e+24|0,e+16|0)|0;j=p[114610];p[114610]=0;if((j|0)==1){break a}f=p[f>>2];p[114610]=0;d=P(2154,d|0,f|0,h|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}c=c+d|0;b=b-d|0;if(d){continue}}break}if(!(p[a+52>>2]!=1|c)){a=p[g>>2];p[a+480208>>2]=p[a+480208>>2]&-513}fb=e+80|0;return c}a=I()|0;H()|0;L(a|0);E()}function gFa(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,3,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(765,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}p[114610]=0;J(470,d|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function UKa(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,2,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(519,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}p[114610]=0;J(470,d|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function LGa(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,2,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(512,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}p[114610]=0;J(470,d|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function ALa(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,3,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(469,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}p[114610]=0;J(470,d|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function Wk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;j=1;i=d&2147483647;m=i;k=c;a:{if(!c&(i|0)==2147418112?a|b:(i|0)==2147418112&c>>>0>0|i>>>0>2147418112){break a}l=h&2147483647;n=l;i=g;if(!g&(l|0)==2147418112?e|f:(l|0)==2147418112&g>>>0>0|l>>>0>2147418112){break a}if(!(a|e|(i|k)|(b|f|(m|n)))){return 0}k=d&h;if((k|0)>0?1:(k|0)>=0?(c&g)>>>0>=0:0){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:(d|0)<(h|0)?1:(d|0)<=(h|0)?c>>>0<g>>>0:0){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:(d|0)>(h|0)?1:(d|0)>=(h|0)?c>>>0>g>>>0:0){break a}j=(a^e|c^g)!=0|(b^f|d^h)!=0}return j}function eja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb+ -64|0;fb=e;p[e+56>>2]=d;d=p[a+28>>2];tn(p[p[d>>2]+ -12>>2]+d|0,0);if(p[p[b>>2]+4>>2]){h=p[a+28>>2];i=e+40|0;f=p[a+12>>2];d=p[p[b>>2]+4>>2];g=d+p[a+8>>2]|0;if(g>>>0<d>>>0){f=f+1|0}f=Bg(i,g,f);d=p[f+12>>2];p[e+8>>2]=p[f+8>>2];p[e+12>>2]=d;d=p[f+4>>2];p[e>>2]=p[f>>2];p[e+4>>2]=d;Ni(h,e)}df(e+16|0,p[a+28>>2]);d=p[e+28>>2];p[e+32>>2]=p[e+24>>2];p[e+36>>2]=d;mI(p[a+28>>2],c,p[e+56>>2]);c=p[b>>2];b=_l(e+16|0,oc(a+32|0,p[p[b>>2]>>2]),r[p[b>>2]+12>>1]);p[114610]=0;U(1630,a|0,c|0,b|0,e+32|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){yb(b);fb=e- -64|0;return}a=I()|0;H()|0;yb(b);L(a|0);E()}function cja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb+ -64|0;fb=e;p[e+56>>2]=d;d=p[a+28>>2];tn(p[p[d>>2]+ -12>>2]+d|0,0);if(p[p[b>>2]+4>>2]){h=p[a+28>>2];i=e+40|0;f=p[a+12>>2];d=p[p[b>>2]+4>>2];g=d+p[a+8>>2]|0;if(g>>>0<d>>>0){f=f+1|0}f=Bg(i,g,f);d=p[f+12>>2];p[e+8>>2]=p[f+8>>2];p[e+12>>2]=d;d=p[f+4>>2];p[e>>2]=p[f>>2];p[e+4>>2]=d;Ni(h,e)}df(e+16|0,p[a+28>>2]);d=p[e+28>>2];p[e+32>>2]=p[e+24>>2];p[e+36>>2]=d;gI(c,p[a+28>>2],p[e+56>>2]);c=p[b>>2];b=_l(e+16|0,oc(a+32|0,p[p[b>>2]>>2]),r[p[b>>2]+12>>1]);p[114610]=0;U(1630,a|0,c|0,b|0,e+32|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){yb(b);fb=e- -64|0;return}a=I()|0;H()|0;yb(b);L(a|0);E()}function M5(a){var b=0,c=w(0),d=w(0),g=w(0),h=0,k=w(0),l=w(0);b=(i(a),e(2));a:{b:{if(!((b|0)>-1?b>>>0>=8388608:0)){if(!(b&2147483647)){return w(w(-1)/w(a*a))}if((b|0)<=-1){return w(w(a-a)/w(0))}b=(i(w(a*w(33554432))),e(2));h=-152;break b}if(b>>>0>2139095039){break a}h=-127;a=w(0);if((b|0)==1065353216){break a}}b=b+4913933|0;k=w((b>>>23|0)+h|0);a=w((f(2,(b&8388607)+1060439283|0),j())+w(-1));c=w(a/w(a+w(2)));d=w(c*c);g=w(d*d);l=a;a=w(a*w(a*w(.5)));a=w(w(k*w(.6931381225585938))+w(l+w(w(w(k*w(905800061445916e-20))+w(c*w(a+w(w(d*w(w(g*w(.2849878668785095))+w(.6666666269302368)))+w(g*w(w(g*w(.24279078841209412))+w(.40000972151756287)))))))-a)))}return a}function Mwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-32|0;fb=e;j=p[a+24>>2];k=p[a+20>>2];l=p[a+16>>2];g=p[a+4>>2];f=g;b=p[a>>2];p[e+24>>2]=b;p[e+28>>2]=f;g=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=o[i+h>>1];p[(e+8|0)+(g<<2)>>2]=f+((v(o[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],k);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],j);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;b=p[e+24>>2];f=p[e+28>>2];continue}break}b=p[e+24>>2];f=p[e+28>>2]}p[a>>2]=b;p[a+4>>2]=f;fb=e+32|0}function zg(a,b){var c=w(0),d=w(0),e=w(0),f=w(0),g=w(0);d=t[a+4268>>2];f=hH(a);c=w(w(t[a+4224>>2]*w(1.899999976158142))+w(.10000000149011612));e=fe(w(10),w(w(w(p[((b<<2)+a|0)+4292>>2])*w(-3))/w(t[a+4268>>2]*w(w(t[a+4220>>2]*w(19.899999618530273))+w(.10000000149011612)))));c=w(w(fe(e,w(w(2)-w(w(2)/c)))+w(-1))/w(w(1)-ho(c>w(1)?w(3.1415927410125732):w(w(f*w(6.2831854820251465))/d))));a:{if(c==w(0)){break a}f=w(c+c);d=w(w(-2)-f);c=w(D(w(w(d*d)+w(w(c*c)*w(-4)))));g=w(w(c-d)/f);if(w(x(g))<=w(1)){break a}g=w(w(-w(c+d))/f)}b=(b<<3)+a|0;t[b+4404>>2]=g;t[b+4400>>2]=e;c=t[a+4272>>2];c=w(c*c);d=w(w(1)-c);e=w(e*e);return w(w(w(w(d*d)*e)/w(w(1)-w(c*e)))+c)}function fAa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-32|0;fb=d;vd(b,0);QN(d,a+1|0);zc(d+16|0,d);p[114610]=0;J(370,b+43|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(d+16|0);c=a+73|0;p[b+24>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+54|0;p[b>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+58|0;p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+62|0;if(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24)){p[b+8>>2]=(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))+1}o[b+30>>1]=(q[a+68|0]<<1)+2;o[b+34>>1]=r[b+34>>1]&65533|q[a|0]>>>6&2;vc(b+8|0,p[b>>2]);vc(b+4|0,p[b+8>>2]);fb=d+32|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function Qza(a,b){var c=0,d=0,e=0;c=fb+ -64|0;fb=c;Ne(c+40|0,a,4);a=p[c+40>>2];p[114610]=0;d=M(412,c+40|0)|0;e=p[114610];p[114610]=0;a:{b:{c:{if((e|0)==1){break c}p[114610]=0;d=M(413,d|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;Q(414,c+8|0,3,d|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(415,c+24|0,c+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}p[114610]=0;K(987,c|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}p[114610]=0;J(470,c|0,c+24|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break b}pb(c+24|0);uc(c+40|0);fb=c- -64|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(c+24|0)}uc(c+40|0);L(a|0);E()}function Bja(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-48|0;fb=d;sj(a,d+40|0);e=p[d+44>>2];if(!e&s[d+40>>2]>256|e>>>0>0){p[d+40>>2]=256;p[d+44>>2]=0}a:{b:{c:{d:{if(p[d+40>>2]|p[d+44>>2]){while(1){mf(a,d+38|0);e=Lb(d+24|0);p[114610]=0;P(726,a|0,e|0,255)|0;f=p[114610];p[114610]=0;if((f|0)==1){break d}p[114610]=0;N(13,d+8|0,c|0,e|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;f=J(1617,b|0,d+38|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break b}xb(f,d+8|0);pb(d+8|0);pb(e);e=p[d+44>>2];g=g+1|0;if(!e&s[d+40>>2]>g>>>0|e>>>0>0){continue}break}}fb=d+48|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+8|0)}pb(e);L(a|0);E()}function vma(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=ve(11555);if(e){l=p[a+12>>2];c=b+16|0;if(dk(a,q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))){g=b+12|0;c=g;a:{if(!(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))){break a}h=b+4|0;while(1){if(!af(a,4)){break a}b:{if((q[h|0]|q[h+1|0]<<8)>>>0>=64){if((uma(a)|0)<1){break b}}d=0;b=1;while(1){c=zt(a);if(c){m=wo(c<<24>>24);i=d>>>0>=e>>>0;j=i&b;c=j;c:{if(i){break c}c=j;if(!(b&1)){break c}c=q[d+11555|0]==(m&255)}b=c;d=d+1|0;continue}break}Qc(a,4);f=b?(d|0)==(e|0)?1:f:f}k=k+1|0;b=g;if(k>>>0<(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))>>>0){continue}break}}d=f&1}dk(a,l)}return d}function qxa(a){var b=0,c=0,d=0;b=fb+ -64|0;fb=b;a:{b:{c:{d:{e:{while(1){p[b+60>>2]=c;p[b+60>>2]=c<<3;Rz(b+32|0,c>>>0<16?18062:17997);p[114610]=0;K(510,b+16|0,b+60|0);d=p[114610];p[114610]=0;if((d|0)==1){break e}p[114610]=0;N(511,b+48|0,b+32|0,b+16|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}p[114610]=0;K(512,b+8|0,(c<<5)+a|0);d=p[114610];p[114610]=0;if((d|0)==1){break c}p[114610]=0;J(470,b+8|0,b+48|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break c}pb(b+48|0);pb(b+16|0);yb(b+32|0);c=c+1|0;if((c|0)!=128){continue}break}fb=b- -64|0;return}c=I()|0;H()|0;break a}c=I()|0;H()|0;break b}c=I()|0;H()|0;pb(b+48|0)}pb(b+16|0)}yb(b+32|0);L(c|0);E()}function wma(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=ve(11555);if(e){l=p[a+8>>2];c=b+16|0;if(Jc(a,q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))){g=b+12|0;c=g;a:{if(!(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))){break a}h=b+4|0;while(1){if(!Hb(a,4)){break a}b:{if((q[h|0]|q[h+1|0]<<8)>>>0>=64){if((vh(a)|0)<1){break b}}d=0;b=1;while(1){c=td(a);if(c){m=wo(c<<24>>24);i=d>>>0>=e>>>0;j=i&b;c=j;c:{if(i){break c}c=j;if(!(b&1)){break c}c=q[d+11555|0]==(m&255)}b=c;d=d+1|0;continue}break}Sb(a,4);f=b?(d|0)==(e|0)?1:f:f}k=k+1|0;b=g;if(k>>>0<(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))>>>0){continue}break}}d=f&1}Jc(a,l)}return d}function mta(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=$j(a,b);a:{if((h|0)==255){break a}if(aj(a)){break a}b:{if(c>>>0>6208431){i=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}i=f;c=NNa(1<<20-f,0,c,0)+24858e3|0;f=ib;c=dd(QNa(c,c>>>0<24858e3?f+1|0:f,49716e3,0),ib)}if(e){o[g+14>>1]=(b&3)+c;o[g+12>>1]=1023;c=r[rf(g+14|0,g+12|0)>>1]}e=ms(h);b=a+4|0;j=Yb(b,h),k=(i<<10|c)>>>8|(d?0:32),n[j|0]=k;Yg(p[a>>2],e|160,c&255);Yg(p[a>>2],e|176,q[Yb(b,h)|0]);n[a+530|0]=1}fb=g+16|0}function Fna(a){var b=0,c=0,d=0;d=fb-32|0;fb=d;BM(d);b=p[d+28>>2];c=p[d+24>>2];n[a+24|0]=c;n[a+25|0]=c>>>8;n[a+26|0]=c>>>16;n[a+27|0]=c>>>24;n[a+28|0]=b;n[a+29|0]=b>>>8;n[a+30|0]=b>>>16;n[a+31|0]=b>>>24;b=p[d+20>>2];c=p[d+16>>2];n[a+16|0]=c;n[a+17|0]=c>>>8;n[a+18|0]=c>>>16;n[a+19|0]=c>>>24;n[a+20|0]=b;n[a+21|0]=b>>>8;n[a+22|0]=b>>>16;n[a+23|0]=b>>>24;b=p[d+12>>2];c=p[d+8>>2];n[a+8|0]=c;n[a+9|0]=c>>>8;n[a+10|0]=c>>>16;n[a+11|0]=c>>>24;n[a+12|0]=b;n[a+13|0]=b>>>8;n[a+14|0]=b>>>16;n[a+15|0]=b>>>24;b=p[d+4>>2];c=p[d>>2];n[a|0]=c;n[a+1|0]=c>>>8;n[a+2|0]=c>>>16;n[a+3|0]=c>>>24;n[a+4|0]=b;n[a+5|0]=b>>>8;n[a+6|0]=b>>>16;n[a+7|0]=b>>>24;fb=d+32|0}function bja(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb+ -64|0;fb=d;e=p[a+28>>2];tn(p[p[e>>2]+ -12>>2]+e|0,0);if(p[p[b>>2]+4>>2]){i=p[a+28>>2];e=d+48|0;h=p[a+12>>2];f=p[p[b>>2]+4>>2];g=f+p[a+8>>2]|0;if(g>>>0<f>>>0){h=h+1|0}f=Bg(e,g,h);g=p[f+12>>2];p[d+16>>2]=p[f+8>>2];p[d+20>>2]=g;e=p[f+4>>2];p[d+8>>2]=p[f>>2];p[d+12>>2]=e;Ni(i,d+8|0)}df(d+24|0,p[a+28>>2]);e=p[d+36>>2];p[d+40>>2]=p[d+32>>2];p[d+44>>2]=e;m[1187](p[a+28>>2],c,p[p[b>>2]+8>>2]);c=p[b>>2];e=_l(d+24|0,oc(a+32|0,p[p[b>>2]>>2]),r[p[b>>2]+12>>1]);p[114610]=0;b=U(1630,a|0,c|0,e|0,d+40|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){yb(e);fb=d- -64|0;return b}a=I()|0;H()|0;yb(e);L(a|0);E()}function GE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;c=1;a:{b:{switch(b-a>>2){case 2:b=b+ -4|0;if(!zd(b,a)){break a}Qb(a,b);break a;case 3:nm(a,a+4|0,b+ -4|0);break a;case 4:yv(a,a+4|0,a+8|0,b+ -4|0);break a;case 5:xv(a,a+4|0,a+8|0,a+12|0,b+ -4|0);break a;case 0:case 1:break a;default:break b}}e=a+8|0;nm(a,a+4|0,e);d=a+12|0;c:{while(1){g=(b|0)==(d|0);if(g){break c}d:{if(zd(d,e)){p[f+12>>2]=p[d>>2];h=d;while(1){e:{c=e;p[h>>2]=p[c>>2];if((a|0)==(c|0)){c=a;break e}h=c;e=c+ -4|0;if(zd(f+12|0,e)){continue}}break}p[c>>2]=p[f+12>>2];i=i+1|0;if((i|0)==8){break d}}e=d;d=d+4|0;continue}break}c=(d+4|0)==(b|0)}c=c|g}fb=f+16|0;return c&1}function AR(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=q[e|0];if(!i|!b){break a}g=d+ -6|0;j=35>>>(g&63)&(g&255)>>>0<6;h=v(0-c|0,6);k=(d+ -2&255)>>>0>2;while(1){g=a+h|0;f=q[g+3|0];b:{if(!((f+ -2&255)>>>0>2|k)){c=1;if(q[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((q[f+2|0]+ -11&255)>>>0>2){break c}if(q[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((q[f+2|0]+ -3&255)>>>0>3){break d}if(q[f+4|0]){break a}}e:{if(!c){break e}c=i;a=q[(a+h|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}n[e|0]=0;return}a=g;b=b+ -1|0;if(b){continue}break}}}function nta(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=255;a:{b:{e=a+58|0;c=q[Yb(e,b)|0];if((c|0)==255){break b}if(n[Yb(e,b)|0]>-1){break a}d=a+22|0;c=c&127;if(r[Yc(d,c)>>1]!=65535){if(r[Yc(d,c)>>1]!=(b|0)){break b}}i=Yc(d,c),j=b,o[i>>1]=j;i=Yb(e,b),j=c,n[i|0]=j;break a}h=a+4|0;f=a+22|0;c=0;d=255;while(1){if(r[Yc(f,c)>>1]==65535){i=Yc(f,c),j=b,o[i>>1]=j;i=Yb(e,b),j=c,n[i|0]=j;break a}if(!(q[Yb(h,c)|0]&32)){g=n[Yb(e,r[Yc(f,c)>>1])|0]>-1?g:c;d=c}c=c+1|0;if((c|0)!=18){continue}break}if((d&255)!=255){c=(g&255)==255?d:g;d=c&255;i=Yb(e,r[Yc(f,d)>>1]),j=255,n[i|0]=j;i=Yc(f,d),j=b,o[i>>1]=j;i=Yb(e,b),j=c,n[i|0]=j}c=$j(a,b)}return c&255}function Qi(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;n[a|0]=0;f=tf(p[p[b>>2]+ -12>>2]+b|0);e=p[p[b>>2]+ -12>>2]+b|0;a:{b:{if(f){if(p[e+72>>2]){Qq(p[(p[p[b>>2]+ -12>>2]+b|0)+72>>2])}c:{if(!(p[(p[p[b>>2]+ -12>>2]+b|0)+4>>2]&4096)|c){break c}qc(d+24|0,p[p[b>>2]+ -12>>2]+b|0);p[114610]=0;f=M(21,d+24|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}Gb(d+24|0);c=mm(d+16|0,b);e=lk(d+8|0);while(1){d:{if(!ao(c,e)){break d}if(!wg(f,8192,Ij(c))){break d}Uk(c);continue}break}if(!Pi(c,e)){break c}mg(p[p[b>>2]+ -12>>2]+b|0,6)}g=a,h=tf(p[p[b>>2]+ -12>>2]+b|0),n[g|0]=h;break b}mg(e,4)}fb=d+32|0;return a}a=I()|0;H()|0;Gb(d+24|0);L(a|0);E()}function Eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;JG(c+24|0);HG(a+24|0,Cd(c+24|0));th(c+24|0);o[a+28>>1]=0;Dba(c+24|0,oM());vs(a+32|0,c+24|0);gg(c+24|0);IG(c+24|0,p[a>>2]);RG(a+4|0,Cd(c+24|0));Nc(c+24|0);wm(p[a+24>>2],p[a+4>>2]);p[a+60>>2]=0;p[a+48>>2]=1065353216;p[a+52>>2]=0;p[a+16>>2]=0;p[a+20>>2]=0;p[a+8>>2]=0;n[a- -64|0]=0;e=c,f=fn(b),p[e+24>>2]=f;e=c,f=pi(b),p[e+16>>2]=f;a:{if(oi(c+24|0,c+16|0)){while(1){d=$g(c+24|0);b=Uf(c,d);p[114610]=0;Q(2081,a|0,b|0,d+12|0,0);d=p[114610];p[114610]=0;if((d|0)==1){break a}pb(b);jp(c+24|0);if(oi(c+24|0,c+16|0)){continue}break}}fb=c+32|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function No(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;if(e){n[e|0]=0}p[f+12>>2]=4;j=a+484344|0;d=_e(Rb(j,b),c,d);g=q[d+5|0];a:{b:{c:{d:{h=q[d+3|0];switch(h+ -10|0){case 2:case 4:case 7:break c;case 0:break d;default:break a}}p[f+12>>2]=2;i=0;break b}p[f+12>>2]=1;i=0;if((h|0)!=17){break b}i=p[a+480180>>2]==4}l=f,m=p[Rb(j,b)+12>>2]+(c^-1)|0,p[l+8>>2]=m;c=p[Cb(f+8|0,f+12|0)>>2];if(!c){break a}while(1){k=v(Qj(Rb(j,b)),6);a=k+d|0;if(q[a+3|0]!=34){break a}h=g<<8;g=i?g>>>0<256?h+ -8192|0:h:h;d=q[(d+k|0)+5|0];c=c+ -1|0;if(e){n[e|0]=1}g=d|g;d=a;if(c){continue}break}}fb=f+16|0;return g|0}function u6(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;p[a+1504>>2]=0;p[a+1508>>2]=0;a:{if(p[a+96>>2]){break a}if(!f6(a)){break a}if(bc(a,1)){Wb(a,35);return 0}h=c;b:{c:{if(!(p[a+84>>2]!=p[a+92>>2]?p[a+80>>2]:0)){c=bc(a,_k(p[a+408>>2]+ -1|0));if((c|0)==-1|(c|0)>=p[a+408>>2]){break a}p[f>>2]=c;c=v(c,6)+a|0;if(!q[c+412|0]){g=p[a+112>>2];f=g>>1;break c}g=p[a+116>>2];f=g>>1;i=bc(a,1);j=bc(a,1);if(!q[c+412|0]|i){break c}p[b>>2]=g-p[a+112>>2]>>2;b=p[a+112>>2]+g>>2;break b}aa(50360,50416,3137,50448);E()}p[b>>2]=0;b=f}p[h>>2]=b;d:{if(!(!q[c+412|0]|j)){b=v(g,3);p[d>>2]=b-p[a+112>>2]>>2;g=b+p[a+112>>2]>>2;break d}p[d>>2]=f}p[e>>2]=g;g=1}return g}function ED(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;fb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=q[b|0];e=d<<24>>24;if((e|0)>=0){p[a>>2]=d;e=(e|0)!=0;break a}d=n[b|0];if(!p[p[21199]>>2]){p[a>>2]=d&57343;e=1;break a}d=(d&255)+ -194|0;if(d>>>0>50){break b}d=p[(d<<2)+57632>>2];if(d<<v(c,6)+ -6<0?c>>>0<=3:0){break b}c=q[b+1|0];e=c>>>3|0;if((e+ -16|e+(d>>26))>>>0>7){break b}c=c+ -128|d<<6;if((c|0)>=0){p[a>>2]=c;e=2;break a}d=q[b+2|0]+ -128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){p[a>>2]=c;e=3;break a}b=q[b+3|0]+ -128|0;if(b>>>0>63){break b}p[a>>2]=b|c<<6;e=4;break a}p[114584]=25;e=-1}return e|0}function Wm(a){var b=0,c=0,d=0;b=(r[a+24>>1]<<2)+(r[p[a+4>>2]+28>>1]>>>(!q[a+77|0]<<1)|0)|0;p[a+40>>2]=((b&3)<<4)+18656;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;o[a+32>>1]=d;o[a+36>>1]=b?1:1<<c+ -12;o[a+34>>1]=-1<<(d&65535)^-1;if(r[a+24>>1]==15){o[a+36>>1]=4095}b=(r[a+26>>1]<<2)+(r[p[a+4>>2]+28>>1]>>>(!q[a+77|0]<<1)|0)|0;p[a+52>>2]=((b&3)<<4)+18656;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;o[a+44>>1]=d;o[a+48>>1]=b?1:1<<c+ -12;o[a+46>>1]=-1<<(d&65535)^-1;b=(r[a+30>>1]<<2)+(r[p[a+4>>2]+28>>1]>>>(!q[a+77|0]<<1)|0)|0;p[a+64>>2]=((b&3)<<4)+18656;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;o[a+56>>1]=d;o[a+60>>1]=b?1:1<<c+ -12;o[a+58>>1]=-1<<(d&65535)^-1}function Lwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;g=p[a+40>>2];h=p[a+36>>2];l=p[a+16>>2];f=p[a+4>>2];e=f;i=p[a>>2];p[b+8>>2]=i;p[b+12>>2]=e;f=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=f;a:{if(!d){f=g>>12;j=h>>12;break a}while(1){f=p[a+32>>2];k=e+l|0;e=n[k|0]<<8;h=p[a+28>>2]+h|0;j=h>>12;e=e+((v((n[k+1|0]<<8)-e|0,i>>>18|0)|0)/16384|0)|0;p[c>>2]=p[c>>2]+v(j,e);g=f+g|0;f=g>>12;p[c+4>>2]=p[c+4>>2]+v(e,f);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;i=p[b+8>>2];e=p[b+12>>2];continue}break}i=p[b+8>>2];e=p[b+12>>2]}p[a+40>>2]=g;p[a+20>>2]=j;p[a+36>>2]=h;p[a+24>>2]=f;p[a>>2]=i;p[a+4>>2]=e;fb=b+16|0}function Nwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;i=p[a+24>>2];j=p[a+20>>2];k=p[a+16>>2];b=p[a+4>>2];f=p[a>>2];p[e+24>>2]=f;p[e+28>>2]=b;g=p[a+12>>2];p[e+16>>2]=p[a+8>>2];p[e+20>>2]=g;if(d){while(1){l=f>>>18|0;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=n[g+h|0]<<8;p[(e+8|0)+(g<<2)>>2]=((v((n[(g|2)+h|0]<<8)-f|0,l)|0)/16384|0)+f;f=b;b=0;g=1;if(f){continue}break}p[c>>2]=p[c>>2]+v(p[e+8>>2],j);p[c+4>>2]=p[c+4>>2]+v(p[e+12>>2],i);Kb(e+24|0,e+16|0);d=d+ -1|0;if(d){c=c+8|0;f=p[e+24>>2];b=p[e+28>>2];continue}break}f=p[e+24>>2];b=p[e+28>>2]}p[a>>2]=f;p[a+4>>2]=b;fb=e+32|0}function Kwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;g=p[a+40>>2];h=p[a+36>>2];l=p[a+16>>2];f=p[a+4>>2];e=f;i=p[a>>2];p[b+8>>2]=i;p[b+12>>2]=e;f=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=f;a:{if(!d){f=g>>12;j=h>>12;break a}while(1){f=p[a+32>>2];k=(e<<1)+l|0;e=o[k>>1];h=p[a+28>>2]+h|0;j=h>>12;e=e+((v(o[k+2>>1]-e|0,i>>>18|0)|0)/16384|0)|0;p[c>>2]=p[c>>2]+v(j,e);g=f+g|0;f=g>>12;p[c+4>>2]=p[c+4>>2]+v(e,f);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;i=p[b+8>>2];e=p[b+12>>2];continue}break}i=p[b+8>>2];e=p[b+12>>2]}p[a+40>>2]=g;p[a+20>>2]=j;p[a+36>>2]=h;p[a+24>>2]=f;p[a>>2]=i;p[a+4>>2]=e;fb=b+16|0}function nda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;p[114610]=0;S(2015,a|0);d=p[114610];p[114610]=0;a:{b:{c:{if((d|0)==1){break c}p[114610]=0;S(2041,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break c}d=p[a+24>>2];b=ic(c+8|0,b);p[114610]=0;e=p[b+4>>2];p[c>>2]=p[b>>2];p[c+4>>2]=e;Q(2080,c+16|0,d|0,c|0,1);b=p[114610];p[114610]=0;if((b|0)==1){break c}b=Pd(Ib(c+16|0));pb(c+16|0);break b}b=O(0)|0;H()|0;T(b|0)|0;b=0;p[114610]=0;Q(1989,36955,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=c+32|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Ioa(a){a=a|0;var b=0,c=0,d=0;c=a+1304360|0;b=a+1074984|0;while(1){p[b+104>>2]=0;p[b+656>>2]=0;p[b+76>>2]=0;p[b+16>>2]=0;b=b+896|0;if((c|0)!=(b|0)){continue}break}GI(a+484344|0);Me(a+1304400|0);Me(a+1304412|0);Me(a+1304424|0);Kz(a+1304500|0);c=a+900380|0;b=a+484380|0;while(1){Zm(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=p[b>>2];if(d){Nb(Us(d))}p[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){CH(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}p[a+480180>>2]=0;p[a+480184>>2]=0;a=a+480186|0;o[a>>1]=0;o[a+2>>1]=0;o[a+4>>1]=0;o[a+6>>1]=0;return 1}function yF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=fb-16|0;fb=e;a:{b:{c:{d=a+8|0;d:{if(!$k(d)){if((b|0)<0|(lr(d)|0)<=(b|0)){break d}a=cp(p[a+32>>2],b+1&65535);o[a+34>>1]=r[a+34>>1]&64511|(c?1024:0);break b}d=$k(d);if((b|0)<0){break d}if((d|0)>(b|0)){break c}}a=W(8)|0;p[114610]=0;c=J(85,e|0,40585)|0;b=p[114610];p[114610]=0;e:{if((b|0)!=1){dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(c);break e}b=I()|0;H()|0;X(a|0)}L(b|0);E()}b=b+1<<2;a=a+32|0;if(!p[(b+p[a>>2]|0)+900380>>2]){break b}a=p[(b+p[a>>2]|0)+900380>>2];n[a+15|0]=q[a+15|0]&253|(c?2:0)}fb=e+16|0;return}E()}function jJa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;vd(b,0);yi(d,1,a);zc(d+16|0,d);p[114610]=0;J(370,b+43|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(d+16|0);c=a+32|0;p[b+24>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+13|0;o[b+34>>1]=r[b+34>>1]&65533|(q[c|0]|q[c+1|0]<<8)<<1&2;c=a+16|0;p[b>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+20|0;p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+24|0;p[b+8>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);n[d+16|0]=q[a+15|0];n[d|0]=64;e=b,f=q[hc(d+16|0,d)|0]<<2,o[e+30>>1]=f;fb=d+32|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function OE(a,b,c,d,e){var f=0,g=0,h=0;f=fb-208|0;fb=f;p[f+204>>2]=c;c=0;Jb(f+160|0,0,40);p[f+200>>2]=p[f+204>>2];a:{if((Dv(0,b,f+200|0,f+80|0,f+160|0,d,e)|0)<0){b=-1;break a}c=p[a+76>>2]>=0?1:c;g=p[a>>2];if(n[a+74|0]<=0){p[a>>2]=g&-33}h=g&32;b:{if(p[a+48>>2]){b=Dv(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}p[a+48>>2]=80;p[a+16>>2]=f+80;p[a+28>>2]=f;p[a+20>>2]=f;g=p[a+44>>2];p[a+44>>2]=f;d=Dv(a,b,f+200|0,f+80|0,f+160|0,d,e);b=d;if(!g){break b}m[p[a+36>>2]](a,0,0)|0;p[a+48>>2]=0;p[a+44>>2]=g;p[a+28>>2]=0;p[a+16>>2]=0;b=p[a+20>>2];p[a+20>>2]=0;b=b?d:-1}d=a;a=p[a>>2];p[d>>2]=a|h;b=a&32?-1:b;if(!c){break a}}fb=f+208|0;return b}function _1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-48|0;fb=f;p[f+40>>2]=b;a:{if(!(p[c+4>>2]&1)){c=m[p[p[a>>2]+24>>2]](a,b,c,d,e)|0;break a}qc(f+24|0,c);p[114610]=0;a=M(2450,f+24|0)|0;b=p[114610];p[114610]=0;b:{if((b|0)!=1){Gb(f+24|0);c:{if(e){Qg(f+24|0,a);break c}Pg(f+24|0,a)}g=f,h=wd(f+24|0),p[g+16>>2]=h;while(1){g=f,h=Aj(f+24|0),p[g+8>>2]=h;if(!Ab(f+16|0,f+8|0)){c=p[f+40>>2];yc(f+24|0);break a}a=p[p[f+16>>2]>>2];p[114610]=0;J(2473,f+40|0,a|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){Rd(f+16|0);continue}break}c=I()|0;H()|0;yc(f+24|0);break b}c=I()|0;H()|0;Gb(f+24|0)}L(c|0);E()}fb=f+48|0;return c|0}function Zwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;h=p[a+40>>2];i=p[a+36>>2];k=p[a+16>>2];e=p[a+4>>2];f=e;g=p[a>>2];p[b+8>>2]=g;p[b+12>>2]=e;e=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=e;a:{if(!d){e=h>>12;j=i>>12;break a}while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;g=o[f+2>>1];e=p[a+32>>2];i=p[a+28>>2]+i|0;j=i>>12;p[c>>2]=p[c>>2]+v(j,o[f>>1]);h=e+h|0;e=h>>12;p[c+4>>2]=p[c+4>>2]+v(g,e);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;g=p[b+8>>2];f=p[b+12>>2];continue}break}g=p[b+8>>2];f=p[b+12>>2]}p[a+40>>2]=h;p[a+20>>2]=j;p[a+36>>2]=i;p[a+24>>2]=e;p[a>>2]=g;p[a+4>>2]=f;fb=b+16|0}function Tma(a){var b=0,c=0,d=0,e=0,f=0;b=fb+ -64|0;fb=b;a:{e=p[a+4>>2];if(!e){break a}d=78352;while(1){c=p[a+4>>2];p[b+56>>2]=p[a>>2];p[b+60>>2]=c;c=ic(b+48|0,p[d+8>>2]);f=p[b+60>>2];p[b+24>>2]=p[b+56>>2];p[b+28>>2]=f;f=p[c+4>>2];p[b+16>>2]=p[c>>2];p[b+20>>2]=f;if(mJ(b+24|0,b+16|0)){break a}d=d+12|0;if((d|0)!=78868){continue}break}d=78880;while(1){b:{c=p[a+4>>2];p[b+40>>2]=p[a>>2];p[b+44>>2]=c;c=ic(b+32|0,p[d+8>>2]);e=p[b+44>>2];p[b+8>>2]=p[b+40>>2];p[b+12>>2]=e;e=p[c+4>>2];p[b>>2]=p[c>>2];p[b+4>>2]=e;c=mJ(b+8|0,b);if(c){break b}d=d+12|0;if((d|0)!=78928){continue}}break}fb=b- -64|0;return c}fb=b- -64|0;return(e|0)!=0}function j2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-48|0;fb=f;p[f+40>>2]=b;a:{if(!(p[c+4>>2]&1)){c=m[p[p[a>>2]+24>>2]](a,b,c,d,e)|0;break a}qc(f+24|0,c);p[114610]=0;a=M(2416,f+24|0)|0;b=p[114610];p[114610]=0;b:{if((b|0)!=1){Gb(f+24|0);c:{if(e){Qg(f+24|0,a);break c}Pg(f+24|0,a)}g=f,h=wd(f+24|0),p[g+16>>2]=h;while(1){g=f,h=jf(f+24|0),p[g+8>>2]=h;if(!Ab(f+16|0,f+8|0)){c=p[f+40>>2];pb(f+24|0);break a}a=n[p[f+16>>2]];p[114610]=0;J(2336,f+40|0,a|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){bg(f+16|0);continue}break}c=I()|0;H()|0;pb(f+24|0);break b}c=I()|0;H()|0;Gb(f+24|0)}L(c|0);E()}fb=f+48|0;return c|0}function fCa(a,b,c,d){var e=0,f=0,g=0;e=fb-80|0;fb=e;Me(b);Ne(e+56|0,a,d);a=p[e+56>>2];p[114610]=0;f=M(412,e+56|0)|0;g=p[114610];p[114610]=0;a:{b:{c:{if((g|0)==1){break c}p[114610]=0;f=M(413,f|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;Q(414,e+8|0,2,f|0,a|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;K(415,e+24|0,e+8|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;N(13,e+40|0,c|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}xb(b,e+40|0);pb(e+40|0);pb(e+24|0);uc(e+56|0);fb=e+80|0;return!d|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(e+24|0)}uc(e+56|0);L(a|0);E()}function OCa(a,b,c,d){var e=0,f=0,g=0;e=fb-80|0;fb=e;Me(b);Ne(e+56|0,a,d);a=p[e+56>>2];p[114610]=0;f=M(412,e+56|0)|0;g=p[114610];p[114610]=0;a:{b:{c:{if((g|0)==1){break c}p[114610]=0;f=M(413,f|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break c}p[114610]=0;Q(414,e+8|0,3,f|0,a|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;K(415,e+24|0,e+8|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;N(13,e+40|0,c|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}xb(b,e+40|0);pb(e+40|0);pb(e+24|0);uc(e+56|0);fb=e+80|0;return!d|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(e+24|0)}uc(e+56|0);L(a|0);E()}function _wa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;h=p[a+40>>2];i=p[a+36>>2];k=p[a+16>>2];e=p[a+4>>2];f=e;g=p[a>>2];p[b+8>>2]=g;p[b+12>>2]=e;e=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=e;a:{if(!d){e=h>>12;j=i>>12;break a}while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+k|0;g=n[f+1|0];e=p[a+32>>2];i=p[a+28>>2]+i|0;j=i>>12;p[c>>2]=p[c>>2]+(v(j,n[f|0])<<8);h=e+h|0;e=h>>12;p[c+4>>2]=p[c+4>>2]+(v(g,e)<<8);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;g=p[b+8>>2];f=p[b+12>>2];continue}break}g=p[b+8>>2];f=p[b+12>>2]}p[a+40>>2]=h;p[a+20>>2]=j;p[a+36>>2]=i;p[a+24>>2]=e;p[a>>2]=g;p[a+4>>2]=f;fb=b+16|0}function EK(a,b,c){var d=0,e=0;a:{if(p[a+480180>>2]==4){d=q[b+834|0];if(c){n[b+834|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(p[a+480180>>2]!=1048576){break a}if(c){n[b+833|0]=c;break a}c=q[b+833|0]}b:{if(!(n[b+872|0]&1)|!(c&255)){break b}d=p[b+700>>2];if(!d){break b}c:{if(!(q[a+480208|0]&16)){break c}d=p[b+700>>2];if(p[a+480180>>2]==4){break c}e=b;a=wK(a,c&15);b=NNa(a,a>>31,d,d>>31)+32768|0;a=ib;a=rc(ONa(b,b>>>0<32768?a+1|0:a,65536,0),ib);p[e+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;p[b+700>>2]=c;if((c|0)>0){break b}p[b+700>>2]=1;if(p[a+480180>>2]!=2){break b}p[b+696>>2]=0;p[b+88>>2]=p[b+88>>2]|2101248}}function t4(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;p[114610]=0;e=J(15,c+8|0,a|0)|0;d=p[114610];p[114610]=0;a:{b:{c:{if((d|0)!=1){d:{if(!q[e|0]){break d}d=Dk(c,a);p[114610]=0;J(2336,d|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){if(!Ck(d)){break d}b=p[p[a>>2]+ -12>>2];p[114610]=0;K(18,a+b|0,1);b=p[114610];p[114610]=0;if((b|0)!=1){break d}}b=O(0)|0;H()|0;uf(e);break c}uf(e);break b}b=O(0)|0;H()|0}T(b|0)|0;b=p[p[a>>2]+ -12>>2];p[114610]=0;S(19,a+b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=c+16|0;return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Qna(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=fb-32|0;fb=g;a:{if(r[a+480192>>1]<b>>>0){break a}b=p[((b<<2)+a|0)+900380>>2];if(!b){break a}AM(g+16|0,b);i=g,j=uP(g+16|0),p[i+8>>2]=j;i=g,j=hj(g+16|0),p[i>>2]=j;while(1){b:{p[114610]=0;b=J(789,g+8|0,g|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break b}if(!b){ip(g+16|0);break a}p[114610]=0;b=M(790,g+8|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break b}b=r[b>>1];if(b>>>0<=r[a+480190>>1]){b=v(b,104)+a|0;n[b+484421|0]=f;n[b+484418|0]=c;n[b+484420|0]=e;n[b+484419|0]=d}Vs(g+8|0);continue}break}a=I()|0;H()|0;ip(g+16|0);L(a|0);E()}fb=g+32|0}function Qh(a,b){var c=0,d=0,f=0,g=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;h(+b);j=e(1)|0;i=e(0)|0;f=j&2147483647;c=f;f=c+ -1048576|0;d=i;if(d>>>0<0){f=f+1|0}a:{if((f|0)==2145386495|f>>>0<2145386495){k=d<<28;f=(c&15)<<28|d>>>4;c=(c>>>4|0)+1006632960|0;d=f;c=d>>>0<0?c+1|0:c;break a}if((c|0)==2146435072&d>>>0>=0|c>>>0>2146435072){k=i<<28;f=i;c=j;i=c>>>4|0;d=(c&15)<<28|f>>>4;c=i|2147418112;break a}if(!(c|d)){d=0;c=0;break a}f=c;c=(c|0)==1&d>>>0<0|c>>>0<1?y(i)+32|0:y(c);ef(g,d,f,0,0,c+49|0);l=p[g>>2];k=p[g+4>>2];d=p[g+8>>2];c=p[g+12>>2]^65536|15372-c<<16}p[a>>2]=l;p[a+4>>2]=k;p[a+8>>2]=d;p[a+12>>2]=j&-2147483648|c;fb=g+16|0}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=w(0);c=fb-16|0;fb=c;a:{b:{c:{d:{switch(b+ -1|0){case 0:d=w(dY(t[a+48>>2])*w(2e3));if(!(w(x(d))<w(2147483648))){break c}a=~~d;break b;case 1:a=(v(p[p[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:a=Vaa(q[p[a+24>>2]+24648|0]);break b;case 3:p[c>>2]=0;Uaa(c,p[a+24>>2]+24604|0);a=p[c>>2];break b;default:break d}}a=W(8)|0;p[114610]=0;c=J(85,c|0,38580)|0;b=p[114610];p[114610]=0;e:{if((b|0)!=1){dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(c);break e}b=I()|0;H()|0;X(a|0)}L(b|0);E()}a=-2147483648}fb=c+16|0;return a|0}E()}function zua(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb+ -64|0;fb=f;d=le(a);j=d<<6;h=p[a+20>>2];g=h+(v(p[a>>2],d)<<1)|0;while(1){if(d){i=v(d,e);k=v(e^-1,d);c=0;while(1){o[g+(c+i<<1)>>1]=r[g+(c-d<<1)>>1];o[(c+k<<1)+h>>1]=r[(c<<1)+h>>1];c=c+1|0;if((c|0)!=(d|0)){continue}break}}e=e+1|0;if((e|0)!=16){continue}break}g=g+(d<<5)|0;c=r[a+34>>1];if(c&2){i=p[a+8>>2];e=p[a+4>>2];vb(f+32|0,b+1074308|0,33);wM(f+40|0,g,(v(d,e)<<1)+h|0,i-e|0,d,(c&4)>>>2|0,tb(f+32|0));c=r[a+34>>1]}if(c&8){e=p[a+16>>2];a=p[a+12>>2];vb(f+32|0,b+1074308|0,33);wM(f+8|0,g+(j<<1)|0,(v(a,d)<<1)+h|0,e-a|0,d,(c&16)>>>4|0,tb(f+32|0))}fb=f- -64|0}function rI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=w(0),h=0,i=w(0),j=0,k=0,l=w(0);e=fb-16|0;fb=e;if(!(!r[b>>1]|o[d>>1]>o[d+2>>1]|(!(t[c>>2]>w(0))|(o[d+2>>1]-o[d>>1]|0)>32766))){o[a>>1]=3;f=a+4|0;bi(f);o[a+28>>1]=65472;p[e+12>>2]=1065353216;tI(f,128,e+12|0);p[a+32>>2]=0;o[a+30>>1]=0;bi(a+16|0);o[a+28>>1]=r[d>>1];j=a,k=aka(r[b>>1]),o[j+30>>1]=k;g=w(x(t[c>>2]));t[a+32>>2]=g;g=fe(g,w(w(1)/w(o[a+30>>1])));h=1;cl(f,(o[d+2>>1]-o[d>>1]|0)+1|0);b=o[d>>1];if((b|0)<=o[d+2>>1]){while(1){i=fe(g,w(b|0));j=Fb(f,b-o[a+28>>1]|0),l=i,t[j>>2]=l;c=(b|0)<o[d+2>>1];b=b+1|0;if(c){continue}break}}qo(a)}fb=e+16|0;return h|0}function wta(a,b){var c=0,d=0,e=0;p[a+3832>>2]=0;p[a+3836>>2]=0;c=a+3837|0;n[c|0]=0;n[c+1|0]=0;n[c+2|0]=0;n[c+3|0]=0;n[c+4|0]=0;n[c+5|0]=0;n[c+6|0]=0;n[c+7|0]=0;while(1){sf((v(e,84)+a|0)+808|0,a);e=e+1|0;if((e|0)!=36){continue}break}while(1){p[(v(d,44)+a|0)+32>>2]=a;d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){c=p[(d<<2)+19744>>2];e=(v(d,44)+a|0)+16|0;a:{if(!(!(1<<d&3591)|d>>>0>11)){c=v(c,84)+a|0;$L(e,c+808|0,c+1060|0,c+1312|0,c+1564|0);break a}c=v(c,84)+a|0;$L(e,c+808|0,c+1060|0,0,0)}d=d+1|0;if((d|0)!=18){continue}break}d=0;while(1){Wm((v(d,84)+a|0)+808|0);d=d+1|0;if((d|0)!=36){continue}break}_L(a,b)}function ag(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb+ -64|0;fb=e;a:{b:{if(c+ -1>>>0>1023){break b}if(Cg(a,b)){break b}c:{d:{if(of(a)>>>0<=b>>>0){d=Ir(e+8|0,a);p[114610]=0;N(1582,a|0,b+1|0,d|0);f=p[114610];p[114610]=0;if((f|0)==1){break d}hl(d)}d=De(a,b);p[114610]=0;J(1583,d|0,c|0)|0;c=p[114610];p[114610]=0;e:{if((c|0)!=1){c=De(a,b);p[c+16>>2]=0;p[c+20>>2]=0;c=De(a,b);p[114610]=0;J(1584,c|0,32260)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break e}}a=O(71348)|0;b=H()|0;break c}g=Ch(De(a,b));break b}a=O(71348)|0;b=H()|0;hl(d)}if(($(71348)|0)!=(b|0)){break a}T(a|0)|0;V()}fb=e- -64|0;return g|0}L(a|0);E()}function QAa(a,b,c,d){var e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;c=ki(c,b);p[f+12>>2]=c;a:{if((c|0)<1){break a}e=p[b+4>>2];b:{if(!e){e=p[d>>2];break b}g=32-e|0;p[f+8>>2]=g;c=p[Yd(f+8|0,f+12|0)>>2];p[f+12>>2]=p[f+12>>2]-c;e=p[d>>2];g=-1<<p[b+4>>2]&-1>>>g-c;h=p[b>>2];p[e>>2]=p[e>>2]&(g^-1)|g&p[h>>2];c=c+p[d+4>>2]|0;p[d+4>>2]=c&31;e=e+(c>>>3&536870908)|0;p[d>>2]=e;p[b>>2]=h+4;c=p[f+12>>2]}h=e;e=(c|0)/32|0;c=e<<2;Ji(h,p[b>>2],c);e=p[f+12>>2]-(e<<5)|0;p[f+12>>2]=e;g=c+p[d>>2]|0;p[d>>2]=g;if((e|0)<1){break a}h=b;b=c+p[b>>2]|0;p[h>>2]=b;c=-1>>>32-e|0;p[g>>2]=p[g>>2]&(c^-1)|c&p[b>>2];p[d+4>>2]=p[f+12>>2]}Ed(a,d);fb=f+16|0}function F3(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=p[a>>2]+1794895138|0;e=Qk(p[a+8>>2],f);g=Qk(p[a+12>>2],f);d=Qk(p[a+16>>2],f);a:{if(e>>>0>=b>>>2>>>0){break a}h=b-(e<<2)|0;if((d|g)&3|(g>>>0>=h>>>0|d>>>0>=h>>>0)){break a}l=d>>>2|0;m=g>>>2|0;g=0;while(1){h=e>>>1|0;i=h+g|0;j=i<<1;d=(j+m<<2)+a|0;k=Qk(p[d>>2],f);d=Qk(p[d+4>>2],f);if(b>>>0<=d>>>0|k>>>0>=b-d>>>0|q[(d+k|0)+a|0]){break a}d=Th(c,a+d|0);if(!d){c=(l+j<<2)+a|0;e=Qk(p[c>>2],f);c=Qk(p[c+4>>2],f);if(b>>>0<=c>>>0|e>>>0>=b-c>>>0){break a}n=q[(c+e|0)+a|0]?0:a+c|0;break a}if((e|0)==1){break a}d=(d|0)<0;e=d?h:e-h|0;g=d?g:i;continue}}return n}function kda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;p[114610]=0;S(2015,a|0);e=p[114610];p[114610]=0;a:{b:{c:{if((e|0)==1){break c}p[114610]=0;S(2041,b|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}e=p[a+24>>2];b=ic(d+8|0,b);p[114610]=0;f=p[b+4>>2];p[d>>2]=p[b>>2];p[d+4>>2]=f;Q(2082,e|0,d|0,(c|0)!=0|0,1);c=p[114610];p[114610]=0;b=1;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37006,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}fb=d+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function v0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;b=fb-32|0;fb=b;d=Lb(b+16|0);p[114610]=0;c=Ze(d);e=p[114610];p[114610]=0;a:{b:{if((e|0)==1){break b}e=Ib(f);g=Ib(f);f=wb(f);p[114610]=0;U(2506,b+8|0,c|0,e|0,f+g|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break b}c=Ib(d);p[114610]=0;e=p[114610];p[114610]=0;c:{if((e|0)!=1){e=Lb(a);p[114610]=0;a=Ze(e);f=p[114610];p[114610]=0;if((f|0)==1){break c}f=ve(c);p[114610]=0;U(2508,b|0,a|0,c|0,c+f|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}pb(d);fb=b+32|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(e);break a}a=I()|0;H()|0}pb(d);L(a|0);E()}function Wya(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;vd(b,0);mk(d,2,a);zc(d+16|0,d);p[114610]=0;J(370,b+43|0,d+16|0)|0;c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){pb(d+16|0);c=a+24|0;p[b+24>>2]=q[c|0]|q[c+1|0]<<8;n[d+16|0]=q[a+22|0];n[d|0]=64;f=b,g=q[hc(d+16|0,d)|0]<<2,o[f+30>>1]=g;c=a+16|0;p[b>>2]=q[c|0]|q[c+1|0]<<8;c=a+18|0;p[b+4>>2]=q[c|0]|q[c+1|0]<<8;a=a+20|0;a=q[a|0]|q[a+1|0]<<8;p[b+8>>2]=a;c=p[b>>2];if(c>>>0>1){break b}p[b>>2]=0;break a}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}e=p[b+4>>2];if((a|0)==65535|e>>>0>=c>>>0|e>>>0>=a>>>0){break a}o[b+34>>1]=2;f=b,g=p[Cb(b+8|0,b)>>2],p[f+8>>2]=g}fb=d+32|0}function OH(a,b,c){a=a|0;b=b|0;c=w(c);var d=0;d=fb-16|0;fb=d;t[d+12>>2]=c;Cw(a);Td(d+12|0,w(0));a:{b:{switch(b|0){case 0:p[a+4220>>2]=p[d+12>>2];break a;case 1:p[a+4224>>2]=p[d+12>>2];break a;case 2:p[a+4228>>2]=p[d+12>>2];Bw(a);break a;case 3:n[a+4240|0]=t[d+12>>2]>=w(.5);Bw(a);break a;case 4:b=a;a=zh(w(t[d+12>>2]*w(32)));p[b+4232>>2]=(a|0)<5?a:5;fb=d+16|0;return;case 5:n[a+4241|0]=t[d+12>>2]>=w(.5);break a;case 6:n[a+4242|0]=t[d+12>>2]>=w(.5);break a;case 7:n[a+4244|0]=t[d+12>>2]>=w(.5);break a;case 8:break b;default:break a}}b=a;c=t[d+12>>2];if(c==w(0)){Aw(a);c=t[d+12>>2]}u[b+4256>>3]=c}fb=d+16|0}function ZU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-48|0;fb=d;Ac(b);hq(a);a:{if(!bf(b,d+40|0)){break a}if(!ZA(d+40|0)){break a}if(!c){f=1;break a}if(!Hb(b,4)){break a}vu(a);uu(d+24|0);tu(qg(a)+28|0,d+24|0);gq(d+24|0);c=p[qg(a)+28>>2];e=qj(b);if(e&1){break a}g=e+ -4|0;Jc(b,g);e=td(b);e=td(b)<<8|e<<16|td(b);if(!e){break a}p[114610]=0;K(331,c|0,e|0);h=p[114610];p[114610]=0;f=1;if((h|0)==1){a=O(71348)|0;if((H()|0)==($(71348)|0)){T(a|0)|0;V();f=0;break a}L(a|0);E()}Jc(b,4);XU(YA(b),g,ub(p[c>>2]),e);Ei(d+8|0,c);qu(d+16|0,d+8|0);b=Ln(d+24|0,d+16|0);Nd(qg(a)+12|0,b);sb(b)}fb=d+48|0;return f|0}function M0(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=bD(b);xj(k,a);b=p[k>>2];n[c|0]=b;n[c+1|0]=b>>>8;n[c+2|0]=b>>>16;n[c+3|0]=b>>>24;wj(k,a);Lh(i,k);yc(k);Pg(k,a);Lh(h,k);yc(k);l=d,m=Ph(a),p[l>>2]=m;l=e,m=Oh(a),p[l>>2]=m;Zf(k,a);xb(f,k);pb(k);Qg(k,a);Lh(g,k);yc(k);a=vj(a);break a}a=aD(b);xj(k,a);b=p[k>>2];n[c|0]=b;n[c+1|0]=b>>>8;n[c+2|0]=b>>>16;n[c+3|0]=b>>>24;wj(k,a);Lh(i,k);yc(k);Pg(k,a);Lh(h,k);yc(k);l=d,m=Ph(a),p[l>>2]=m;l=e,m=Oh(a),p[l>>2]=m;Zf(k,a);xb(f,k);pb(k);Qg(k,a);Lh(g,k);yc(k);a=vj(a)}p[j>>2]=a;fb=k+16|0}function H5(a){var b=0,c=0,d=0,f=0;f=fb-16|0;fb=f;c=(i(a),e(2));b=c&2147483647;a:{if(b>>>0<=1061752794){if(b>>>0<964689920){break a}a=qm(+a,0);break a}if(b>>>0<=1081824209){d=+a;if(b>>>0<=1075235811){a=qm(((c|0)>-1?-1.5707963267948966:1.5707963267948966)+d,1);break a}a=qm(((c|0)>-1?-3.141592653589793:3.141592653589793)+d,0);break a}if(b>>>0<=1088565717){d=+a;if(b>>>0<=1085271519){a=qm(((c|0)>-1?-4.71238898038469:4.71238898038469)+d,1);break a}a=qm(((c|0)>-1?-6.283185307179586:6.283185307179586)+d,0);break a}if(b>>>0>=2139095040){a=w(a-a);break a}b=Fv(a,f+8|0);a=qm(u[f+8>>3],b&1)}fb=f+16|0;return a}function ida(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=fb-16|0;fb=e;p[114610]=0;S(2015,a|0);d=p[114610];p[114610]=0;a:{b:{c:{if((d|0)==1){break c}p[114610]=0;S(2041,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break c}d=p[a+24>>2];b=ic(e+8|0,b);p[114610]=0;f=p[b+4>>2];p[e>>2]=p[b>>2];p[e+4>>2]=f;ab(2084,d|0,e|0,+c,1);d=p[114610];p[114610]=0;b=1;if((d|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37068,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}fb=e+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Xu(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;qc(f+8|0,b);p[114610]=0;b=M(2449,f+8|0)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;U(2463,b|0,62096,62128,c|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;b=M(2450,f+8|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}p[114610]=0;c=M(2464,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break a}p[d>>2]=c;p[114610]=0;c=M(2460,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[e>>2]=c;p[114610]=0;K(2461,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Gb(f+8|0);fb=f+16|0;return}a=I()|0;H()|0;Gb(f+8|0);L(a|0);E()}function WHa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-704|0;fb=e;a:{b:{if(d>>>0<=511){d=0;if(!VHa(b,e+24|0)){break b}bU(e+24|0,c);d=554;break b}f=p[b+8>>2];UHa(b,e+24|0);d=WT(e+24|0,c,p[a+480180>>2]);Jc(b,f+d|0);if(!Dh(b,13380)){break b}ld(e+8|0,b,Lf(b));p[114610]=0;b=M(255,e+8|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}p[114610]=0;a=J(621,e+8|0,13385)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}if(a){p[114610]=0;a=M(387,e+8|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}n[c+34|0]=a>>>0>250?0:a}d=(b+d|0)+8|0;sb(e+8|0)}fb=e+704|0;return d|0}a=I()|0;H()|0;sb(e+8|0);L(a|0);E()}function IW(a){var b=0,c=0,d=0;b=fb+ -64|0;fb=b;d=Xc(a);p[114610]=0;c=J(2,b+16|0,7127)|0;a=p[114610];p[114610]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){p[114610]=0;K(219,b+32|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break f}p[114610]=0;p[b+12>>2]=12;p[b+8>>2]=0;p[b+4>>2]=0;_(239,b+48|0,b+32|0,b+12|0,b+8|0,b+4|0);a=p[114610];p[114610]=0;if((a|0)==1){break e}p[114610]=0;J(192,d|0,b+48|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break d}pb(b+48|0);yb(b+32|0);pb(c);fb=b- -64|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;break c}a=I()|0;H()|0;pb(b+48|0)}yb(b+32|0)}pb(c)}pb(d);L(a|0);E()}function rz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;d=(c<<3)+a|0;f=q[d+356|0];n[b+12|0]=q[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Vf(b,sd(q[d+352|0],2,16));n[b+13|0]=q[d+354|0];n[b+14|0]=q[d+355|0];d=q[d+353|0];n[b+15|0]=d;n[b+16|0]=d;d=0;o[e+14>>1]=0;if(Bb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;g=c+160|0;o[e+12>>1]=q[g|0]|q[g+1|0]<<8;g=r[Bi(e+14|0,e+12|0)>>1];o[e+14>>1]=g;h=Fb(b,d),i=g,o[h>>1]=i;o[e+14>>1]=r[e+14>>1]+1;c=c+162|0;p[e+8>>2]=(q[c|0]|q[c+1|0]<<8)>>>f;p[e+4>>2]=64;c=p[Yd(e+8|0,e+4|0)>>2];h=Fb(b,d),i=c,n[h+2|0]=i;d=d+1|0;if(d>>>0<Bb(b)>>>0){continue}break}}fb=e+16|0}function Wq(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-240|0;fb=g;h=p[c>>2];p[g+232>>2]=h;c=p[c+4>>2];p[g>>2]=a;p[g+236>>2]=c;i=1;a:{b:{c:{d:{if(c?0:(h|0)==1){break d}h=a-p[(d<<2)+f>>2]|0;if((m[b|0](h,a)|0)<1){break d}j=!e;while(1){e:{c=h;if(!(!j|(d|0)<2)){e=p[((d<<2)+f|0)+ -8>>2];h=a+ -4|0;if((m[b|0](h,c)|0)>-1){break e}if((m[b|0](h-e|0,c)|0)>-1){break e}}p[(i<<2)+g>>2]=c;a=JE(g+232|0);Xq(g+232|0,a);i=i+1|0;d=a+d|0;if(p[g+236>>2]?0:p[g+232>>2]==1){break b}e=0;j=1;a=c;h=c-p[(d<<2)+f>>2]|0;if((m[b|0](h,p[g>>2])|0)>0){continue}break c}break}c=a;break b}c=a}if(e){break a}}IE(g,i);Cv(c,b,d,f)}fb=g+240|0}function MAa(a,b,c,d){var e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;c=ki(c,b);p[f+12>>2]=c;a:{if((c|0)<1){break a}e=p[b+4>>2];if(e){g=32-e|0;p[f+8>>2]=g;c=p[Yd(f+8|0,f+12|0)>>2];p[f+12>>2]=p[f+12>>2]-c;e=p[d>>2];g=-1<<p[b+4>>2]&-1>>>g-c;p[e>>2]=p[e>>2]&(g^-1)|g&p[p[b>>2]>>2];c=c+p[d+4>>2]|0;p[d+4>>2]=c&31;p[d>>2]=e+(c>>>3&536870908);p[b>>2]=p[b>>2]+4;c=p[f+12>>2]}e=(c|0)/32|0;c=e<<2;Ji(p[d>>2],p[b>>2],c);e=p[f+12>>2]-(e<<5)|0;p[f+12>>2]=e;p[d>>2]=c+p[d>>2];if((e|0)<1){break a}g=b;b=c+p[b>>2]|0;p[g>>2]=b;c=p[d>>2];g=c;h=p[c>>2];c=-1>>>32-e|0;p[g>>2]=h&(c^-1)|c&p[b>>2];p[d+4>>2]=p[f+12>>2]}Ed(a,d);fb=f+16|0}function cr(a,b,c){var d=0,e=0;d=a,e=Wh(w(w(w(w(w(w(w(w(w(t[c+3328>>2]+t[c+256>>2])*w(213))+w(w(t[c+3584>>2]-t[c>>2])*w(29)))+w(w(t[c+3072>>2]-t[c+512>>2])*w(459)))+w(w(t[c+2816>>2]+t[c+768>>2])*w(2037)))+w(w(t[c+2560>>2]-t[c+1024>>2])*w(5153)))+w(w(t[c+2304>>2]+t[c+1280>>2])*w(6574)))+w(w(t[c+2048>>2]-t[c+1536>>2])*w(37489)))+w(t[c+1792>>2]*w(75038)))),o[d>>1]=e;d=(b<<5)+a|0,e=Wh(w(w(w(w(w(w(w(w(t[c+3080>>2]*w(1567))+w(t[c+3592>>2]*w(104)))+w(t[c+2568>>2]*w(9727)))+w(t[c+2056>>2]*w(64019)))+w(t[c+1544>>2]*w(-9975)))+w(t[c+1032>>2]*w(-45)))+w(t[c+520>>2]*w(146)))+w(t[c+8>>2]*w(-5)))),o[d>>1]=e}function W0(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=fD(b);xj(k,a);b=p[k>>2];n[c|0]=b;n[c+1|0]=b>>>8;n[c+2|0]=b>>>16;n[c+3|0]=b>>>24;wj(k,a);xb(i,k);pb(k);Pg(k,a);xb(h,k);pb(k);l=d,m=Ph(a),n[l|0]=m;l=e,m=Oh(a),n[l|0]=m;Zf(k,a);xb(f,k);pb(k);Qg(k,a);xb(g,k);pb(k);a=vj(a);break a}a=eD(b);xj(k,a);b=p[k>>2];n[c|0]=b;n[c+1|0]=b>>>8;n[c+2|0]=b>>>16;n[c+3|0]=b>>>24;wj(k,a);xb(i,k);pb(k);Pg(k,a);xb(h,k);pb(k);l=d,m=Ph(a),n[l|0]=m;l=e,m=Oh(a),n[l|0]=m;Zf(k,a);xb(f,k);pb(k);Qg(k,a);xb(g,k);pb(k);a=vj(a)}p[j>>2]=a;fb=k+16|0}function Kg(a){var b=0,c=0,d=0,f=0,g=0;a:{h(+a);b=e(1)|0;g=e(0)|0;c=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!(b>>>0<1083179008|((c|0)<0?1:(c|0)<=0?g>>>0<0:0))){return a*8.98846567431158e+307}if(b>>>0>=2146435072){return-1/a}if(a<=-1075^1){break a}d=0;if((c|0)<-1?1:(c|0)<=-1){break b}break a}if(b>>>0>1016070143){break a}d=a+1}return d}f=a+26388279066624;h(+f);e(1)|0;c=(e(0)|0)+128|0;b=c<<4&4080;d=u[b+72272>>3];a=a-(f+ -26388279066624)-u[(b|8)+72272>>3];return Jh(d+d*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(c&-256)/256|0)}function bF(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(re(a)){Wb(a,31);return 0}f=a,g=re(a),n[f+1375|0]=g;d=Vh(a);b=Vh(a);Vh(a);f=a,g=Vh(a),p[f+1112>>2]=g;Vh(a);c=re(a);p[a+1116>>2]=c;if(!Mv(a,a+1120|0,c)){Wb(a,10);return 0}p[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=p[a+1116>>2];while(1){if((b|0)<1){break a}b=b+ -1|0;if(q[(b+a|0)+1120|0]==255){continue}break}p[a+1408>>2]=d;p[a+1404>>2]=b}if(q[a+1377|0]){e=p[a+1116>>2];b=27;b:{if((e|0)<1){break b}c=0;b=0;while(1){c=q[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}p[a- -64>>2]=d;p[a+60>>2]=p[a+56>>2]+(b+e|0)}p[a+1380>>2]=0;return 1}function Zu(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;qc(f+8|0,b);p[114610]=0;b=M(21,f+8|0)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;U(2440,b|0,62096,62128,c|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;b=M(2416,f+8|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}p[114610]=0;c=M(2441,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break a}n[d|0]=c;p[114610]=0;c=M(2431,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}n[e|0]=c;p[114610]=0;K(2432,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Gb(f+8|0);fb=f+16|0;return}a=I()|0;H()|0;Gb(f+8|0);L(a|0);E()}function HK(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=0;a:{if(b){n[c|0]=b;break a}b=q[c|0]}b=p[a+480180>>2]&1048580?b&240?b&-16:b&15:b;c=b&240;e=b&255;g=d;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(q[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=p[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;p[d+12>>2]=b;break c}if(f){break b}if(c){if(p[a+480180>>2]&59314208?b:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}p[g+12>>2]=b;if(!b){break b}}if(!(p[a+480180>>2]&59314208)){b=b<<1;p[d+12>>2]=b}a=a+1074444|0;p[d+12>>2]=p[a>>2]+b;Vd(d+12|0,0,256);p[a>>2]=p[d+12>>2]}fb=d+16|0}function Wt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-16|0;fb=c;p[c+12>>2]=b;a:{b:{c:{if(4294967279>=b>>>0){f=Bc(a);h=c,i=wb(a),p[h+8>>2]=i;b=p[Uc(c+12|0,c+8|0)>>2];p[c+12>>2]=b;d=Ok(b);p[c+12>>2]=d;if((d|0)==(f|0)){break a}if((d|0)==10){g=1;b=a;e=p[a>>2];break b}b=p[c+12>>2]+1|0;if(d>>>0>f>>>0){b=Si(b);break c}p[114610]=0;b=J(30,a|0,b|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break c}a=O(0)|0;H()|0;T(a|0)|0;V();break a}tg();E()}g=ze(a);e=Ib(a)}uh(b,e,wb(a)+1|0);if(g){cg(a,e,f+1|0)}d:{if((d|0)!=10){sg(a,p[c+12>>2]+1|0);oe(a,p[c+8>>2]);sf(a,b);break d}cf(a,p[c+8>>2])}}fb=c+16|0}function Cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-4112|0;fb=c;f=m[p[p[a>>2]+112>>2]](a)|0;if(!f){m[p[p[a>>2]+116>>2]](a)}p[c+12>>2]=0;Bha(a+44|0);if(b){g=c+2064|0;while(1){p[c+8>>2]=b;vc(c+8|0,512);$o(c+16|0);m[p[p[a>>2]+60>>2]](a,c+16|0,g,p[c+8>>2]);d=0;e=0;if(p[c+8>>2]){while(1){d=(c+16|0)+(e<<2)|0;t[c+4>>2]=x(t[d>>2]);h=c,i=p[xw(c+12|0,c+4|0)>>2],p[h+12>>2]=i;t[c+4>>2]=x(t[d+2048>>2]);h=c,i=p[xw(c+12|0,c+4|0)>>2],p[h+12>>2]=i;e=e+1|0;d=p[c+8>>2];if(e>>>0<d>>>0){continue}break}}b=b-d|0;if(b){continue}break}}if(!f){m[p[p[a>>2]+120>>2]](a)}fb=c+4112|0;return w(t[c+12>>2])}function oda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[114610]=0;S(2015,a|0);d=p[114610];p[114610]=0;a:{b:{c:{if((d|0)==1){break c}p[114610]=0;S(2041,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break c}d=p[a+24>>2];b=ic(c+8|0,b);p[114610]=0;f=p[b+4>>2];p[c>>2]=p[b>>2];p[c+4>>2]=f;e=+ha(2079,d|0,c|0,1);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36918,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();e=0}fb=c+16|0;return+e}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function XY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-16|0;fb=c;p[c+12>>2]=b;a:{b:{c:{if(1073741807>=b>>>0){f=tq(a);h=c,i=wb(a),p[h+8>>2]=i;b=p[Uc(c+12|0,c+8|0)>>2];p[c+12>>2]=b;d=Zl(b);p[c+12>>2]=d;if((d|0)==(f|0)){break a}g=1;if((d|0)==1){b=a;e=p[a>>2];break b}b=p[c+12>>2]+1|0;if(d>>>0>f>>>0){b=Lk(b);break c}p[114610]=0;b=J(2841,a|0,b|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){break c}a=O(0)|0;H()|0;T(a|0)|0;V();break a}tg();E()}g=ze(a);e=Ib(a)}Rh(b,e,wb(a)+1|0);if(g){Un(e,f+1|0)}d:{if((d|0)!=1){sg(a,p[c+12>>2]+1|0);oe(a,p[c+8>>2]);sf(a,b);break d}cf(a,p[c+8>>2])}}fb=c+16|0}function xF(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a:{b:{c:{c=a+8|0;d:{if(!$k(c)){if((b|0)<0|(lr(c)|0)<=(b|0)){break d}c=(q[cp(p[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=$k(c);if((b|0)<0){break d}if((c|0)>(b|0)){break c}}a=W(8)|0;p[114610]=0;c=J(85,d|0,40585)|0;b=p[114610];p[114610]=0;e:{if((b|0)!=1){dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(c);break e}b=I()|0;H()|0;X(a|0)}L(b|0);E()}b=b+1<<2;a=a+32|0;c=1;if(!p[(b+p[a>>2]|0)+900380>>2]){break b}c=(q[p[(b+p[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}fb=d+16|0;return c|0}E()}function PM(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;p[f+8>>2]=e;p[f+12>>2]=d;a:{if(!d){break a}Me(a);Wt(a,c);if(!c){break a}e=0;while(1){j=c-g|0;p[f+4>>2]=j;h=p[Cb(f+12|0,f+4|0)>>2];Pn(a,ub(b)+g|0,h);Bs(a,1,13);i=e+h|0;if(e>>>0<i>>>0){while(1){b:{c:{d:{k=n[Xl(a,e)|0];switch(k+ -10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=Xl(a,e),m=32,n[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}p[f+4>>2]=j-h;e=i+1|0;g=p[Cb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}fb=f+16|0;return(d|0)!=0|0}function qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{if((c|0)==1){break c}p[114610]=0;S(2041,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break c}c=p[a+24>>2];b=ic(d+8|0,b);p[114610]=0;e=p[b+4>>2];p[d>>2]=p[b>>2];p[d+4>>2]=e;b=P(2077,c|0,d|0,1)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36856,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}fb=d+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function nHa(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,2,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;J(378,b|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function SMa(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,2,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;J(369,b|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function RMa(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,1,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;J(370,b|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function OJa(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,3,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;J(370,b|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function Fya(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,2,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;J(370,b|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function rS(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,3,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;J(369,b|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function qS(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;Q(414,d+8|0,3,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break c}p[114610]=0;J(378,b|0,d+24|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+24|0)}uc(d+40|0);L(a|0);E()}function jda(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;p[114610]=0;S(2015,a|0);f=p[114610];p[114610]=0;a:{b:{c:{if((f|0)==1){break c}p[114610]=0;S(2041,b|0);f=p[114610];p[114610]=0;if((f|0)==1){break c}f=p[a+24>>2];b=ic(e+8|0,b);p[114610]=0;g=p[b+4>>2];p[e>>2]=p[b>>2];p[e+4>>2]=g;Aa(2083,f|0,e|0,c|0,d|0,1);c=p[114610];p[114610]=0;b=1;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37037,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}fb=e+16|0;return b}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function YJa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;vd(b,0);p[b>>2]=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);c=a+4|0;p[b+12>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+8|0;p[b+16>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+12|0;c=q[c|0]|q[c+1|0]<<8;o[b+32>>1]=64;p[b+24>>2]=c;e=b;c=a+14|0;d=256;a:{if(!q[c|0]){break a}d=q[c|0]+1|0}o[e+30>>1]=d;o[b+34>>1]=r[b+34>>1]&32767|!q[c|0]<<15;a=a+15|0;if(!(!(n[a|0]&1)|s[b+16>>2]<=s[b+12>>2])){o[b+34>>1]=r[b+34>>1]|8}if(q[a|0]&2){o[b+34>>1]=r[b+34>>1]|1;p[b>>2]=p[b>>2]>>>1;p[b+12>>2]=p[b+12>>2]>>>1;p[b+16>>2]=p[b+16>>2]>>>1}}function $i(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;g=Po(a);f=bj(g);rsa(a,f);a:{if(!b){break a}d=a+12|0;ks(d);if(rd(d)>>>0>1023){break a}p[c+28>>2]=0;e=p[a+24>>2]+484344|0;i=c,j=Ub(e),p[i+24>>2]=j;i=c,j=Vb(e),p[i+16>>2]=j;if(Ab(c+24|0,c+16|0)){while(1){p[c+12>>2]=p[p[c+24>>2]+12>>2];i=c,j=p[Uc(c+28|0,c+12|0)>>2],p[i+28>>2]=j;Qx(c+24|0);if(Ab(c+24|0,c+16|0)){continue}break}e=p[c+28>>2]}else{e=0}yL(d,e)}if(f){d=0;while(1){e=id(a,d);h=Px(a,r[kc(g,d)>>1]);b:{if(b){n[c+28|0]=0;xL(e,h,c+28|0);break b}zy(e,h,0)}d=d+1|0;if((f|0)!=(d|0)){continue}break}}fb=c+32|0}function rE(a){var b=0,c=0;a:{b=p[a+4>>2];b:{if(!p[(p[p[b>>2]+ -12>>2]+b|0)+24>>2]){break b}b=p[a+4>>2];if(!tf(p[p[b>>2]+ -12>>2]+b|0)){break b}b=p[a+4>>2];if(!(p[(p[p[b>>2]+ -12>>2]+b|0)+4>>2]&8192)){break b}if(wv()){break b}b=p[a+4>>2];b=p[(p[p[b>>2]+ -12>>2]+b|0)+24>>2];p[114610]=0;b=M(2329,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=p[a+4>>2];b=p[p[a>>2]+ -12>>2];p[114610]=0;K(2330,a+b|0,1);a=p[114610];p[114610]=0;if((a|0)!=1){break b}}a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break a}}return}a=O(0)|0;H()|0;rb(a);E()}function kl(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=a+1074308|0;vb(e+8|0,f,84);a:{if(tb(e+8|0)){break a}b:{if(p[a+480208>>2]&16384){break b}if((d|0)!=8){vb(e+8|0,f,10);if(!tb(e+8|0)){break b}}p[b+88>>2]=p[b+88>>2]&-257}c:{d:{e:{switch(d+ -4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(p[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}p[b+88>>2]=p[b+88>>2]|256;c=128}p[b+692>>2]=c}o[b+796>>1]=0;p[b+88>>2]=p[b+88>>2]|2097152;vb(e+8|0,f,10);if(!tb(e+8|0)){break a}n[b+851|0]=0;o[b+790>>1]=0}fb=e+16|0}function Rna(a,b){var c=0,d=0;c=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=c;c=q[b+11|0]|q[b+12|0]<<8|(q[b+13|0]<<16|q[b+14|0]<<24);d=q[b+7|0]|q[b+8|0]<<8|(q[b+9|0]<<16|q[b+10|0]<<24);n[a+7|0]=d;n[a+8|0]=d>>>8;n[a+9|0]=d>>>16;n[a+10|0]=d>>>24;n[a+11|0]=c;n[a+12|0]=c>>>8;n[a+13|0]=c>>>16;n[a+14|0]=c>>>24;n[a+15|0]=q[b+15|0];c=p[b+44>>2];p[a+40>>2]=p[b+40>>2];p[a+44>>2]=c;c=p[b+36>>2];p[a+32>>2]=p[b+32>>2];p[a+36>>2]=c;c=p[b+28>>2];p[a+24>>2]=p[b+24>>2];p[a+28>>2]=c;c=p[b+20>>2];p[a+16>>2]=p[b+16>>2];p[a+20>>2]=c;lx(a+48|0,b+48|0);lx(a+68|0,b+68|0);lx(a+88|0,b+88|0);ac(a+108|0,b+108|0,448)}function yua(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb+ -64|0;fb=f;d=le(a);j=d<<6;h=p[a+20>>2];g=h+v(p[a>>2],d)|0;while(1){if(d){i=v(d,e);k=v(e^-1,d);c=0;while(1){n[g+(c+i|0)|0]=q[g+(c-d|0)|0];n[(c+k|0)+h|0]=q[c+h|0];c=c+1|0;if((c|0)!=(d|0)){continue}break}}e=e+1|0;if((e|0)!=16){continue}break}g=g+(d<<4)|0;c=r[a+34>>1];if(c&2){i=p[a+8>>2];e=p[a+4>>2];vb(f+32|0,b+1074308|0,33);vM(f+40|0,g,v(d,e)+h|0,i-e|0,d,(c&4)>>>2|0,tb(f+32|0));c=r[a+34>>1]}if(c&8){e=p[a+16>>2];a=p[a+12>>2];vb(f+32|0,b+1074308|0,33);vM(f+8|0,g+j|0,v(a,d)+h|0,e-a|0,d,(c&16)>>>4|0,tb(f+32|0))}fb=f- -64|0}function c7(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if((b|0)>=5){k=b+ -4|0;while(1){if(pF(a)){g=Sv(a,p[c>>2]);h=g+jo(a)|0;i=0;b:{c:{if(g){break c}f=4;m=e+4|0;while(1){if(((f<<1)+e|0)>=(k|0)){break b}g=0;j=a+f|0;d:{if(!ko(a,j)){break d}i=f-jo(a)|0;l=jo(j)+i|0;if((l+(f+m|0)|0)>(b|0)){break d}if(!ko(a,j+l|0)){break d}p[c>>2]=i;g=i;h=f}i=!g;if(f>>>0>2302){break c}f=f+1|0;if(!g){continue}break}}if((e+h|0)>(b|0)|i){break b}if(V6(a,b-e|0,g)){break a}}if(!((b|0)!=(h|0)|e)){e=0;h=b;break a}p[c>>2]=0}a=a+1|0;e=e+1|0;if((k|0)!=(e|0)){continue}break}}h=0;e=b}p[d>>2]=h;return e}function lY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(Xf(a,p[b+8>>2],f)){Du(b,c,d,e);return}h=q[b+53|0];g=p[a+12>>2];n[b+53|0]=0;i=q[b+52|0];n[b+52|0]=0;j=a+16|0;Bu(j,b,c,d,e,f);k=q[b+53|0];h=h|k;l=q[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(q[b+54|0]){break a}b:{if(l){if(p[b+24>>2]==1){break a}if(q[a+8|0]&2){break b}break a}if(!k){break b}if(!(n[a+8|0]&1)){break a}}o[b+52>>1]=0;Bu(g,b,c,d,e,f);k=q[b+53|0];h=k|h;l=q[b+52|0];i=l|i;g=g+8|0;if(g>>>0<j>>>0){continue}break}}n[b+53|0]=(h&255)!=0;n[b+52|0]=(i&255)!=0}function g4(a){a=a|0;var b=0;b=p[14202];f4(b);e4();d4(b);c4();b=p[14203];dE(461348,b,461396);mv(460712,461348);cE(461404,b,461452);lv(460796,461404);b=p[13902];dE(461460,b,461508);mv(460880,461460);mv(461048,p[(p[p[115220]+ -12>>2]+460880|0)+24>>2]);cE(461516,b,461564);lv(460964,461516);lv(461132,p[(p[p[115241]+ -12>>2]+460964|0)+24>>2]);Jq(p[p[115134]+ -12>>2]+460536|0,460712);Jq(p[p[115156]+ -12>>2]+460624|0,460796);bE(p[p[115220]+ -12>>2]+460880|0);bE(p[p[115241]+ -12>>2]+460964|0);Jq(p[p[115220]+ -12>>2]+460880|0,460712);Jq(p[p[115241]+ -12>>2]+460964|0,460796);return a|0}function aLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;p[e+24>>2]=b;b=p[a>>2];f=e,g=Ub(a),p[f>>2]=g;b=b+(Ap(e+24|0,e)<<1)|0;a:{b:{if(s[a+4>>2]<s[qb(a)>>2]){d=p[a+4>>2];if((d|0)==(b|0)){RKa(a,c);break b}QKa(a,b,d,b+2|0);c=b>>>0<=c>>>0?c>>>0<s[a+4>>2]?c+2|0:c:c;n[b|0]=q[c|0];n[b+1|0]=q[c+1|0];break b}d=qb(a);d=UR(e,Ai(a,fc(a)+1|0),b-p[a>>2]>>1,d);p[114610]=0;K(515,d|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}p[114610]=0;b=P(516,a|0,d|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}ut(d)}a=Ze(b);fb=e+32|0;return a|0}a=I()|0;H()|0;ut(d);L(a|0);E()}function pda(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{c:{if((c|0)==1){break c}p[114610]=0;S(2041,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break c}c=p[a+24>>2];b=ic(d+8|0,b);p[114610]=0;e=p[b+4>>2];p[d>>2]=p[b>>2];p[d+4>>2]=e;b=UB(c,d,1);e=p[114610];p[114610]=0;c=ib;if((e|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36887,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0;c=0}fb=d+16|0;ib=c;return b}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Zna(a,b,c){var d=0,e=0,f=0;d=fb-32|0;fb=d;a:{if(OJ(b)){p[d+16>>2]=p[5128];c=p[5125];p[d>>2]=p[5124];p[d+4>>2]=c;c=p[5127];p[d+8>>2]=p[5126];p[d+12>>2]=c;Mb(a,((b<<2)+d|0)+ -1004|0);break a}if(Ud(b)){f=Xc(d);p[114610]=0;e=b+ -1|0;b=(e|0)/12|0;c=J(1433,f|0,(e-v(b,12)<<2)+c|0)|0;e=p[114610];p[114610]=0;b:{if((e|0)==1){break b}p[114610]=0;b=P(1434,c|0,1,b+48|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;J(4,a|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break b}pb(f);break a}a=I()|0;H()|0;pb(f);L(a|0);E()}if(!b){Mb(a,20516);break a}Mb(a,20520)}fb=d+32|0}function X3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;d=me(b,-1);e=q[a+52|0];a:{if(d){d=b;if(e){break a}d=p[a+48>>2];f=a,g=me(d,-1)^1,n[f+52|0]=g;break a}if(e){f=c,g=zm(p[a+48>>2]),n[f+19|0]=g;b:{c:{switch(Hq(p[a+36>>2],p[a+40>>2],c+19|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)+ -1|0){case 2:d=p[a+48>>2];p[c+20>>2]=c+25;n[c+24|0]=d;default:while(1){d=p[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break b}d=d+ -1|0;p[c+20>>2]=d;if((Mq(n[d|0],p[a+32>>2])|0)!=-1){continue}break}break;case 0:case 1:break c}}d=-1;e=0}if(!e){break a}}n[a+52|0]=1;p[a+48>>2]=b;d=b}fb=c+32|0;return d|0}function yGa(a,b){var c=0,d=0;c=(a|0)==(b|0);n[b+12|0]=c;a:{if(c){break a}while(1){if(q[p[b+8>>2]+12|0]){break a}d=_g(p[b+8>>2]);c=p[b+8>>2];b:{c:{if(d){c=p[p[c+8>>2]+4>>2];if(!(!c|q[c+12|0])){c=c+12|0;b=p[b+8>>2];n[b+12|0]=1;b=p[b+8>>2];break c}if(!_g(b)){b=p[b+8>>2];mp(b)}a=p[b+8>>2];n[a+12|0]=1;a=p[a+8>>2];n[a+12|0]=0;lp(a);return}c=p[p[c+8>>2]>>2];if(!c|q[c+12|0]){break b}c=c+12|0;b=p[b+8>>2];n[b+12|0]=1;b=p[b+8>>2]}n[b+12|0]=(a|0)==(b|0);n[c|0]=1;if((a|0)!=(b|0)){continue}break a}break}if(_g(b)){b=p[b+8>>2];lp(b)}a=p[b+8>>2];n[a+12|0]=1;a=p[a+8>>2];n[a+12|0]=0;mp(a)}}function Zo(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;g=Bb(a)+ -1|0;a:{if((Bb(a)|0)==1){break a}while(1){if(r[sc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Bb(a)+ -1>>>0){continue}break}}h=r[sc(a,g)>>1];p[f+12>>2]=0;b:{if((h|0)<=(b|0)){j=f,k=(q[sc(a,g)+2|0]<<16)/(d|0)|0,p[j+12>>2]=k;break b}e=0;if(g){e=g+ -1|0;i=(q[sc(a,e)+2|0]<<16)/(d|0)|0;p[f+12>>2]=i;e=r[sc(a,e)>>1]}if((e|0)>=(b|0)|e>>>0>=h>>>0){break b}j=f,k=((v(((q[sc(a,g)+2|0]<<16)/(d|0)|0)-i|0,b-e|0)|0)/(h-e|0)|0)+i|0,p[j+12>>2]=k}Vd(f+12|0,0,65536);fb=f+16|0;return(v(p[f+12>>2],c)+32768|0)/65536|0}function Y8(a){var b=0,c=0,d=0,e=0;c=fb-160|0;fb=c;a=vm(c+16|0,a,8);d=p[p[a>>2]+ -12>>2];p[114610]=0;b=Y(122)|0;e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}p[114610]=0;N(123,c+8|0,d+(c+16|0)|0,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}Gb(c+8|0);p[114610]=0;d=J(180,a|0,144)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;d=J(181,d|0,c+4|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[p[d>>2]+ -12>>2];p[114610]=0;d=M(174,b+d|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[c+4>>2];ff(a);fb=c+160|0;return d?0:b}c=I()|0;H()|0;ff(a);L(c|0);E()}function QA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;c=p[b+16>>2];p[a+4>>2]=0;p[a>>2]=c;d=b+80|0;g=a;c=p[b+84>>2];f=p[d>>2];a:{if(c>>>0<=15){break a}p[e+12>>2]=c+ -16;f=p[Uc(d,e+12|0)>>2]}p[g+8>>2]=f;b:{if(!(q[b+88|0]&2)|!q[b+816|0]){break b}c:{d:{e:{if(!((p[b+88>>2]&2050)==2?(q[p[b+104>>2]+34|0]&8)>>>3|0:0)){c=p[b+104>>2];break e}c=p[b+104>>2];if(p[b+80>>2]!=p[c+12>>2]){break e}d=p[b+84>>2];if((d|0)==p[c+16>>2]){break d}}b=p[b+84>>2];if((b|0)!=p[c+8>>2]){break b}b=(p[c>>2]-b|0)+48|0;break c}b=(p[c>>2]-d|0)+112|0}h=a,i=p[a>>2]+v(Fn(c),b)|0,p[h+4>>2]=i}fb=e+16|0}function qha(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;c=p[a+12>>2];d=c;e=p[a+8>>2];a:{if((c|0)<0?1:(c|0)<=0?e>>>0<0:0){break a}if(i=1,j=(l=e>>>0>zb(a)>>>0,m=0,n=(d|0)>=0,n?l:m),k=(d|0)>0,k?i:j){break a}d=zb(a);e=p[a+8>>2];g=0-((d>>>0<e>>>0)+p[a+12>>2]|0)|0;c=f;p[c+8>>2]=d-e;p[c+12>>2]=g;i=c,j=eh(b),p[i>>2]=j;p[c+4>>2]=0;c=qz(c+8|0,c);c=NQ(p[c>>2],p[c+4>>2]);if((c|0)!=(eh(b)|0)){break a}Ye(p[b>>2],p[b>>2]+c|0,ub(p[a>>2]+p[a+8>>2]|0));b=a;e=a;d=p[a+12>>2];a=c+p[a+8>>2]|0;if(a>>>0<c>>>0){d=d+1|0}p[e+8>>2]=a;p[b+12>>2]=d;h=1}fb=f+16|0;return h}function ou(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;p[e+28>>2]=d;a:{f=p[b>>2];b:{if(!(m[p[p[f>>2]+40>>2]](f,c,d)|0)){Hh(a);break b}Ek(e+8|0,b);p[114610]=0;b=M(271,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[p[b>>2]+24>>2];p[114610]=0;b=M(d|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;p[e+4>>2]=b-c;b=J(33,e+28|0,e+4|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}b=p[b>>2];p[114610]=0;Q(272,e+16|0,e+8|0,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}bB(a,e+16|0);sb(e+16|0);sb(e+8|0)}fb=e+32|0;return}a=I()|0;H()|0;sb(e+8|0);L(a|0);E()}function daa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;f=Xg(a);a:{b:{c:{d:{e:{e=b+24|0;if(r[p[e>>2]+480188>>1]){a=0;while(1){d=p[e>>2];p[114610]=0;K(2191,c|0,(d+(a<<5)|0)+480289|0);d=p[114610];p[114610]=0;if((d|0)==1){break e}p[114610]=0;N(2185,c+16|0,b|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}p[114610]=0;K(1534,f|0,c+16|0);d=p[114610];p[114610]=0;if((d|0)==1){break c}pb(c+16|0);pb(c);a=a+1|0;if(a>>>0<r[p[e>>2]+480188>>1]){continue}break}}fb=c+32|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;pb(c+16|0)}pb(c)}bd(f);L(a|0);E()}function Ov(a,b,c){var d=0,e=0,f=0,g=w(0),h=w(0),i=w(0),j=w(0),k=w(0),l=w(0),m=w(0),n=0;d=fb-32|0;fb=d;lF(w(-t[a>>2]),w(t[a+12>>2]+t[a+24>>2]),w(t[a+36>>2]+t[a+48>>2]),d+20|0);lF(t[a+60>>2],w(t[a+48>>2]-t[a+36>>2]),w(t[a+24>>2]-t[a+12>>2]),d+8|0);t[d+12>>2]=-t[d+12>>2];a=0;while(1){e=a<<2;f=e+c|0;h=t[f>>2];n=f;f=e+48928|0;g=t[f>>2];i=t[e+(d+20|0)>>2];j=t[e+(d+8|0)>>2];k=t[f+12>>2];t[n>>2]=w(g*i)-w(j*k);f=b+e|0;l=t[(0-a<<2)+48936>>2];e=5-a<<2;m=t[e+48928>>2];g=w(w(g*j)+w(k*i));t[f>>2]=w(h*l)-w(m*g);t[b+e>>2]=w(m*h)+w(g*l);a=a+1|0;if((a|0)!=3){continue}break}fb=d+32|0}function fza(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-144|0;fb=c;oy(a);a:{b:{if(!af(a,64)){break b}c:{d:{e:{if(!dk(a,60)){break e}if(!wN(a,17148)){break e}b=15;break d}oy(a);if(!af(a,128)){break b}b=0;f=1;if(!dk(a,124)){break d}d=31;if(wN(a,17153)){break c}}d=b;if(f){break a}}oy(a);b=0;while(1){if(bza(a)>>>0>131072){break a}b=b+1|0;if((b&65535)>>>0<d>>>0){continue}break}Qc(a,4);if(!af(a,2)){break b}if(aza(a)>>>0<178){break a}e=-1;b=v(d,30);if(!af(a,b)){break a}Qc(a,b);b=a;a=c+8|0;b=_ya(b,a);if(!b){IO(a)}if(!b){break a}e=vN(c+8|0);break a}e=-1}fb=c+144|0;return e|0}function Q3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-32|0;fb=c;a:{b:{c:{if(me(b,-1)){break c}h=c,i=zm(b),n[h+23|0]=i;if(q[a+44|0]){if((Ii(c+23|0,1,1,p[a+32>>2])|0)!=1){break b}break c}p[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+23|0;while(1){e=Hq(p[a+36>>2],p[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(p[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Ii(d,1,1,p[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=p[c+16>>2]-(c+24|0)|0;if((Ii(c+24|0,1,d,p[a+32>>2])|0)!=(d|0)){break b}d=p[c+12>>2];if((e|0)==1){continue}break}}a=pr(b);break a}a=-1}fb=c+32|0;return a|0}function pj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=p[a+28>>2];if((c|0)>=(b|0)){e=p[a+24>>2];break a}i=a+32|0;f=p[a+20>>2];d=p[a+16>>2];g=c;while(1){b:{if(d>>>0>=f>>>0){f=fq(a,i,1024);p[a+16>>2]=0;p[a+20>>2]=f;if(!f){break b}d=0;g=p[a+28>>2]}h=d+1|0;p[a+16>>2]=h;d=q[(a+d|0)+32|0];c=g+8|0;p[a+28>>2]=c;e=p[a+24>>2]|d<<g;p[a+24>>2]=e;d=h;g=c;if((c|0)<(b|0)){continue}break a}break}a=W(8)|0;p[114610]=0;M(264,a|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){b=I()|0;H()|0;X(a|0);L(b|0);E()}ba(a|0,77024,265);E()}p[a+28>>2]=c-b;p[a+24>>2]=e>>>b;return(-1<<b^-1)&e}function T3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;d=me(b,-1);e=q[a+52|0];a:{if(d){d=b;if(e){break a}d=p[a+48>>2];f=a,g=me(d,-1)^1,n[f+52|0]=g;break a}if(e){p[c+16>>2]=p[a+48>>2];b:{c:{switch(Hq(p[a+36>>2],p[a+40>>2],c+16|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)+ -1|0){case 2:d=p[a+48>>2];p[c+20>>2]=c+25;n[c+24|0]=d;default:while(1){d=p[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break b}d=d+ -1|0;p[c+20>>2]=d;if((Mq(n[d|0],p[a+32>>2])|0)!=-1){continue}break}break;case 0:case 1:break c}}d=-1;e=0}if(!e){break a}}n[a+52|0]=1;p[a+48>>2]=b;d=b}fb=c+32|0;return d|0}function ywa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=fb-16|0;fb=b;h=p[a+24>>2];i=p[a+20>>2];j=p[a+16>>2];g=p[a+4>>2];e=g;f=p[a>>2];p[b+8>>2]=f;p[b+12>>2]=e;g=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=g;if(d){while(1){e=(e<<1)+j|0;f=(f>>>21&2040)+27824|0;e=(((v(o[e>>1],o[f+2>>1])+v(o[e+ -2>>1],o[f>>1])|0)+v(o[e+2>>1],o[f+4>>1])|0)+v(o[e+4>>1],o[f+6>>1])|0)/16384|0;p[c>>2]=p[c>>2]+v(e,i);p[c+4>>2]=p[c+4>>2]+v(e,h);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=p[b+8>>2];e=p[b+12>>2];continue}break}f=p[b+8>>2];e=p[b+12>>2]}p[a>>2]=f;p[a+4>>2]=e;fb=b+16|0}function xJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;a:{if(q[b+813|0]!=27){a=n[b+851|0];break a}e=a+1074308|0;vb(c+8|0,e,21);d=tb(c+8|0);f=a;a=q[b+841|0];a=ex(f,q[b+848|0],d?a:a+16>>>2|0);vb(c+8|0,e,45);b:{if(!(!tb(c+8|0)|q[b+848|0]!=3)){f=b;d=q[b+841|0];c:{if(!(!d|d>>>0>=q[b+849|0])){a=q[b+852|0];d=d+1|0;break c}n[b+852|0]=a;n[b+841|0]=0;d=1}n[f+841|0]=d;a=a<<24>>24;break b}n[b+841|0]=q[b+841|0]+q[b+849|0]}vb(c+8|0,e,47);if(!tb(c+8|0)){break a}n[b+851|0]=a}if(a){g=b,h=Pb(p[b+684>>2]+((v(q[b+850|0],a)+2|0)/8|0)|0,0,256),p[g+684>>2]=h}fb=c+16|0}function c6(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=w(0);h=1;b=q[(q[(p[b+4>>2]+v(c,3)|0)+2|0]+b|0)+9|0];if(!r[((b<<1)+a|0)+132>>1]){Wb(a,21);return}i=d>>1;g=p[a+260>>2]+v(b,1596)|0;b=v(q[g+1588|0],o[f>>1]);a=0;j=p[g+1592>>2];if((j|0)>=2){k=g+1592|0;l=g+1588|0;while(1){d=q[(g+h|0)+838|0]<<1;c=o[d+f>>1];if((c|0)>=0){c=v(q[l|0],c&65535);d=r[(d+g|0)+338>>1];if((d|0)!=(a|0)){Y5(e,a,b,d,c,i);j=p[k>>2];a=d}b=c}h=h+1|0;if((h|0)<(j|0)){continue}break}}if((a|0)<(i|0)){m=t[(b<<2)+50800>>2];while(1){b=(a<<2)+e|0;t[b>>2]=t[b>>2]*m;a=a+1|0;if((i|0)!=(a|0)){continue}break}}}function tIa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;p[e+28>>2]=d;a:{b:{if(q[a+24|0]){if(!d){break a}i=a+40|0;break b}j=m[p[p[a>>2]+44>>2]](a,b,c,d)|0;break a}while(1){f=EJa(a,c);g=c-p[ti(i,f)>>2]|0;p[e+8>>2]=4096-g;k=e,l=p[Cb(e+8|0,e+28|0)>>2],p[k+24>>2]=l;d=e;if(s[ti(i,f)+4>>2]>g>>>0){h=p[ti(i,f)+4>>2]-g|0}else{h=0}p[d+20>>2]=h;d=p[Cb(e+24|0,e+20|0)>>2];Ez(e+8|0,a,f);h=p[e+8>>2];Ez(e,a,f);Ye(g+h|0,d+(p[e>>2]+g|0)|0,b);f=p[e+28>>2]-d|0;p[e+28>>2]=f;j=d+j|0;if(s[e+24>>2]>d>>>0){break a}c=c+d|0;b=b+d|0;if(f){continue}break}}fb=e+32|0;return j}function dAa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-32|0;fb=d;vd(b,0);QN(d,a+1|0);zc(d+16|0,d);p[114610]=0;J(370,b+43|0,d+16|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(d+16|0);c=a+78|0;p[b+24>>2]=q[c|0]|q[c+1|0]<<8;c=a+58|0;p[b>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+62|0;p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+66|0;p[b+8>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);o[b+30>>1]=(q[a+73|0]<<1)+2;o[b+34>>1]=r[b+34>>1]&65533|q[a|0]>>>6&2;vc(b+8|0,p[b>>2]);vc(b+4|0,p[b+8>>2]);fb=d+32|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function dza(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;vd(b,1);p[b>>2]=c;n[b+37|0]=q[a+24|0]<<4;n[d+15|0]=q[a+25|0];n[d+14|0]=64;g=b,h=q[hc(d+15|0,d+14|0)|0]<<2,o[g+30>>1]=h;c=a+26|0;c=q[c|0]|q[c+1|0]<<8;a=a+28|0;e=p[b>>2];a:{if(!e){break a}f=q[a|0]|q[a+1|0]<<8;a=(c<<8&16711680|c<<24)>>>16|0;p[b+4>>2]=a;c=((f<<8&16711680|f<<24)>>>15|0)+a|0;p[b+8>>2]=c;if(e>>>0<=a>>>0){a=e+ -1|0;p[b+4>>2]=a}if(c>>>0>e>>>0){p[b+8>>2]=e;c=e}if(!(c-a>>>0>3?!(c>>>0<a>>>0|c>>>0<4):0)){p[b+4>>2]=0;p[b+8>>2]=0;break a}if(c>>>0<=a>>>0){break a}o[b+34>>1]=r[b+34>>1]|2}fb=d+16|0}



function EJa(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;f=a+40|0;c=a+232|0;g=b-(b&4095)|0;a:{while(1){b:{b=p[nf(c,e)>>2];if(!q[ti(f,b)+8|0]){break b}if(p[ti(f,b)>>2]!=(g|0)){break b}h=d,i=p[nf(c,e)>>2],p[h+8>>2]=i;a=e<<2;it(c,a+c|0,(a+c|0)+4|0);a=p[d+8>>2];h=nf(c,0),i=a,p[h>>2]=i;break a}e=e+1|0;if((e|0)!=16){continue}break}h=d,i=p[nf(c,15)>>2],p[h+8>>2]=i;it(c,c+60|0,c- -64|0);b=p[d+8>>2];h=nf(c,0),i=b,p[h>>2]=i;b=p[nf(c,0)>>2];c=ti(f,b);p[c>>2]=g;Ez(d+8|0,a,b);h=c,i=m[p[p[a>>2]+44>>2]](a,p[d+8>>2],g,4096)|0,p[h+4>>2]=i;n[c+8|0]=1}fb=d+16|0;return b}function Axa(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;p[e+12>>2]=c;d=p[b+4>>2];a:{if(d){p[e+8>>2]=32-d;c=p[Cb(e+8|0,e+12|0)>>2];d=p[b>>2];f=-1<<p[b+4>>2]&-1>>>p[e+8>>2]-c&(p[d>>2]^-1);if(f){Lc(a,d,MNa(f));break a}f=p[e+12>>2];if((f|0)==(c|0)){iy(a,b,c);break a}c=f-c|0;p[e+12>>2]=c;p[b>>2]=d+4}if(c>>>0>=32){d=p[b>>2];while(1){f=p[d>>2];if((f|0)!=-1){Lc(a,d,MNa(f^-1));break a}d=d+4|0;p[b>>2]=d;c=c+ -32|0;p[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=p[b>>2];break b}d=p[b>>2];b=(p[d>>2]^-1)&-1>>>32-c;if(!b){break b}Lc(a,d,MNa(b));break a}Lc(a,d,c)}fb=e+16|0}function $wa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=p[a+40>>2];h=p[a+36>>2];k=p[a+16>>2];e=p[a+4>>2];f=e;i=p[a>>2];p[b+8>>2]=i;p[b+12>>2]=e;e=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=e;a:{if(!d){e=g>>12;j=h>>12;break a}while(1){e=p[a+32>>2];f=o[(f<<1)+k>>1];h=p[a+28>>2]+h|0;j=h>>12;p[c>>2]=p[c>>2]+v(f,j);g=e+g|0;e=g>>12;p[c+4>>2]=p[c+4>>2]+v(f,e);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=p[b+12>>2];continue}break}i=p[b+8>>2];f=p[b+12>>2]}p[a+40>>2]=g;p[a+20>>2]=j;p[a+36>>2]=h;p[a+24>>2]=e;p[a>>2]=i;p[a+4>>2]=f;fb=b+16|0}function jsa(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;p[e+12>>2]=c;d=p[b+4>>2];a:{if(d){p[e+8>>2]=32-d;c=p[Cb(e+8|0,e+12|0)>>2];f=-1<<d&-1>>>p[e+8>>2]-c;d=p[b>>2];f=f&(p[d>>2]^-1);if(f){Lc(a,d,MNa(f));break a}f=p[e+12>>2];if((f|0)==(c|0)){nL(a,b,c);break a}c=f-c|0;p[e+12>>2]=c;p[b>>2]=d+4}if(c>>>0>=32){d=p[b>>2];while(1){f=p[d>>2];if((f|0)!=-1){Lc(a,d,MNa(f^-1));break a}d=d+4|0;p[b>>2]=d;c=c+ -32|0;p[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=p[b>>2];break b}d=p[b>>2];b=(p[d>>2]^-1)&-1>>>32-c;if(!b){break b}Lc(a,d,MNa(b));break a}Lc(a,d,c)}fb=e+16|0}function zwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=fb-16|0;fb=b;h=p[a+24>>2];i=p[a+20>>2];j=p[a+16>>2];g=p[a+4>>2];e=g;f=p[a>>2];p[b+8>>2]=f;p[b+12>>2]=e;g=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=g;if(d){while(1){e=e+j|0;f=(f>>>21&2040)+27824|0;e=(((v(n[e|0],o[f+2>>1])+v(n[e+ -1|0],o[f>>1])|0)+v(n[e+1|0],o[f+4>>1])|0)+v(n[e+2|0],o[f+6>>1])<<8)/16384|0;p[c>>2]=p[c>>2]+v(e,i);p[c+4>>2]=p[c+4>>2]+v(e,h);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=p[b+8>>2];e=p[b+12>>2];continue}break}f=p[b+8>>2];e=p[b+12>>2]}p[a>>2]=f;p[a+4>>2]=e;fb=b+16|0}function axa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=p[a+40>>2];h=p[a+36>>2];k=p[a+16>>2];e=p[a+4>>2];f=e;i=p[a>>2];p[b+8>>2]=i;p[b+12>>2]=e;e=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=e;a:{if(!d){e=g>>12;j=h>>12;break a}while(1){e=p[a+32>>2];f=n[f+k|0]<<8;h=p[a+28>>2]+h|0;j=h>>12;p[c>>2]=p[c>>2]+v(f,j);g=e+g|0;e=g>>12;p[c+4>>2]=p[c+4>>2]+v(f,e);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=p[b+12>>2];continue}break}i=p[b+8>>2];f=p[b+12>>2]}p[a+40>>2]=g;p[a+20>>2]=j;p[a+36>>2]=h;p[a+24>>2]=e;p[a>>2]=i;p[a+4>>2]=f;fb=b+16|0}function $na(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;t[c+8>>2]=2;o[c+14>>1]=12;p[c+4>>2]=15;d=Ee(64);p[114610]=0;e=M(1427,d|0)|0;f=p[114610];p[114610]=0;a:{b:{if((f|0)!=1){d=nx(c,e);e=p[d>>2];p[114610]=0;K(1428,e|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}b=p[d>>2];p[114610]=0;b=P(1429,b|0,c+14|0,c+8|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}c:{if(!b){mx(a);break c}b=p[d>>2];p[114610]=0;K(1430,b|0,c+4|0);b=p[114610];p[114610]=0;if((b|0)==1){break b}np(a,d)}Qf(d);fb=c+16|0;return}a=I()|0;H()|0;Nb(d);break a}a=I()|0;H()|0;Qf(d)}L(a|0);E()}function Kea(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0,n=0;l=fb-32|0;fb=l;n=p[c>>2];m=p[c+8>>2];k=l;c=p[c+4>>2];p[k+8>>2]=c;p[k+12>>2]=m;p[114610]=0;p[k+20>>2]=n;p[k+16>>2]=d;p[k+24>>2]=c;p[k+28>>2]=m;c=p[k+20>>2];p[k>>2]=p[k+16>>2];p[k+4>>2]=c;d=Ca(2007,a|0,b|0,k|0)|0;a=p[114610];p[114610]=0;a:{if((a|0)==1){a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;ca(2e3,34588,e|0,f|0,g|0,h|0,i|0,j|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=-255}fb=l+32|0;return d}b=I()|0;H()|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)!=1){L(b|0);E()}a=O(0)|0;H()|0;rb(a);E()}function uta(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;while(1){tta((v(e,44)+a|0)+16|0,d+14|0,d+12|0);f=o[d+12>>1]+f|0;g=o[d+14>>1]+g|0;e=e+1|0;if((e|0)!=18){continue}break}e=b;b=(g|0)<32767?g:32767;o[e>>1]=(b|0)>-32768?b:-32768;b=(f|0)<32767?f:32767;o[c>>1]=(b|0)>-32768?b:-32768;o[a+3832>>1]=r[a+3832>>1]+1;b=(r[a+3834>>1]+1>>>0)%13440|0;o[a+3834>>1]=b;b=((b>>>0<6720?b:13440-b|0)|0)/256|0;o[a+3836>>1]=b;if(!q[a+3843|0]){o[a+3836>>1]=b>>>2}b=r[a+3838>>1]+1|0;o[a+3838>>1]=b;if((b&65535)>>>0>=1024){o[a+3838>>1]=0;o[a+3840>>1]=r[a+3840>>1]+1&7}fb=d+16|0}function lna(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;a:{if(!dx(a,b,0)){break a}e=p[b+656>>2];h=a+1074308|0;vb(d+8|0,h,31);b:{if(tb(d+8|0)){a=p[b+728>>2];if(a){break b}break a}a=p[b+728>>2]}vb(d+8|0,h,31);f=e+48|0;i=a-tb(d+8|0)|0;a=Zo(f,i,256,64);g=q[e+65|0];c:{if((g|0)==255){break c}b=p[b+732>>2];if((b|0)==-1){break c}g=q[Fb(f,g)+2|0];f=r[Fb(f,q[e+65|0])>>1];vb(d+8|0,h,94);e=g<<2;a=(f|0)==(i|0)?e:a;if(tb(d+8|0)){a=b+(a-e<<1)|0;break c}if(!g){a=0;break c}a=(v(a,b)|0)/(e|0)|0}j=c,k=(v(p[c>>2],Pb(a,0,512))|0)/256|0,p[j>>2]=k}fb=d+16|0}function h_(){var a=0;a:{if(n[462688]&1){break a}if(!nd(462688)){break a}a=462400;while(1){a=Lb(a)+12|0;if((a|0)!=462688){continue}break}md(462688)}Ec(462400,67532);Ec(462412,67540);Ec(462424,67549);Ec(462436,67555);Ec(462448,67561);Ec(462460,67565);Ec(462472,67570);Ec(462484,67575);Ec(462496,67582);Ec(462508,67592);Ec(462520,67600);Ec(462532,67609);Ec(462544,67618);Ec(462556,67622);Ec(462568,67626);Ec(462580,67630);Ec(462592,67561);Ec(462604,67634);Ec(462616,67638);Ec(462628,67642);Ec(462640,67646);Ec(462652,67650);Ec(462664,67654);Ec(462676,67658)}function e_(){var a=0;a:{if(n[462992]&1){break a}if(!nd(462992)){break a}a=462704;while(1){a=Ue(a)+12|0;if((a|0)!=462992){continue}break}md(462992)}Rc(462704,67664);Rc(462716,67696);Rc(462728,67732);Rc(462740,67756);Rc(462752,67780);Rc(462764,67796);Rc(462776,67816);Rc(462788,67836);Rc(462800,67864);Rc(462812,67904);Rc(462824,67936);Rc(462836,67972);Rc(462848,68008);Rc(462860,68024);Rc(462872,68040);Rc(462884,68056);Rc(462896,67780);Rc(462908,68072);Rc(462920,68088);Rc(462932,68104);Rc(462944,68120);Rc(462956,68136);Rc(462968,68152);Rc(462980,68168)}function T2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=q[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=p[114584];p[114584]=0;a=bv(a,e+12|0,d,de());d=ib;g=p[114584];g:{if(g){if(p[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}p[114584]=h;if(p[e+12>>2]==(b|0)){break d}}}}p[c>>2]=4;a=0;b=0;break a}if((d|0)==-1&4294967295>=a>>>0|4294967295>d>>>0){break b}}p[c>>2]=4;a=-1;b=-1;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+(0<b>>>0)|0)|0:d}fb=e+16|0;ib=b;return a|0}function Iya(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{b:{if(!ue(a)){break b}f=p[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break b}Zm(b);ky(b,a);p[b+20>>2]=0;p[b>>2]=d;if(!Wo(b)){break b}if(p[a>>2]!=(d|0)){Jb(b+68|0,0,36)}f=p[b+20>>2];p[114610]=0;f=M(466,f|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break a}a=p[a+20>>2];p[114610]=0;a=M(466,a|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break a}ac(f,a+c|0,d);a=r[b+34>>1];if(e){p[b+8>>2]=d;p[b+4>>2]=0;o[b+34>>1]=a|2;return}p[b+4>>2]=0;p[b+8>>2]=0;o[b+34>>1]=a&65533}return}a=O(0)|0;H()|0;rb(a);E()}function kra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=p[a>>2]<<1;e=p[Cb(d+8|0,d+12|0)>>2];p[d+8>>2]=p[a>>2]<<1;p[d+4>>2]=p[d+12>>2]-e;g=p[Cb(d+8|0,d+4|0)>>2]>>>1|0;c=ub(b);h=e>>>1|0;if(h){f=p[a+20>>2];e=h;while(1){i=f,j=(ub(q[c|0])|ub(q[c+1|0])<<8)^32768,o[i>>1]=j;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}b=ub(b);if(g){f=p[a+20>>2]+2|0;c=b+(p[a>>2]<<1)|0;e=g;while(1){i=f,j=(ub(q[c|0])|ub(q[c+1|0])<<8)^32768,o[i>>1]=j;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}fb=d+16|0;return g+h<<1}function hra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=p[a>>2]<<1;e=p[Cb(d+8|0,d+12|0)>>2];p[d+8>>2]=p[a>>2]<<1;p[d+4>>2]=p[d+12>>2]-e;g=p[Cb(d+8|0,d+4|0)>>2]>>>1|0;c=ub(b);h=e>>>1|0;if(h){f=p[a+20>>2];e=h;while(1){i=f,j=(ub(q[c+1|0])|ub(q[c|0])<<8)^32768,o[i>>1]=j;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}b=ub(b);if(g){f=p[a+20>>2]+2|0;c=b+(p[a>>2]<<1)|0;e=g;while(1){i=f,j=(ub(q[c+1|0])|ub(q[c|0])<<8)^32768,o[i>>1]=j;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}fb=d+16|0;return g+h<<1}function N3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;a:{b:{c:{if(me(b,-1)){break c}p[c+20>>2]=b;if(q[a+44|0]){if((Ii(c+20|0,4,1,p[a+32>>2])|0)!=1){break b}break c}p[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+20|0;while(1){e=Hq(p[a+36>>2],p[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(p[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Ii(d,1,1,p[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=p[c+16>>2]-(c+24|0)|0;if((Ii(c+24|0,1,d,p[a+32>>2])|0)!=(d|0)){break b}d=p[c+12>>2];if((e|0)==1){continue}break}}a=pr(b);break a}a=-1}fb=c+32|0;return a|0}function r5(){var a=0,b=0,c=0,d=0;a=fb-48|0;fb=a;p[114610]=0;b=J(2308,0,a+32|0)|0;c=p[114610];p[114610]=0;a:{b:{c:{if((c|0)==1){break c}if(b){p[114610]=0;a=p[114610];p[114610]=0;if((a|0)==1){break c}a=p[114584];p[114610]=0;K(2310,a|0,55612);a=p[114610];p[114610]=0;if((a|0)!=1){break b}break c}b=Uq(a+16|0,a+32|0);p[a+4>>2]=p[a+36>>2]/1e3;c=Uq(a+8|0,a+4|0);p[114610]=0;b=TB(2311,b,c);c=ib;d=p[114610];p[114610]=0;if((d|0)!=1){break a}}a=O(0)|0;H()|0;rb(a)}E()}p[a+24>>2]=b;p[a+28>>2]=c;b=Zj(a+40|0,a+24|0);c=p[b+4>>2];b=p[b>>2];fb=a+48|0;ib=c;return b}function jO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-80|0;fb=e;a:{if(p[b+4>>2]==p[d+4>>2]){f=p[b+4>>2];p[e+72>>2]=p[b>>2];p[e+76>>2]=f;b=p[c+4>>2];p[e+64>>2]=p[c>>2];p[e+68>>2]=b;b=Ed(e+56|0,d);c=p[e+76>>2];p[e+8>>2]=p[e+72>>2];p[e+12>>2]=c;c=p[e+68>>2];p[e>>2]=p[e+64>>2];p[e+4>>2]=c;QAa(a,e+8|0,e,b);break a}f=p[b+4>>2];p[e+48>>2]=p[b>>2];p[e+52>>2]=f;b=p[c+4>>2];p[e+40>>2]=p[c>>2];p[e+44>>2]=b;b=Ed(e+32|0,d);c=p[e+52>>2];p[e+24>>2]=p[e+48>>2];p[e+28>>2]=c;c=p[e+44>>2];p[e+16>>2]=p[e+40>>2];p[e+20>>2]=c;PAa(a,e+24|0,e+16|0,b)}fb=e+80|0}function Bxa(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;p[e+12>>2]=c;d=p[b+4>>2];a:{if(d){p[e+8>>2]=32-d;c=Cb(e+8|0,e+12|0);d=p[b>>2];c=p[c>>2];f=p[d>>2]&(-1<<p[b+4>>2]&-1>>>p[e+8>>2]-c);if(f){Lc(a,d,MNa(f));break a}f=p[e+12>>2];if((f|0)==(c|0)){iy(a,b,c);break a}c=f-c|0;p[e+12>>2]=c;p[b>>2]=d+4}if(c>>>0>=32){d=p[b>>2];while(1){f=p[d>>2];if(f){Lc(a,d,MNa(f));break a}d=d+4|0;p[b>>2]=d;c=c+ -32|0;p[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=p[b>>2];break b}d=p[b>>2];b=p[d>>2]&-1>>>32-c;if(!b){break b}Lc(a,d,MNa(b));break a}Lc(a,d,c)}fb=e+16|0}function g3(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[c+12>>2]=0;xD(a,c+12|0,1);d=p[c+12>>2];e=d>>>2&3;n[c+11|0]=e;if(e){n[c+4|0]=3;d=q[hc(c+4|0,c+11|0)|0];n[c+4|0]=0;n[c|0]=0;n[c+10|0]=0;a:{if(!d){break a}mh(a,c+4|0);if((d|0)==1){break a}mh(a,c);if(d>>>0<3){break a}mh(a,c+10|0);f=q[c+10|0]<<24}d=q[c+12|0]|q[c+4|0]<<8|q[c|0]<<16|f;p[c+12>>2]=d}p[c+4>>2]=d>>>4;p[c>>2]=1e6;ym(b,p[Cb(c+4|0,c)>>2]);if(wb(b)){d=0;while(1){Hj(a,cc(b,d),1);d=d+1|0;if(d>>>0<wb(b)>>>0){continue}break}}b=(p[c+12>>2]>>>4|0)-wb(b)|0;p[c+12>>2]=b;if(b){Tk(a,b,-1)}fb=c+16|0}function Aza(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-80|0;fb=d;e=p[a+4>>2];f=p[b+4>>2];g=p[b>>2];p[d+72>>2]=g;p[d+76>>2]=f;h=p[c+4>>2];c=p[c>>2];p[d+64>>2]=c;p[d+68>>2]=h;p[d+24>>2]=g;p[d+28>>2]=f;p[d+16>>2]=c;p[d+20>>2]=h;b=GN(d+24|0,d+16|0)+p[a+4>>2]|0;p[a+4>>2]=b;if(!((b+ -1^e+ -1)>>>0<32?e:0)){i=p[a>>2];p[(b>>>0<33?i:i+(b+ -1>>>3&536870908)|0)>>2]=0}p[d+48>>2]=c;p[d+52>>2]=h;p[d+56>>2]=g;p[d+60>>2]=f;zn(d+40|0,a,e);a=p[d+60>>2];p[d+8>>2]=p[d+56>>2];p[d+12>>2]=a;a=p[d+52>>2];p[d>>2]=p[d+48>>2];p[d+4>>2]=a;jO(d+32|0,d+8|0,d,d+40|0);fb=d+80|0}function jra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;p[e+12>>2]=c;p[e+8>>2]=p[a>>2]<<1;f=p[Cb(e+8|0,e+12|0)>>2];p[e+8>>2]=p[a>>2]<<1;p[e+4>>2]=p[e+12>>2]-f;h=p[Cb(e+8|0,e+4|0)>>2]>>>1|0;c=ub(b);i=f>>>1|0;if(i){g=p[a+20>>2];f=i;j=d;while(1){j=(ub(q[c|0])|ub(q[c+1|0])<<8)+j|0;o[g>>1]=j;g=g+4|0;c=c+2|0;f=f+ -1|0;if(f){continue}break}}b=ub(b);if(h){g=p[a+20>>2]+2|0;c=b+(p[a>>2]<<1)|0;f=h;while(1){d=(ub(q[c|0])|ub(q[c+1|0])<<8)+d|0;o[g>>1]=d;g=g+4|0;c=c+2|0;f=f+ -1|0;if(f){continue}break}}fb=e+16|0;return h+i<<1}function gra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;p[e+12>>2]=c;p[e+8>>2]=p[a>>2]<<1;f=p[Cb(e+8|0,e+12|0)>>2];p[e+8>>2]=p[a>>2]<<1;p[e+4>>2]=p[e+12>>2]-f;h=p[Cb(e+8|0,e+4|0)>>2]>>>1|0;c=ub(b);i=f>>>1|0;if(i){g=p[a+20>>2];f=i;j=d;while(1){j=(ub(q[c+1|0])|ub(q[c|0])<<8)+j|0;o[g>>1]=j;g=g+4|0;c=c+2|0;f=f+ -1|0;if(f){continue}break}}b=ub(b);if(h){g=p[a+20>>2]+2|0;c=b+(p[a>>2]<<1)|0;f=h;while(1){d=(ub(q[c+1|0])|ub(q[c|0])<<8)+d|0;o[g>>1]=d;g=g+4|0;c=c+2|0;f=f+ -1|0;if(f){continue}break}}fb=e+16|0;return h+i<<1}function b3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=p[114584];p[114584]=0;d=zD(a,e+12|0,d,de());a=ib;f=p[114584];d:{if(f){if(p[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}p[114584]=g;if(p[e+12>>2]==(b|0)){break c}}}p[c>>2]=4;d=0;a=0;break a}if((a|0)<-2147483648?1:(a|0)<=-2147483648?d>>>0<0:0){break b}if(2147483647>(a|0)?1:2147483647>=(a|0)?4294967295>=d>>>0:0){break a}}p[c>>2]=4;if((a|0)>0?1:(a|0)>=0?d>>>0>=1:0){d=-1;a=2147483647;break a}d=0;a=-2147483648}fb=e+16|0;ib=a;return d|0}function OO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=sCa(a);a:{if(c>>>0>5){break a}while(1){b=v(d,30)+a|0;c=rCa(b+20|0)+c|0;if(c>>>0>48){break a}e=b+45|0;if(q[b+44|0]|q[e|0]>64){break a}b=b+42|0;f=q[b|0]|q[b+1|0]<<8;if((f<<24|f<<8&16711680)>>>16>>>0>32768){break a}b=q[b|0]|q[b+1|0]<<8;g=((b<<24|b<<8&16711680)>>>16|0)+g|0;h=q[e|0]|h;d=d+1|0;if((d|0)!=15){continue}break}if(!g|!(h&255)){break a}b=a+470|0;if(q[b|0]>128){break a}c=a+471|0;if(q[c|0]>220){break a}a=a+472|0;a=q[aCa(a,a+128|0)|0];if(a>>>0>63|(a|q[b|0]?0:!q[c|0])){break a}i=1}return i}function Lpa(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b:{if(c){d=q[b+861|0];c:{if(d){c=d+ -1|0;n[b+861|0]=c;if(c&255){break c}vb(e+8|0,a+1074308|0,16);if(!tb(e+8|0)){c=-1;if(p[a+480180>>2]!=2){break a}}p[b+804>>2]=p[a+1074424>>2]+1;break b}vb(e+8|0,a+1074308|0,17);if(!(tb(e+8|0)|p[a+480180>>2]&3|!r[a+480188>>1])){d=a+1074984|0;while(1){if(q[d+861|0]?(b|0)!=(d|0):0){break b}d=d+896|0;f=f+1|0;if((f&65535)>>>0<r[a+480188>>1]){continue}break}}n[b+861|0]=c}c=p[b+804>>2];p[a+1074432>>2]=c;break a}p[b+804>>2]=p[a+1074424>>2]}c=-1}fb=e+16|0;return c}function nU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;p[d+12>>2]=p[p[a+1056>>2]>>2]-p[a+1060>>2];p[d+8>>2]=16384;e=p[Cb(d+12|0,d+8|0)>>2];p[a+1068>>2]=e;c=17;p[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c+ -1;e=pj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Sp(d+4|0,pj(a,4));break b}if((c|0)>16){break c}c=f+ -8|0;if((e|0)<(c|0)|(e|0)>(f+7|0)){break d}Sp(d+4|0,e-c|0);break b}LA(a,e,f,b);break b}c=e&(f^-1);if(e&f){p[d+4>>2]=c+1;break b}LA(a,c,0,b)}if(!p[a+1068>>2]){break a}c=p[d+4>>2];if((c|0)<18){continue}break}}fb=d+16|0}function ksa(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;p[e+12>>2]=c;d=p[b+4>>2];a:{if(d){p[e+8>>2]=32-d;c=Cb(e+8|0,e+12|0);f=p[b>>2];c=p[c>>2];d=p[f>>2]&(-1<<d&-1>>>p[e+8>>2]-c);if(d){Lc(a,f,MNa(d));break a}d=p[e+12>>2];if((d|0)==(c|0)){nL(a,b,c);break a}c=d-c|0;p[e+12>>2]=c;p[b>>2]=f+4}if(c>>>0>=32){d=p[b>>2];while(1){f=p[d>>2];if(f){Lc(a,d,MNa(f));break a}d=d+4|0;p[b>>2]=d;c=c+ -32|0;p[e+12>>2]=c;if(c>>>0>31){continue}break}}b:{if(!c){d=p[b>>2];break b}d=p[b>>2];b=p[d>>2]&-1>>>32-c;if(!b){break b}Lc(a,d,MNa(b));break a}Lc(a,d,c)}fb=e+16|0}function mU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;p[d+12>>2]=p[p[a+1056>>2]>>2]-p[a+1060>>2];p[d+8>>2]=32768;e=p[Cb(d+12|0,d+8|0)>>2];p[a+1068>>2]=e;c=9;p[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c+ -1;e=pj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}Sp(d+4|0,pj(a,3));break b}if((c|0)>8){break c}c=f+ -4|0;if((e|0)<(c|0)|(e|0)>(f+3|0)){break d}Sp(d+4|0,e-c|0);break b}KA(a,e,f,b);break b}c=e&(f^-1);if(e&f){p[d+4>>2]=c+1;break b}KA(a,c,0,b)}if(!p[a+1068>>2]){break a}c=p[d+4>>2];if((c|0)<10){continue}break}}fb=d+16|0}function ZB(a,b){var c=0,d=0,e=0,f=0;c=fb+ -64|0;fb=c;d=p[a>>2];e=p[d+ -4>>2];f=p[d+ -8>>2];p[c+20>>2]=0;p[c+16>>2]=71880;p[c+12>>2]=a;p[c+8>>2]=b;d=0;Jb(c+24|0,0,39);a=a+f|0;a:{if(Xf(e,b,0)){p[c+56>>2]=1;m[p[p[e>>2]+20>>2]](e,c+8|0,a,a,1,0);d=p[c+32>>2]==1?a:0;break a}m[p[p[e>>2]+24>>2]](e,c+8|0,a,1,0);b:{switch(p[c+44>>2]){case 0:d=p[c+48>>2]==1?p[c+36>>2]==1?p[c+40>>2]==1?p[c+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(p[c+32>>2]!=1){if(p[c+48>>2]|p[c+36>>2]!=1|p[c+40>>2]!=1){break a}}d=p[c+24>>2]}fb=c- -64|0;return d}function Z1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=fb-32|0;fb=a;o[a+28>>1]=q[62144]|q[62145]<<8;p[a+24>>2]=q[62140]|q[62141]<<8|(q[62142]<<16|q[62143]<<24);Cj(a+24|1,62132,1,p[c+4>>2]);g=p[c+4>>2];f=a+ -16|0;fb=f;h=de();p[a>>2]=e;e=g>>>9&1;g=Te(f,e+13|0,h,a+24|0,a)+f|0;h=Yf(f,g,c);e=f-((e<<3)+107&112)|0;fb=e;qc(a+8|0,c);p[114610]=0;ca(2474,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=p[114610];p[114610]=0;if((f|0)!=1){Gb(a+8|0);b=dm(b,e,p[a+20>>2],p[a+16>>2],c,d);fb=a+32|0;return b|0}b=I()|0;H()|0;Gb(a+8|0);L(b|0);E()}function vqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,g=w(0),h=0,i=0,k=w(0),l=0,m=0;e=fb-16|0;fb=e;p[e+8>>2]=c>>>2;p[e+4>>2]=p[a>>2];h=p[Cb(e+8|0,e+4|0)>>2];k=t[d>>2];b=ub(b);if(h){d=p[a+20>>2];c=h;while(1){a=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);t[e+12>>2]=k*(f(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),j());Td(e+12|0,w(-1));g=w(t[e+12>>2]*w(32768));t[e+12>>2]=g;a=d;g=$d(g);a:{if(w(x(g))<w(2147483648)){i=~~g;break a}i=-2147483648}l=a,m=Mc(i),o[l>>1]=m;d=d+2|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return h<<2}function uda(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;p[114610]=0;S(2015,a|0);h=p[114610];p[114610]=0;a:{b:{if((h|0)!=1){c:{h=p[a+24>>2];p[114610]=0;ca(2073,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=p[114610];p[114610]=0;if((b|0)==1){break c}b=Pd(Ib(g));pb(g);break b}}b=O(0)|0;H()|0;T(b|0)|0;b=0;p[114610]=0;Q(1989,36722,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=g+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function tda(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;p[114610]=0;S(2015,a|0);h=p[114610];p[114610]=0;a:{b:{if((h|0)!=1){c:{h=p[a+24>>2];p[114610]=0;ca(2074,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=p[114610];p[114610]=0;if((b|0)==1){break c}b=Pd(Ib(g));pb(g);break b}}b=O(0)|0;H()|0;T(b|0)|0;b=0;p[114610]=0;Q(1989,36764,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=g+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function lra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=p[a>>2]<<1;e=p[Cb(d+8|0,d+12|0)>>2];p[d+8>>2]=p[a>>2]<<1;p[d+4>>2]=p[d+12>>2]-e;g=p[Cb(d+8|0,d+4|0)>>2]>>>1|0;c=ub(b);h=e>>>1|0;if(h){f=p[a+20>>2];e=h;while(1){i=f,j=ub(q[c|0])|ub(q[c+1|0])<<8,o[i>>1]=j;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}b=ub(b);if(g){f=p[a+20>>2]+2|0;c=b+(p[a>>2]<<1)|0;e=g;while(1){i=f,j=ub(q[c|0])|ub(q[c+1|0])<<8,o[i>>1]=j;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}fb=d+16|0;return g+h<<1}function ira(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=p[a>>2]<<1;e=p[Cb(d+8|0,d+12|0)>>2];p[d+8>>2]=p[a>>2]<<1;p[d+4>>2]=p[d+12>>2]-e;g=p[Cb(d+8|0,d+4|0)>>2]>>>1|0;c=ub(b);h=e>>>1|0;if(h){f=p[a+20>>2];e=h;while(1){i=f,j=ub(q[c+1|0])|ub(q[c|0])<<8,o[i>>1]=j;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}b=ub(b);if(g){f=p[a+20>>2]+2|0;c=b+(p[a>>2]<<1)|0;e=g;while(1){i=f,j=ub(q[c+1|0])|ub(q[c|0])<<8,o[i>>1]=j;f=f+4|0;c=c+2|0;e=e+ -1|0;if(e){continue}break}}fb=d+16|0;return g+h<<1}function Zea(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;a:{b:{if(!a){a=Pd(34085);break b}p[114610]=0;c=J(85,b|0,a|0)|0;a=p[114610];p[114610]=0;c:{d:{if((a|0)!=1){p[114610]=0;K(1993,b+16|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}a=Pd(Ib(b+16|0));pb(b+16|0);pb(c);break b}a=O(0)|0;H()|0;break c}a=O(0)|0;H()|0;pb(c)}T(a|0)|0;a=0;p[114610]=0;Q(1989,34086,0,0,0);c=p[114610];p[114610]=0;if((c|0)==1){break a}V()}fb=b+32|0;return a|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function PLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-208|0;fb=d;$z(c,a);xS(c,d+16|0,v(q[a+4|0],3));a:{if(q[a+4|0]<2){break a}n[d+12|0]=64;Vf(b,q[hc(a+4|0,d+12|0)|0]);n[b+13|0]=q[a+2|0];n[b+14|0]=q[a+3|0];a=q[a+1|0];n[b+15|0]=a;n[b+16|0]=a;if(!Bb(b)){break a}a=0;while(1){if(a){c=r[Fb(b,a+ -1|0)>>1];p[d+12>>2]=1;e=(d+16|0)+v(a,3)|0;p[d+8>>2]=(n[e+1|0]&1)<<8|q[e|0];e=r[Gf(d+12|0,d+8|0)>>1];f=Fb(b,a),g=c+e|0,o[f>>1]=g}c=q[((d+16|0)+v(a,3)|0)+2|0];f=Fb(b,a),g=c,n[f+2|0]=g;a=a+1|0;if(a>>>0<Bb(b)>>>0){continue}break}}fb=d+208|0}function oFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;g=d+8|0;e=b;h=e;if(HP(e,d+24|0)){f=d+26|0;f=q[f|0]|q[f+1|0]<<8|(q[f+2|0]<<16|q[f+3|0]<<24)}ld(g,h,f);e=q[d+24|0]|q[d+25|0]<<8|(q[d+26|0]<<16|q[d+27|0]<<24);n[a|0]=e;n[a+1|0]=e>>>8;n[a+2|0]=e>>>16;n[a+3|0]=e>>>24;e=q[d+28|0]|q[d+29|0]<<8;n[a+4|0]=e;n[a+5|0]=e>>>8;Ml(a+8|0,d+8|0);sb(d+8|0);a:{if(!c){break a}e=(f>>>0)%(c>>>0)|0;if(!e){break a}p[114610]=0;J(338,b|0,c-e|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}b=I()|0;H()|0;Ce(a);L(b|0);E()}fb=d+32|0}function Yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;f=Vw(a);a:{b:{c:{d:{while(1){p[114610]=0;a=J(258,b|0,8)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}if(a){p[114610]=0;N(1554,e+8|0,b|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}p[114610]=0;K(1555,f|0,e+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}Ce(e+8|0);a=uy(f);if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=(d|0)){continue}}break}fb=e+32|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;Ce(e+8|0);break a}a=I()|0;H()|0}fl(f);L(a|0);E()}function lua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;f=r[wk(a,b)>>1];a:{if(!Vo(a,b)){break a}d=p[a+24>>2]+484360|0;j=c,k=Ub(d),p[j+8>>2]=k;j=c,k=Vb(d),p[j>>2]=k;if(!Ab(c+8|0,c)){break a}h=f&65535;while(1){b:{g=p[c+8>>2];i=qt(g);if(i){e=0;while(1){if(!(!((a|0)!=(g|0)|(b|0)!=(e|0))|r[kc(g,e)>>1]!=(h|0))){d=CI(p[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}Zx(c+8|0);if(Ab(c+8|0,c)){continue}break a}break}j=wk(a,b),k=d,o[j>>1]=k;f=d}fb=c+16|0;return f&65535}function qAa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;f=wy(a);a:{b:{c:{d:{while(1){p[114610]=0;a=J(258,b|0,8)|0;g=p[114610];p[114610]=0;if((g|0)==1){break b}if(a){p[114610]=0;N(974,e+8|0,b|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}p[114610]=0;K(975,f|0,e+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}Ce(e+8|0);a=uy(f);if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=(d|0)){continue}}break}fb=e+32|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;Ce(e+8|0);break a}a=I()|0;H()|0}sl(f);L(a|0);E()}function Ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;Eg(d,2,a+6|0);zc(d+16|0,d);p[114610]=0;J(369,b+492|0,d+16|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){pb(d+16|0);f=b+236|0;g=c+1|0;c=0;e=0;while(1){h=q[(a+c|0)+38|0];i=Yc(f,c),j=g+h|0,o[i>>1]=j;e=e+1|0;c=e&255;if(128>c>>>0){continue}break}c=a+226|0;p[b>>2]=(q[c|0]|q[c+1|0]<<8)<<5;Uw(a+180|0,b+48|0,0);Uw(a+228|0,b+88|0,2);Uw(a+276|0,b+68|0,1);a=a+324|0;if(!(q[a|0]|q[a+1|0]<<8)){Jb(b+236|0,0,256)}fb=d+32|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function o5(){var a=0,b=0,c=0,d=0;a=fb-48|0;fb=a;p[114610]=0;b=J(2308,1,a+32|0)|0;c=p[114610];p[114610]=0;a:{b:{c:{if((c|0)==1){break c}if(b){p[114610]=0;a=p[114610];p[114610]=0;if((a|0)==1){break c}a=p[114584];p[114610]=0;K(2310,a|0,55649);a=p[114610];p[114610]=0;if((a|0)!=1){break b}break c}b=Uq(a+16|0,a+32|0);c=Uq(a+8|0,a+32|4);p[114610]=0;b=TB(2312,b,c);c=ib;d=p[114610];p[114610]=0;if((d|0)!=1){break a}}a=O(0)|0;H()|0;rb(a)}E()}p[a+24>>2]=b;p[a+28>>2]=c;b=Zj(a+40|0,a+24|0);c=p[b+4>>2];b=p[b>>2];fb=a+48|0;ib=c;return b}function wna(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=p[a+24620>>2];c=rc(ONa(NNa(c,c>>31,100,0),ib,1e3,0),ib);a:{if(!c){break a}e=c>>>0<1048576?c:1048576;p[a+1074380>>2]=e;b=r[a+480212>>1];if(!b){break a}h=b>>>0>1?b:1;f=a+1074376|0;b=0;while(1){a=v(r[((b<<1)+f|0)+90>>1],896)+f|0;d=a+1280|0;p[d>>2]=0;p[d+4>>2]=0;p[a+708>>2]=e;d=p[a+632>>2]<<12;p[a+648>>2]=d;g=p[a+628>>2]<<12;p[a+644>>2]=g;p[a+696>>2]=p[a+696>>2]|65536;p[a+636>>2]=(0-g|0)/(e|0);p[a+640>>2]=(0-d|0)/(e|0);b=b+1|0;if((h|0)!=(b|0)){continue}break}}return(c|0)!=0}function Zua(a,b,c){var d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;p[e+24>>2]=b;b=p[a>>2];f=e,g=Ub(a),p[f>>2]=g;b=b+(Ts(e+24|0,e)<<2)|0;a:{b:{if(s[a+4>>2]<s[qb(a)>>2]){d=p[a+4>>2];if((d|0)!=(b|0)){break b}LP(a,c);break a}d=qb(a);d=An(e,se(a,Bb(a)+1|0),b-p[a>>2]>>2,d);p[114610]=0;K(1160,d|0,c|0);c=p[114610];p[114610]=0;c:{if((c|0)==1){break c}p[114610]=0;b=P(1161,a|0,d|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}Fh(d);break a}a=I()|0;H()|0;Fh(d);L(a|0);E()}Vua(a,b,d,b+4|0);o[b>>1]=r[c>>1];n[b+2|0]=q[c+2|0]}Ze(b);fb=e+32|0}function i2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=fb-32|0;fb=a;o[a+28>>1]=q[62144]|q[62145]<<8;p[a+24>>2]=q[62140]|q[62141]<<8|(q[62142]<<16|q[62143]<<24);Cj(a+24|1,62132,1,p[c+4>>2]);g=p[c+4>>2];f=a+ -16|0;fb=f;h=de();p[a>>2]=e;g=Te(f,(g>>>9&1)+13|0,h,a+24|0,a)+f|0;h=Yf(f,g,c);e=f+ -32|0;fb=e;qc(a+8|0,c);p[114610]=0;ca(2465,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=p[114610];p[114610]=0;if((f|0)!=1){Gb(a+8|0);b=Kl(b,e,p[a+20>>2],p[a+16>>2],c,d);fb=a+32|0;return b|0}b=I()|0;H()|0;Gb(a+8|0);L(b|0);E()}function FK(a,b,c){var d=0,e=0;a:{if(p[a+480180>>2]==4){d=q[b+834|0];if(c){n[b+834|0]=d&240|c&15;break a}c=d&15;break a}if(p[a+480180>>2]!=1048576){break a}if(c){n[b+833|0]=c;break a}c=q[b+833|0]}b:{if(!(n[b+872|0]&1)|!(c&255)){break b}d=p[b+700>>2];if(!d){break b}c:{if(!(q[a+480208|0]&16)){break c}d=p[b+700>>2];if(p[a+480180>>2]==4){break c}e=b;a=vK(a,c&15);b=NNa(a,a>>31,d,d>>31)+32768|0;a=ib;a=rc(ONa(b,b>>>0<32768?a+1|0:a,65536,0),ib);p[e+700>>2]=a-((a|0)==(d|0));return}a=(c&255)+d|0;p[b+700>>2]=(a|0)<65535?a:65535}}function ola(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;p[f+8>>2]=e;p[f+12>>2]=c;g=p[Cb(f+12|0,f+8|0)>>2];a:{b:{if(!g){c=b;break b}e=g;c=b;while(1){h=q[d|0];n[c|0]=h;if(!h){break a}d=d+1|0;c=c+1|0;e=e+ -1|0;if(e){continue}break}}e=0}c:{d:{e:{switch(a+ -1|0){case 0:case 1:d=p[f+12>>2];n[f+7|0]=0;Lr(c,((c+d|0)-g|0)+e|0,f+7|0);break d;case 2:case 3:break e;default:break c}}d=p[f+12>>2];n[f+6|0]=32;Lr(c,((c+d|0)-g|0)+e|0,f+6|0)}f:{switch(a+ -1|0){case 0:case 3:break f;default:break c}}n[(p[f+12>>2]+b|0)+ -1|0]=0}fb=f+16|0}function bIa(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;Eg(e,1,a);zc(e+16|0,e);p[114610]=0;J(369,b+492|0,e+16|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){pb(e+16|0);d=a+378|0;if(q[d|0]|q[d+1|0]<<8){f=b+236|0;d=0;while(1){g=q[(a+d|0)+32|0];h=Yc(f,d),i=c+g|0,o[h>>1]=i;d=d+1|0;if(d>>>0<120){continue}break}}c=a+376|0;p[b>>2]=q[c|0]|q[c+1|0]<<8;rz(a,b+48|0,0);rz(a,b+68|0,1);rz(a,b+88|0,2);a=q[b+100|0];if(a&1){n[b+100|0]=a|16}if(!(p[b>>2]|n[b+60|0]&1)){p[b>>2]=32767}fb=e+32|0;return}a=I()|0;H()|0;pb(e+16|0);L(a|0);E()}function Fv(a,b){var c=0,d=0,g=0,h=0,k=0,l=0;d=fb-16|0;fb=d;g=(i(a),e(2));c=g&2147483647;a:{if(c>>>0<=1305022426){k=+a;h=k*.6366197723675814+6755399441055744+ -6755399441055744;u[b>>3]=k+h*-1.5707963109016418+h*-1.5893254773528196e-8;if(x(h)<2147483648){c=~~h;break a}c=-2147483648;break a}if(c>>>0>=2139095040){u[b>>3]=w(a-a);c=0;break a}l=c;c=(c>>>23|0)+ -150|0;u[d+8>>3]=(f(2,l-(c<<23)|0),j());c=UE(d+8|0,d,c,1,0);if((g|0)<=-1){u[b>>3]=-u[d>>3];c=0-c|0;break a}g=p[d+4>>2];p[b>>2]=p[d>>2];p[b+4>>2]=g}fb=d+16|0;return c}function sj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,o=0,r=0;e=fb-16|0;fb=e;p[b>>2]=0;p[b+4>>2]=0;n[e+15|0]=0;i=Mg(a,e+15|0);c=q[e+15|0];p[b>>2]=(c&252)>>>2;p[b+4>>2]=0;f=c&3;if(f){k=-1<<f^-1;while(1){n[e+15|0]=0;l=Mg(a,e+15|0);f=b;g=p[b>>2];m=p[b+4>>2];c=q[e+15|0];d=h;h=j+1|0;if(h>>>0<1){d=d+1|0}j=h;h=d;o=f;r=g;g=c;c=j;c=(c<<3)+ -2|0;d=c;c=c&31;if(32<=(d&63)>>>0){d=g<<c;c=0}else{d=(1<<c)-1&g>>>32-c;c=g<<c}p[o>>2]=r|c;p[f+4>>2]=d|m;i=i&l;if((j|0)!=(k|0)|h){continue}break}}fb=e+16|0;return i|0}function by(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(cd(a)){break a}o[p[a>>2]>>1]=0;Ke(p[a>>2]+2|0,b);e=c,f=Ub(a),p[e>>2]=f;e=c,f=Yo(c,1),p[e+8>>2]=f;e=c,f=Vb(a),p[e>>2]=f;if(!Ab(c+8|0,c)){break a}while(1){d=p[c+8>>2];e=c,f=DM(c+8|0,1),p[e>>2]=f;d=r[Bi(d,p[c>>2])>>1];o[p[c+8>>2]>>1]=d;Ke(p[c+8>>2]+2|0,b);gT(c+8|0);e=c,f=Vb(a),p[e>>2]=f;if(Ab(c+8|0,c)){continue}break}}Ke(a+14|0,Bb(a)+ -1&255);Ke(a+13|0,q[a+14|0]);Ke(a+16|0,Bb(a)+ -1&255);Ke(a+15|0,q[a+16|0]);if(q[a+17|0]!=255){Ke(a+17|0,Bb(a)+ -1&255)}fb=c+16|0}function n9(a){var b=0,c=0,d=0,e=0;b=fb-160|0;fb=b;a=vm(b+16|0,a,8);c=p[p[a>>2]+ -12>>2];p[114610]=0;d=Y(122)|0;e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}p[114610]=0;N(123,b+8|0,c+(b+16|0)|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}Gb(b+8|0);p[114610]=0;c=J(178,a|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[p[c>>2]+ -12>>2];p[114610]=0;c=M(174,c+d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b+4>>2];e=p[b>>2];ff(a);fb=b+160|0;ib=c?0:d;return c?0:e}b=I()|0;H()|0;ff(a);L(b|0);E()}function f2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=fb-32|0;fb=a;o[a+28>>1]=q[62144]|q[62145]<<8;p[a+24>>2]=q[62140]|q[62141]<<8|(q[62142]<<16|q[62143]<<24);Cj(a+24|1,62132,0,p[c+4>>2]);g=p[c+4>>2];f=a+ -16|0;fb=f;h=de();p[a>>2]=e;g=Te(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=Yf(f,g,c);e=f+ -32|0;fb=e;qc(a+8|0,c);p[114610]=0;ca(2465,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=p[114610];p[114610]=0;if((f|0)!=1){Gb(a+8|0);b=Kl(b,e,p[a+20>>2],p[a+16>>2],c,d);fb=a+32|0;return b|0}b=I()|0;H()|0;Gb(a+8|0);L(b|0);E()}function W1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=fb-32|0;fb=a;o[a+28>>1]=q[62144]|q[62145]<<8;p[a+24>>2]=q[62140]|q[62141]<<8|(q[62142]<<16|q[62143]<<24);Cj(a+24|1,62132,0,p[c+4>>2]);g=p[c+4>>2];f=a+ -16|0;fb=f;h=de();p[a>>2]=e;g=Te(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=Yf(f,g,c);e=f+ -96|0;fb=e;qc(a+8|0,c);p[114610]=0;ca(2474,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=p[114610];p[114610]=0;if((f|0)!=1){Gb(a+8|0);b=dm(b,e,p[a+20>>2],p[a+16>>2],c,d);fb=a+32|0;return b|0}b=I()|0;H()|0;Gb(a+8|0);L(b|0);E()}function ema(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=a+206|0;p[b>>2]=q[e|0]|q[e+1|0]<<8;aJ(a,b+48|0,q[a+192|0],q[a+200|0],q[a+194|0],q[a+195|0],q[a+196|0],0);aJ(a,b+68|0,q[a+193|0],q[a+201|0],q[a+197|0],q[a+198|0],q[a+199|0],1);e=b+236|0;while(1){f=q[a+c|0];g=Yc(e,c+12|0),h=f,o[g>>1]=h;c=c+1|0;if((c|0)!=96){continue}break}if(q[a+208|0]){n[b+31|0]=q[a+209|0]+1;$I(b+31|0,1,16);c=a+210|0;o[d+14>>1]=q[c|0]|q[c+1|0]<<8;o[d+12>>1]=127;g=b,h=q[rf(d+14|0,d+12|0)|0]+1|0,n[g+30|0]=h}n[b+33|0]=q[a+212|0];fb=d+16|0}function wda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;p[114610]=0;S(2015,a|0);g=p[114610];p[114610]=0;a:{b:{if((g|0)!=1){c:{g=p[a+24>>2];p[114610]=0;fa(2071,f|0,g|0,b|0,c|0,d|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break c}b=Pd(Ib(f));pb(f);break b}}b=O(0)|0;H()|0;T(b|0)|0;b=0;p[114610]=0;Q(1989,36619,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=f+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function vda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;p[114610]=0;S(2015,a|0);g=p[114610];p[114610]=0;a:{b:{if((g|0)!=1){c:{g=p[a+24>>2];p[114610]=0;fa(2072,f|0,g|0,b|0,c|0,d|0,e|0);b=p[114610];p[114610]=0;if((b|0)==1){break c}b=Pd(Ib(f));pb(f);break b}}b=O(0)|0;H()|0;T(b|0)|0;b=0;p[114610]=0;Q(1989,36669,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}fb=f+16|0;return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function oAa(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;n[b+15|0]=128;d=pt(a,127,b+15|0);p[114610]=0;n[b+14|0]=64;e=P(886,a+12|0,127,b+14|0)|0;c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;n[b+13|0]=0;P(976,a+24|0,127,b+13|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break b}p[a+36>>2]=-1;p[a+40>>2]=108855296;n[a+44|0]=0;n[a+45|0]=0;n[a+46|0]=0;n[a+47|0]=0;n[a+48|0]=0;n[a+49|0]=0;n[a+50|0]=0;n[a+51|0]=0;n[a+52|0]=0;n[a+53|0]=0;fb=b+16|0;return a|0}a=I()|0;H()|0;break a}a=I()|0;H()|0;Xd(e)}Xd(d);L(a|0);E()}function nCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-528|0;fb=d;c=-1;a:{if(!af(a,1468)){break a}dk(a,1464);XO(a,d+524|0);if(!Sd(d+524|0,15977)){c=0;if(!Sd(d+524|0,15982)){break a}}dk(a,20);b=1;while(1){c=-1;if(!UO(a,d)){break a}e=Ky(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}SBa(a,d+520|0);e=Zc(d+520|0);c=0;if(q[d+520|0]>128){break a}mCa(a,d);a=d+512|0;b=d;c=q[e|0];b:{while(1){if(q[b|0]>c>>>0){break b}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}fb=d+528|0;return c|0}function ST(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;uF(b);a:{if(!(q[a|0]|q[a+1|0]<<8)){c=a+2|0;if(!(q[c|0]|q[c+1|0]<<8)){break a}}p[b+20>>2]=((q[a|0]|q[a+1|0]<<8)>>>9|0)+80;d=b,e=Pb((q[a|0]|q[a+1|0]<<8)>>>5&15,1,12)+ -1|0,p[d+16>>2]=e;d=b,e=Pb((q[a|0]|q[a+1|0]<<8)&31,1,31),p[d+12>>2]=e;c=a+2|0;d=b,e=Pb((q[c|0]|q[c+1|0]<<8)>>>11|0,0,23),p[d+8>>2]=e;d=b,e=Pb((q[c|0]|q[c+1|0]<<8)>>>5&63,0,59),p[d+4>>2]=e;d=b,e=Pb((q[c|0]|q[c+1|0]<<8)<<1&62,0,59),p[d>>2]=e}a=a+4|0;p[b+44>>2]=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24)}function Q1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=fb-208|0;fb=a;o[a+204>>1]=q[62150]|q[62151]<<8;p[a+200>>2]=q[62146]|q[62147]<<8|(q[62148]<<16|q[62149]<<24);f=de();p[a>>2]=e;h=Te(a+176|0,20,f,a+200|0,a);e=h+(a+176|0)|0;f=Yf(a+176|0,e,c);qc(a+8|0,c);p[114610]=0;g=M(2449,a+8|0)|0;i=p[114610];p[114610]=0;if((i|0)!=1){Gb(a+8|0);uD(g,a+176|0,e,a+16|0);g=b;b=(a+16|0)+(h<<2)|0;b=dm(g,a+16|0,(e|0)==(f|0)?b:((f-a<<2)+a|0)+ -688|0,b,c,d);fb=a+208|0;return b|0}b=I()|0;H()|0;Gb(a+8|0);L(b|0);E()}function KHa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=fb-32|0;fb=f;p[f+28>>2]=c;h=Hb(b,c<<2);a:{if(!h){break a}vc(f+28|0,65535);ig(a,r[f+28>>1]);i=f,j=Ub(a),p[i+16>>2]=j;i=f,j=Vb(a),p[i+8>>2]=j;if(!Ab(f+16|0,f+8|0)){break a}while(1){a=p[f+16>>2];vp(b,f+24|0);c=f+24|0;c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);o[a>>1]=c;c=c&65535;g=65535;b:{c:{if((c|0)==(d|0)){break c}if((c|0)!=(e|0)){break b}g=65534}o[a>>1]=g}te(f+16|0);if(Ab(f+16|0,f+8|0)){continue}break}}fb=f+32|0;return h|0}function nY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Xf(a,p[b+8>>2],e)){Cu(b,c,d);return}a:{if(Xf(a,p[b>>2],e)){if(!(p[b+20>>2]!=(c|0)?p[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}p[b+32>>2]=1;return}p[b+32>>2]=d;b:{if(p[b+44>>2]==4){break b}o[b+52>>1]=0;a=p[a+8>>2];m[p[p[a>>2]+20>>2]](a,b,c,c,1,e);if(q[b+53|0]){p[b+44>>2]=3;if(!q[b+52|0]){break b}break a}p[b+44>>2]=4}p[b+20>>2]=c;p[b+40>>2]=p[b+40>>2]+1;if(p[b+36>>2]!=1|p[b+24>>2]!=2){break a}n[b+54|0]=1;return}a=p[a+8>>2];m[p[p[a>>2]+24>>2]](a,b,c,d,e)}}function om(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+ -64|0;b=c&31;if(32<=(c&63)>>>0){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;i=d;j=64-f|0;g=j&31;if(32<=(j&63)>>>0){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|h<<g;j=i<<g}i=b;g=f;b=g&31;if(32<=(g&63)>>>0){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if(32<=(f&63)>>>0){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}p[a>>2]=b;p[a+4>>2]=c;p[a+8>>2]=d;p[a+12>>2]=e}function t9(a){var b=0,c=0,d=0,e=0;b=fb-160|0;fb=b;a=vm(b+16|0,a,8);d=p[p[a>>2]+ -12>>2];p[114610]=0;c=Y(122)|0;e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}p[114610]=0;N(123,b+8|0,d+(b+16|0)|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}Gb(b+8|0);p[114610]=0;d=J(177,a|0,b+6|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[p[d>>2]+ -12>>2];p[114610]=0;d=M(174,c+d|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}c=r[b+6>>1];ff(a);fb=b+160|0;return(d?0:c)&65535}b=I()|0;H()|0;ff(a);L(b|0);E()}function mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;p[114610]=0;S(2015,a|0);d=p[114610];p[114610]=0;a:{if((d|0)==1){break a}p[114610]=0;S(2026,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[a+24>>2];p[114610]=0;b=J(2027,d|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[c>>2]=b;return 1}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35166,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)!=1){V();return 0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function bx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;a:{if((c|0)<2){break a}j=(c+ -2|0)/2|0;f=d-a|0;if((j|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=vo(b,r[e>>1],r[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(vo(b,r[e>>1],r[d>>1])){break a}o[h+14>>1]=r[d>>1];while(1){b:{f=e;o[d>>1]=r[e>>1];if((j|0)<(g|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){i=vo(b,r[e>>1],r[e+2>>1]);e=i?e+2|0:e;g=i?d:g}d=f;if(!vo(b,r[e>>1],r[h+14>>1])){continue}}break}o[f>>1]=r[h+14>>1]}fb=h+16|0}function ex(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;vb(e+8|0,a+1074308|0,21);a:{if(tb(e+8|0)){c=c&255;b:{switch((b&3)-1|0){default:d=n[c+21552|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=sJ(Mm(a))+ -64|0;break a}d=n[(c>>>1&31)+20656|0];if(p[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=n[a+21424|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=n[a+21488|0]}a=d;fb=e+16|0;return a}function Nra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;f=Lb(a);a:{b:{c:{if(nc(b)){a=0;while(1){d:{if(!a){break d}p[114610]=0;J(1251,f|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break d}a=I()|0;H()|0;break a}d=id(b,a);p[114610]=0;K(1252,e|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break c}p[114610]=0;J(1251,f|0,e|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}pb(e);a=a+1|0;if(a>>>0<nc(b)>>>0){continue}break}}fb=e+16|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(e)}pb(f);L(a|0);E()}function Lqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;p[e+8>>2]=c>>>3;p[e+4>>2]=p[a>>2];d=p[Cb(e+8|0,e+4|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){g=q[b+4|0]|q[b+5|0]<<8|(q[b+6|0]<<16|q[b+7|0]<<24);p[e+8>>2]=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);p[e+12>>2]=g;wf(e+8|0,-1,1);f=u[e+8>>3]*32768;u[e+8>>3]=f;g=a;f=Id(f);a:{if(x(f)<2147483648){h=~~f;break a}h=-2147483648}i=g,j=Mc(h),o[i>>1]=j;a=a+2|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<3}function HE(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;h=-1;f=d&2147483647;i=f;g=c;a:{if(!c&(f|0)==2147418112?a|b:(f|0)==2147418112&c>>>0>0|f>>>0>2147418112){break a}f=e&2147483647;j=f;if((f|0)==2147418112?0:f>>>0>2147418112){break a}if(!(a|g|(i|j|b))){return 0}g=d&e;if((g|0)>0?1:(g|0)>=0){if(!c&(d|0)==(e|0)?!b&a>>>0<0|b>>>0<0:(d|0)<(e|0)?1:(d|0)<=(e|0)?c>>>0<0:0){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?!b&a>>>0>0|b>>>0>0:(d|0)>(e|0)?1:(d|0)>=(e|0)?c>>>0>0:0){break a}h=(a|c)!=0|(d^e|b)!=0}return h}function zr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;e=a;c=p[b>>2];f=p[b+8>>2];c=c&24576?c:p[b+4>>2]?(f|0)!=-1?c&-12289|8192:c:c;b=143;a:{b:{if(c&1){break b}if(!(c&2)){break a}b=144}ew(e,b)}c:{if(c&4096){break c}if(c&8192){g=d,h=Ze(4),p[g+24>>2]=h;vG(a,d+24|0);break c}if(!(c&16384)){break c}g=d,h=Ze(256),p[g+16>>2]=h;vG(a,d+16|0)}b=a;d:{if(c&16){e=145}else{if(!(c&32)){break d}e=146}ew(b,e)}if((f|0)!=-1){g=d,h=Ze(f),p[g+8>>2]=h;a=p[p[a>>2]+ -12>>2]+a|0;a;p[a+8>>2]=p[d+8>>2]}fb=d+32|0}function Oqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=w(0),h=0,i=0,j=0;e=fb-16|0;fb=e;p[e+8>>2]=c>>>2;p[e+4>>2]=p[a>>2];d=p[Cb(e+8|0,e+4|0)>>2];b=ub(b);if(d){c=p[a+20>>2];a=d;while(1){f=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);p[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);Td(e+12|0,w(-1));g=w(t[e+12>>2]*w(32768));t[e+12>>2]=g;f=c;g=$d(g);a:{if(w(x(g))<w(2147483648)){h=~~g;break a}h=-2147483648}i=f,j=Mc(h),o[i>>1]=j;c=c+2|0;b=b+4|0;a=a+ -1|0;if(a){continue}break}}fb=e+16|0;return d<<2}function tM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=p[a+8>>2];c=f+ -1|0;d=p[a+12>>2];g=p[a>>2]+v(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){n[b+g|0]=q[p[a+4>>2]+(v(c,d)+b|0)|0];b=b+1|0;d=p[a+12>>2];if((b|0)<(d|0)){continue}break}f=p[a+8>>2]}b=v(d,h);i=f+ -1|0;a:{if(!((i|0)!=(c|0)|(e|0)<1)){if(!q[a+16|0]){e=1;c=0;break a}e=-1;c=c-((c|0)!=0&q[a+17|0]!=0)|0;break a}if(!((e|0)>-1|c)){c=q[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function e3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=p[114584];p[114584]=0;a=zD(a,e+12|0,d,de());d=ib;f=p[114584];d:{if(f){if(p[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}p[114584]=g;if(p[e+12>>2]==(b|0)){break c}}}p[c>>2]=4;b=0;break a}if(((d|0)<-1?1:(d|0)<=-1?a>>>0<2147483648:0)|((d|0)>0?1:(d|0)>=0?a>>>0>2147483647:0)){break b}b=a;break a}p[c>>2]=4;b=2147483647;if((d|0)>0?1:(d|0)>=0?a>>>0>=1:0){break a}b=-2147483648}fb=e+16|0;return b|0}function $1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=fb-96|0;fb=a;o[a+92>>1]=q[62150]|q[62151]<<8;p[a+88>>2]=q[62146]|q[62147]<<8|(q[62148]<<16|q[62149]<<24);f=de();p[a>>2]=e;h=Te(a- -64|0,20,f,a+88|0,a);e=h+(a- -64|0)|0;f=Yf(a- -64|0,e,c);qc(a+8|0,c);p[114610]=0;g=M(21,a+8|0)|0;i=p[114610];p[114610]=0;if((i|0)!=1){Gb(a+8|0);vD(g,a- -64|0,e,a+16|0);g=b;b=(a+16|0)+h|0;b=Kl(g,a+16|0,(e|0)==(f|0)?b:((f-a|0)+a|0)+ -48|0,b,c,d);fb=a+96|0;return b|0}b=I()|0;H()|0;Gb(a+8|0);L(b|0);E()}function C3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-32|0;fb=f;a:{b:{if(JD(c)){while(1){if(a>>>d&1){j=(d<<2)+c|0,k=KD(d,b),p[j>>2]=k}d=d+1|0;if((d|0)!=6){continue}break}break b}while(1){i=(f+8|0)+(d<<2)|0;e=1<<d&a;g=p[(d<<2)+c>>2];c:{if(!(e|!c)){break c}g=KD(d,e?b:58056)}e=g;p[i>>2]=e;h=((e|0)!=0)+h|0;d=d+1|0;if((d|0)!=6){continue}break}d=57888;d:{switch(h|0){case 0:break a;case 1:break d;default:break b}}if(p[f+8>>2]!=57860){break b}d=57912;break a}d=c}fb=f+32|0;return d|0}function BW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;f=Xc(a);a:{b:{c:{if(nc(b)){a=0;while(1){d:{if(!a){break d}p[114610]=0;J(192,f|0,c|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){break d}a=I()|0;H()|0;break a}d=id(b,a);p[114610]=0;K(252,e|0,d|0);d=p[114610];p[114610]=0;if((d|0)==1){break c}p[114610]=0;J(192,f|0,e|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}pb(e);a=a+1|0;if(a>>>0<nc(b)>>>0){continue}break}}fb=e+16|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(e)}pb(f);L(a|0);E()}function kG(a){var b=0,c=0,d=0,e=0;b=fb-160|0;fb=b;a=vm(b+16|0,a,8);d=p[p[a>>2]+ -12>>2];p[114610]=0;c=Y(122)|0;e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}p[114610]=0;N(123,b+8|0,d+(b+16|0)|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}Gb(b+8|0);p[114610]=0;d=J(173,a|0,b+4|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[p[d>>2]+ -12>>2];p[114610]=0;d=M(174,c+d|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2];ff(a);fb=b+160|0;return d?0:c}b=I()|0;H()|0;ff(a);L(b|0);E()}function f9(a){var b=0,c=0,d=0,e=0,f=0;b=fb-160|0;fb=b;a=vm(b+16|0,a,8);c=p[p[a>>2]+ -12>>2];p[114610]=0;d=Y(122)|0;e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}p[114610]=0;N(123,b+8|0,c+(b+16|0)|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}Gb(b+8|0);p[114610]=0;c=J(179,a|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[p[c>>2]+ -12>>2];p[114610]=0;c=M(174,c+d|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}f=u[b>>3];ff(a);fb=b+160|0;return c?0:f}b=I()|0;H()|0;ff(a);L(b|0);E()}function Xo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=r[a+34>>1];if(!b){b=a;if(d&512){xM(a);d=r[a+34>>1]}o[b+34>>1]=d&65023;return}p[a>>2]=4;o[a+34>>1]=d&64958|512;Wo(a);b=q[c+8|0]|q[c+9|0]<<8|(q[c+10|0]<<16|q[c+11|0]<<24);n[a+76|0]=b;n[a+77|0]=b>>>8;n[a+78|0]=b>>>16;n[a+79|0]=b>>>24;b=q[c+4|0]|q[c+5|0]<<8|(q[c+6|0]<<16|q[c+7|0]<<24);c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);n[a+68|0]=c;n[a+69|0]=c>>>8;n[a+70|0]=c>>>16;n[a+71|0]=c>>>24;n[a+72|0]=b;n[a+73|0]=b>>>8;n[a+74|0]=b>>>16;n[a+75|0]=b>>>24}function Oua(a,b){var c=0,d=0,e=0;vc(a,65536);vc(a+4|0,64);vc(a+8|0,256);Lg(a+28|0,16384);Ke(a+30|0,128);Ke(a+31|0,17);if(q[a+16|0]>=4){n[a+16|0]=0}if(q[a+17|0]>=5){n[a+17|0]=0}if(q[a+18|0]>=3){n[a+18|0]=0}Ke(a+19|0,64);Ke(a+20|0,100);Tua(a+26|0);Ke(a+23|0,64);Ke(a+24|0,64);by(a+48|0,64);by(a+68|0,64);by(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){a:{if(q[Yb(c,b)|0]){if(q[Yb(c,b)|0]<121){break a}}d=Yb(c,b),e=b+1|0,n[d|0]=e}b=b+1|0;if(b>>>0<128){continue}break}if(!Kp(q[a+14|0])){n[a+14|0]=5}}function Rqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>4;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b|0]);ub(q[b+1|0]);ub(q[b+2|0]);ub(q[b+3|0]);ub(q[b+4|0]);ub(q[b+5|0]);f=a,g=ub(q[b+6|0])|ub(q[b+7|0])<<8,o[f>>1]=g;ub(q[b+8|0]);ub(q[b+9|0]);ub(q[b+10|0]);ub(q[b+11|0]);ub(q[b+12|0]);ub(q[b+13|0]);f=a,g=ub(q[b+14|0])|ub(q[b+15|0])<<8,o[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<4}function Qqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>4;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b+7|0]);ub(q[b+6|0]);ub(q[b+5|0]);ub(q[b+4|0]);ub(q[b+3|0]);ub(q[b+2|0]);f=a,g=ub(q[b+1|0])|ub(q[b|0])<<8,o[f>>1]=g;ub(q[b+15|0]);ub(q[b+14|0]);ub(q[b+13|0]);ub(q[b+12|0]);ub(q[b+11|0]);ub(q[b+10|0]);f=a,g=ub(q[b+9|0])|ub(q[b+8|0])<<8,o[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<4}function DK(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{b:{c:{f=!d;d=c>>31;d=d+c^d;if(f|(d|0)<224){break c}vb(e+8|0,a+1074308|0,3);if(tb(e+8|0)){break c}if(!(n[(v(b,896)+a|0)+1075856|0]&1)){break a}c=v((c>>31)+((c|0)>0)|0,d&15);c=(d|0)>239?c<<2:c;break b}if(n[(v(b,896)+a|0)+1075856|0]&1){vb(e+8|0,a+1074308|0,3);if(!tb(e+8|0)){break a}}c=c<<2}if(!c){break a}d=yx(a,b);if(!d){break a}f=d;a=p[(v(b,896)+a|0)+1075640>>2];g=13;d:{if(!a){break d}g=q[a+33|0]}m[p[p[d>>2]+80>>2]](f,c,g<<24>>24,b)}fb=e+16|0}function ef(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){d=b;e=f+ -64|0;b=e&31;if(32<=(e&63)>>>0){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;i=f;d=f&31;if(32<=(f&63)>>>0){h=g<<d;j=0}else{h=(1<<d)-1&g>>>32-d|e<<d;j=g<<d}d=c;g=b;f=64-f|0;e=f&31;if(32<=(f&63)>>>0){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=j|d;e=f|h;f=b;b=i&31;if(32<=(i&63)>>>0){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}p[a>>2]=b;p[a+4>>2]=c;p[a+8>>2]=d;p[a+12>>2]=e}function KK(a,b){var c=0,d=0,e=0;a:{b:{if(!q[b+866|0]|p[a+480180>>2]!=1){break b}d=p[b+104>>2];if(!d){break b}if(!ue(d)|(r[d+34>>1]&3)!=2){break b}c=q[b+867|0]+q[(q[b+866|0]&15)+21344|0]|0;n[b+867|0]=c;if(c<<24>>24>-1){break b}n[b+867|0]=0;c=p[b+784>>2]+1|0;p[b+784>>2]=c;p[b+784>>2]=c>>>0<p[d+8>>2]-p[d+4>>2]>>>0?c:0;c=p[d+20>>2];p[114610]=0;c=M(466,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}b=ub(c)+(p[b+784>>2]+p[d+4>>2]|0)|0;n[b|0]=q[b|0]^-1;$x(d,a,0)}return}a=O(0)|0;H()|0;rb(a);E()}function Jaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-32|0;fb=b;a:{b:{if(Xh(a)){mo(b+24|0);break b}xm(b+8|0,a);p[114610]=0;K(2175,b+24|0,b+8|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}gf(b+8|0)}c=a+36|0;c:{if(Xh(a)){break c}c=p[b+24>>2]}a=p[a+8>>2];d:{if((a|0)==-1){e=b,f=Ub(c),p[e+8>>2]=f;e=b,f=Vb(c),p[e>>2]=f;if(!Ab(b+8|0,b)){break d}while(1){d=u[p[b+8>>2]>>3]+d;ok(b+8|0);if(Ab(b+8|0,b)){continue}break}break d}d=u[Gc(c,a)>>3]}Nj(b+24|0);fb=b+32|0;return+d}a=I()|0;H()|0;gf(b+8|0);L(a|0);E()}function hLa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=fb-32|0;fb=f;p[f+28>>2]=c;g=Hb(b,c<<1);a:{if(!g){break a}vc(f+28|0,65535);ig(a,r[f+28>>1]);h=f,i=Ub(a),p[h+16>>2]=i;h=f,i=Vb(a),p[h+8>>2]=i;if(!Ab(f+16|0,f+8|0)){break a}while(1){a=p[f+16>>2];aA(b,f+24|0);c=f+24|0;c=q[c|0]|q[c+1|0]<<8;c=(c<<24|c<<8&16711680)>>>16|0;o[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}o[a>>1]=c}te(f+16|0);if(Ab(f+16|0,f+8|0)){continue}break}}fb=f+32|0;return g|0}function Kpa(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;p[c+8>>2]=b;d=p[a+8>>2];a:{if((p[a+480180>>2]==16384?1e4:32e4)>>>0<=b>>>0){b=p[a+480208>>2];vb(c,a+1074308|0,92);if((tb(c)|0)==((b&4096)>>>12|0)){break a}p[c>>2]=v(p[d+24>>2],1e4);g=a+1074420|0,h=p[Cb(c+8|0,c)>>2],p[g>>2]=h;break a}if(q[a+480209|0]&16){break a}e=a+1074420|0;b=(b>>>0)/1e4|0;f=v(b&15,1e4);p[e>>2]=p[e>>2]+((b&240)==16?f:0-f|0);b=p[d+20>>2];d=p[d+24>>2];vb(c,a+1074308|0,8);En(e,v(b,1e4),tb(c)?255e4:v(d,1e4))}fb=c+16|0}function wqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,g=w(0),h=0,i=w(0),k=0,l=0,m=0;e=fb-16|0;fb=e;p[e+8>>2]=c>>>2;p[e+4>>2]=p[a>>2];c=p[Cb(e+8|0,e+4|0)>>2];i=t[d>>2];b=ub(b);if(c){a=p[a+20>>2];d=c;while(1){t[e+12>>2]=i*(f(2,q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24)),j());Td(e+12|0,w(-1));g=w(t[e+12>>2]*w(32768));t[e+12>>2]=g;k=a;g=$d(g);a:{if(w(x(g))<w(2147483648)){h=~~g;break a}h=-2147483648}l=k,m=Mc(h),o[l>>1]=m;a=a+2|0;b=b+4|0;d=d+ -1|0;if(d){continue}break}}fb=e+16|0;return c<<2}function wS(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Me(b);Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{if((f|0)==1){break a}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}p[114610]=0;Q(414,d+8|0,3,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}xb(b,d+24|0);pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;uc(d+40|0);L(a|0);E()}function uM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=b?33:32;e=p[a+12>>2];g=p[a>>2]+v(e,62)|0;d=b?1:-1;j=v(e,d)<<1;f=p[a+8>>2]+ -1|0;c=f;while(1){if((e|0)>=1){k=v(c,e);l=p[a+4>>2];b=0;while(1){o[(b<<1)+g>>1]=r[(b+k<<1)+l>>1];b=b+1|0;if((e|0)!=(b|0)){continue}break}}a:{if(!((c|0)!=(f|0)|(d|0)<=0)){if(!q[a+16|0]){d=1;c=0;break a}d=-1;c=f-((f|0)!=0&q[a+17|0]!=0)|0;break a}if(!((d|0)>-1|c)){b=q[a+16|0];d=b?1:-1;c=b?0:f;break a}c=d+c|0}g=g+j|0;h=h+1|0;if((i|0)!=(h|0)){continue}break}}function e8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0;h=fb-16|0;fb=h;if(e){k=c+16|0;while(1){i=0;if(d){while(1){g=Id(u[Tg(b,i,j)>>3]*134217728);f=nf(c,i);l=f;f=cj(g)+(p[f>>2]>>1)|0;m=f;f=gr(k)+f&-4096;p[l>>2]=m-f;u[h+8>>3]=+(f|0)*7.450580596923828e-9;wf(h+8|0,-1,1);g=u[h+8>>3]*32768;u[h+8>>3]=g;g=Id(g);a:{if(x(g)<2147483648){f=~~g;break a}f=-2147483648}f=Mc(f);n=sm(a,i,j),q=f,o[n>>1]=q;i=i+1|0;if((i|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}fb=h+16|0}function _2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=q[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=p[114584];p[114584]=0;a=bv(a,e+12|0,d,de());d=ib;g=p[114584];g:{if(g){if(p[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}p[114584]=h;if(p[e+12>>2]==(b|0)){break d}}}}p[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535|d>>>0<0){break b}}p[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a&65535}function WR(a,b,c){var d=0,e=0,f=0;d=fb+ -64|0;fb=d;Me(b);Ne(d+40|0,a,c);a=p[d+40>>2];p[114610]=0;e=M(412,d+40|0)|0;f=p[114610];p[114610]=0;a:{if((f|0)==1){break a}p[114610]=0;e=M(413,e|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}p[114610]=0;Q(414,d+8|0,2,e|0,a|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}p[114610]=0;K(415,d+24|0,d+8|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}xb(b,d+24|0);pb(d+24|0);uc(d+40|0);fb=d- -64|0;return!c|(a|0)!=0}a=I()|0;H()|0;uc(d+40|0);L(a|0);E()}function I8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,q=0;h=fb-16|0;fb=h;if(e){k=c+16|0;while(1){i=0;if(d){while(1){g=Id(u[Tg(b,i,j)>>3]*134217728);f=nf(c,i);l=f;f=cj(g)+(p[f>>2]>>1)|0;m=f;f=gr(k)+f&-4096;p[l>>2]=m-f;u[h+8>>3]=+(f|0)*7.450580596923828e-9;wf(h+8|0,-1,1);g=u[h+8>>3]*32768;u[h+8>>3]=g;g=Id(g);a:{if(x(g)<2147483648){f=~~g;break a}f=-2147483648}f=Mc(f);n=um(a,i,j),q=f,o[n>>1]=q;i=i+1|0;if((i|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}fb=h+16|0}function dm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}h=p[e+12>>2];g=c-b|0;if((g|0)>=1){g=g>>2;if((Jl(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(h|0)>(b|0)?h-b|0:0;if((b|0)>=1){f=sD(i,b,f);h=Ib(f);p[114610]=0;h=P(2477,a|0,h|0,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break a}yc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>=1){b=b>>2;if((Jl(a,c,b)|0)!=(b|0)){break b}}oy(e);j=a}fb=i+16|0;return j|0}a=I()|0;H()|0;yc(f);L(a|0);E()}function X1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=fb-32|0;fb=a;p[a+24>>2]=37;p[a+28>>2]=0;Cj(a+24|1,62134,1,p[c+4>>2]);h=p[c+4>>2];g=a+ -32|0;fb=g;i=de();p[a>>2]=e;p[a+4>>2]=f;e=h>>>9&1;f=Te(g,e+23|0,i,a+24|0,a)+g|0;h=Yf(g,f,c);e=g-((e<<3)+187&240)|0;fb=e;qc(a+8|0,c);p[114610]=0;ca(2474,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=p[114610];p[114610]=0;if((f|0)!=1){Gb(a+8|0);b=dm(b,e,p[a+20>>2],p[a+16>>2],c,d);fb=a+32|0;return b|0}b=I()|0;H()|0;Gb(a+8|0);L(b|0);E()}function V1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=fb-32|0;fb=a;p[a+24>>2]=37;p[a+28>>2]=0;Cj(a+24|1,62134,0,p[c+4>>2]);h=p[c+4>>2];g=a+ -32|0;fb=g;i=de();p[a>>2]=e;p[a+4>>2]=f;e=h>>>9&1;f=Te(g,e+23|0,i,a+24|0,a)+g|0;h=Yf(g,f,c);e=g-((e<<3)+187&240)|0;fb=e;qc(a+8|0,c);p[114610]=0;ca(2474,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=p[114610];p[114610]=0;if((f|0)!=1){Gb(a+8|0);b=dm(b,e,p[a+20>>2],p[a+16>>2],c,d);fb=a+32|0;return b|0}b=I()|0;H()|0;Gb(a+8|0);L(b|0);E()}function gH(a){var b=w(0),c=w(0),d=w(0),e=w(0),f=w(0),g=0;dL(a+4208|0,t[a+4272>>2]);b=w(w(t[a+4208>>2]*w(15920))+w(80));g=He(p[a+16>>2]);c=fe(w(10),w(w(w(t[a+4216>>2]*w(30))+w(-15))*w(.02500000037252903)));b=w(w(b*w(6.2831854820251465))/w(g>>>0));d=VE(b);e=ho(b);d=w(d*K5(w(w(w(b*w(.02888113260269165))*w(w(t[a+4212>>2]*w(35))+w(1)))/d)));f=w(d/c);b=w(f+w(1));t[a+4236>>2]=w(w(1)-f)/b;e=w(w(e*w(-2))/b);t[a+4232>>2]=e;c=w(d*c);t[a+4228>>2]=w(w(1)-c)/b;t[a+4224>>2]=e;t[a+4220>>2]=w(c+w(1))/b}function UW(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;c=Mb(b,7035);p[114610]=0;N(226,b+16|0,a|0,c|0);a=p[114610];p[114610]=0;a:{b:{c:{if((a|0)!=1){pb(c);if(nc(b+16|0)){break c}a=0;break a}d=I()|0;H()|0;pb(c);break b}a=0;while(1){d:{c=id(b+16|0,d);p[114610]=0;c=M(227,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=nc(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(d>>>0<c>>>0){continue}break a}break}d=I()|0;H()|0;Xk(b+16|0)}L(d|0);E()}Xk(b+16|0);fb=b+32|0;return a|0}function Pwa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=fb-16|0;fb=b;h=p[a+24>>2];i=p[a+20>>2];j=p[a+16>>2];f=p[a+4>>2];e=f;g=p[a>>2];p[b+8>>2]=g;p[b+12>>2]=e;f=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=f;if(d){while(1){f=e+j|0;e=n[f|0]<<8;e=e+((v((n[f+1|0]<<8)-e|0,g>>>18|0)|0)/16384|0)|0;p[c>>2]=p[c>>2]+v(e,i);p[c+4>>2]=p[c+4>>2]+v(e,h);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;g=p[b+8>>2];e=p[b+12>>2];continue}break}g=p[b+8>>2];e=p[b+12>>2]}p[a>>2]=g;p[a+4>>2]=e;fb=b+16|0}function BNa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=Dh(b,11882);a:{if(!e){break a}if(!Hb(b,6)){break a}while(1){b:{d=Lf(b);c:{if((d|0)==(xk(11887)|0)){break c}c=q[11892]|q[11893]<<8|(q[11894]<<16|q[11895]<<24);if(!(d&1616928864)|d&-2139062144){break c}if((c|0)!=(d|0)){break b}}jg(b,4);break a}c=1;g=kg(b);if(r[a+480192>>1]){while(1){f=p[(((c&65535)<<2)+a|0)+900380>>2];if(f){DNa(f,d,g,b)}c=c+1|0;if((c&65535)>>>0<=r[a+480192>>1]){continue}break}}if(Hb(b,6)){continue}break}}return e|0}function Owa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=fb-16|0;fb=b;h=p[a+24>>2];i=p[a+20>>2];j=p[a+16>>2];f=p[a+4>>2];e=f;g=p[a>>2];p[b+8>>2]=g;p[b+12>>2]=e;f=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=f;if(d){while(1){f=(e<<1)+j|0;e=o[f>>1];e=e+((v(o[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;p[c>>2]=p[c>>2]+v(e,i);p[c+4>>2]=p[c+4>>2]+v(e,h);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;g=p[b+8>>2];e=p[b+12>>2];continue}break}g=p[b+8>>2];e=p[b+12>>2]}p[a>>2]=g;p[a+4>>2]=e;fb=b+16|0}function E6(a,b,c,d,e,f){var g=0,h=0,i=0,j=w(0),k=0,l=0,m=w(0),n=w(0),o=0;h=q[c|0];if(h){o=q[d+1|0]&8?7:64;k=c;while(1){l=q[d+3|0]&32;a:{b:{if((i|0)<=p[((i>>>0)%3<<2)+e>>2]){break b}g=q[b+i|0];if(o>>>0<=g>>>0){break b}m=l?w(1.4142135381698608):w(1);c:{if(q[d+1|0]&8){g=g<<3;j=t[g+48576>>2];n=t[(g|4)+48576>>2];break c}j=Pv(w(1),g+1>>>1<<f);g=g&1;n=g?w(1):j;j=g?j:w(1)}C6(a,h,w(j*m),w(n*m));break a}if(!l){break a}oF(a,h)}a=(q[k|0]<<2)+a|0;i=i+1|0;k=i+c|0;h=q[k|0];if(h){continue}break}}}function bxa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=fb-16|0;fb=b;g=p[a+24>>2];h=p[a+20>>2];i=p[a+16>>2];e=p[a+4>>2];f=p[a>>2];p[b+8>>2]=f;p[b+12>>2]=e;j=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=o[e+2>>1];p[c>>2]=p[c>>2]+v(o[e>>1],h);p[c+4>>2]=p[c+4>>2]+v(f,g);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=p[b+8>>2];e=p[b+12>>2];continue}break}f=p[b+8>>2];e=p[b+12>>2]}p[a>>2]=f;p[a+4>>2]=e;fb=b+16|0}function gea(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;p[114610]=0;S(2015,a|0);h=p[114610];p[114610]=0;a:{b:{if((h|0)!=1){h=p[a+24>>2];p[114610]=0;b=na(2032,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35282,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function dea(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;p[114610]=0;S(2015,a|0);h=p[114610];p[114610]=0;a:{b:{if((h|0)!=1){h=p[a+24>>2];p[114610]=0;b=na(2035,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35371,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function wra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=p[a>>2];g=p[Cb(d+8|0,d+12|0)>>2];p[d+8>>2]=p[a>>2];p[d+4>>2]=p[d+12>>2]-g;h=p[Cb(d+8|0,d+4|0)>>2];c=ub(b);if(g){e=p[a+20>>2];f=g;while(1){i=e,j=ub(q[c|0])^128,n[i|0]=j;e=e+2|0;c=c+1|0;f=f+ -1|0;if(f){continue}break}}b=ub(b);if(h){c=b+p[a>>2]|0;e=p[a+20>>2]+1|0;f=h;while(1){i=e,j=ub(q[c|0])^128,n[i|0]=j;e=e+2|0;c=c+1|0;f=f+ -1|0;if(f){continue}break}}fb=d+16|0;return g+h|0}function vra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;p[e+12>>2]=c;p[e+8>>2]=p[a>>2];h=p[Cb(e+8|0,e+12|0)>>2];p[e+8>>2]=p[a>>2];p[e+4>>2]=p[e+12>>2]-h;i=p[Cb(e+8|0,e+4|0)>>2];c=ub(b);if(h){f=p[a+20>>2];g=h;j=d;while(1){j=ub(q[c|0])+j|0;n[f|0]=j;f=f+2|0;c=c+1|0;g=g+ -1|0;if(g){continue}break}}b=ub(b);if(i){c=b+p[a>>2]|0;f=p[a+20>>2]+1|0;g=i;while(1){d=ub(q[c|0])+d|0;n[f|0]=d;f=f+2|0;c=c+1|0;g=g+ -1|0;if(g){continue}break}}fb=e+16|0;return h+i|0}function cxa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=fb-16|0;fb=b;g=p[a+24>>2];h=p[a+20>>2];i=p[a+16>>2];e=p[a+4>>2];f=p[a>>2];p[b+8>>2]=f;p[b+12>>2]=e;j=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=j;if(d){while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=n[e+1|0];p[c>>2]=p[c>>2]+(v(n[e|0],h)<<8);p[c+4>>2]=p[c+4>>2]+(v(f,g)<<8);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;f=p[b+8>>2];e=p[b+12>>2];continue}break}f=p[b+8>>2];e=p[b+12>>2]}p[a>>2]=f;p[a+4>>2]=e;fb=b+16|0}function g2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=fb-32|0;fb=a;p[a+24>>2]=37;p[a+28>>2]=0;Cj(a+24|1,62134,1,p[c+4>>2]);h=p[c+4>>2];g=a+ -32|0;fb=g;i=de();p[a>>2]=e;p[a+4>>2]=f;f=Te(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=Yf(g,f,c);e=g+ -48|0;fb=e;qc(a+8|0,c);p[114610]=0;ca(2465,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=p[114610];p[114610]=0;if((f|0)!=1){Gb(a+8|0);b=Kl(b,e,p[a+20>>2],p[a+16>>2],c,d);fb=a+32|0;return b|0}b=I()|0;H()|0;Gb(a+8|0);L(b|0);E()}function e2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=fb-32|0;fb=a;p[a+24>>2]=37;p[a+28>>2]=0;Cj(a+24|1,62134,0,p[c+4>>2]);h=p[c+4>>2];g=a+ -32|0;fb=g;i=de();p[a>>2]=e;p[a+4>>2]=f;f=Te(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=Yf(g,f,c);e=g+ -48|0;fb=e;qc(a+8|0,c);p[114610]=0;ca(2465,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=p[114610];p[114610]=0;if((f|0)!=1){Gb(a+8|0);b=Kl(b,e,p[a+20>>2],p[a+16>>2],c,d);fb=a+32|0;return b|0}b=I()|0;H()|0;Gb(a+8|0);L(b|0);E()}function Oca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;p[114610]=0;S(2088,a|0);f=p[114610];p[114610]=0;a:{b:{if((f|0)!=1){f=p[a+28>>2];g=p[p[f>>2]+72>>2];p[114610]=0;b=Za(g|0,f|0,b|0,c|0,+d,+e)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37534,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=-1}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function $q(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!c|!(a&3)){break c}e=b&255;while(1){if((e|0)==q[a|0]){break b}a=a+1|0;c=c+ -1|0;d=(c|0)!=0;if(!c){break c}if(a&3){continue}break}}if(!d){break a}}d:{if(q[a|0]==(b&255)|c>>>0<4){break d}d=v(b&255,16843009);while(1){e=d^p[a>>2];if((e^-1)&e+ -16843009&-2139062144){break d}a=a+4|0;c=c+ -4|0;if(c>>>0>3){continue}break}}if(!c){break a}b=b&255;while(1){if((b|0)==q[a|0]){return a}a=a+1|0;c=c+ -1|0;if(c){continue}break}}return 0}function j4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;p[d+16>>2]=b;e=p[a+48>>2];p[d+20>>2]=c-((e|0)!=0);f=p[a+44>>2];p[d+28>>2]=e;p[d+24>>2]=f;a:{b:{c:{if(co(Ta(p[a+60>>2],d+16|0,2,d+12|0)|0)){p[d+12>>2]=-1;c=-1;break c}e=p[d+12>>2];if((e|0)>0){break b}c=e}p[a>>2]=p[a>>2]|c&48^16;break a}g=p[d+20>>2];if(e>>>0<=g>>>0){c=e;break a}f=p[a+44>>2];p[a+4>>2]=f;p[a+8>>2]=f+(e-g|0);if(!p[a+48>>2]){break a}p[a+4>>2]=f+1;n[(b+c|0)+ -1|0]=q[f|0]}fb=d+32|0;return c|0}function H0(a,b,c){var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=wb(a);e=tq(a);g=Rs(b,c);a:{if(!g){break a}if(wz(b,Ib(a),Ib(a)+(wb(a)<<2)|0)){d=fb-16|0;fb=d;yD(f,b,c);fb=d+16|0;b=f;c=Ib(b);d=wb(b);p[114610]=0;P(2500,a|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){yc(b);break a}a=I()|0;H()|0;yc(b);L(a|0);E()}if(e-d>>>0<g>>>0){hC(a,e,(d+g|0)-e|0,d,d)}e=Ib(a)+(d<<2)|0;while(1){if((b|0)!=(c|0)){Je(e,b);b=b+4|0;e=e+4|0;continue}break}p[f>>2]=0;Je(e,f);Jg(a,d+g|0)}fb=f+16|0;return a}function z8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;x8(c+16|0,c,b,a,f);fb=c+80|0}function y8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;u8(c+16|0,c,b,a,f);fb=c+80|0}function qca(a){var b=0,c=0,d=0;b=fb-160|0;fb=b;c=Mb(b+120|0,38115);p[114610]=0;K(2116,b+104|0,20617);d=p[114610];p[114610]=0;a:{b:{c:{d:{e:{if((d|0)!=1){p[114610]=0;N(3,b+136|0,c|0,b+104|0);d=p[114610];p[114610]=0;if((d|0)==1){break e}p[114610]=0;_(2117,b+88|0,a|0,1,38108,b+136|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}pb(b+136|0);pb(b+104|0);break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;break c}a=I()|0;H()|0;pb(b+136|0)}pb(b+104|0)}pb(c);L(a|0);E()}pb(c);fb=b+160|0}function fr(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;B8(c+16|0,c,b,a,f);fb=c+80|0}function _v(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;J8(c+16|0,c,b,a,f);fb=c+80|0}function Zv(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;v8(c+16|0,c,b,a,f);fb=c+80|0}function Yma(a,b){a=a|0;b=b|0;var c=0;b=78352;Wma(a);a:{while(1){b:{if(!cd(a)){if(!Th(p[b+8>>2],p[_i(a)>>2])){break b}}p[114610]=0;K(1516,a|0,b+8|0);c=p[114610];p[114610]=0;if((c|0)!=1){break b}break a}b=b+12|0;if((b|0)!=78868){continue}break}b=78880;while(1){c:{if(!cd(a)){if(!Th(p[b+8>>2],p[_i(a)>>2])){break c}}p[114610]=0;K(1516,a|0,b+8|0);c=p[114610];p[114610]=0;if((c|0)!=1){break c}break a}b=b+12|0;if((b|0)!=78928){continue}break}return}b=I()|0;H()|0;_w(a);L(b|0);E()}function T8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;Q8(c+16|0,c,b,a,f);fb=c+80|0}function R8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;O8(c+16|0,c,b,a,f);fb=c+80|0}function N8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;K8(c+16|0,c,b,a,f);fb=c+80|0}function L8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;I8(c+16|0,c,b,a,f);fb=c+80|0}function Kl(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}g=p[e+12>>2];h=c-b|0;if((h|0)>=1){if((Jl(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(g|0)>(b|0)?g-b|0:0;if((b|0)>=1){f=nj(i,b,f);g=Ib(f);p[114610]=0;g=P(28,a|0,g|0,b|0)|0;h=p[114610];p[114610]=0;if((h|0)==1){break a}pb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>=1){if((Jl(a,c,b)|0)!=(b|0)){break b}}oy(e);j=a}fb=i+16|0;return j|0}a=I()|0;H()|0;pb(f);L(a|0);E()}function C8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;A8(c+16|0,c,b,a,f);fb=c+80|0}function $v(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];e=p[d+24>>2];p[c+40>>2]=p[d+20>>2];p[c+44>>2]=e;e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;rh(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];e=p[c+76>>2];p[c+24>>2]=p[c+72>>2];p[c+28>>2]=e;e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;P8(c+16|0,c,b,a,f);fb=c+80|0}function xra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=p[a>>2];g=p[Cb(d+8|0,d+12|0)>>2];p[d+8>>2]=p[a>>2];p[d+4>>2]=p[d+12>>2]-g;h=p[Cb(d+8|0,d+4|0)>>2];c=ub(b);if(g){e=p[a+20>>2];f=g;while(1){i=e,j=Qm(q[c|0]),n[i|0]=j;e=e+2|0;c=c+1|0;f=f+ -1|0;if(f){continue}break}}b=ub(b);if(h){c=b+p[a>>2]|0;e=p[a+20>>2]+1|0;f=h;while(1){i=e,j=Qm(q[c|0]),n[i|0]=j;e=e+2|0;c=c+1|0;f=f+ -1|0;if(f){continue}break}}fb=d+16|0;return g+h|0}function wD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=q[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=p[114584];p[114584]=0;a=bv(a,e+12|0,d,de());d=ib;g=p[114584];g:{if(g){if(p[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}p[114584]=h;if(p[e+12>>2]==(b|0)){break d}}}}p[c>>2]=4;a=0;break a}if(!d|d>>>0<0){break b}}p[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a|0}function coa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;a:{if((b+ -1&65535)>>>0>3998){break a}f=1;e=(v(b,104)+a|0)+484380|0;if(!ue(e)){break a}g=a+1304360|0;d=a+1074984|0;while(1){if(p[d+104>>2]==(e|0)){p[d+76>>2]=0;p[d>>2]=0;p[d+4>>2]=0;p[d+16>>2]=0}d=d+896|0;if((g|0)!=(d|0)){continue}break}Zm(e);p[e>>2]=0;a=(v(b,104)+a|0)+484414|0;o[a>>1]=r[a>>1]&65470;p[c+24>>2]=0;p[c+8>>2]=0;p[c+16>>2]=0;p[c+20>>2]=0;p[c>>2]=0;p[c+4>>2]=0;Xo(e,0,c)}fb=c+32|0;return f|0}function JQ(a,b){a=a|0;b=b|0;var c=0,d=0;d=q[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!q[a|0]){break a}}c:{d:{switch(q[a+3|0]){case 10:case 17:case 18:c=8;break c;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:c=q[a|0];if(!(c&7)){break c};case 11:c=q[a+3|0];return v(oz(a),b+1>>>1|0)+(((c|0)==11)<<4)|0;case 9:break d;default:break c}}c=16}d=q[a+3|0];c=v(oz(a),v(c>>>3|0,b))+(((d|0)==11)<<4)|0}return c|0}function CN(a){var b=0;a:{if((q[a+44|0]|q[a+45|0]<<8|(q[a+46|0]<<16|q[a+47|0]<<24))!=1179472976|q[a+28|0]!=26|q[a+30|0]>2){break a}b=a+40|0;if(q[b|0]|q[b+1|0]<<8){break a}b=a+38|0;if(!(q[b|0]|q[b+1|0]<<8)|(q[b|0]|q[b+1|0]<<8)>>>0>32){break a}b=a+32|0;if(!(q[b|0]|q[b+1|0]<<8)|(q[b|0]|q[b+1|0]<<8)>>>0>256){break a}b=a+34|0;if(!(q[b|0]|q[b+1|0]<<8)|(q[b|0]|q[b+1|0]<<8)>>>0>255){break a}a=a+36|0;if(!(q[a|0]|q[a+1|0]<<8)){break a}return(q[a|0]|q[a+1|0]<<8)>>>0<129}return 0}function f8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-16|0;fb=g;if(e){k=c+4|0;while(1){h=0;if(d){while(1){f=u[Tg(b,h,i)>>3];Yb(c,h);l=g,m=+(cj(Id(f*134217728))-1024+((hr(k)^-2147483648)>>>21)|0)*7.450580596923828e-9,u[l+8>>3]=m;wf(g+8|0,-1,1);f=u[g+8>>3]*32768;u[g+8>>3]=f;f=Id(f);a:{if(x(f)<2147483648){j=~~f;break a}j=-2147483648}j=Mc(j);l=sm(a,h,i),n=j,o[l>>1]=n;h=h+1|0;if((h|0)!=(d|0)){continue}break}}i=i+1|0;if((i|0)!=(e|0)){continue}break}}fb=g+16|0}function J8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-16|0;fb=g;if(e){k=c+4|0;while(1){h=0;if(d){while(1){f=u[Tg(b,h,i)>>3];Yb(c,h);l=g,m=+(cj(Id(f*134217728))-1024+((hr(k)^-2147483648)>>>21)|0)*7.450580596923828e-9,u[l+8>>3]=m;wf(g+8|0,-1,1);f=u[g+8>>3]*32768;u[g+8>>3]=f;f=Id(f);a:{if(x(f)<2147483648){j=~~f;break a}j=-2147483648}j=Mc(j);l=um(a,h,i),n=j,o[l>>1]=n;h=h+1|0;if((h|0)!=(d|0)){continue}break}}i=i+1|0;if((i|0)!=(e|0)){continue}break}}fb=g+16|0}function R6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;i=q[c+14|0];g=i+q[c+13|0]|0;F6(a+2304|0,p[c>>2],g,f+4|0);if(q[c+13|0]){e=p[f+12>>2];h=p[f+8>>2];j=p[f+4>>2];h=(j|0)<(h|0)?h:j;e=(h|0)<(e|0)?e:h;p[f+12>>2]=e;p[f+8>>2]=e;p[f+4>>2]=e}i=i?3:1;h=g-i|0;e=0;while(1){j=e+h|0;g=j-i|0;k=q[d+1|0]<<28>>31&3;a:{if(p[(f+4|0)+(e<<2)>>2]>=(g|0)){break a}k=q[b+g|0]}g=k;n[b+j|0]=g;e=e+1|0;if((i|0)!=(e|0)){continue}break}E6(a,b,p[c>>2],d,f+4|0,o[c+36>>1]&1);fb=f+16|0}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;p[114610]=0;S(2088,a|0);e=p[114610];p[114610]=0;a:{b:{if((e|0)!=1){e=p[a+28>>2];f=p[p[e>>2]+12>>2];p[114610]=0;b=U(f|0,e|0,b|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37968,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=-1}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;p[114610]=0;S(2088,a|0);e=p[114610];p[114610]=0;a:{b:{if((e|0)!=1){e=p[a+28>>2];f=p[p[e>>2]+8>>2];p[114610]=0;b=U(f|0,e|0,b|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37925,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=-1}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Tca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;p[114610]=0;S(2088,a|0);d=p[114610];p[114610]=0;e=1;a:{b:{if((d|0)!=1){d=p[a+28>>2];f=p[p[d>>2]+56>>2];p[114610]=0;N(f|0,d|0,b|0,(c|0)!=0|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37432,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();e=0}return e|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Qca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;p[114610]=0;S(2088,a|0);d=p[114610];p[114610]=0;e=1;a:{b:{if((d|0)!=1){d=p[a+28>>2];f=p[p[d>>2]+64>>2];p[114610]=0;N(f|0,d|0,b|0,(c|0)!=0|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37480,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();e=0}return e|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Jj(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!p[p[21199]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){n[a+1|0]=b&63|128;n[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344?b>>>0>=55296:0)){n[a+2|0]=b&63|128;n[a|0]=b>>>12|224;n[a+1|0]=b>>>6&63|128;return 3}if(b+ -65536>>>0<=1048575){n[a+3|0]=b&63|128;n[a|0]=b>>>18|240;n[a+2|0]=b>>>6&63|128;n[a+1|0]=b>>>12&63|128;return 4}}p[114584]=25;a=-1}else{a=1}return a|0}n[a|0]=b;return 1}function FE(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=p[a+104>>2];b=(h<<3)+a|0;c=((h+7>>>0)%12<<3)+a|0;f=p[c>>2];e=p[c+4>>2];i=p[a+96>>2];j=p[a+100>>2];a:{if(!(i|j)){g=p[b+4>>2];d=g;c=p[b>>2];k=(d|0)==(e|0)&f>>>0<c>>>0|e>>>0<d>>>0;break a}g=p[b+4>>2];d=g;c=p[b>>2];k=(d|0)==(e|0)&f>>>0<=c>>>0|e>>>0<d>>>0}d=f-i|0;p[b>>2]=d-c;p[b+4>>2]=e-((f>>>0<i>>>0)+j|0)-((d>>>0<c>>>0)+g)&65535;p[a+104>>2]=(h+1>>>0)%12;p[a+96>>2]=k;p[a+100>>2]=0;ib=p[b+4>>2];return p[b>>2]}function tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=_h(a,b,c,d);p[a>>2]=80928;d=Pj(a+4208|0);p[a+4240>>2]=0;p[a+4244>>2]=0;c=He(c);p[a+4260>>2]=0;p[a+4256>>2]=c;p[a+4236>>2]=0;c=a+4228|0;p[c>>2]=1048576e3;p[c+4>>2]=1048576e3;p[a+4220>>2]=1056964608;p[a+4224>>2]=1056964608;p[114610]=0;P(1639,a+44|0,2,2)|0;c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;S(1640,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}return a|0}a=I()|0;H()|0;Ef(d);Ge(b);L(a|0);E()}function aMa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=fb-32|0;fb=f;p[f+28>>2]=c;g=Hb(b,c<<1);a:{if(!g){break a}vc(f+28|0,65535);ig(a,r[f+28>>1]);h=f,i=Ub(a),p[h+16>>2]=i;h=f,i=Vb(a),p[h+8>>2]=i;if(!Ab(f+16|0,f+8|0)){break a}while(1){a=p[f+16>>2];aA(b,f+24|0);c=f+24|0;c=q[c|0]|q[c+1|0]<<8;o[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}o[a>>1]=c}te(f+16|0);if(Ab(f+16|0,f+8|0)){continue}break}}fb=f+32|0;return g|0}function JJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-560|0;fb=d;o[d+558>>1]=b;a:{b:{if((b+ -1&65535)>>>0>254){break b}f=((b<<2)+a|0)+900380|0;e=p[f>>2];c:{if(e){b=CM(d,c);Rna(e,b);Us(b);break c}b=ug(556);if(!b){e=0;p[f>>2]=0;break b}p[114610]=0;e=J(1435,b|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}p[((r[d+558>>1]<<2)+a|0)+900380>>2]=b}g=a,h=r[Bi(a+480192|0,d+558|0)>>1],o[g+480192>>1]=h}fb=d+560|0;return e|0}a=I()|0;H()|0;Nb(b);L(a|0);E()}function bJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;JIa(a);e=a;a:{b:{c:{d:{while(1){p[114610]=0;a=J(258,b|0,8)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}if(!a){break c}p[114610]=0;N(602,d+8|0,b|0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;K(603,e|0,d+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}Ce(d+8|0);continue}break}a=I()|0;H()|0;break a}a=I()|0;H()|0;Ce(d+8|0);break a}fb=d+32|0;return}a=I()|0;H()|0}yz(e);L(a|0);E()}



function DFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;KEa(a);e=a;a:{b:{c:{d:{while(1){p[114610]=0;a=J(258,b|0,6)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}if(!a){break c}p[114610]=0;N(761,d+8|0,b|0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;K(762,e|0,d+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}Ce(d+8|0);continue}break}a=I()|0;H()|0;break a}a=I()|0;H()|0;Ce(d+8|0);break a}fb=d+32|0;return}a=I()|0;H()|0}Yy(e);L(a|0);E()}



function Pqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=w(0),g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;p[e+8>>2]=c>>>2;p[e+4>>2]=p[a>>2];d=p[Cb(e+8|0,e+4|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){p[e+12>>2]=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);Td(e+12|0,w(-1));f=w(t[e+12>>2]*w(32768));t[e+12>>2]=f;h=a;f=$d(f);a:{if(w(x(f))<w(2147483648)){g=~~f;break a}g=-2147483648}i=h,j=Mc(g),o[i>>1]=j;a=a+2|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<2}function mLa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;FKa(a);e=a;a:{b:{c:{d:{while(1){p[114610]=0;a=J(258,b|0,8)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}if(!a){break c}p[114610]=0;N(513,d+8|0,b|0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;K(514,e|0,d+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}Ce(d+8|0);continue}break}a=I()|0;H()|0;break a}a=I()|0;H()|0;Ce(d+8|0);break a}fb=d+32|0;return}a=I()|0;H()|0}Qz(e);L(a|0);E()}function cKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;sJa(a);e=a;a:{b:{c:{d:{while(1){p[114610]=0;a=J(258,b|0,8)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}if(!a){break c}p[114610]=0;N(553,d+8|0,b|0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;K(554,e|0,d+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}Ce(d+8|0);continue}break}a=I()|0;H()|0;break a}a=I()|0;H()|0;Ce(d+8|0);break a}fb=d+32|0;return}a=I()|0;H()|0}Iz(e);L(a|0);E()}function zH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=_h(a,b,c,d);p[a>>2]=80288;c=Pj(a+4260|0);p[a+4232>>2]=1061997773;d=a+4224|0;p[d>>2]=1061158912;p[d+4>>2]=1059082943;d=a+4216|0;p[d>>2]=1038174126;p[d+4>>2]=1065353216;p[a+4208>>2]=1056964608;p[a+4212>>2]=1036831949;p[114610]=0;P(1639,a+44|0,2,2)|0;d=p[114610];p[114610]=0;a:{if((d|0)==1){break a}p[114610]=0;S(1640,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}return a|0}a=I()|0;H()|0;Ef(c);Ge(b);L(a|0);E()}function kHa(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if(Ys(a)){p[b>>2]=0;a=0;break a}f=Dg(a,e,16);d=ub(q[e|0]);c=d&127;p[b>>2]=c;d=d<<24>>24;b:{if(!(f>>>0<2|(d|0)>-1)){d=c?32-y(c)|0:0;c=1;while(1){g=ub(q[c+e|0]);p[b>>2]=g&127|p[b>>2]<<7;d=d+7|0;c=c+1|0;if((f|0)==(c|0)){Sb(a,f);f=Dg(a,e,16);c=0}g=g<<24>>24;if((g|0)<0?c>>>0<f>>>0:0){continue}break}Sb(a,c);a=(g|0)<0;if(d>>>0<33){break b}p[b>>2]=-1;a=0;break a}Sb(a,1);a=(d|0)<0}a=a^1}fb=e+16|0;return a}function Xla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Vw(a);a:{b:{c:{d:{while(1){p[114610]=0;a=J(258,b|0,8)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}if(!a){break c}p[114610]=0;N(1554,d+8|0,b|0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;K(1555,e|0,d+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}Ce(d+8|0);continue}break}a=I()|0;H()|0;break a}a=I()|0;H()|0;Ce(d+8|0);break a}fb=d+32|0;return}a=I()|0;H()|0}fl(e);L(a|0);E()}function Vca(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;p[114610]=0;S(2088,a|0);d=p[114610];p[114610]=0;e=1;a:{b:{if((d|0)!=1){d=p[a+28>>2];f=p[p[d>>2]+48>>2];p[114610]=0;$a(f|0,d|0,b|0,+c);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37394,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();e=0}return e|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function xda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;p[114610]=0;S(2015,a|0);f=p[114610];p[114610]=0;a:{b:{if((f|0)!=1){f=p[a+24>>2];p[114610]=0;b=Z(2070,f|0,b|0,c|0,d|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36572,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function hea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;p[114610]=0;S(2015,a|0);f=p[114610];p[114610]=0;a:{b:{if((f|0)!=1){f=p[a+24>>2];p[114610]=0;b=Z(2031,f|0,b|0,c|0,d|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35255,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function eea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;p[114610]=0;S(2015,a|0);f=p[114610];p[114610]=0;a:{b:{if((f|0)!=1){f=p[a+24>>2];p[114610]=0;b=Z(2034,f|0,b|0,c|0,d|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35338,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function pAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=wy(a);a:{b:{c:{d:{while(1){p[114610]=0;a=J(258,b|0,8)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}if(!a){break c}p[114610]=0;N(974,d+8|0,b|0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;K(975,e|0,d+8|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}Ce(d+8|0);continue}break}a=I()|0;H()|0;break a}a=I()|0;H()|0;Ce(d+8|0);break a}fb=d+32|0;return}a=I()|0;H()|0}sl(e);L(a|0);E()}function aw(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!kr(b)){break a}a=a+24|0;if(!Cg(p[a>>2]+484344|0,b&65535)){break a}b=Rb(p[a>>2]+484344|0,b);if((d|0)<0|p[b+12>>2]<=(c|0)|(c|0)<0|(r[p[a>>2]+480188>>1]<=(d|0)|e>>>0>5)){break a}a=_e(b,c,d&65535);b:{switch(e|0){case 0:f=q[a|0];break a;case 1:f=q[a+1|0];break a;case 2:f=q[a+2|0];break a;case 3:f=q[a+3|0];break a;case 4:f=q[a+4|0];break a;case 5:break b;default:break a}}f=q[a+5|0]}return f|0}function Ve(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;g=Hm(a);f=e;i=e;a:{if(b){j=p[b+4>>2];h=p[b>>2];break a}h=Hm(a)}p[i+8>>2]=h;p[f+12>>2]=j;f=p[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;if(a>>>0<c>>>0){d=d+1|0}b=a;p[e>>2]=2048;p[e+4>>2]=0;a=mA(e+8|0,e);c=p[a>>2];a=p[a+4>>2];c:{if(!a&c>>>0>g>>>0|a>>>0>0){a=-1;if(!d&b>>>0<=g>>>0|d>>>0<0){break c}break b}a=0;c=p[e+12>>2];if((c|0)==(d|0)&s[e+8>>2]<b>>>0|c>>>0<d>>>0){break b}}a=1}fb=e+16|0;return a}function bc(a,b){var c=0,d=0,e=0;a:{b:{c=p[a+1396>>2];if((c|0)>=0){c:{if((c|0)<(b|0)){if((b|0)>=25){break b}if(!c){p[a+1392>>2]=0}while(1){c=-1;e=br(a);d=0;if((e|0)==-1){break c}d=p[a+1396>>2];c=d+8|0;p[a+1396>>2]=c;p[a+1392>>2]=p[a+1392>>2]+(e<<d);if((c|0)<(b|0)){continue}break}}if((c|0)<(b|0)){break a}d=p[a+1392>>2];p[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}p[a+1396>>2]=c}return d}return bc(a,24)+(bc(a,b+ -24|0)<<24)|0}aa(50470,50416,1617,50489);E()}function R0(a,b,c){var d=0,e=0,f=0,g=0;f=fb-32|0;fb=f;d=wb(a);e=Bc(a);g=zi(b,c);a:{if(!g){break a}if(wz(b,Ib(a),Ib(a)+wb(a)|0)){b=di(f+16|0,b,c);c=Ib(b);d=wb(b);p[114610]=0;P(2492,a|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(b);break a}a=I()|0;H()|0;pb(b);L(a|0);E()}if(e-d>>>0<g>>>0){El(a,e,(d+g|0)-e|0,d,d,0,0)}e=Ib(a)+d|0;while(1){if((b|0)!=(c|0)){ae(e,b);b=b+1|0;e=e+1|0;continue}break}n[f+15|0]=0;ae(e,f+15|0);Jg(a,d+g|0)}fb=f+32|0;return a}function xR(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=p[a+1060>>2];if((b|0)>255){break a}while(1){f=(v(b,6)+a|0)+1068|0,g=pj(a,7),n[f|0]=g;d=pj(a,1);e=pj(a,1);c=p[a+1056>>2];if((c|0)>255){break a}b=p[a+1060>>2]+1|0;p[a+1056>>2]=b;p[a+1060>>2]=b;b:{if(d){o[(v(c,6)+a|0)+1064>>1]=b;xR(a);b=p[a+1060>>2];break b}o[(v(c,6)+a|0)+1064>>1]=65535}p[a+1056>>2]=b;if(e){o[(v(c,6)+a|0)+1066>>1]=b;if((b|0)<=255){continue}break a}break}o[(v(c,6)+a|0)+1066>>1]=65535}}function iC(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Ib(a);a:{if(536870887>b>>>0){p[i+8>>2]=b<<1;p[i+12>>2]=b+c;c=Zl(p[Uc(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=Lk(k);if(e){Rh(c,j,e)}if(g){Rh(c+(e<<2)|0,h,g)}d=d-f|0;h=d-e|0;if(h){e=e<<2;Rh((e+c|0)+(g<<2)|0,(e+j|0)+(f<<2)|0,h)}b=b+1|0;if((b|0)!=2){Un(j,b)}sf(a,c);sg(a,k);b=a;a=d+g|0;oe(b,a);p[i+4>>2]=0;Je(c+(a<<2)|0,i+4|0);fb=i+16|0;return}tg();E()}function cma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;ema(a+33|0,b);h=b+236|0;e=a+27|0;while(1){f=0;g=(a+d|0)+33|0;if((q[e|0]|q[e+1|0]<<8)>>>0>q[g|0]){f=q[g|0]}i=Yc(h,d+12|0),j=f,o[i>>1]=j;d=d+1|0;if((d|0)!=96){continue}break}xn(c,3,a+4|0);zc(c+16|0,c);p[114610]=0;J(369,b+492|0,c+16|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){pb(c+16|0);if(!q[a+241|0]){n[b+30|0]=q[a+26|0]}fb=c+32|0;return}a=I()|0;H()|0;pb(c+16|0);L(a|0);E()}function zia(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-144|0;fb=c;d=Vg(c+8|0);e=p[p[d>>2]+ -12>>2];p[114610]=0;f=Y(122)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;N(123,c|0,e+(c+8|0)|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}Gb(c);p[114610]=0;K(136,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(125,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Qd(d);fb=c+144|0;return}a=I()|0;H()|0;Qd(d);L(a|0);E()}function lja(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-144|0;fb=c;d=Vg(c+8|0);e=p[p[d>>2]+ -12>>2];p[114610]=0;f=Y(122)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;N(123,c|0,e+(c+8|0)|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}Gb(c);p[114610]=0;K(133,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(125,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Qd(d);fb=c+144|0;return}a=I()|0;H()|0;Qd(d);L(a|0);E()}function eka(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-144|0;fb=c;d=Vg(c+8|0);e=p[p[d>>2]+ -12>>2];p[114610]=0;f=Y(122)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;N(123,c|0,e+(c+8|0)|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}Gb(c);p[114610]=0;K(130,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(125,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Qd(d);fb=c+144|0;return}a=I()|0;H()|0;Qd(d);L(a|0);E()}function Via(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-144|0;fb=c;d=Vg(c+8|0);e=p[p[d>>2]+ -12>>2];p[114610]=0;f=Y(122)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;N(123,c|0,e+(c+8|0)|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}Gb(c);p[114610]=0;K(134,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(125,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Qd(d);fb=c+144|0;return}a=I()|0;H()|0;Qd(d);L(a|0);E()}function Sja(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-144|0;fb=c;d=Vg(c+8|0);e=p[p[d>>2]+ -12>>2];p[114610]=0;f=Y(122)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;N(123,c|0,e+(c+8|0)|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}Gb(c);p[114610]=0;K(131,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(125,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Qd(d);fb=c+144|0;return}a=I()|0;H()|0;Qd(d);L(a|0);E()}function Mia(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-144|0;fb=c;d=Vg(c+8|0);e=p[p[d>>2]+ -12>>2];p[114610]=0;f=Y(122)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;N(123,c|0,e+(c+8|0)|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}Gb(c);p[114610]=0;K(135,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(125,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Qd(d);fb=c+144|0;return}a=I()|0;H()|0;Qd(d);L(a|0);E()}function M3(a,b){var c=0,d=0,f=0,g=0,h=0,j=0,k=0;f=fb-16|0;fb=f;g=(i(b),e(2));c=g&2147483647;a:{if(c+ -8388608>>>0<=2130706431){d=c;c=c>>>7|0;d=d<<25;c=c+1065353216|0;h=d;c=d>>>0<0?c+1|0:c;break a}if(c>>>0>=2139095040){c=g;d=c>>>7|0;h=c<<25;c=d|2147418112;break a}if(!c){c=0;break a}d=c;c=y(c);ef(f,d,0,0,0,c+81|0);j=p[f>>2];k=p[f+4>>2];h=p[f+8>>2];c=p[f+12>>2]^65536|16265-c<<16}p[a>>2]=j;p[a+4>>2]=k;p[a+8>>2]=h;p[a+12>>2]=g&-2147483648|c;fb=f+16|0}function lI(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-144|0;fb=c;d=Vg(c+8|0);e=p[p[d>>2]+ -12>>2];p[114610]=0;f=Y(122)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;N(123,c|0,e+(c+8|0)|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}Gb(c);p[114610]=0;K(132,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(125,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Qd(d);fb=c+144|0;return}a=I()|0;H()|0;Qd(d);L(a|0);E()}function Y5(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=w(0);g=e-c|0;i=d-b|0;e=(g|0)/(i|0)|0;f=(d|0)>(f|0)?f:d;a:{if((f|0)<=(b|0)){break a}d=(b<<2)+a|0;t[d>>2]=t[d>>2]*t[((c&255)<<2)+50800>>2];d=b+1|0;if((d|0)>=(f|0)){break a}b=0;j=g>>31;j=v((e|0)<0?e:0-e|0,i)+(j+g^j)|0;g=(g|0)<0?-1:1;while(1){h=(d<<2)+a|0;k=h;l=t[h>>2];b=b+j|0;h=(b|0)<(i|0);c=(c+e|0)+(h?0:g)|0;t[k>>2]=l*t[((c&255)<<2)+50800>>2];b=b-(h?0:i)|0;d=d+1|0;if((f|0)!=(d|0)){continue}break}}}function Nw(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-144|0;fb=c;d=Vg(c+8|0);e=p[p[d>>2]+ -12>>2];p[114610]=0;f=Y(122)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;N(123,c|0,e+(c+8|0)|0,f|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}Gb(c);p[114610]=0;K(124,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(125,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Qd(d);fb=c+144|0;return}a=I()|0;H()|0;Qd(d);L(a|0);E()}function cda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;p[114610]=0;S(2088,a|0);c=p[114610];p[114610]=0;d=1;a:{b:{if((c|0)!=1){c=p[a+28>>2];e=p[p[c>>2]+16>>2];p[114610]=0;K(e|0,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37254,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=0}return d|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;p[114610]=0;S(2088,a|0);c=p[114610];p[114610]=0;d=1;a:{b:{if((c|0)!=1){c=p[a+28>>2];e=p[p[c>>2]+20>>2];p[114610]=0;K(e|0,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37272,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=0}return d|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Nca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;p[114610]=0;S(2088,a|0);c=p[114610];p[114610]=0;d=1;a:{b:{if((c|0)!=1){c=p[a+28>>2];e=p[p[c>>2]+76>>2];p[114610]=0;K(e|0,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37544,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=0}return d|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Zca(a,b){a=a|0;b=+b;var c=0,d=0,e=0;p[114610]=0;S(2088,a|0);c=p[114610];p[114610]=0;d=1;a:{b:{if((c|0)!=1){c=p[a+28>>2];e=p[p[c>>2]+32>>2];p[114610]=0;ka(e|0,c|0,+b);c=p[114610];p[114610]=0;if((c|0)!=1){break b}}d=O(0)|0;H()|0;T(d|0)|0;p[114610]=0;Q(1989,37324,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=0}return d|0}a=I()|0;H()|0;p[114610]=0;R(20);d=p[114610];p[114610]=0;if((d|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Xw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=fb-48|0;fb=f;a:{if(!c){c=jc(a,b);a=p[d+12>>2];p[c+8>>2]=p[d+8>>2];p[c+12>>2]=a;a=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=a;break a}e=p[d+12>>2];p[f+24>>2]=p[d+8>>2];p[f+28>>2]=e;g=p[d+4>>2];e=f;p[e+16>>2]=p[d>>2];p[e+20>>2]=g;g=c>>>1|0;Xw(a,b,g,e+16|0);wh(e+32|0,d,jc(a,c));d=p[e+44>>2];p[e+8>>2]=p[e+40>>2];p[e+12>>2]=d;d=p[e+36>>2];p[e>>2]=p[e+32>>2];p[e+4>>2]=d;Xw(a,b|c,g,e)}fb=f+48|0}function Xca(a,b){a=a|0;b=+b;var c=0,d=0,e=0;p[114610]=0;S(2088,a|0);c=p[114610];p[114610]=0;d=1;a:{b:{if((c|0)!=1){c=p[a+28>>2];e=p[p[c>>2]+40>>2];p[114610]=0;ka(e|0,c|0,+b);c=p[114610];p[114610]=0;if((c|0)!=1){break b}}d=O(0)|0;H()|0;T(d|0)|0;p[114610]=0;Q(1989,37358,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=0}return d|0}a=I()|0;H()|0;p[114610]=0;R(20);d=p[114610];p[114610]=0;if((d|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Raa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(!(g?!(!f|(!d|!e)):0)){b=W(8)|0;p[114610]=0;c=J(85,h|0,38601)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}Yh(a,b,4);c=gw(a,c,d,e,f,g);u[a+16>>3]=+(c>>>0)/+(b|0)+u[a+16>>3];fb=h+16|0;return c|0}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function Oaa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(!(g?!(!f|(!d|!e)):0)){b=W(8)|0;p[114610]=0;c=J(85,h|0,38601)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}Yh(a,b,4);c=fw(a,c,d,e,f,g);u[a+16>>3]=+(c>>>0)/+(b|0)+u[a+16>>3];fb=h+16|0;return c|0}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function $ca(a,b){a=a|0;b=+b;var c=0,d=0,e=0;p[114610]=0;S(2088,a|0);c=p[114610];p[114610]=0;d=1;a:{b:{if((c|0)!=1){c=p[a+28>>2];e=p[p[c>>2]+24>>2];p[114610]=0;ka(e|0,c|0,+b);c=p[114610];p[114610]=0;if((c|0)!=1){break b}}d=O(0)|0;H()|0;T(d|0)|0;p[114610]=0;Q(1989,37290,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=0}return d|0}a=I()|0;H()|0;p[114610]=0;R(20);d=p[114610];p[114610]=0;if((d|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function iea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;p[114610]=0;S(2015,a|0);e=p[114610];p[114610]=0;a:{b:{if((e|0)!=1){e=p[a+24>>2];p[114610]=0;b=U(2030,e|0,b|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35230,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function gma(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb+ -64|0;fb=f;while(1){h=+(g+ -4096|0)*.0001220703125;e=0;d=0;while(1){i=hma(d,h,b,c);u[(d<<3)+f>>3]=i;e=i+e;d=d+1|0;if((d|0)!=8){continue}break}e=1/e;k=g<<3;d=0;while(1){l=(d+k<<1)+a|0;h=A(z(B(u[(d<<3)+f>>3]*32768*e+.5),32768),-32768);a:{if(x(h)<2147483648){j=~~h;break a}j=-2147483648}o[l>>1]=j;d=d+1|0;if((d|0)!=8){continue}break}g=g+1|0;if((g|0)!=8193){continue}break}fb=f- -64|0}function fea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;p[114610]=0;S(2015,a|0);e=p[114610];p[114610]=0;a:{b:{if((e|0)!=1){e=p[a+24>>2];p[114610]=0;b=U(2033,e|0,b|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35307,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function cea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;p[114610]=0;S(2015,a|0);e=p[114610];p[114610]=0;a:{b:{if((e|0)!=1){e=p[a+24>>2];p[114610]=0;b=U(2036,e|0,b|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35402,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;p[114610]=0;S(2015,a|0);e=p[114610];p[114610]=0;a:{b:{if((e|0)!=1){e=p[a+24>>2];p[114610]=0;b=U(2037,e|0,b|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35441,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;p[114610]=0;S(2015,a|0);e=p[114610];p[114610]=0;a:{b:{if((e|0)!=1){e=p[a+24>>2];p[114610]=0;b=U(2038,e|0,b|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35478,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Uca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;p[114610]=0;S(2088,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+28>>2];e=p[p[c>>2]+52>>2];p[114610]=0;d=+_a(e|0,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37413,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=0}return+d}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function LD(a,b){var c=0,d=0;a:{d=b&255;if(d){if(a&3){while(1){c=q[a|0];if(!c|(c|0)==(b&255)){break a}a=a+1|0;if(a&3){continue}break}}c=p[a>>2];b:{if((c^-1)&c+ -16843009&-2139062144){break b}d=v(d,16843009);while(1){c=c^d;if((c^-1)&c+ -16843009&-2139062144){break b}c=p[a+4>>2];a=a+4|0;if(!(c+ -16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=a;d=q[c|0];if(d){a=c+1|0;if((d|0)!=(b&255)){continue}}break}return c}return ve(a)+a|0}return a}function $da(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;p[114610]=0;S(2015,a|0);e=p[114610];p[114610]=0;a:{b:{if((e|0)!=1){e=p[a+24>>2];p[114610]=0;b=U(2039,e|0,b|0,c|0,d|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35523,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Sca(a,b){a=a|0;b=b|0;var c=0,d=0;p[114610]=0;S(2088,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+28>>2];d=p[p[c>>2]+60>>2];p[114610]=0;b=J(d|0,c|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37456,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=-1}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Pca(a,b){a=a|0;b=b|0;var c=0,d=0;p[114610]=0;S(2088,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+28>>2];d=p[p[c>>2]+68>>2];p[114610]=0;b=J(d|0,c|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37507,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=-1}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Nma(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[c+12>>2]=p[a+4>>2];p[c+8>>2]=p[b+4>>2];a:{b:{if(!p[Cb(c+12|0,c+8|0)>>2]){break b}while(1){e=wo(n[oc(a,d)|0]);f=wo(n[oc(b,d)|0]);if((e|0)!=(f|0)){d=(e&255)>>>0<(f&255)>>>0?-1:1;break a}if(e){p[c+12>>2]=p[a+4>>2];p[c+8>>2]=p[b+4>>2];d=d+1|0;if(d>>>0>=s[Cb(c+12|0,c+8|0)>>2]){break b}continue}break}d=0;break a}d=0;if(p[a+4>>2]==p[b+4>>2]){break a}d=s[a+4>>2]<s[b+4>>2]?-1:1}fb=c+16|0;return d}function Gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;qc(a,b);p[114610]=0;N(128,d+8|0,b|0,c|0);e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}Gb(d+8|0);p[114610]=0;e=M(27,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}if(e){p[114610]=0;b=M(27,b|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}p[114610]=0;N(129,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}Gb(d)}fb=d+16|0;return}b=I()|0;H()|0;Gb(a);L(b|0);E()}function rp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=fb-32|0;fb=f;p[f+28>>2]=c;g=Hb(b,c);a:{if(!g){break a}vc(f+28|0,65535);ig(a,r[f+28>>1]);h=f,i=Ub(a),p[h+16>>2]=i;h=f,i=Vb(a),p[h+8>>2]=i;if(!Ab(f+16|0,f+8|0)){break a}while(1){a=p[f+16>>2];GIa(b,f+27|0);c=q[f+27|0];o[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}o[a>>1]=c}te(f+16|0);if(Ab(f+16|0,f+8|0)){continue}break}}fb=f+32|0;return g|0}function XI(a){var b=0;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=1163089229){break a}b=a+4|0;if((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))!=-1095062050?(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))!=-1346458146:0){break a}b=a+16|0;if(!(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))){break a}a=a+8|0;return((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))+24|0)==(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))}return 0}function aI(a){var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{if(Oj(a)>>>0<=$e(a)>>>0){break b}b=qb(a);d=$e(a);e=$e(a);p[114610]=0;b=U(1643,c+8|0,d|0,e|0,b|0)|0;d=p[114610];p[114610]=0;c:{d:{if((d|0)!=1){p[114610]=0;K(1644,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}Fr(b);break b}a=O(0)|0;H()|0;break c}a=O(0)|0;H()|0;Fr(b)}T(a|0)|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break a}}fb=c+32|0;return}a=O(0)|0;H()|0;rb(a);E()}function _H(a){var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{if(rd(a)>>>0<=Bb(a)>>>0){break b}b=qb(a);d=Bb(a);e=Bb(a);p[114610]=0;b=U(1645,c+8|0,d|0,e|0,b|0)|0;d=p[114610];p[114610]=0;c:{d:{if((d|0)!=1){p[114610]=0;K(1646,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}Er(b);break b}a=O(0)|0;H()|0;break c}a=O(0)|0;H()|0;Er(b)}T(a|0)|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break a}}fb=c+32|0;return}a=O(0)|0;H()|0;rb(a);E()}function jFa(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;n[b+12|0]=0;OP(b);REa(b);c=q[a+1|0];a:{if(!c){break a}f=0-c|0;while(1){n[d+7|0]=64;f=(f<<16>>16)+c|0;QEa(b,kp(d+8|0,f&65535,q[hc(((e<<1)+a|0)+2|0,d+7|0)|0]));e=e+1|0;if((e|0)==15){break a}c=q[((e<<1)+a|0)+1|0];if(c){continue}break}}c=q[a+32|0];n[b+14|0]=c>>>4;n[b+13|0]=c&15;a=q[a+31|0];c=a&15;n[b+15|0]=c;n[b+16|0]=c;if(a&16){n[b+12|0]=q[b+12|0]|4}if(a&32){n[b+12|0]=q[b+12|0]|2}fb=d+16|0}function _h(a,b,c,d){var e=0,f=0;p[a+20>>2]=d;p[a+16>>2]=c;p[a+12>>2]=b;p[a+4>>2]=0;p[a+8>>2]=0;p[a>>2]=79824;c=a+24|0;p[c>>2]=0;p[c+4>>2]=0;p[c+16>>2]=0;p[c+8>>2]=0;p[c+12>>2]=0;Hha(a+44|0);p[a+4196>>2]=1065353216;p[a+4200>>2]=0;b=0;o[a+4204>>1]=0;p[c>>2]=a+99&-8;e=p[a+20>>2];d=p[a+16>>2];if((e|0)!=(d+906300|0)){f=a+4200|0;while(1){a:{c=b+1|0;if(b>>>0>247){break a}b=c;if((e|0)!=((v(c,160)+d|0)+906300|0)){continue}}break}n[f|0]=c}return a}function MW(a,b){a=a|0;b=b|0;var c=0;a=Xc(a);a:{if(q[b+16|0]){p[114610]=0;J(235,a|0,7065)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}}if(q[b+17|0]){p[114610]=0;J(235,a|0,7072)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}}if(Pc(a)){p[114610]=0;J(235,a|0,7079)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}}if(q[b+18|0]){p[114610]=0;J(235,a|0,7085)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}}return}b=I()|0;H()|0;pb(a);L(b|0);E()}function s0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-160|0;fb=e;p[e+152>>2]=b;f=e+144|0;a:{b:while(1){if(c>>>0<d>>>0){p[e+8>>2]=c;if((m[p[p[a>>2]+16>>2]](a,e+144|0,c,(d-c|0)>32?c+32|0:d,e+8|0,e+16|0,f,e+12|0)|0)==2){break a}b=e+16|0;if(p[e+8>>2]==(c|0)){break a}while(1)if(b>>>0>=s[e+12>>2]){c=p[e+8>>2];continue b}else{p[e+4>>2]=p[b>>2];gC(p[e+152>>2],p[e+4>>2]);b=b+4|0;continue}}break}fb=e+160|0;return p[e+152>>2]}am(62916);E()}function Zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;f=p[c+12>>2];a:{if(!f){break a}g=n[c+16|0];e=wb(b);if(!e){break a}h=e+ -1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(q[cc(b,0)|0]==43){break b}if(q[cc(b,0)|0]==45){break b}}i=d,j=wd(b),p[i+8>>2]=j;i=d,j=lf(d+8|0,e-c|0),p[i+16>>2]=j;Ld(d+24|0,d+16|0);dw(b,p[d+24>>2],1,g)}c=c+1|0;if((e|0)!=(c|0)){continue}break}}Wc(a,b);fb=d+32|0}function ZO(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;e=r[c>>1];while(1){a:{e=e<<1;o[c>>1]=e;n[b|0]=(e&65534)>>>0>255;e=q[c|0];o[c>>1]=e;if(!e){if(!Ae(a,f+15|0)){break a}e=q[f+15|0];o[c>>1]=e<<1|1;n[b|0]=e>>>7;o[c>>1]=q[c|0]}n[d|0]=q[b|0]+(q[d|0]<<1);e=r[c>>1]<<1;o[c>>1]=e;n[b|0]=(e&65534)>>>0>255;e=q[c|0];o[c>>1]=e;if(!e){if(!Ae(a,f+14|0)){break a}e=q[f+14|0];o[c>>1]=e<<1|1;n[b|0]=e>>>7;e=q[c|0];o[c>>1]=e}if(q[b|0]){continue}}break}fb=f+16|0}function V5(a,b,c,d){var e=0,f=0,g=w(0);f=_E(a,b);a:{if((f|0)<0){break a}e=p[b>>2];a=(e|0)<(d|0)?e:d;f=v(e,f);if(q[b+22|0]){e=1;if((a|0)<1){break a}d=0;while(1){e=(d<<2)+c|0;g=w(t[p[b+28>>2]+(d+f<<2)>>2]+g);t[e>>2]=t[e>>2]+g;g=w(t[b+12>>2]+g);e=1;d=d+1|0;if((a|0)!=(d|0)){continue}break}break a}e=1;if((a|0)<1){break a}d=0;while(1){e=(d<<2)+c|0;t[e>>2]=t[e>>2]+t[p[b+28>>2]+(d+f<<2)>>2];e=1;d=d+1|0;if((a|0)!=(d|0)){continue}break}}return e}function OM(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a=Lb(a);d=wb(b);p[114610]=0;K(111,a|0,d|0);d=p[114610];p[114610]=0;if((d|0)!=1){a:{e=c,f=wd(b),p[e+8>>2]=f;e=c,f=jf(b),p[e>>2]=f;if(Ab(c+8|0,c)){while(1){b=q[p[c+8>>2]];b:{if((b|0)==13){p[114610]=0;K(110,a|0,10);break b}p[114610]=0;K(110,a|0,b<<24>>24)}b=p[114610];p[114610]=0;if((b|0)==1){break a}bg(c+8|0);if(Ab(c+8|0,c)){continue}break}}fb=c+16|0;return}}b=I()|0;H()|0;pb(a);L(b|0);E()}function CR(a){var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{if(Hf(a)>>>0<=Cc(a)>>>0){break b}b=qb(a);d=Cc(a);e=Cc(a);p[114610]=0;b=U(39,c+8|0,d|0,e|0,b|0)|0;d=p[114610];p[114610]=0;c:{d:{if((d|0)!=1){p[114610]=0;K(40,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break d}Ht(b);break b}a=O(0)|0;H()|0;break c}a=O(0)|0;H()|0;Ht(b)}T(a|0)|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)==1){break a}}fb=c+32|0;return}a=O(0)|0;H()|0;rb(a);E()}function kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;p[114610]=0;S(2015,a|0);d=p[114610];p[114610]=0;e=1;a:{b:{if((d|0)!=1){d=p[a+24>>2];p[114610]=0;N(2029,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35198,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();e=0}return e|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function nea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;p[114610]=0;S(2015,a|0);d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){d=p[a+24>>2];p[114610]=0;e=+ha(2025,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35128,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();e=0}return+e}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function nca(a){var b=0,c=0,d=0;b=fb-48|0;fb=b;GB(b+16|0);p[114610]=0;c=J(2,b|0,39480)|0;d=p[114610];p[114610]=0;a:{b:{c:{d:{if((d|0)!=1){p[114610]=0;N(251,b+32|0,b+16|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}p[114610]=0;N(9,a|0,0,b+32|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}pb(b+32|0);pb(c);pb(b+16|0);fb=b+48|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;pb(b+32|0)}pb(c)}pb(b+16|0);L(a|0);E()}function Oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=_h(a,b,c,d);p[a>>2]=80520;c=Pj(a+4256|0);d=a+4224|0;p[d>>2]=1017370378;p[d+4>>2]=1065353216;d=a+4216|0;p[d>>2]=1028670828;p[d+4>>2]=1059760811;p[a+4208>>2]=1056964608;p[a+4212>>2]=1017370378;p[114610]=0;P(1639,a+44|0,2,2)|0;d=p[114610];p[114610]=0;a:{if((d|0)==1){break a}p[114610]=0;S(1640,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}return a|0}a=I()|0;H()|0;Ef(c);Ge(b);L(a|0);E()}function yn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,n=0;d=fb-32|0;fb=d;p[d+24>>2]=0;p[d+28>>2]=0;p[d+16>>2]=0;p[d+20>>2]=0;p[d+12>>2]=c;a:{if(c){while(1){p[d+8>>2]=16;e=p[Cb(d+8|0,d+12|0)>>2];f=p[a>>2];if((e|0)!=((j=f,k=ub(d+16|0),l=p[a+8>>2]+g|0,n=e,i=p[p[f>>2]+28>>2],m[i](j|0,k|0,l|0,n|0)|0)|0)){break a}if(hd(d+16|0,b+g|0,e)){break a}f=p[d+12>>2]-e|0;p[d+12>>2]=f;g=e+g|0;if(f){continue}break}}Sb(a,c);h=1}fb=d+32|0;return h}function fx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=e;a:{if(!dj(b)){c=rK(a,c,p[b+704>>2],d);break a}c=p[b+700>>2]}p[f+12>>2]=c;b=p[b+656>>2];b:{if(!b){break b}f=p[b+40>>2];if(!f){break b}d=(f|0)/2|0;b=p[a+1074420>>2];b=NNa(b,b>>31,c,c>>31);c=d+b|0;d=ib+(d>>31)|0;g=e,h=rc(ONa(c,c>>>0<b>>>0?d+1|0:d,f,f>>31),ib),p[g+12>>2]=h}vc(e+12|0,2147483647);a=ONa(0,p[e+12>>2],p[a+24620>>2]<<4,0);fb=e+16|0;return a|0}function ZE(a){var b=w(0),c=0,d=w(0),e=w(0),f=w(0),g=w(0),h=0,i=w(0),j=0,k=0,l=w(0),m=w(0),n=w(0),o=w(0),p=0;j=a+ -24|0;b=t[j>>2];c=a+ -8|0;d=t[c>>2];e=w(b+d);k=a+ -16|0;f=t[k>>2];l=t[a>>2];g=w(f+l);t[a>>2]=e+g;t[c>>2]=g-e;c=a+ -28|0;g=t[c>>2];h=a+ -12|0;m=t[h>>2];e=w(g+m);p=h;h=a+ -20|0;i=t[h>>2];a=a+ -4|0;n=t[a>>2];o=w(i+n);t[p>>2]=o-e;i=w(n-i);b=w(d-b);t[c>>2]=i+b;d=w(m-g);f=w(l-f);t[k>>2]=d+f;t[j>>2]=f-d;t[a>>2]=o+e;t[h>>2]=i-b}function Qda(a,b){a=a|0;b=b|0;var c=0,d=w(0);p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;d=w(ia(2050,c|0,b|0));b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35877,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=w(0)}return w(d)}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Pda(a,b){a=a|0;b=b|0;var c=0,d=w(0);p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;d=w(ia(2051,c|0,b|0));b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35920,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=w(0)}return w(d)}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Oda(a,b){a=a|0;b=b|0;var c=0,d=w(0);p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;d=w(ia(2052,c|0,b|0));b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35963,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=w(0)}return w(d)}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Nda(a,b){a=a|0;b=b|0;var c=0,d=w(0);p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;d=w(ia(2053,c|0,b|0));b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36007,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=w(0)}return w(d)}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Mda(a,b){a=a|0;b=b|0;var c=0,d=w(0);p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;d=w(ia(2054,c|0,b|0));b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36055,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=w(0)}return w(d)}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function _ca(a){a=a|0;var b=0,c=0,d=0;p[114610]=0;S(2088,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+28>>2];d=p[p[b>>2]+28>>2];p[114610]=0;c=+ea(d|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37307,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();c=0}return+c}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Yca(a){a=a|0;var b=0,c=0,d=0;p[114610]=0;S(2088,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+28>>2];d=p[p[b>>2]+36>>2];p[114610]=0;c=+ea(d|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37341,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();c=0}return+c}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Wca(a){a=a|0;var b=0,c=0,d=0;p[114610]=0;S(2088,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+28>>2];d=p[p[b>>2]+44>>2];p[114610]=0;c=+ea(d|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37376,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();c=0}return+c}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function BL(a,b){var c=0,d=0,e=0,f=0;o[a+24>>1]=0;p[a+20>>2]=0;p[a>>2]=0;p[a+4>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;e=a;d=3546895/+(b>>>0);c=d*.25;a:{if(x(c)<2147483648){b=~~c;break a}b=-2147483648}p[e+16>>2]=b;c=(d- +(b<<2))*4294967296;b:{if(x(c)<0x8000000000000000){f=~~c>>>0;b=x(c)>=1?c>0?~~z(B(c/4294967296),4294967295)>>>0:~~C((c- +(~~c>>>0>>>0))/4294967296)>>>0:0;break b}b=-2147483648}p[a>>2]=0;p[a+4>>2]=0;p[a+8>>2]=f;p[a+12>>2]=b}function moa(a){var b=0,c=0;while(1){_m((v(b,896)+a|0)+1074984|0,a,b&65535);b=b+1|0;if((b|0)!=256){continue}break}$i(a+1304360|0,1);p[a+1074444>>2]=p[a+480200>>2];b=a+1074416|0;p[b>>2]=p[a+480196>>2];p[a+1074420>>2]=p[a+480204>>2];p[a+480208>>2]=p[a+480208>>2]&-769;Ex(a+1074376|0);o[a+1074440>>1]=0;c=a+1074428|0;p[c>>2]=0;p[c+4>>2]=0;c=a+1074396|0;p[c>>2]=0;p[c+4>>2]=0;p[a+1074376>>2]=0;p[a+1074380>>2]=0;p[a+1074392>>2]=p[b>>2]}function Xea(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;a:{b:{if(!a){break b}a=ic(b+8|0,a);p[114610]=0;c=p[a+4>>2];p[b>>2]=p[a>>2];p[b+4>>2]=c;a=M(1996,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break a}a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;Q(1989,34140,0,0,0);a=p[114610];p[114610]=0;if((a|0)!=1){V();break b}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}a=0}fb=b+16|0;return a|0}function Gpa(a,b,c,d,e){var f=0,g=0;if(q[a+480209|0]&16){if((c&255)>>>0>=16){n[b+869|0]=(c&240)>>>4}a=c&15;if(a){n[b+870|0]=a}n[b+868|0]=q[b+869|0];return}c=q[b+868|0]+ -1|0;n[b+868|0]=c;a:{if(c&255){break a}n[b+868|0]=q[b+869|0];c=q[b+870|0];c=d?c:0-c|0;b:{if(dj(b)){p[b+876>>2]=p[b+876>>2]+v(c,p[p[p[b+656>>2]+44>>2]+36>>2]);break b}f=b,g=dg(a,Xr(a,p[b+700>>2],0,0)+c|0,8363,0),p[f+700>>2]=g}if(!e){break a}p[b>>2]=0;p[b+4>>2]=0}}function ofa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;n[a+4202|0]=1;b=ji(w(w(He(p[a+16>>2])>>>0)*w(.04500000178813934)));c=ji(w(w(b>>>0)*w(1.1892070770263672)));d=ji(w(w(c>>>0)*w(1.1892070770263672)));g=ji(w(w(d>>>0)*w(1.1892070770263672)));e=ji(w(w(b+d>>>0)*w(.11546666920185089)));f=ji(w(w(c+g>>>0)*w(.11546666920185089)));p[a+4292>>2]=f;p[a+4288>>2]=e;p[a+4276>>2]=d-e;p[a+4272>>2]=b-e;p[a+4284>>2]=g-f;p[a+4280>>2]=c-f;eH(a);cH(a)}function Ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=_h(a,b,c,d);p[a>>2]=79416;d=Pj(a+4208|0);p[a+4220>>2]=0;p[a+4224>>2]=0;e=a,f=He(c),p[e+4232>>2]=f;p[114610]=0;S(1638,a+4260|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;P(1639,a+44|0,2,2)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}p[114610]=0;S(1640,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}return a|0}a=I()|0;H()|0;Ef(d);Ge(b);L(a|0);E()}function Ms(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(q[Yb(a,0)|0]&15)<<8|q[Yb(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=r[(c<<1)+20784>>1];if(d>>>0>=f>>>0){if(!(!c|(d|0)==(f|0)|(r[(c<<1)+20782>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}n[b|0]=e;c=q[Yb(a,2)|0];g=b,h=q[Yb(a,0)|0]&16|c>>>4,n[g+1|0]=h;g=b,h=q[Yb(a,2)|0]&15,n[g+3|0]=h;g=b,h=q[Yb(a,3)|0],n[g+5|0]=h}function uea(a,b){a=a|0;b=b|0;var c=0,d=0;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;d=1;a:{b:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;K(2018,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34890,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=0}return d|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function sea(a,b){a=a|0;b=b|0;var c=0,d=0;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;d=1;a:{b:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;K(2020,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34956,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();d=0}return d|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function rIa(a,b){var c=0;vd(b,0);c=a+32|0;p[b>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+38|0;p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+42|0;c=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);p[b+24>>2]=16726;p[b+8>>2]=c;o[b+30>>1]=q[a+37|0]<<4;if(n[a+46|0]&1){p[b>>2]=p[b>>2]>>>1;p[b+4>>2]=p[b+4>>2]>>>1;p[b+8>>2]=p[b+8>>2]>>>1}if(!(!(q[a+47|0]&8)|s[b+8>>2]<=s[b+4>>2])){o[b+34>>1]=r[b+34>>1]|2}}function Wxa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;a:{b:{if(c>>>0>d>>>0){break b}if(ke(b)>>>0<=d>>>0){break b}while(1){f=c&65535;if(Ch(De(b,f))){h=Ub(De(b,f));i=Vb(De(b,f));f=bN(g,e);p[114610]=0;Q(1032,g+24|0,h|0,i|0,f|0);h=p[114610];p[114610]=0;if((h|0)==1){break a}ce(g+24|0);ce(f)}c=c+1|0;if((c&65535)>>>0<=d>>>0){continue}break}}aN(a,e);fb=g+48|0;return}a=I()|0;H()|0;ce(f);L(a|0);E()}function Vz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,n=0;d=fb-32|0;fb=d;p[d+24>>2]=0;p[d+28>>2]=0;p[d+16>>2]=0;p[d+20>>2]=0;p[d+12>>2]=c;a:{if(c){while(1){p[d+8>>2]=16;e=p[Cb(d+8|0,d+12|0)>>2];if((e|0)!=((j=a,k=ub(d+16|0),l=p[a+12>>2]+f|0,n=e,i=p[p[a>>2]+28>>2],m[i](j|0,k|0,l|0,n|0)|0)|0)){break a}if(hd(d+16|0,b+f|0,e)){break a}g=p[d+12>>2]-e|0;p[d+12>>2]=g;f=e+f|0;if(g){continue}break}}Qc(a,c);h=1}fb=d+32|0;return h}function w8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;Fi(c,b);p[a+44>>2]=0;b=p[a+48>>2];if(b&8){d=a,e=Ib(c)+wb(c)|0,p[d+44>>2]=e;Bm(a,Ib(c),Ib(c),p[a+44>>2]);b=p[a+48>>2]}a:{if(!(b&16)){break a}b=wb(c);d=a,e=b+Ib(c)|0,p[d+44>>2]=e;ym(c,Bc(c));ow(a,Ib(c),Ib(c)+wb(c)|0);if(!(q[a+48|0]&3)){break a}b:{if((b|0)<=-1){c=b+ -2147483647|0;while(1){b=c;qr(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}qr(a,b)}}function b5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((f|0)>=(c|0)){break a}d=p[a+12>>2];g=p[a+16>>2];b:{if(d>>>0<g>>>0){p[e+12>>2]=2147483647;p[e+8>>2]=g-d>>2;p[e+4>>2]=c-f;d=p[Yd(e+12|0,Yd(e+8|0,e+4|0))>>2];Rh(b,p[a+12>>2],d);p[a+12>>2]=p[a+12>>2]+(d<<2);b=(d<<2)+b|0;break b}d=m[p[p[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}p[b>>2]=d;d=1;b=b+4|0}f=d+f|0;continue}break}fb=e+16|0;return f|0}function j6(a){var b=0,c=0,d=0,e=0;Jb(a+36|0,255,2048);b=p[(q[a+23|0]?2092:4)+a>>2];if((b|0)>=1){b=(b|0)<32767?b:32767;e=(b|0)>1?b:1;d=p[a+8>>2];while(1){a:{if(q[c+d|0]>10){break a}b:{if(q[a+23|0]){b=Yk(p[p[a+2084>>2]+(c<<2)>>2]);break b}b=p[p[a+32>>2]+(c<<2)>>2]}if(b>>>0>1023){break a}while(1){o[((b<<1)+a|0)+36>>1]=c;d=p[a+8>>2];b=(1<<q[d+c|0])+b|0;if(b>>>0<1024){continue}break}}c=c+1|0;if((e|0)!=(c|0)){continue}break}}}function gI(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a:{if(Bb(a)>>>0>511){break a}if(!tf(p[p[b>>2]+ -12>>2]+b|0)){break a}aja(d+8|0,b,c);b:{c:{if(!kd(d+8|0)){p[114610]=0;N(1631,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break c}uQ(d+8|0,Cd(d));Qf(d)}if(!kd(d+8|0)){break b}e=p[d+8>>2];p[114610]=0;K(1632,a|0,d+8|0);a=p[114610];p[114610]=0;if((a|0)!=1){break b}}a=I()|0;H()|0;Qf(d+8|0);L(a|0);E()}Qf(d+8|0)}fb=d+16|0;return e}function eca(a){var b=0,c=0,d=0;b=fb-48|0;fb=b;c=Mb(b+16|0,39485);p[114610]=0;K(2121,b|0,2);d=p[114610];p[114610]=0;a:{b:{c:{d:{if((d|0)!=1){p[114610]=0;N(3,b+32|0,c|0,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break d}p[114610]=0;N(9,a|0,0,b+32|0);a=p[114610];p[114610]=0;if((a|0)==1){break c}pb(b+32|0);pb(b);pb(c);fb=b+48|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;break b}a=I()|0;H()|0;pb(b+32|0)}pb(b)}pb(c);L(a|0);E()}function p8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;tm(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;n8(c+16|0,c,b,a,f);fb=c+80|0}function o8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;tm(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;l8(c+16|0,c,b,a,f);fb=c+80|0}function j8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;tm(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;g8(c+16|0,c,b,a,f);fb=c+80|0}function i8(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;tm(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;e8(c+16|0,c,b,a,f);fb=c+80|0}function f5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;while(1){a:{if((f|0)>=(c|0)){break a}d=p[a+12>>2];g=p[a+16>>2];b:{if(d>>>0<g>>>0){p[e+12>>2]=2147483647;p[e+8>>2]=g-d;p[e+4>>2]=c-f;d=p[Yd(e+12|0,Yd(e+8|0,e+4|0))>>2];uh(b,p[a+12>>2],d);p[a+12>>2]=p[a+12>>2]+d;break b}d=m[p[p[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=zm(d),n[h|0]=i;d=1}b=b+d|0;f=d+f|0;continue}break}fb=e+16|0;return f|0}function er(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;lo(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;Z7(c+16|0,c,b,a,f);fb=c+80|0}function _7(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;lo(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;Y7(c+16|0,c,b,a,f);fb=c+80|0}function Yv(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;tm(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;m8(c+16|0,c,b,a,f);fb=c+80|0}function Xv(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;tm(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;f8(c+16|0,c,b,a,f);fb=c+80|0}function Wv(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;lo(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;T7(c+16|0,c,b,a,f);fb=c+80|0}function W7(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;lo(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;U7(c+16|0,c,b,a,f);fb=c+80|0}function V7(a,b){var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=p[a>>2];f=p[d+4>>2];p[c+40>>2]=p[d+20>>2];e=p[d+16>>2];p[c+32>>2]=p[d+12>>2];p[c+36>>2]=e;lo(c- -64|0,c+32|0,f);d=ee(c+48|0,p[p[a+4>>2]>>2],p[p[a+8>>2]>>2],p[p[a+12>>2]>>2]);f=p[p[a+12>>2]>>2];a=p[p[a+8>>2]>>2];p[c+24>>2]=p[c+72>>2];e=p[c+68>>2];p[c+16>>2]=p[c+64>>2];p[c+20>>2]=e;p[c+8>>2]=p[d+8>>2];e=p[d+4>>2];p[c>>2]=p[d>>2];p[c+4>>2]=e;S7(c+16|0,c,b,a,f);fb=c+80|0}function zda(a,b){a=a|0;b=b|0;var c=0;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;b=J(2068,c|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36503,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function yda(a,b){a=a|0;b=b|0;var c=0;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;b=J(2069,c|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36536,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function vd(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;Zm(a);p[a+16>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;p[a>>2]=0;p[a+4>>2]=0;o[a+32>>1]=64;p[a+24>>2]=8363;p[a+28>>2]=16777344;p[a+36>>2]=0;n[a+39|0]=0;n[a+40|0]=0;n[a+41|0]=0;n[a+42|0]=0;c=r[a+34>>1]&-25151;o[a+34>>1]=(b|0)==4?c|32:c;b=Mb(d,18468);p[114610]=0;J(370,a+43|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(b);xM(a);fb=d+16|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function mBa(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+24|0]=0;n[a+25|0]=0;n[a+26|0]=0;n[a+27|0]=0;n[a+28|0]=0;n[a+29|0]=0;n[a+30|0]=0;n[a+31|0]=0;n[a+16|0]=0;n[a+17|0]=0;n[a+18|0]=0;n[a+19|0]=0;n[a+20|0]=0;n[a+21|0]=0;n[a+22|0]=0;n[a+23|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;fb=b+16|0}function dxa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=fb-16|0;fb=b;g=p[a+24>>2];h=p[a+20>>2];i=p[a+16>>2];e=p[a+4>>2];f=p[a>>2];p[b+8>>2]=f;p[b+12>>2]=e;j=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=j;if(d){while(1){e=o[(e<<1)+i>>1];p[c>>2]=p[c>>2]+v(e,h);p[c+4>>2]=p[c+4>>2]+v(e,g);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;e=p[b+12>>2];continue}break}f=p[b+8>>2];e=p[b+12>>2]}p[a>>2]=f;p[a+4>>2]=e;fb=b+16|0}function yo(a,b,c){var d=0,e=0;a=Ue(a);d=wb(b);p[114610]=0;K(113,a|0,d|0);d=p[114610];p[114610]=0;if((d|0)!=1){a:{if(wb(b)){while(1){d=q[cc(b,e)|0];b:{if(256>d>>>0){d=p[(d<<2)+c>>2];p[114610]=0;K(112,a|0,d|0);d=p[114610];p[114610]=0;if((d|0)!=1){break b}break a}p[114610]=0;K(112,a|0,65533);d=p[114610];p[114610]=0;if((d|0)==1){break a}}e=e+1|0;if(e>>>0<wb(b)>>>0){continue}break}}return}}b=I()|0;H()|0;yc(a);L(b|0);E()}function Saa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){b=W(8)|0;p[114610]=0;c=J(85,f|0,38601)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}Yh(a,b,2);c=gw(a,c,d,e,0,0);u[a+16>>3]=+(c>>>0)/+(b|0)+u[a+16>>3];fb=f+16|0;return c|0}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function Paa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){b=W(8)|0;p[114610]=0;c=J(85,f|0,38601)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}Yh(a,b,2);c=fw(a,c,d,e,0,0);u[a+16>>3]=+(c>>>0)/+(b|0)+u[a+16>>3];fb=f+16|0;return c|0}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function KO(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+22|0]=0;n[a+23|0]=0;n[a+24|0]=0;n[a+25|0]=0;n[a+26|0]=0;n[a+27|0]=0;n[a+28|0]=0;n[a+29|0]=0;n[a+16|0]=0;n[a+17|0]=0;n[a+18|0]=0;n[a+19|0]=0;n[a+20|0]=0;n[a+21|0]=0;n[a+22|0]=0;n[a+23|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;fb=b+16|0}function pea(a,b){a=a|0;b=+b;var c=0;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=p[a+24>>2];p[114610]=0;b=+bb(2023,c|0,+b);c=p[114610];p[114610]=0;if((c|0)!=1){break b}}c=O(0)|0;H()|0;T(c|0)|0;p[114610]=0;Q(1989,35056,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return+b}a=I()|0;H()|0;p[114610]=0;R(20);c=p[114610];p[114610]=0;if((c|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function RA(a){var b=0;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=1179340888|(q[a+8|0]|q[a+9|0]<<8|(q[a+10|0]<<16|q[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))){break a}a=a+12|0;if(!(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))){break a}a=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);return(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0>27}return 0}function Jda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2057,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36168,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}



function Hpa(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){n[b+836|0]=c;break a}c=q[b+836|0]}b:{c:{d:{e=c&240;d=c&15;if(!(!e|(d|0)!=15)){if(!(q[a+480209|0]&16)){break b}break d}f=p[a+480208>>2]&4096;if(!(!d|(e|0)!=240)){if(!f){break b}c=0-d|0;break c}if(f){break b}if(!d){break d}c=0-d|0;if(!e){break c}if(p[a+480180>>2]&25690144){break b}break c}c=(c&255)>>>4|0;if(!c){break b}}g=b,h=Pb(p[b+760>>2]+c|0,0,64),p[g+760>>2]=h}}function exa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=fb-16|0;fb=b;g=p[a+24>>2];h=p[a+20>>2];i=p[a+16>>2];e=p[a+4>>2];f=p[a>>2];p[b+8>>2]=f;p[b+12>>2]=e;j=p[a+12>>2];p[b>>2]=p[a+8>>2];p[b+4>>2]=j;if(d){while(1){e=n[e+i|0]<<8;p[c>>2]=p[c>>2]+v(e,h);p[c+4>>2]=p[c+4>>2]+v(e,g);Kb(b+8|0,b);d=d+ -1|0;if(d){c=c+8|0;e=p[b+12>>2];continue}break}f=p[b+8>>2];e=p[b+12>>2]}p[a>>2]=f;p[a+4>>2]=e;fb=b+16|0}function K6(a,b){var c=0,d=0,e=0;a:{b:{c:{c=q[a+3|0];e=c>>>6|0;switch(e+ -1|0){case 2:break a;case 0:break c;default:break b}}d=(c>>>2&12)+4|0;break a}d=32}c=q[a+1|0];d:{if((c&6)==6){a=32;c=50108;break d}if(!(c&8)){a=30;c=50111;break d}c=q[a+2|0]>>>2&3;a=Rv(a)>>>((e|0)!=3)|0;a=a?a:192;if(a>>>0<=55){a=(c|0)==2?12:8;c=50132;break d}a=(c|0)!=1?a>>>0>95?30:27:27;c=50120}n[b+768|0]=a;n[b+769|0]=(d|0)>(a|0)?a:d;return c}function xu(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if((b^-1)+ -17>>>0>=c>>>0){j=Ib(a);a:{if(2147483623>b>>>0){p[i+8>>2]=b<<1;p[i+12>>2]=b+c;c=Ok(p[Uc(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=Si(k);if(e){uh(c,j,e)}if(g){uh(c+e|0,h,g)}d=d-f|0;h=d-e|0;if(h){uh((c+e|0)+g|0,(e+j|0)+f|0,h)}b=b+1|0;if((b|0)!=11){cg(a,j,b)}sf(a,c);sg(a,k);b=a;a=d+g|0;oe(b,a);n[i+7|0]=0;ae(a+c|0,i+7|0);fb=i+16|0;return}tg();E()}function Jv(a){var b=0,c=0,d=0;a:{b:{if(!p[a+1384>>2]){b=p[a+1380>>2];if((b|0)==-1){p[a+1388>>2]=p[a+1116>>2]+ -1;if(!ar(a)){p[a+1384>>2]=1;return 0}if(!(n[a+1375|0]&1)){break b}b=p[a+1380>>2]}d=b+1|0;p[a+1380>>2]=d;c=q[(a+b|0)+1120|0];if((c|0)!=255){p[a+1388>>2]=b;p[a+1384>>2]=1}if((d|0)>=p[a+1116>>2]){p[a+1380>>2]=-1}if(q[a+1376|0]){break a}n[a+1376|0]=c}return c}Wb(a,32);return 0}aa(50534,50416,1549,50555);E()}function BY(){var a=0,b=0,c=0,d=0,e=0,f=0;a=fb-48|0;fb=a;a:{b=p[115917];if(b){c=b+48|0;if(aC(c)){d=a;if(p[c>>2]==1126902529&p[c+4>>2]==1129074247){c=p[b+44>>2]}else{c=b+80|0}p[d+44>>2]=c;d=p[b>>2];b=p[d+4>>2];if(m[p[p[17831]+16>>2]](71324,d,a+44|0)|0){break a}p[a+20>>2]=b;p[a+16>>2]=p[21328];E()}p[a+32>>2]=p[21328];E()}E()}c=p[21328];d=p[a+44>>2];e=a,f=m[p[p[d>>2]+8>>2]](d)|0,p[e+8>>2]=f;p[a+4>>2]=b;p[a>>2]=c;E()}function tea(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2019,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34920,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=-1}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function oDa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;tl(e+24|0,e+16|0,c);p[114610]=0;N(874,e+36|0,e+8|0,d|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;K(672,e|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(518,a|0,b|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}We(e+24|0);fb=e+48|0;return}c=I()|0;H()|0;pb(e+24|0);break a}c=I()|0;H()|0;We(e+24|0)}L(c|0);E()}function _ta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;mz(e+24|0,e+16|0,c);p[114610]=0;N(671,e+36|0,e+8|0,d|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;K(672,e|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(518,a|0,b|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}We(e+24|0);fb=e+48|0;return}c=I()|0;H()|0;pb(e+24|0);break a}c=I()|0;H()|0;We(e+24|0)}L(c|0);E()}function Sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;ft(d,2,a+2|0);zc(d+16|0,d);p[114610]=0;J(369,b+492|0,d+16|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){pb(d+16|0);e=b+236|0;f=c+1|0;c=0;while(1){g=q[(a+c|0)+31|0];h=Yc(e,c),i=f+g|0,o[h>>1]=i;c=c+1|0;if(c>>>0<120){continue}break}c=a+223|0;p[b>>2]=(q[c|0]|q[c+1|0]<<8)<<5;Jla(a+158|0,b);fb=d+32|0;return}a=I()|0;H()|0;pb(d+16|0);L(a|0);E()}function rea(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2021,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34988,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function bfa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;f=p[a+4160>>2];g=p[a+4156>>2];if(d){j=p[a+4164>>2];e=p[a+4168>>2];while(1){h=p[b>>2];i=p[b+4>>2];e=e-i|0;f=(((e|0)/1024|0)-e|0)+f|0;p[c+4>>2]=f+p[c+4>>2];e=j-h|0;e=(((e|0)/1024|0)-e|0)+g|0;p[c>>2]=e+p[c>>2];f=f+((f|0)/-512|0)|0;g=e+((e|0)/-512|0)|0;c=c+8|0;b=b+8|0;e=i;j=h;d=d+ -1|0;if(d){continue}break}}p[a+4168>>2]=i;p[a+4164>>2]=h;p[a+4160>>2]=f;p[a+4156>>2]=g}function Wda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2044,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35668,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Vda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2045,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35701,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Uda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2046,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35734,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Tda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2047,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35767,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Sda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2048,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35802,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Rda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2049,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35833,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Lda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2055,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36104,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Kda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2056,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36136,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Ida(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2058,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36198,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Hda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2059,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36230,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Gda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;b=M(2060,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,36265,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();b=0}return b|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function nKa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;On(e+24|0,e+16|0,c);p[114610]=0;N(240,e+36|0,e+8|0,d|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;K(78,e|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(72,a|0,b|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}We(e+24|0);fb=e+48|0;return}c=I()|0;H()|0;pb(e+24|0);break a}c=I()|0;H()|0;We(e+24|0)}L(c|0);E()}function ls(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;p[b+40>>2]=0;p[b+44>>2]=0;e=b- -64|0;p[e>>2]=0;p[e+4>>2]=0;p[b+56>>2]=0;p[b+60>>2]=0;p[b+48>>2]=0;p[b+52>>2]=0;while(1){DL(b,u[Fk(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=d,h=Ub(c),p[g+8>>2]=h;g=d,h=Vb(c),p[g>>2]=h;if(Ab(d+8|0,d)){while(1){e=p[d+8>>2];g=e,i=DL(b,u[e>>3]),u[g>>3]=i;Sx(d+8|0);if(Ab(d+8|0,d)){continue}break}}Lsa(a,c);fb=d+16|0}function kMa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;gA(e+24|0,e+16|0,c);p[114610]=0;N(444,e+36|0,e+8|0,d|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;K(78,e|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(72,a|0,b|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}We(e+24|0);fb=e+48|0;return}c=I()|0;H()|0;pb(e+24|0);break a}c=I()|0;H()|0;We(e+24|0)}L(c|0);E()}function CHa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;On(e+24|0,e+16|0,c);p[114610]=0;N(224,e+36|0,e+8|0,d|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;K(78,e|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(72,a|0,b|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}We(e+24|0);fb=e+48|0;return}c=I()|0;H()|0;pb(e+24|0);break a}c=I()|0;H()|0;We(e+24|0)}L(c|0);E()}function qea(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;c=+ea(2022,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35020,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();c=0}return+c}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function qBa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;qO(e+24|0,e+16|0,c);p[114610]=0;N(77,e+36|0,e+8|0,d|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;K(78,e|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(72,a|0,b|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}We(e+24|0);fb=e+48|0;return}c=I()|0;H()|0;pb(e+24|0);break a}c=I()|0;H()|0;We(e+24|0)}L(c|0);E()}function oea(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;c=+ea(2024,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35092,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();c=0}return+c}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function cha(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;f=b,g=Ub(a),p[f+8>>2]=g;f=b,g=Vb(a),p[f>>2]=g;if(Ab(b+8|0,b)){while(1){e=p[b+8>>2];a:{while(1){c=p[e>>2];d=p[c>>2];if(!d){break a}c=p[p[d>>2]+8>>2];p[114610]=0;S(c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}b=O(0)|0;H()|0;ww(a);rb(b);E()}if(c){yb(c+20|0);yb(c+8|0);Nb(c)}Rd(b+8|0);if(Ab(b+8|0,b)){continue}break}}ww(a);fb=b+16|0;return a}function Xda(a){a=a|0;var b=0,c=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=p[a+24>>2];p[114610]=0;c=+ea(2043,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,35627,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();c=0}return+c}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function WW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;tl(e+24|0,e+16|0,c);p[114610]=0;N(224,e+36|0,e+8|0,d|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;K(78,e|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(72,a|0,b|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}We(e+24|0);fb=e+48|0;return}c=I()|0;H()|0;pb(e+24|0);break a}c=I()|0;H()|0;We(e+24|0)}L(c|0);E()}function K2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-32|0;fb=e;a:{if((b|0)!=(c|0)){j=p[114584];p[114584]=0;vZ(e,b,e+28|0);b=p[e+8>>2];f=p[e+12>>2];g=p[e>>2];h=p[e+4>>2];i=p[114584];b:{if(i){if(p[e+28>>2]!=(c|0)){break b}if((i|0)!=68){break a}p[d>>2]=4;break a}p[114584]=j;if(p[e+28>>2]==(c|0)){break a}}}p[d>>2]=4;g=0;h=0;b=0;f=0}p[a>>2]=g;p[a+4>>2]=h;p[a+8>>2]=b;p[a+12>>2]=f;fb=e+32|0}function fba(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=fb+ -64|0;fb=d;e=p[a>>2];f=p[a+4>>2];g=p[a+12>>2];a=p[a+8>>2];p[d+16>>2]=a;p[d+20>>2]=g;p[d+32>>2]=e;p[d+36>>2]=f;p[d+8>>2]=e;p[d+12>>2]=f;p[d+40>>2]=a;p[d+44>>2]=g;uG(d+48|0,d+8|0);a=no(d+24|0,c);p[114610]=0;b=+ra(2161,d+48|0,+b,a|0);c=p[114610];p[114610]=0;if((c|0)!=1){Nc(a);sb(d+48|0);fb=d- -64|0;return+b}c=I()|0;H()|0;Nc(a);sb(d+48|0);L(c|0);E()}function kma(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-32|0;fb=e;a:{b:{if(0>c>>>0){break b}if(ke(b)>>>0<=c>>>0){break b}f=p[d>>2];g=p[d+4>>2];while(1){d=h&65535;if(Ch(De(b,d))){i=Ub(De(b,d));j=Vb(De(b,d));d=e;p[d+24>>2]=f;p[d+28>>2]=g;p[d+8>>2]=f;p[d+12>>2]=g;jma(d+16|0,i,j,d+8|0)}h=h+1|0;if((h&65535)>>>0<=c>>>0){continue}break}p[a>>2]=f;p[a+4>>2]=g;break a}b=p[d+4>>2];p[a>>2]=p[d>>2];p[a+4>>2]=b}fb=e+32|0}function BHa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;Via(e+24|0,c);p[114610]=0;N(671,e+36|0,e+8|0,d|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;K(672,e|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(518,a|0,b|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}We(e+24|0);fb=e+48|0;return}c=I()|0;H()|0;pb(e+24|0);break a}c=I()|0;H()|0;We(e+24|0)}L(c|0);E()}function BF(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){if((al(a+8|0)|0)>(b|0)){break d}}a=W(8)|0;p[114610]=0;c=J(85,c|0,40569)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(c);break b}fb=c+16|0;return+(+p[(p[a+32>>2]+v(b,896)|0)+1075744>>2]*.015625)}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function ila(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;i=p[a+4>>2];d=v((i-d|0)/6|0,6)+b|0;e=tp(g,a,(c-d|0)/6|0);a:{if(c>>>0>d>>>0){f=d;while(1){h=qb(a);j=p[e+4>>2];p[114610]=0;N(1566,h|0,j|0,f|0);h=p[114610];p[114610]=0;if((h|0)==1){break a}p[e+4>>2]=p[e+4>>2]+6;f=f+6|0;if(f>>>0<c>>>0){continue}break}}Db(e);a=d-b|0;if(a){Ji(v((a|0)/-6|0,6)+i|0,b,a)}fb=g+16|0;return}a=I()|0;H()|0;Db(e);L(a|0);E()}function cba(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=fb-32|0;fb=b;p[b+24>>2]=e;p[b+28>>2]=f;a:{a=Qr(a,yl(b+16|0,ub(c),d),b+24|0);if(a+1>>>0>=3){a=W(8)|0;p[114610]=0;b=J(85,b|0,38544)|0;c=p[114610];p[114610]=0;b:{if((c|0)!=1){dc(a,b);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}d=I()|0;H()|0;pb(b);break b}d=I()|0;H()|0;X(a|0)}L(d|0);E()}fb=b+32|0;return a|0}E()}function d5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;while(1){a:{if((f|0)>=(c|0)){break a}d=p[a+24>>2];g=p[a+28>>2];if(d>>>0>=g>>>0){if(((i=a,j=og(n[b|0]),h=p[p[a>>2]+52>>2],m[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{p[e+12>>2]=g-d;p[e+8>>2]=c-f;d=p[Yd(e+12|0,e+8|0)>>2];uh(p[a+24>>2],b,d);p[a+24>>2]=d+p[a+24>>2];f=f+d|0;b=b+d|0}continue}break}fb=e+16|0;return f|0}function av(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-160|0;fb=e;Jb(e+16|0,0,144);p[e+92>>2]=-1;p[e+60>>2]=b;p[e+24>>2]=-1;p[e+20>>2]=b;Rg(e+16|0,0,0);RD(e,e+16|0,d,1);d=p[e+8>>2];g=p[e+12>>2];h=p[e>>2];i=p[e+4>>2];if(c){j=c;f=b;b=p[e+20>>2]-p[e+24>>2]|0;k=b;c=b+p[e+136>>2]|0;b=p[e+140>>2]+(b>>31)|0;b=c>>>0<k>>>0?b+1|0:b;p[j>>2]=!(b|c)?f:f+c|0}p[a>>2]=h;p[a+4>>2]=i;p[a+8>>2]=d;p[a+12>>2]=g;fb=e+160|0}function zF(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){if((al(a+8|0)|0)>(b|0)){break d}}a=W(8)|0;p[114610]=0;c=J(85,c|0,40569)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(c);break b}fb=c+16|0;return(q[(p[a+32>>2]+v(b,896)|0)+1075073|0]&4)>>>2|0}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function eda(a){a=a|0;var b=0;p[114610]=0;S(2088,a|0);b=p[114610];p[114610]=0;if((b|0)!=1){p[a+24>>2]=0;b=p[a+28>>2];if(b){m[p[p[b>>2]+4>>2]](b)}p[a+28>>2]=0;b=p[a+20>>2];if(b){Nb(b)}Nb(a);return}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37197,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)!=1){V();return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Toa(a,b){var c=0,d=0;a=Lb(a);c=wb(b);p[114610]=0;K(111,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){a:{if(wb(b)){while(1){c=p[Ui(b,d)>>2];b:{if(c>>>0<=127){p[114610]=0;K(110,a|0,c<<24>>24);c=p[114610];p[114610]=0;if((c|0)!=1){break b}break a}p[114610]=0;K(110,a|0,63);c=p[114610];p[114610]=0;if((c|0)==1){break a}}d=d+1|0;if(d>>>0<wb(b)>>>0){continue}break}}return}}b=I()|0;H()|0;pb(a);L(b|0);E()}function RLa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;yS(e+24|0,c);p[114610]=0;N(224,e+36|0,e+8|0,d|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;K(78,e|0,e+24|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}p[114610]=0;N(72,a|0,b|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}We(e+24|0);fb=e+48|0;return}c=I()|0;H()|0;pb(e+24|0);break a}c=I()|0;H()|0;We(e+24|0)}L(c|0);E()}function Noa(a,b){var c=0,d=0;a=Lb(a);c=wb(b);p[114610]=0;K(111,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){a:{if(wb(b)){while(1){c=p[Ui(b,d)>>2];b:{if(c>>>0<=255){p[114610]=0;K(110,a|0,c<<24>>24);c=p[114610];p[114610]=0;if((c|0)!=1){break b}break a}p[114610]=0;K(110,a|0,63);c=p[114610];p[114610]=0;if((c|0)==1){break a}}d=d+1|0;if(d>>>0<wb(b)>>>0){continue}break}}return}}b=I()|0;H()|0;pb(a);L(b|0);E()}function MKa(a,b){var c=0,d=0,e=0;yp(a);n[a+8|0]=0;p[a+4>>2]=b;p[a>>2]=76400;b=xi(a+12|0);n[a+24|0]=0;p[114610]=0;J(35,a+28|0,0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){b=a+40|0;c=b+192|0;while(1){p[b>>2]=0;p[b+4>>2]=0;n[b+8|0]=0;b=b+12|0;if((c|0)!=(b|0)){continue}break}if(q[a+24|0]){a=a+232|0;b=0;while(1){d=nf(a,b),e=b,p[d>>2]=e;b=b+1|0;if((b|0)!=16){continue}break}}return}a=I()|0;H()|0;Gg(b);L(a|0);E()}function Taa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){b=W(8)|0;p[114610]=0;c=J(85,e|0,38601)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}Yh(a,b,1);c=gw(a,c,d,0,0,0);u[a+16>>3]=+(c>>>0)/+(b|0)+u[a+16>>3];fb=e+16|0;return c|0}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function Qaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){b=W(8)|0;p[114610]=0;c=J(85,e|0,38601)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}Yh(a,b,1);c=fw(a,c,d,0,0,0);u[a+16>>3]=+(c>>>0)/+(b|0)+u[a+16>>3];fb=e+16|0;return c|0}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function Gk(a){var b=0,c=0;kq(a,1,10879);p[114610]=0;b=Y(228)|0;c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[a+12>>2]=b;p[114610]=0;b=Y(229)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}n[a+16|0]=b;p[114610]=0;b=Y(230)|0;c=p[114610];p[114610]=0;if((c|0)==1){break a}n[a+18|0]=0;n[a+17|0]=b;p[114610]=0;S(231,a+20|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}return}b=I()|0;H()|0;pb(a);L(b|0);E()}function hba(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=fb-32|0;fb=b;p[b+24>>2]=e;p[b+28>>2]=f;a:{a=Qr(a,yl(b+16|0,c,d),b+24|0);if(a+1>>>0>=3){a=W(8)|0;p[114610]=0;b=J(85,b|0,38544)|0;c=p[114610];p[114610]=0;b:{if((c|0)!=1){dc(a,b);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}d=I()|0;H()|0;pb(b);break b}d=I()|0;H()|0;X(a|0)}L(d|0);E()}fb=b+32|0;return a|0}E()}function g8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-16|0;fb=g;if(e){while(1){h=0;if(d){while(1){f=Tg(b,h,j);k=p[f+4>>2];f=p[f>>2];Yb(c,h);p[g+8>>2]=f;p[g+12>>2]=k;wf(g+8|0,-1,1);i=u[g+8>>3]*32768;u[g+8>>3]=i;i=Id(i);a:{if(x(i)<2147483648){f=~~i;break a}f=-2147483648}f=Mc(f);l=sm(a,h,j),m=f,o[l>>1]=m;h=h+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}fb=g+16|0}function _E(a,b){var c=0,d=0,e=0;if(!q[b+21|0]){Wb(a,21);return-1}if(p[a+1396>>2]<=9){Kj(a)}c=p[a+1392>>2];e=o[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=q[e+p[b+8>>2]|0];p[a+1392>>2]=d>>>c;c=p[a+1396>>2]-c|0;d=(c|0)<0;p[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=Zk(a,b)}if(!((c|0)>=p[b+2092>>2]?q[b+23|0]:0)){if(!((c|0)>-1|(p[a+1384>>2]?!q[a+1376|0]:0))){Wb(a,21)}return c}aa(50744,50416,1778,50766);E()}function K8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-16|0;fb=g;if(e){while(1){h=0;if(d){while(1){f=Tg(b,h,j);k=p[f+4>>2];f=p[f>>2];Yb(c,h);p[g+8>>2]=f;p[g+12>>2]=k;wf(g+8|0,-1,1);i=u[g+8>>3]*32768;u[g+8>>3]=i;i=Id(i);a:{if(x(i)<2147483648){f=~~i;break a}f=-2147483648}f=Mc(f);l=um(a,h,j),m=f,o[l>>1]=m;h=h+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((j|0)!=(e|0)){continue}break}}fb=g+16|0}function BO(a){var b=0;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=808604749){break a}b=a+8|0;if((q[b|0]|q[b+1|0]<<8)>>>0<512|(q[b|0]|q[b+1|0]<<8)>>>0>767){break a}b=a+112|0;if(!(q[b|0]|q[b+1|0]<<8)|(q[b|0]|q[b+1|0]<<8)>>>0>64){break a}b=a+106|0;if((q[b|0]|q[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((q[b|0]|q[b+1|0]<<8)>>>0>255){break a}a=a+124|0;return(q[a|0]|q[a+1|0]<<8)>>>0<4e3}return 0}function qe(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;h(+a);d=e(1)|0;e(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=fo(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(TE(a,b)&3){case 0:c=fo(u[b>>3],u[b+8>>3]);break a;case 1:c=-go(u[b>>3],u[b+8>>3],1);break a;case 2:c=-fo(u[b>>3],u[b+8>>3]);break a;default:break b}}c=go(u[b>>3],u[b+8>>3],1)}a=c;fb=b+16|0;return a}function aoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;$na(a,b);b=0;a:{b:{c:{while(1){d=p[a>>2];p[114610]=0;o[c+14>>1]=b;e=J(2,c|0,(b<<2)+20704|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break c}p[114610]=0;N(1426,d|0,c+14|0,e|0);d=p[114610];p[114610]=0;if((d|0)==1){break b}pb(e);b=b+1|0;if((b|0)!=12){continue}break}fb=c+16|0;return}b=I()|0;H()|0;break a}b=I()|0;H()|0;pb(e)}Qf(a);L(b|0);E()}function Coa(a,b){var c=0,d=0;a=Ue(a);c=wb(b);p[114610]=0;K(113,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){a:{if(wb(b)){while(1){c=n[cc(b,d)|0];b:{if((c|0)>=0){p[114610]=0;K(112,a|0,c&255);c=p[114610];p[114610]=0;if((c|0)!=1){break b}break a}p[114610]=0;K(112,a|0,65533);c=p[114610];p[114610]=0;if((c|0)==1){break a}}d=d+1|0;if(d>>>0<wb(b)>>>0){continue}break}}return}}b=I()|0;H()|0;yc(a);L(b|0);E()}function Naa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){b=W(8)|0;p[114610]=0;c=J(85,e|0,38601)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}Yh(a,b,2);c=xG(a,c,2,d);u[a+16>>3]=+(c>>>0)/+(b|0)+u[a+16>>3];fb=e+16|0;return c|0}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function Maa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){b=W(8)|0;p[114610]=0;c=J(85,e|0,38601)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}Yh(a,b,4);c=xG(a,c,4,d);u[a+16>>3]=+(c>>>0)/+(b|0)+u[a+16>>3];fb=e+16|0;return c|0}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function Laa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){b=W(8)|0;p[114610]=0;c=J(85,e|0,38601)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}Yh(a,b,2);c=wG(a,c,2,d);u[a+16>>3]=+(c>>>0)/+(b|0)+u[a+16>>3];fb=e+16|0;return c|0}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function Kaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){b=W(8)|0;p[114610]=0;c=J(85,e|0,38601)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}Yh(a,b,4);c=wG(a,c,4,d);u[a+16>>3]=+(c>>>0)/+(b|0)+u[a+16>>3];fb=e+16|0;return c|0}a=I()|0;H()|0;X(b|0)}L(a|0)}E()}function Mba(a){var b=0,c=0;c=fb-16|0;fb=c;b=3;a:{b:{if(!a|(a|0)>7){break b}b=2;if((a|0)>2){break b}b=1;if((a|0)==2){break b}b=0;if((a|0)>0){break b}b=W(8)|0;p[114610]=0;c=J(85,c|0,39795)|0;a=p[114610];p[114610]=0;c:{if((a|0)!=1){dc(b,c);p[114610]=0;N(2009,b|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break c}a=I()|0;H()|0;X(b|0)}L(a|0);E()}fb=c+16|0;return b}E()}function P5(a,b){var c=0;a:{b:{if((a^b)&3){break b}if(b&3){while(1){c=q[b|0];n[a|0]=c;if(!c){break a}a=a+1|0;b=b+1|0;if(b&3){continue}break}}c=p[b>>2];if((c^-1)&c+ -16843009&-2139062144){break b}while(1){p[a>>2]=c;c=p[b+4>>2];a=a+4|0;b=b+4|0;if(!(c+ -16843009&(c^-1)&-2139062144)){continue}break}}c=q[b|0];n[a|0]=c;if(!c){break a}while(1){c=q[b+1|0];n[a+1|0]=c;a=a+1|0;b=b+1|0;if(c){continue}break}}}function Gr(a){var b=0,c=0,d=0;b=q[a+4266|0];t[a+4236>>2]=w(b>>>0)*w(.00390625);p[a+4228>>2]=(v(p[a+4232>>2],q[a+4264|0])+250>>>0)/500;t[a+4240>>2]=w(256-b|0)*w(.00390625);c=q[a+4267|0];b=q[a+4265|0];t[a+4244>>2]=w(v(c,b)|0)*w(152587890625e-16);d=c|-256;t[a+4256>>2]=w(v(d,b|-256)|0)*w(152587890625e-16);t[a+4252>>2]=w(v(b,d)|0)*w(152587890625e-16);t[a+4248>>2]=w(v(256-b|0,c)|0)*w(152587890625e-16)}function oM(){var a=0,b=0;a=fb-240|0;fb=a;a:{b:{if(n[85480]&1){break b}if(!nd(85480)){break b}p[114610]=0;Y(102)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(103,a+120|0,85328);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;J(104,85360,ac(a,a+120|0,120)|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}md(85480)}fb=a+240|0;return 85360}a=I()|0;H()|0;ge(85480);L(a|0);E()}function ey(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;p[f+8>>2]=c;g=f,h=pf(b),p[g+28>>2]=h;Ne(f+8|0,b,p[Cb(f+8|0,f+28|0)>>2]);p[114610]=0;b=M(412,f+8|0)|0;c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}c=p[f+8>>2];p[114610]=0;a=Z(440,a|0,b|0,c|0,d|0,e|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}uc(f+8|0);fb=f+32|0;return a|0}a=I()|0;H()|0;uc(f+8|0);L(a|0);E()}function y7(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=p[b+4>>2];b=p[b>>2];p[c+12>>2]=0;p[c+8>>2]=0;p[c+4>>2]=0;s7(Uv(1970,1,1)+ONa(b,d,86400,0)|0,c+12|0,c+8|0,c+4|0);uF(a);p[a+20>>2]=p[c+12>>2]+ -1900;p[a+16>>2]=p[c+8>>2]+ -1;e=p[c+4>>2];g=a,h=PNa(ONa(b,d,3600,0),ib,24),p[g+8>>2]=h;p[a+12>>2]=e;d=ONa(b,d,60,0);e=ib;g=a,h=PNa(d,e,60),p[g+4>>2]=h;f=a;a=NNa(d,e,60,0);p[f>>2]=b-a;fb=c+16|0}function Zw(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=z(c,.999);c=d*32768;h=d*3.141592653589793;i=Nr(b);while(1){j=a;k=c;e=((f<<12^-1)&28672)+(f>>>3|0)|0;if((e|0)!=16384){g=+(e+ -16384|0);d=g*.000244140625;g=Nr(D(g*-152587890625e-16*d+1)*b);d=h*d;d=g*Sh(d)/(d*i)}else{d=1}d=B(k*d+.5);a:{if(x(d)<2147483648){e=~~d;break a}e=-2147483648}o[j>>1]=e;a=a+2|0;f=f+1|0;if((f|0)!=32768){continue}break}}function UN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=qp(a);f=d,g=Ub(b),p[f+8>>2]=g;f=d,g=Vb(b),p[f>>2]=g;a:{if(Ab(d+8|0,d)){while(1){a=p[d+8>>2];if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))==(c|0)){a=qb(a);p[114610]=0;K(604,e|0,a|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}}ok(d+8|0);if(Ab(d+8|0,d)){continue}break}}fb=d+16|0;return}a=I()|0;H()|0;$c(e);L(a|0);E()}function hHa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;JFa(c+24|0,b);p[114610]=0;K(705,c+8|0,c+24|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[114610]=0;K(706,c+16|0,c+8|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[c+16>>2];d=p[c+20>>2];p[114610]=0;P(707,a|0,b|0,d|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}uc(c+24|0);fb=c+48|0;return}a=I()|0;H()|0;uc(c+24|0);L(a|0);E()}function IF(a,b){a=a|0;b=+b;var c=0,d=0;c=fb-16|0;fb=c;a:{b:{c:{if(!(b<=4?!(b<=0):0)){d=W(8)|0;p[114610]=0;c=J(85,c|0,40505)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(d,c);p[114610]=0;N(2009,d|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}d=ek(65536/b);a=a+32|0;p[p[a>>2]+480244>>2]=d;zo(p[a>>2]);fb=c+16|0;return}a=I()|0;H()|0;X(d|0)}L(a|0)}E()}function GF(a,b){a=a|0;b=+b;var c=0,d=0;c=fb-16|0;fb=c;a:{b:{c:{if(!(b<=4?!(b<=0):0)){d=W(8)|0;p[114610]=0;c=J(85,c|0,40526)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(d,c);p[114610]=0;N(2009,d|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}d=ek(b*65536);a=a+32|0;p[p[a>>2]+480240>>2]=d;zo(p[a>>2]);fb=c+16|0;return}a=I()|0;H()|0;X(d|0)}L(a|0)}E()}function dF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(b<<2)+a|0;e=d+1068|0;g=c<<1&-4;i=e,j=Jd(a,g),p[i>>2]=j;f=d+1076|0;i=f,j=Jd(a,g),p[i>>2]=j;h=d+1084|0;d=Jd(a,c&-4);p[h>>2]=d;a:{b:{e=p[e>>2];if(!(!e|!d)){f=p[f>>2];if(f){break b}}break a}S5(c,e,f,d);d=(b<<2)+a|0;b=Jd(a,g);p[d+1092>>2]=b;if(!b){break a}R5(c,b);b=Jd(a,c>>3<<1);p[d+1100>>2]=b;if(!b){break a}Q5(c,b);return 1}Wb(a,3);return 0}function Sh(a){var b=0,c=0;b=fb-16|0;fb=b;h(+a);c=e(1)|0;e(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=go(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(TE(a,b)&3){case 0:a=go(u[b>>3],u[b+8>>3],1);break a;case 1:a=fo(u[b>>3],u[b+8>>3]);break a;case 2:a=-go(u[b>>3],u[b+8>>3],1);break a;default:break b}}a=-fo(u[b>>3],u[b+8>>3])}fb=b+16|0;return a}function qF(a,b,c,d,e,f){var g=0,h=0;if((d|0)>=1){while(1){M6(v(g,2304)+b|0,c);g=g+1|0;if((g|0)!=(d|0)){continue}break}}f=ac(f,a,3840);if((c|0)>=1){h=d<<5;g=0;while(1){L6((g<<2)+b|0,(v(g,h)<<1)+e|0,d,f+(g<<8)|0);g=g+2|0;if((g|0)<(c|0)){continue}break}}b=c<<6;a:{if((d|0)==1){g=0;while(1){p[(g<<2)+a>>2]=p[f+(b+g<<2)>>2];c=g>>>0<958;g=g+2|0;if(c){continue}break}break a}ac(a,f+(b<<2)|0,3840)}}function PW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;a:{b:{c:{d:{if(!(d=!Pc(b),e=0,f=p[b+12>>2],f?d:e)){Xc(a);break d}OW(c+16|0,b);p[114610]=0;K(234,c|0,b+12|0);b=p[114610];p[114610]=0;if((b|0)==1){break c}p[114610]=0;N(3,a|0,c+16|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}pb(c);pb(c+16|0)}fb=c+32|0;return}b=I()|0;H()|0;break a}b=I()|0;H()|0;pb(c)}pb(c+16|0);L(b|0);E()}function wea(a,b){a=a|0;b=b|0;var c=0;p[114610]=0;S(2015,a|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[a+16>>2]=b;b=p[a+20>>2];if(!b){break b}Nb(b);p[a+20>>2]=0;return}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34833,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Op(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;e=p[a+4>>2];d=p[a>>2];n[c+12|0]=0;Lr(d,d+e|0,c+12|0);d=Ib(b);e=Ib(b);g=c,h=wb(b),p[g+12>>2]=h;p[c+8>>2]=p[a+4>>2]+ -1;Ye(d,e+p[Cb(c+12|0,c+8|0)>>2]|0,p[a>>2]);d=p[a>>2];g=c,h=wb(b),p[g+12>>2]=h;p[c+8>>2]=p[a+4>>2]+ -1;b=p[Cb(c+12|0,c+8|0)>>2];e=p[a+4>>2];f=p[a>>2];n[c+7|0]=0;Lr(b+d|0,e+f|0,c+7|0);fb=c+16|0;return a|0}function KT(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;p[d+12>>2]=b;c=p[a+4>>2];a:{if(!c){c=p[a>>2];break a}p[d+8>>2]=32-c;b=Cb(d+8|0,d+12|0);c=p[a>>2];b=p[b>>2];p[c>>2]=p[c>>2]&(-1<<p[a+4>>2]&-1>>>p[d+8>>2]-b^-1);b=p[d+12>>2]-b|0;p[d+12>>2]=b;c=c+4|0;p[a>>2]=c}e=c;c=b>>>5<<2;Jb(e,0,c);b=p[d+12>>2]-(b&-32)|0;p[d+12>>2]=b;if(b){e=a;a=c+p[a>>2]|0;p[e>>2]=a;p[a>>2]=p[a>>2]&(-1>>>32-b^-1)}fb=d+16|0}function K5(a){var b=w(0),c=w(0),d=0;c=(f(2,(i(a),e(2))&-2147483648|1056964608),j());d=(i(a),e(2))&2147483647;b=(f(2,d),j());a:{if(d>>>0<=1118925334){b=I5(b);if(d>>>0<=1065353215){if(d>>>0<964689920){break a}return w(c*w(w(b+b)-w(w(b*b)/w(b+w(1)))))}return w(c*w(b+w(b/w(b+w(1)))))}a=w(w(c+c)*w(w(L5(w(b+w(-162.88958740234375)))*w(1.661534994731145e+35))*w(1.661534994731145e+35)))}return a}function IL(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=Nr(b);d=Psa(a);a=0;a:{while(1){c=1;if((a|0)!=1024){p[114610]=0;c=+(a+ -1024|0);f=+db(1215,+(D(c*c*-9.5367431640625e-7+1)*b));g=p[114610];p[114610]=0;if((g|0)==1){break a}c=c*.0372006759294457;c=f*Sh(c)/(c*e)}h=Fk(d,a),i=c*.011841342921061943,u[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=I()|0;H()|0;zf(d);L(a|0);E()}function t0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb+ -64|0;fb=e;p[e+56>>2]=b;f=e+48|0;a:{b:while(1){if(c>>>0<d>>>0){p[e+8>>2]=c;if((m[p[p[a>>2]+12>>2]](a,e+48|0,c,d,e+8|0,e+16|0,f,e+12|0)|0)==2){break a}b=e+16|0;if(p[e+8>>2]==(c|0)){break a}while(1)if(b>>>0>=s[e+12>>2]){c=p[e+8>>2];continue b}else{ZC(e+56|0,b);b=b+1|0;continue}}break}fb=e- -64|0;return p[e+56>>2]}am(62916);E()}function Ty(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;EP(a,b);e=b+8|0;e=q[e|0]|q[e+1|0]<<8|(q[e+2|0]<<16|q[e+3|0]<<24);Jc(a,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+504|0);DP(a,d);a:{b=b+32|0;if(!(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))){break a}b=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);if(!Jc(a,b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))){break a}mn(a,c);return}Jb(c,0,80)}function dC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;c=Mb(d,c);p[114610]=0;N(2843,d+16|0,b|0,c|0);e=p[114610];p[114610]=0;a:{b:{if((e|0)!=1){p[114610]=0;J(2844,a|0,d+16|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break b}pb(d+16|0);pb(c);p[a>>2]=70676;c=p[b+4>>2];p[a+8>>2]=p[b>>2];p[a+12>>2]=c;fb=d+32|0;return a|0}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+16|0)}pb(c);L(a|0);E()}function _P(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=p[a>>2];b:{if(!b){break b}e=p[a+8>>2];if(!e){break b}c=p[a+12>>2];if(!c){break b}a=m[c|0](b)|0;d=ib;f=d;if((d|0)<0?1:(d|0)<=0?a>>>0<0:0){break b}if((m[e|0](b,0,0,0)|0)<=-1){break a}if((m[e|0](b,0,0,2)|0)<=-1){break a}d=m[c|0](b)|0;c=ib;m[e|0](b,a,f,0)|0;if((c|0)<0?1:(c|0)<=0?d>>>0<0:0){break b}g=NQ(d,c)}return g}m[e|0](b,a,f,0)|0;return 0}function Vqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>3;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b|0]);ub(q[b+1|0]);f=a,g=ub(q[b+2|0])|ub(q[b+3|0])<<8,o[f>>1]=g;ub(q[b+4|0]);ub(q[b+5|0]);f=a,g=ub(q[b+6|0])|ub(q[b+7|0])<<8,o[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<3}function Uqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>3;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b+3|0]);ub(q[b+2|0]);f=a,g=ub(q[b+1|0])|ub(q[b|0])<<8,o[f>>1]=g;ub(q[b+7|0]);ub(q[b+6|0]);f=a,g=ub(q[b+5|0])|ub(q[b+4|0])<<8,o[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<3}function Bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=_h(a,b,c,d);p[a+4224>>2]=1049951732;c=a+4216|0;p[c>>2]=1065353216;p[c+4>>2]=1049951732;p[a+4208>>2]=1060320051;p[a+4212>>2]=1041865114;p[a>>2]=80724;p[114610]=0;P(1639,a+44|0,2,2)|0;c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;S(1640,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}return a|0}a=I()|0;H()|0;Ge(b);L(a|0);E()}function Cza(a,b){var c=0,d=0,e=0;c=JN(a,b);p[114610]=0;e=J(991,a+12|0,b+12|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;J(992,a+24|0,b+24|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}c=p[b+40>>2];p[a+36>>2]=p[b+36>>2];p[a+40>>2]=c;o[a+52>>1]=r[b+52>>1];c=p[b+48>>2];p[a+44>>2]=p[b+44>>2];p[a+48>>2]=c;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;Xd(e)}Xd(c);L(a|0);E()}function Au(a,b,c){var d=0,e=0,f=0,g=0;d=p[c+16>>2];a:{if(!d){if(bY(c)){break a}d=p[c+16>>2]}f=p[c+20>>2];if(d-f>>>0<b>>>0){return m[p[c+36>>2]](c,a,b)|0}b:{if(n[c+75|0]<0){break b}e=b;while(1){d=e;if(!d){break b}e=d+ -1|0;if(q[e+a|0]!=10){continue}break}e=m[p[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=p[c+20>>2];g=d}ac(f,a,b);p[c+20>>2]=p[c+20>>2]+b;e=b+g|0}return e}function Kia(a){a=a|0;var b=0,c=0;b=p[a+20>>2];p[b+148>>2]=-1;p[114610]=0;K(508,b+4|0,8);b=p[114610];p[114610]=0;if((b|0)!=1){c=p[p[a+20>>2]+4>>2];b=p[a+4264>>2];a=p[a+4260>>2];n[c|0]=a;n[c+1|0]=a>>>8;n[c+2|0]=a>>>16;n[c+3|0]=a>>>24;n[c+4|0]=b;n[c+5|0]=b>>>8;n[c+6|0]=b>>>16;n[c+7|0]=b>>>24;return}b=O(71348)|0;if((H()|0)==($(71348)|0)){T(b|0)|0;fs(p[a+20>>2]+4|0);V();return}L(b|0);E()}function vF(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){a=W(8)|0;p[114610]=0;c=J(85,c|0,40569)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(c);break b}a=p[a+32>>2]+v(b,896)|0;p[a+1075e3>>2]=0;p[a+1075060>>2]=0;fb=c+16|0;return}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function n_(){var a=0;a:{if(n[462216]&1){break a}if(!nd(462216)){break a}a=462048;while(1){a=Lb(a)+12|0;if((a|0)!=462216){continue}break}md(462216)}Ec(462048,67104);Ec(462060,67111);Ec(462072,67118);Ec(462084,67126);Ec(462096,67136);Ec(462108,67145);Ec(462120,67152);Ec(462132,67161);Ec(462144,67165);Ec(462156,67169);Ec(462168,67173);Ec(462180,67177);Ec(462192,67181);Ec(462204,67185)}function k_(){var a=0;a:{if(n[462392]&1){break a}if(!nd(462392)){break a}a=462224;while(1){a=Ue(a)+12|0;if((a|0)!=462392){continue}break}md(462392)}Rc(462224,67192);Rc(462236,67220);Rc(462248,67248);Rc(462260,67280);Rc(462272,67320);Rc(462284,67356);Rc(462296,67384);Rc(462308,67420);Rc(462320,67436);Rc(462332,67452);Rc(462344,67468);Rc(462356,67484);Rc(462368,67500);Rc(462380,67516)}function k7(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=p[((q[b|0]^a&255)<<2)+40736>>2]^a>>>8;a=a>>>8^p[((q[b+1|0]^a&255)<<2)+40736>>2];a=a>>>8^p[((q[b+2|0]^a&255)<<2)+40736>>2];a=a>>>8^p[((q[b+3|0]^a&255)<<2)+40736>>2];b=b+4|0;c=c+ -4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=p[((q[b|0]^a&255)<<2)+40736>>2]^a>>>8;b=b+1|0;c=c+ -1|0;if(c){continue}break}}return a^-1}function fy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;p[e+8>>2]=c;f=e,g=pf(b),p[f+28>>2]=g;Ne(e+8|0,b,p[Cb(e+8|0,e+28|0)>>2]);p[114610]=0;b=M(412,e+8|0)|0;c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}c=p[e+8>>2];p[114610]=0;U(1063,a|0,b|0,c|0,d|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}uc(e+8|0);fb=e+32|0;return 1}a=I()|0;H()|0;uc(e+8|0);L(a|0);E()}function xL(a,b,c){var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;p[a+4>>2]=0;a:{if(b){b:{if(Fs(a)>>>0>=b>>>0){p[a+4>>2]=b;break b}qb(a);e=yy(d+16|0);p[114610]=0;f=J(933,a|0,b|0)|0;g=p[114610];p[114610]=0;if((g|0)==1){break a}p[114610]=0;K(934,e|0,f|0);f=p[114610];p[114610]=0;if((f|0)==1){break a}p[e+4>>2]=b;xy(a,e);ce(e)}ej(d,a);Mp(d,b,q[c|0])}fb=d+32|0;return}a=I()|0;H()|0;ce(e);L(a|0);E()}function vw(a){var b=w(0),c=w(0),d=0,e=w(0),f=0;b=w(He(p[a+16>>2])>>>0);c=w(w(m[p[p[a>>2]+200>>2]](a))*b);d=a,e=w(w(c*w(2.0480000972747803))*w(m[p[p[a>>2]+192>>2]](a))),t[d+4248>>2]=e;d=a,f=zh(w(w(c*w(4.0960001945495605))+w(8192))),p[d+4256>>2]=f;c=w(m[p[p[a>>2]+204>>2]](a));t[a+4252>>2]=c;b=w(c/b);if(!(m[p[p[a>>2]+188>>2]](a)|0)){b=VE(w(b*w(3.1415927410125732)))}t[a+4244>>2]=b+b}function vea(a){a=a|0;var b=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){p[a+16>>2]=0;b=p[a+20>>2];if(!b){break b}Nb(b);p[a+20>>2]=0;return}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34863,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V()}return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function dHa(a,b){var c=0,d=0;c=fb-48|0;fb=c;hz(c+24|0,b);p[114610]=0;K(705,c+8|0,c+24|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[114610]=0;K(706,c+16|0,c+8|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}b=p[c+16>>2];d=p[c+20>>2];p[114610]=0;P(707,a|0,b|0,d|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}uc(c+24|0);fb=c+48|0;return}a=I()|0;H()|0;uc(c+24|0);L(a|0);E()}function LT(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;p[d+12>>2]=b;c=p[a+4>>2];a:{if(!c){c=p[a>>2];break a}p[d+8>>2]=32-c;b=Cb(d+8|0,d+12|0);c=p[a>>2];b=p[b>>2];p[c>>2]=p[c>>2]|-1<<p[a+4>>2]&-1>>>p[d+8>>2]-b;b=p[d+12>>2]-b|0;p[d+12>>2]=b;c=c+4|0;p[a>>2]=c}e=c;c=b>>>5<<2;Jb(e,255,c);b=p[d+12>>2]-(b&-32)|0;p[d+12>>2]=b;if(b){e=a;a=c+p[a>>2]|0;p[e>>2]=a;p[a>>2]=p[a>>2]|-1>>>32-b}fb=d+16|0}function $4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;while(1){a:{if((e|0)>=(c|0)){break a}f=p[a+24>>2];g=p[a+28>>2];if(f>>>0>=g>>>0){if((m[p[p[a>>2]+52>>2]](a,p[b>>2])|0)==-1){break a}e=e+1|0;b=b+4|0}else{p[d+12>>2]=g-f>>2;p[d+8>>2]=c-e;f=p[Yd(d+12|0,d+8|0)>>2];Rh(p[a+24>>2],b,f);g=f<<2;p[a+24>>2]=g+p[a+24>>2];e=e+f|0;b=b+g|0}continue}break}fb=d+16|0;return e|0}function zW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;a:{b:{e=vW(Ib(b),wb(b),Ib(c),wb(c));if((e|0)!=-1){f=d,g=wd(b),p[f+32>>2]=g;c=Ld(d+40|0,d+32|0);f=d,g=wd(b),p[f+8>>2]=g;f=d,g=lf(d+8|0,e),p[f+16>>2]=g;e=Ld(d+24|0,d+16|0);Nx(b,p[c>>2],p[e>>2]);break b}if(!wb(b)){break b}if((uW(Ib(b),wb(b),Ib(c),wb(c))|0)!=(wb(b)+ -1|0)){break b}Xc(a);break a}Wc(a,b)}fb=d+48|0}function Dea(a){a=a|0;var b=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;if((b|0)!=1){b=p[a+24>>2];if(b){Nb(mr(b))}p[a+24>>2]=0;b=p[a+20>>2];if(b){Nb(b)}Nb(a);return}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34684,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)!=1){V();return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function K7(a){var b=0,c=0,d=0,e=0;e=fb-16|0;fb=e;b=Uv(p[a+20>>2]+1900|0,p[a+16>>2]+1|0,p[a+12>>2])-Uv(1970,1,1)|0;c=NNa(b,b>>31,86400,0);b=v(p[a+8>>2],3600);d=b;c=c+b|0;b=ib+(b>>31)|0;b=c>>>0<d>>>0?b+1|0:b;d=v(p[a+4>>2],60);c=d+c|0;b=(d>>31)+b|0;b=c>>>0<d>>>0?b+1|0:b;a=p[a>>2];d=a;c=a+c|0;a=(a>>31)+b|0;a=OF(e+8|0,c,c>>>0<d>>>0?a+1|0:a);b=p[a>>2];fb=e+16|0;ib=p[a+4>>2];return b}function xea(a){a=a|0;var b=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){a=p[a+20>>2];if(!a){break b}return Pd(a)|0}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34795,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();return 0}return Pd(34085)|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function sAa(a,b){a=a|0;b=b|0;var c=0;b=fb-32|0;fb=b;c=-1;a:{if(!Cz(a,b+16|0)){break a}c=0;if(!VN(b+16|0)){break a}c=-1;if(!oj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))){break a}a=b+8|0;c=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);a=b+8|0;c=(c|0)==((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))&2139062143)}a=c;fb=b+32|0;return a|0}function SQ(a){var b=0,c=0,d=0;a:{if((q[a+60|0]|q[a+61|0]<<8|(q[a+62|0]<<16|q[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((q[b|0]|q[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if((q[b|0]|q[b+1|0]<<8)>>>0>255){break a}b=a+576|0;a=a- -64|0;while(1){c=0;b:{switch(q[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}c=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}return c&1}function Nh(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;p[f+8>>2]=b;a:{if(Pi(a,f+8|0)){p[c>>2]=p[c>>2]|6;b=0;break a}b=Ij(a);if(!wg(d,2048,b)){p[c>>2]=p[c>>2]|4;b=0;break a}b=cm(d,b);while(1){b:{Uk(a);b=b+ -48|0;if(!ao(a,f+8|0)|(e|0)<2){break b}g=Ij(a);if(!wg(d,2048,g)){break a}e=e+ -1|0;b=cm(d,g)+v(b,10)|0;continue}break}if(!Pi(a,f+8|0)){break a}p[c>>2]=p[c>>2]|2}fb=f+16|0;return b}function Mh(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;p[f+8>>2]=b;a:{if(Fj(a,f+8|0)){p[c>>2]=p[c>>2]|6;b=0;break a}b=Rk(a);if(!Gj(d,2048,b)){p[c>>2]=p[c>>2]|4;b=0;break a}b=bm(d,b);while(1){b:{lm(a);b=b+ -48|0;if(!Pq(a,f+8|0)|(e|0)<2){break b}g=Rk(a);if(!Gj(d,2048,g)){break a}e=e+ -1|0;b=bm(d,g)+v(b,10)|0;continue}break}if(!Fj(a,f+8|0)){break a}p[c>>2]=p[c>>2]|2}fb=f+16|0;return b}function oqa(a,b,c){var d=0,e=w(0),f=w(0),g=0,h=0;d=fb-16|0;fb=d;e=w(v(c+256|0,b)>>>0);b=d;a:{if(p[a+480180>>2]!=33554432){f=w(110);e=w(w(e/(q[a+480209|0]&128?w(10240):w(12288)))+w(.25));break a}f=w(125);e=w(e*w(9227362170349807e-20))}g=b,h=zh(w(fe(w(2),e)*f)),p[g+12>>2]=h;Vd(d+12|0,120,2e4);b=p[d+12>>2];a=p[a+24620>>2];if(b<<1>(a|0)){b=a>>>1|0;p[d+12>>2]=b}fb=d+16|0;return b}function Yh(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-48|0;fb=d;e=a+24|0;f=p[p[e>>2]+24620>>2];a:{if(!((f|0)!=(b|0)|p[p[e>>2]+24624>>2]!=(c|0))){if(q[a+29|0]){break a}BJ(p[e>>2],1);break a}ac(d+8|0,p[e>>2]+24604|0,40);g=p[d+40>>2];h=p[d+44>>2];p[d+28>>2]=c;p[d+24>>2]=b;gl(d+8|0,g);Vm(d+8|0,h);hx(p[e>>2],d+8|0);if((b|0)==(f|0)){break a}loa(p[e>>2]);koa(p[e>>2])}n[a+29|0]=1;fb=d+48|0}function Pw(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-16|0;fb=f;a:{while(1){h=g&255;if(Rw(b,c,h>>>0>1)){n[f+15|0]=0;n[f+14|0]=0;NI(a,f+15|0,f+14|0);break a}bh(b,d);bh(c,e);g=g+1|0;if(h>>>0<3){continue}break}if(Fm(q[b|0])>>>0>Fm(q[d|0])>>>0){bh(b,d);bh(c,e)}n[f+11|0]=q[b|0];NI(f+12|0,f+11|0,c);n[b|0]=0;n[c|0]=0;b=r[f+12>>1];n[a|0]=b;n[a+1|0]=b>>>8}fb=f+16|0}function jR(a){var b=0,c=0;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=777268804){break a}b=a+4|0;c=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<14){break a}b=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>256){break a}a=a+8|0;return!(q[a|0]|q[a+1|0]<<8)}return 0}function Lua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;p[d+24>>2]=b;a:{b=Eh(d+8|0,a+8|0,Kua(b,c));if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];f=p[d+24>>2];p[114610]=0;N(770,c|0,e|0,f|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}p[b>>2]=p[b>>2]+4;Rd(d+24|0);if(p[b>>2]!=p[b+4>>2]){continue}break}}lc(b);fb=d+32|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function $ia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=Ee(64);p[114610]=0;f=M(1427,d|0)|0;g=p[114610];p[114610]=0;a:{if((g|0)!=1){d=nx(e+8|0,f);f=p[d>>2];p[114610]=0;b=P(1634,f|0,b|0,c|0)|0;c=p[114610];p[114610]=0;b:{c:{if((c|0)!=1){if((b|0)==1){break c}mx(a);break b}a=I()|0;H()|0;Qf(d);break a}np(a,d)}Qf(d);fb=e+16|0;return}a=I()|0;H()|0;Nb(d)}L(a|0);E()}function xKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;p[d+24>>2]=b;a:{b=Fl(d+8|0,a+8|0,Nz(b,c));if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];f=p[d+24>>2];p[114610]=0;N(522,c|0,e|0,f|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}p[b>>2]=p[b>>2]+2;te(d+24|0);if(p[b>>2]!=p[b+4>>2]){continue}break}}lc(b);fb=d+32|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function hua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;p[d+12>>2]=b;a:{if(hh(a)>>>0>=b>>>0){g=d,h=ne(a),p[g+8>>2]=h;e=p[a>>2];b=c;f=p[Cb(d+12|0,d+8|0)>>2];if(f){while(1){e=wua(e,b)+32|0;f=f+ -1|0;if(f){continue}break}}b=p[d+12>>2];e=p[d+8>>2];if(b>>>0>e>>>0){Yx(a,b-e|0,c);break a}lM(a,p[a>>2]+(b<<5)|0);break a}gua(a);fua(a,Ol(a,b));Yx(a,b,c)}fb=d+16|0}function _ha(a,b){a=a|0;b=b|0;var c=w(0);a:{switch(b|0){case 0:return w(t[a+4220>>2]);case 1:return w(t[a+4224>>2]);case 2:return w(t[a+4228>>2]);case 3:return w(q[a+4240|0]?w(1):w(0));case 4:return w(w(w(p[a+4232>>2])*w(.03125)));case 5:return w(q[a+4241|0]?w(1):w(0));case 6:return w(q[a+4242|0]?w(1):w(0));case 7:c=q[a+4244|0]?w(1):w(0);break;default:break a}}return w(c)}function EF(a,b){a=a|0;b=+b;var c=0,d=0;c=fb-16|0;fb=c;a:{b:{c:{if(!(b<=1?!(b<0):0)){d=W(8)|0;p[114610]=0;c=J(85,c|0,40547)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(d,c);p[114610]=0;N(2009,d|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);break b}d=ek(b*256);p[p[a+32>>2]+1074444>>2]=d;fb=c+16|0;return}a=I()|0;H()|0;X(d|0)}L(a|0)}E()}function Zsa(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+23|0]=0;n[a+24|0]=0;n[a+25|0]=0;n[a+26|0]=0;n[a+16|0]=0;n[a+17|0]=0;n[a+18|0]=0;n[a+19|0]=0;n[a+20|0]=0;n[a+21|0]=0;n[a+22|0]=0;n[a+23|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;fb=b+16|0}function oh(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=e;e=0;k=e;h=c;c=0;g=NNa(j,e,h,c);e=ib;l=g;g=g>>>0<0?e+1|0:e;f=d;e=0;i=b;d=NNa(f,e,b,0);b=ib;f=NNa(f,e,h,c);c=b+f|0;b=ib;b=c>>>0<f>>>0?b+1|0:b;h=b;f=b+l|0;b=g;b=f>>>0<h>>>0?b+1|0:b;g=b;b=NNa(i,m,j,k)+c|0;e=ib;e=b>>>0<c>>>0?e+1|0:e;i=e;f=e+f|0;e=g;p[a+8>>2]=f;p[a+12>>2]=f>>>0<i>>>0?e+1|0:e;p[a>>2]=d;p[a+4>>2]=b}function Bx(a,b,c,d){a:{if(p[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=v(b,896)+a|0;p[c+1075680>>2]=0;d=c+1074992|0;p[d>>2]=0;p[d+4>>2]=0;d=c+1075072|0;c=p[d>>2]|4096;p[d>>2]=c;break b}c=v(b,896)+a|0;p[c+1075672>>2]=0;c=p[c+1075072>>2]}d=v(b,896)+a|0;p[d+1075072>>2]=c|2097152;Tj(a,b,255,0);if(!(q[d+1075073|0]&2)){break a}a=a+1304392|0;if(!kd(a)){break a}ii(p[a>>2],b,0)}}function _Ca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=w(0),h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;if(d){a=(e<<1)+a|0;e=0;c=c<<1;while(1){p[f+12>>2]=p[b>>2];Td(f+12|0,w(-1));g=w(t[f+12>>2]*w(32768));t[f+12>>2]=g;i=a;g=$d(g);a:{if(w(x(g))<w(2147483648)){h=~~g;break a}h=-2147483648}j=i,k=Mc(h),o[j>>1]=k;b=b+4|0;a=a+c|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}fb=f+16|0}function Zqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=(c>>>0)/6;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b|0]);f=a,g=ub(q[b+1|0])|ub(q[b+2|0])<<8,o[f>>1]=g;ub(q[b+3|0]);f=a,g=ub(q[b+4|0])|ub(q[b+5|0])<<8,o[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return v(d,6)|0}function Yqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=(c>>>0)/6;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b+2|0]);f=a,g=ub(q[b+1|0])|ub(q[b|0])<<8,o[f>>1]=g;ub(q[b+5|0]);f=a,g=ub(q[b+4|0])|ub(q[b+3|0])<<8,o[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return v(d,6)|0}function H6(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;while(1){g=q[d+i|0];if(g){a:{if(f&8){ac(a,b,g);break a}j=q[c+i|0];if(!j){Jb(a,0,g);Jb(b,0,g);break a}l=(f|0)>-1?-1:-1<<j^-1;h=0;while(1){k=Kd(e,j);n[b+h|0]=(k|0)==(l|0)?-1:k;n[a+h|0]=k;h=h+1|0;if((h|0)!=(g|0)){continue}break}}f=f<<1;a=a+g|0;b=b+g|0;i=i+1|0;if((i|0)!=4){continue}}break}n[a+2|0]=0;n[a|0]=0;n[a+1|0]=0}function Aq(a,b,c){var d=0,e=0;if(c&2048){n[a|0]=43;a=a+1|0}if(c&1024){n[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){n[a|0]=10798;n[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=q[b|0];if(e){n[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}n[a|0]=b;return(d|0)!=260}function _k(a){if((a|0)>=0){if((a|0)<=16383){if((a|0)<=15){return n[a+50576|0]}if((a|0)<=511){return n[(a>>>5|0)+50576|0]+5|0}return n[(a>>>10|0)+50576|0]+10|0}if((a|0)<=16777215){if((a|0)<=524287){return n[(a>>>15|0)+50576|0]+15|0}return n[(a>>>20|0)+50576|0]+20|0}if((a|0)<=536870911){return n[(a>>>25|0)+50576|0]+25|0}a=n[(a>>>30|0)+50576|0]+30|0}else{a=0}return a}function Tqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>3;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b|0]);ub(q[b+1|0]);ub(q[b+2|0]);ub(q[b+3|0]);ub(q[b+4|0]);ub(q[b+5|0]);f=a,g=ub(q[b+6|0])|ub(q[b+7|0])<<8,o[f>>1]=g;a=a+2|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<3}function Sqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>3;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b+7|0]);ub(q[b+6|0]);ub(q[b+5|0]);ub(q[b+4|0]);ub(q[b+3|0]);ub(q[b+2|0]);f=a,g=ub(q[b+1|0])|ub(q[b|0])<<8,o[f>>1]=g;a=a+2|0;b=b+8|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<3}function i6(a,b){var c=0,d=0,e=w(0),f=0;d=B(Gv(+w(w(eo(+w(a|0)))/w(b|0))));a:{if(x(d)<2147483648){c=~~d;break a}c=-2147483648}f=c;d=B(Bv(+w(w(c|0)+w(1)),b));b:{if(x(d)<2147483648){c=~~d;break b}c=-2147483648}c=f+((c|0)<=(a|0))|0;e=w(c|0);if(!(Bv(+w(e+w(1)),b)<=+(a|0))){d=B(Bv(+e,b));c:{if(x(d)<2147483648){b=~~d;break c}b=-2147483648}return(b|0)>(a|0)?-1:c}return-1}function h7(a){var b=0;if(!a){return-2}p[a+44>>2]=0;p[a+48>>2]=0;p[a+52>>2]=0;p[a+20>>2]=0;p[a+24>>2]=0;p[a+8>>2]=0;b=p[a+32>>2];if(!b){p[a+32>>2]=2299;b=2299}if(!p[a+36>>2]){p[a+36>>2]=2300}b=m[b|0](p[a+40>>2],1,43784)|0;if(!b){return-4}p[a+28>>2]=b;p[b+43780>>2]=1;p[b+10992>>2]=0;p[b+10996>>2]=0;p[b>>2]=0;p[b+11008>>2]=15;p[b+11e3>>2]=1;p[b+11004>>2]=0;return 0}function gD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;f=p[_b(a)>>2];d=p[c>>2]-p[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=p[b>>2];i=p[a>>2];g=oq((f|0)==2482?0:p[a>>2],d);if(g){if((f|0)!=2482){Cd(a)}p[e+4>>2]=2420;f=Hd(e+8|0,g,e+4|0);dD(a,f);wc(f);p[b>>2]=p[a>>2]+(h-i|0);p[c>>2]=p[a>>2]+(d&-4);fb=e+16|0;return}Mu();E()}function JF(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b+ -32>>>0>=481){a=W(8)|0;p[114610]=0;c=J(85,c|0,40491)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(c);break b}p[p[a+32>>2]+1074420>>2]=v(b,1e4);fb=c+16|0;return}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function _5(a,b,c,d,e,f){var g=0,h=0;a:{if(f){g=1;if((e|0)<1){break a}f=0;while(1){if(!V5(a,b,(d<<2)+c|0,e-f|0)){return 0}h=p[b>>2];d=h+d|0;f=f+h|0;if((f|0)<(e|0)){continue}break}break a}g=1;f=(e|0)/p[b>>2]|0;if((f|0)<1){break a}c=(d<<2)+c|0;e=e-d|0;g=0;d=0;while(1){if(!U5(a,b,c+(d<<2)|0,e-d|0,f)){break a}d=d+1|0;if((f|0)!=(d|0)){continue}break}return 1}return g}function WE(a,b){a:{if((b|0)>=128){a=w(a*w(1.7014118346046923e+38));if((b|0)<255){b=b+ -127|0;break a}a=w(a*w(1.7014118346046923e+38));b=((b|0)<381?b:381)+ -254|0;break a}if((b|0)>-127){break a}a=w(a*w(1.1754943508222875e-38));if((b|0)>-253){b=b+126|0;break a}a=w(a*w(1.1754943508222875e-38));b=((b|0)>-378?b:-378)+252|0}return w(a*(f(2,(b<<23)+1065353216|0),j()))}function xka(a,b){var c=0,d=0,e=0;e=wka(a,b);p[a+20>>2]=p[b+20>>2];c=p[b+16>>2];p[a+12>>2]=p[b+12>>2];p[a+16>>2]=c;p[114610]=0;c=J(1589,a+24|0,b+24|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;J(120,a+36|0,b+36|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break b}p[a+48>>2]=p[b+48>>2];return}a=I()|0;H()|0;break a}a=I()|0;H()|0;be(c)}wl(e);L(a|0);E()}function aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=fb-32|0;fb=b;a:{a=Qr(a,yl(b+24|0,ub(c),d),0);if(a+1>>>0>=3){a=W(8)|0;p[114610]=0;b=J(85,b+8|0,38544)|0;c=p[114610];p[114610]=0;b:{if((c|0)!=1){dc(a,b);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}d=I()|0;H()|0;pb(b);break b}d=I()|0;H()|0;X(a|0)}L(d|0);E()}fb=b+32|0;return a|0}E()}function GM(a,b,c,d){var e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;if(dj(a)){e=q[(Ud(q[a+819|0])?819:821)+a|0];vb(f+8|0,d+1074308|0,34);a:{if(!tb(f+8|0)){break a}if(e){if(e>>>0>120){break a}e=q[Yb(p[a+656>>2]+108|0,e+ -1|0)|0];break a}e=0}g=a,h=ji(w(w(w(p[a+704>>2]<<4)*b)*Tja(p[p[a+656>>2]+44>>2],(c+e<<16)+ -3997696>>16,p[a+876>>2]+p[a+768>>2]|0))),p[g+700>>2]=h}fb=f+16|0}function Fka(a,b,c){var d=0,e=0;e=fb-32|0;fb=e;a:{b:{if((p[qb(a)>>2]-p[a+4>>2]|0)/52>>>0>=b>>>0){Lw(a,b,c);break b}d=qb(a);d=uka(e+8|0,DI(a,of(a)+b|0),of(a),d);p[114610]=0;N(1585,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(1586,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}vI(d)}fb=e+32|0;return}a=I()|0;H()|0;vI(d);L(a|0);E()}function zea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;p[114610]=0;S(2015,a|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[a+16>>2]=0;p[a+12>>2]=c;p[a+8>>2]=b;return}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34735,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)!=1){V();return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function oI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;e=0;a:{if(!tf(p[p[a>>2]+ -12>>2]+a|0)){break a}p[c+12>>2]=0;ni(a,c+12|0);d=p[c+12>>2];e=0;if(d>>>0>65535){break a}cl(b,d);if(p[c+12>>2]){while(1){p[c+8>>2]=0;po(a,c+8|0);d=p[c+8>>2];g=Fb(b,f),h=d,p[g>>2]=h;f=f+1|0;if(f>>>0<s[c+12>>2]){continue}break}}e=tf(p[p[a>>2]+ -12>>2]+a|0)}d=e;fb=c+16|0;return d}function nI(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=0;a:{if(!tf(p[p[a>>2]+ -12>>2]+a|0)){break a}o[c+14>>1]=0;mf(a,c+14|0);e=r[c+14>>1];d=0;if(e>>>0>65535){break a}cl(b,e);if(r[c+14>>1]){e=0;while(1){p[c+8>>2]=0;po(a,c+8|0);d=p[c+8>>2];f=Fb(b,e),g=d,p[f>>2]=g;e=e+1|0;if(e>>>0<r[c+14>>1]){continue}break}}d=tf(p[p[a>>2]+ -12>>2]+a|0)}a=d;fb=c+16|0;return a}function Qra(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;i=p[a+4>>2];d=(i-d|0)+b|0;e=Gh(g,a,c-d>>1);a:{if(c>>>0>d>>>0){f=d;while(1){h=qb(a);j=p[e+4>>2];p[114610]=0;N(1249,h|0,j|0,f|0);h=p[114610];p[114610]=0;if((h|0)==1){break a}p[e+4>>2]=p[e+4>>2]+2;f=f+2|0;if(f>>>0<c>>>0){continue}break}}Db(e);it(b,d,i);fb=g+16|0;return}a=I()|0;H()|0;Db(e);L(a|0);E()}function QKa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;i=p[a+4>>2];d=(i-d|0)+b|0;e=Gh(g,a,c-d>>1);a:{if(c>>>0>d>>>0){f=d;while(1){h=qb(a);j=p[e+4>>2];p[114610]=0;N(522,h|0,j|0,f|0);h=p[114610];p[114610]=0;if((h|0)==1){break a}p[e+4>>2]=p[e+4>>2]+2;f=f+2|0;if(f>>>0<c>>>0){continue}break}}Db(e);wKa(b,d,i);fb=g+16|0;return}a=I()|0;H()|0;Db(e);L(a|0);E()}function Vua(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;i=p[a+4>>2];d=(i-d|0)+b|0;e=he(g,a,c-d>>2);a:{if(c>>>0>d>>>0){f=d;while(1){h=qb(a);j=p[e+4>>2];p[114610]=0;N(770,h|0,j|0,f|0);h=p[114610];p[114610]=0;if((h|0)==1){break a}p[e+4>>2]=p[e+4>>2]+4;f=f+4|0;if(f>>>0<c>>>0){continue}break}}Db(e);it(b,d,i);fb=g+16|0;return}a=I()|0;H()|0;Db(e);L(a|0);E()}function Ko(a,b,c,d){a:{if(p[a+480180>>2]==4){if(c){n[b+830|0]=q[b+830|0]&15|c<<4;break a}c=q[b+830|0]>>>4|0;break a}if(d){if(c){n[b+854|0]=c;break a}c=q[b+854|0];break a}if(c){n[b+830|0]=c;break a}c=q[b+830|0]}b:{if(!(n[b+872|0]&1)){break b}c=p[b+688>>2]+((c&255)<<2)|0;p[b+688>>2]=(c|0)<256?c:256;if(!(p[a+480180>>2]&1)){break b}p[b+88>>2]=p[b+88>>2]|2097152}}function D6(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=fb-80|0;fb=f;if((c|0)>=1){g=f|8;h=f|4;while(1){d=ac(f,a,72);e=p[b+20>>2];p[a+16>>2]=p[b+16>>2];p[a+20>>2]=e;e=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=e;e=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=e;e=d;d=b+24|0;Ov(e,a+24|0,d);Ov(h,a+48|0,d);Ov(g,b,d);a=a+72|0;b=b+36|0;d=(c|0)>1;c=c+ -1|0;if(d){continue}break}}fb=f+80|0}function Bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=_h(a,b,c,d);p[a+4272>>2]=1065353216;p[a+4216>>2]=1056964608;p[a+4208>>2]=1056880300;p[a+4212>>2]=1050733080;p[a>>2]=81772;p[114610]=0;P(1639,a+44|0,2,2)|0;c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;S(1640,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}return a|0}a=I()|0;H()|0;Ge(b);L(a|0);E()}function pN(a){var b=0;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=860902483){break a}b=a+4|0;b=q[b|0]|q[b+1|0]<<8;if((b<<24|b<<8&16711680)>>>16>>>0>2|q[a+6|0]>128){break a}b=a+200|0;b=q[b|0]|q[b+1|0]<<8;if((b<<24|b<<8&16711680)>>>16>>>0>3999){break a}b=a+140|0;if(!(q[b|0]|q[b+1|0]<<8)){break a}a=a+148|0;return(q[a|0]|q[a+1|0]<<8)==12800}return 0}function U0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;f=p[_b(a)>>2];d=p[c>>2]-p[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=p[b>>2];i=p[a>>2];g=oq((f|0)==2482?0:p[a>>2],d);if(g){if((f|0)!=2482){Cd(a)}p[e+4>>2]=2420;f=Hd(e+8|0,g,e+4|0);dD(a,f);wc(f);p[b>>2]=p[a>>2]+(h-i|0);p[c>>2]=d+p[a>>2];fb=e+16|0;return}Mu();E()}function M7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;c=no(e+24|0,c);p[114610]=0;f=p[b+12>>2];p[e+16>>2]=p[b+8>>2];p[e+20>>2]=f;f=p[b+4>>2];p[e+8>>2]=p[b>>2];p[e+12>>2]=f;U(2013,a+8|0,e+8|0,c|0,d|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){Nc(c);NF(a);b=MF(a+88|0);p[a>>2]=84280;p[b>>2]=84368;fb=e+32|0;return a|0}a=I()|0;H()|0;Nc(c);L(a|0);E()}function eHa(a,b,c){var d=0,e=0;e=fb-32|0;fb=e;a:{b:{if((p[qb(a)>>2]-p[a+4>>2]|0)/6>>>0>=b>>>0){jz(a,b,c);break b}d=qb(a);d=cQ(e+8|0,_y(a,Rf(a)+b|0),Rf(a),d);p[114610]=0;N(710,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(711,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Xs(d)}fb=e+32|0;return}a=I()|0;H()|0;Xs(d);L(a|0);E()}function aja(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=Ee(64);p[114610]=0;f=M(1427,d|0)|0;g=p[114610];p[114610]=0;a:{if((g|0)!=1){d=nx(e+8|0,f);f=p[d>>2];p[114610]=0;b=P(1633,f|0,b|0,c|0)|0;c=p[114610];p[114610]=0;b:{c:{if((c|0)!=1){if((b|0)==1){break c}mx(a);break b}a=I()|0;H()|0;Qf(d);break a}np(a,d)}Qf(d);fb=e+16|0;return}a=I()|0;H()|0;Nb(d)}L(a|0);E()}function KF(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b+ -1>>>0>=65535){a=W(8)|0;p[114610]=0;c=J(85,c|0,40472)|0;b=p[114610];p[114610]=0;if((b|0)==1){break c}dc(a,c);p[114610]=0;N(2009,a|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}b=I()|0;H()|0;pb(c);break b}p[p[a+32>>2]+1074416>>2]=b;fb=c+16|0;return}b=I()|0;H()|0;X(a|0)}L(b|0)}E()}function zJ(a,b){var c=0,d=0;a:{if(r[a+480188>>1]<=b>>>0){break a}b:{c:{c=v(b,896)+a|0;d=q[c+1075797|0];switch(d+ -31|0){case 1:break b;case 0:break c;default:break a}}if(!(q[a+480209|0]&16)){break a}}c=n[c+1075799|0];if((c|0)>=0){uK(a,b,(d|0)==32,((q[(v(b,896)+a|0)+1075848|0]<<5)+a|0)+901692|0,c&255);return}uK(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function kka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;o[a>>1]=0;c=Pj(a+4|0);d=Pj(a+16|0);p[a+36>>2]=0;e=Xc(a+40|0);f=jka(a+52|0);bi(c);o[a+28>>1]=65472;p[114610]=0;p[b+12>>2]=1065353216;N(1592,c|0,128,b+12|0);g=p[114610];p[114610]=0;if((g|0)!=1){p[a+32>>2]=0;o[a+30>>1]=0;bi(d);fb=b+16|0;return a|0}a=I()|0;H()|0;qQ(f);pb(e);Ef(d);Ef(c);L(a|0);E()}function gka(a,b,c){var d=0,e=0;e=fb-32|0;fb=e;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>2>>>0>=b>>>0){Gw(a,b,c);break b}d=qb(a);d=Iw(e+8|0,se(a,Bb(a)+b|0),Bb(a),d);p[114610]=0;N(1596,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(1597,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Dm(d)}fb=e+32|0;return}a=I()|0;H()|0;Dm(d);L(a|0);E()}function Nta(a,b,c){var d=0,e=0;e=fb-32|0;fb=e;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>5>>>0>=b>>>0){Yx(a,b,c);break b}d=qb(a);d=cM(e+8|0,Ol(a,ne(a)+b|0),ne(a),d);p[114610]=0;N(1194,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(1181,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}ns(d)}fb=e+32|0;return}a=I()|0;H()|0;ns(d);L(a|0);E()}function Mea(a,b,c,d,e,f,g,h,i,j){p[114610]=0;a=Da(2006,a|0,b|0,c|0,d|0)|0;b=p[114610];p[114610]=0;a:{if((b|0)==1){a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;ca(2e3,34545,e|0,f|0,g|0,h|0,i|0,j|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();a=-255}return a}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function l8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(e){j=c+16|0;while(1){g=0;if(d){while(1){f=p[Bf(b,g,h)>>2];i=nf(c,g);f=f+(p[i>>2]>>1)|0;k=f;f=gr(j)+f&-4096;p[i>>2]=k-f;f=f+ -2147481600>>>12|0;f=f>>>0>491520?f:491520;l=sm(a,g,h),m=(f|0)<557055?f:557055,o[l>>1]=m;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function em(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;qc(d+8|0,b);p[114610]=0;b=M(2450,d+8|0)|0;e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}p[114610]=0;e=M(2460,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}p[c>>2]=e;p[114610]=0;K(2461,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Gb(d+8|0);fb=d+16|0;return}a=I()|0;H()|0;Gb(d+8|0);L(a|0);E()}function O8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(e){j=c+16|0;while(1){g=0;if(d){while(1){f=p[Bf(b,g,h)>>2];i=nf(c,g);f=f+(p[i>>2]>>1)|0;k=f;f=gr(j)+f&-4096;p[i>>2]=k-f;f=f+ -2147481600>>>12|0;f=f>>>0>491520?f:491520;l=um(a,g,h),m=(f|0)<557055?f:557055,o[l>>1]=m;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function Fq(a,b,c,d){var e=0,f=0;e=fb-160|0;fb=e;ac(e+8|0,58064,144);a:{b:{if(b+ -1>>>0>=2147483647){if(b){break b}b=1;a=e+159|0}p[e+52>>2]=a;p[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;p[e+56>>2]=b;a=a+b|0;p[e+36>>2]=a;p[e+24>>2]=a;a=OE(e+8|0,c,d,2303,2304);if(!b){break a}b=p[e+28>>2];n[b-((b|0)==p[e+24>>2])|0]=0;break a}p[114584]=61;a=-1}fb=e+160|0;return a}function pNa(a,b,c){var d=0,e=0;e=fb-32|0;fb=e;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>1>>>0>=b>>>0){Gt(a,b,c);break b}d=qb(a);d=Ft(e+8|0,Ai(a,fc(a)+b|0),fc(a),d);p[114610]=0;N(379,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(380,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}vk(d)}fb=e+32|0;return}a=I()|0;H()|0;vk(d);L(a|0);E()}function nsa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if((p[qb(a)>>2]-p[a+4>>2]|0)/12>>>0>=b>>>0){bsa(a,b);break b}c=qb(a);c=asa(d+8|0,km(a,nc(a)+b|0),nc(a),c);p[114610]=0;K(1235,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(1236,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}oL(c)}fb=d+32|0;return}a=I()|0;H()|0;oL(c);L(a|0);E()}function gm(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;qc(d+8|0,b);p[114610]=0;b=M(2416,d+8|0)|0;e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}p[114610]=0;e=M(2431,b|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break a}n[c|0]=e;p[114610]=0;K(2432,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Gb(d+8|0);fb=d+16|0;return}a=I()|0;H()|0;Gb(d+8|0);L(a|0);E()}function ZCa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=w(0),h=0,i=0,j=0,k=0;f=fb-16|0;fb=f;if(d){a=a+e|0;e=0;while(1){p[f+12>>2]=p[b>>2];Td(f+12|0,w(-1));g=w(t[f+12>>2]*w(128));t[f+12>>2]=g;i=a;g=$d(g);a:{if(w(x(g))<w(2147483648)){h=~~g;break a}h=-2147483648}j=i,k=PCa(h),n[j|0]=k;a=a+c|0;b=b+4|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}fb=f+16|0}function Qw(a,b,c,d){var e=0,f=0;a:{e=q[a|0];f=q[c|0];b:{if(!(q[d|0]|((e|0)!=11|(f+ -5&255)>>>0>1))){n[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(q[b|0]|(e+ -5&255)>>>0>1){break a}n[a|0]=(e|0)==5?7:6;n[b|0]=q[d|0];break b}if(!((e|0)!=10|(f|0)!=20|q[d|0]!=159)){n[a|0]=39;break b}if((f|0)!=10|(e|0)!=20|q[b|0]!=159){break a}n[a|0]=39;n[b|0]=q[d|0]}n[c|0]=0}}function Nea(a,b,c,d,e,f,g,h,i,j,k,l){p[114610]=0;a=VB(2005,a,b,c,d,e,f);b=p[114610];p[114610]=0;a:{if((b|0)==1){a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;ca(2e3,34519,g|0,h|0,i|0,j|0,k|0,l|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();a=-255}return a}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=_h(a,b,c,d);c=a+4216|0;p[c>>2]=1051372203;p[c+4>>2]=0;p[a+4208>>2]=1065353216;p[a+4212>>2]=1065353216;p[a>>2]=81976;p[114610]=0;P(1639,a+44|0,2,2)|0;c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;S(1640,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}return a|0}a=I()|0;H()|0;Ge(b);L(a|0);E()}function rGa(a,b,c){var d=0,e=0;e=fb-32|0;fb=e;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>2>>>0>=b>>>0){dT(a,b,c);break b}d=qb(a);d=hs(e+8|0,se(a,Bb(a)+b|0),Bb(a),d);p[114610]=0;N(738,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(96,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Wj(d)}fb=e+32|0;return}a=I()|0;H()|0;Wj(d);L(a|0);E()}function fFa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if((p[qb(a)>>2]-p[a+4>>2]|0)/33>>>0>=b>>>0){dFa(a,b);break b}c=qb(a);c=bFa(d+8|0,cFa(a,gk(a)+b|0),gk(a),c);p[114610]=0;K(766,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(767,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}SP(c)}fb=d+32|0;return}a=I()|0;H()|0;SP(c);L(a|0);E()}function Eya(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if((p[qb(a)>>2]-p[a+4>>2]|0)/12>>>0>=b>>>0){rya(a,b);break b}c=qb(a);c=my(d+8|0,km(a,nc(a)+b|0),nc(a),c);p[114610]=0;K(1020,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(1021,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}hN(c)}fb=d+32|0;return}a=I()|0;H()|0;hN(c);L(a|0);E()}function XIa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a=qp(a);e=d,f=Ub(b),p[e+8>>2]=f;e=d,f=Vb(b),p[e>>2]=f;a:{if(Ab(d+8|0,d)){while(1){b=p[d+8>>2];if((xk(b)|0)==(c|0)){b=qb(b);p[114610]=0;K(604,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}}ok(d+8|0);if(Ab(d+8|0,d)){continue}break}}fb=d+16|0;return}b=I()|0;H()|0;$c(a);L(b|0);E()}function uia(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>11>>>0>=b>>>0){qia(a,b);break b}c=qb(a);c=WH(d+8|0,pia(a,$e(a)+b|0),$e(a),c);p[114610]=0;K(1648,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(1644,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Fr(c)}fb=d+32|0;return}a=I()|0;H()|0;Fr(c);L(a|0);E()}function oHa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if((p[qb(a)>>2]-p[a+4>>2]|0)/48>>>0>=b>>>0){dGa(a,b);break b}c=qb(a);c=qR(d+8|0,rR(a,si(a)+b|0),si(a),c);p[114610]=0;K(700,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(561,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}ht(c)}fb=d+32|0;return}a=I()|0;H()|0;ht(c);L(a|0);E()}function lba(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;a=Xg(a);p[114610]=0;K(2156,b+16|0,0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){c=Ub(b+16|0);d=Vb(b+16|0);e=p[Ic(b+8|0,a)>>2];p[114610]=0;P(2157,c|0,d|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)==1){break b}_w(b+16|0);fb=b+32|0;return}c=I()|0;H()|0;break a}c=I()|0;H()|0;_w(b+16|0)}bd(a);L(c|0);E()}function jHa(a,b,c){var d=0,e=0;e=fb-32|0;fb=e;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>>0>=b>>>0){lt(a,b,c);break b}d=qb(a);d=HA(e+8|0,Bl(a,Cc(a)+b|0),Cc(a),d);p[114610]=0;N(704,d|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(364,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Qp(d)}fb=e+32|0;return}a=I()|0;H()|0;Qp(d);L(a|0);E()}function FS(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=q[b|0]|q[b+1|0]<<8;c=NNa(q[a+3|0],0,18,0);d=d+c|0;b=ib;b=d>>>0<c>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=q[b|0]|q[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=q[a|0]|q[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;if(b>>>0<3){a=a+1|0}ib=a;return b}function Aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;p[114610]=0;S(2015,a|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[a+4>>2]=c;p[a>>2]=b?b:1997;return}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34707,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)!=1){V();return}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function rN(a){var b=0,c=0;a:{if(q[a+29|0]!=2){break a}b=q[a+28|0];if(q[a+30|0]!=2|((b|0)!=2?(b|0)!=26:0)){break a}b=q[a+31|0];if(b>>>0>21|!(1<<b&3146753)|q[a+33|0]>64){break a}b=q[a+34|0];if((b|0)!=88?b>>>0>=65:0){break a}b=a+28|0;a=a+20|0;while(1){c=q[a|0]+ -32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function b4(){var a=0;p[114610]=0;M(2392,460712)|0;a=p[114610];p[114610]=0;a:{if((a|0)==1){break a}p[114610]=0;M(2393,460796)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}p[114610]=0;M(2392,461048)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}p[114610]=0;M(2393,461132)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}return}a=O(0)|0;H()|0;rb(a);E()}function tia(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>2>>>0>=b>>>0){gia(a,b);break b}c=qb(a);c=UH(d+8|0,se(a,Bb(a)+b|0),Bb(a),c);p[114610]=0;K(1649,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(1646,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Er(c)}fb=d+32|0;return}a=I()|0;H()|0;Er(c);L(a|0);E()}function iBa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>3>>>0>=b>>>0){hBa(a,b);break b}c=qb(a);c=fBa(d+8|0,gBa(a,ng(a)+b|0),ng(a),c);p[114610]=0;K(925,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(926,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}pO(c)}fb=d+32|0;return}a=I()|0;H()|0;pO(c);L(a|0);E()}function cka(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>2>>>0>=b>>>0){xja(a,b);break b}c=qb(a);c=Iw(d+8|0,se(a,Bb(a)+b|0),Bb(a),c);p[114610]=0;K(1598,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(1597,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Dm(c)}fb=d+32|0;return}a=I()|0;H()|0;Dm(c);L(a|0);E()}function vMa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>1>>>0>=b>>>0){uMa(a,b);break b}c=qb(a);c=tMa(d+8|0,Ai(a,fc(a)+b|0),fc(a),c);p[114610]=0;K(423,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(424,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}MS(c)}fb=d+32|0;return}a=I()|0;H()|0;MS(c);L(a|0);E()}function qua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;p[d+16>>2]=b;e=d,f=Fy(a,b,c),p[e+24>>2]=f;a:{if(!Ab(d+24|0,d+16|0)){break a}p[d+8>>2]=p[d+24>>2];if(!Ab(te(d+8|0),d+16|0)){break a}while(1){if(r[p[d+8>>2]>>1]!=r[c>>1]){o[p[d+24>>2]>>1]=r[p[d+8>>2]>>1];te(d+24|0)}if(Ab(te(d+8|0),d+16|0)){continue}break}}fb=d+32|0;return p[d+24>>2]}function jGa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>2>>>0>=b>>>0){iGa(a,b);break b}c=qb(a);c=gGa(d+8|0,se(a,Bb(a)+b|0),Bb(a),c);p[114610]=0;K(741,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(742,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}hQ(c)}fb=d+32|0;return}a=I()|0;H()|0;hQ(c);L(a|0);E()}function Woa(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-192|0;fb=c;ac(c+144|0,b,44);d=p[b+44>>2];if(d){ac(c+44|0,b,44);g=c,h=K7(c+44|0),p[g+96>>2]=h;p[c+100>>2]=ib;b=p[c+100>>2];f=p[c+96>>2];e=Mra(Id(+(d>>>0)*.054945054945054944));d=f+e|0;b=ib+b|0;y7(c+96|0,OF(c+88|0,d,d>>>0<e>>>0?b+1|0:b));ac(c+144|0,c+96|0,44)}b=a;a=ac(c,c+144|0,44);d7(b,a);fb=a+192|0}function PDa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>2>>>0>=b>>>0){ODa(a,b);break b}c=qb(a);c=NDa(d+8|0,se(a,Bb(a)+b|0),Bb(a),c);p[114610]=0;K(823,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(824,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}pP(c)}fb=d+32|0;return}a=I()|0;H()|0;pP(c);L(a|0);E()}function FDa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>1>>>0>=b>>>0){EDa(a,b);break b}c=qb(a);c=DDa(d+8|0,Ai(a,fc(a)+b|0),fc(a),c);p[114610]=0;K(830,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(831,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}kP(c)}fb=d+32|0;return}a=I()|0;H()|0;kP(c);L(a|0);E()}function yAa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>2>>>0>=b>>>0){cO(a,b);break b}c=qb(a);c=xAa(d+8|0,se(a,Bb(a)+b|0),Bb(a),c);p[114610]=0;K(951,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(952,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}XN(c)}fb=d+32|0;return}a=I()|0;H()|0;XN(c);L(a|0);E()}function v$(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[sq(a)>>2]-p[a+4>>2]>>2>>>0>=b>>>0){TC(a,b);break b}c=Nk(a);c=CZ(d+8|0,DZ(a,Bb(a)+b|0),Bb(a),c);p[114610]=0;K(2562,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(2563,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}oC(c)}fb=d+32|0;return}a=I()|0;H()|0;oC(c);L(a|0);E()}function tY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb+ -64|0;fb=d;e=1;a:{if(Xf(a,b,0)){break a}e=0;if(!b){break a}b=ZB(b,71928);e=0;if(!b){break a}p[d+20>>2]=-1;p[d+16>>2]=a;p[d+12>>2]=0;p[d+8>>2]=b;Jb(d+24|0,0,39);p[d+56>>2]=1;m[p[p[b>>2]+28>>2]](b,d+8|0,p[c>>2],1);a=p[d+32>>2];if((a|0)==1){p[c>>2]=p[d+24>>2]}e=(a|0)==1}a=e;fb=d- -64|0;return a|0}function fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;a:{if(!(q[c+1|0]&4)){break a}c=p[c+4>>2];g=d,h=wd(b),p[g+8>>2]=h;b:{if(!wb(b)){break b}if(q[cc(b,0)|0]==43){bg(d+8|0);c=c+1|0;break b}if(q[cc(b,0)|0]!=45){break b}bg(d+8|0);c=c+1|0}if(wb(b)>>>0>=c>>>0){break a}e=Ld(d,d+8|0);f=wb(b);dw(b,p[e>>2],c-f|0,48)}Wc(a,b);fb=d+16|0}function rla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;a:{b:{e=lN(b,c);if((e|0)!=-1){f=d,g=wd(b),p[f+16>>2]=g;f=d,g=lf(d+16|0,e),p[f+24>>2]=g;f=d,g=lf(d+24|0,1),p[f+32>>2]=g;c=Ld(d+40|0,d+32|0);f=d,g=jf(b),p[f>>2]=g;e=Ld(d+8|0,d);Nx(b,p[c>>2],p[e>>2]);break b}if(!wb(b)){break b}if(gL(b,c)){break b}Lb(a);break a}Wc(a,b)}fb=d+48|0}function kBa(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+24|0]=0;n[a+25|0]=0;n[a+16|0]=0;n[a+17|0]=0;n[a+18|0]=0;n[a+19|0]=0;n[a+20|0]=0;n[a+21|0]=0;n[a+22|0]=0;n[a+23|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;fb=b+16|0}function hFa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>4>>>0>=b>>>0){bT(a,b);break b}c=qb(a);c=dR(d+8|0,mq(a,gd(a)+b|0),gd(a),c);p[114610]=0;K(764,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(612,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}et(c)}fb=d+32|0;return}a=I()|0;H()|0;et(c);L(a|0);E()}function era(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c>>>2;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=(ub(q[b|0])|ub(q[b+1|0])<<8)^32768,o[f>>1]=g;f=a,g=(ub(q[b+2|0])|ub(q[b+3|0])<<8)^32768,o[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e<<2}function bra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c>>>2;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=(ub(q[b+1|0])|ub(q[b|0])<<8)^32768,o[f>>1]=g;f=a,g=(ub(q[b+3|0])|ub(q[b+2|0])<<8)^32768,o[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e<<2}function aZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-16|0;fb=f;p[f+8>>2]=e;p[f+12>>2]=c;c=wb(a);if(!((e|0)==-1|c>>>0<b>>>0)){p[f>>2]=c-b;g=f,h=p[Cb(f+12|0,f)>>2],p[g+4>>2]=h;b=Jm(Ib(a)+b|0,d,p[Cb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=p[f+4>>2];c=p[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}fb=f+16|0;return b|0}Yl();E()}function aNa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;a:{b:{e=lN(b,c);if((e|0)!=-1){f=d,g=wd(b),p[f+16>>2]=g;f=d,g=lf(d+16|0,e),p[f+24>>2]=g;f=d,g=lf(d+24|0,1),p[f+32>>2]=g;c=Ld(d+40|0,d+32|0);f=d,g=jf(b),p[f>>2]=g;e=Ld(d+8|0,d);Nx(b,p[c>>2],p[e>>2]);break b}if(!wb(b)){break b}if(gL(b,c)){break b}Xc(a);break a}Wc(a,b)}fb=d+48|0}function TMa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>1>>>0>=b>>>0){RS(a,b);break b}c=qb(a);c=Ft(d+8|0,Ai(a,fc(a)+b|0),fc(a),c);p[114610]=0;K(410,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(380,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}vk(c)}fb=d+32|0;return}a=I()|0;H()|0;vk(c);L(a|0);E()}function Pra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{c=Fl(e,a+8|0,Lx(b,c));if(p[c>>2]!=p[c+4>>2]){while(1){d=p[a+16>>2];f=p[c>>2];p[114610]=0;N(1250,d|0,f|0,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[c>>2]+2|0;p[c>>2]=d;b=b+2|0;if((d|0)!=p[c+4>>2]){continue}break}}lc(c);fb=e+16|0;return}a=I()|0;H()|0;lc(c);L(a|0);E()}function Jia(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((Cc(p[a+20>>2]+4|0)|0)!=8){break b}c=p[p[a+20>>2]+4>>2];if((q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))!=1869112133){break b}b=p[p[a+20>>2]+4>>2];c=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);b=q[b+4|0]|q[b+5|0]<<8|(q[b+6|0]<<16|q[b+7|0]<<24);p[a+4260>>2]=c;p[a+4264>>2]=b;break a}DH(a,b)}Gr(a)}function Gl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;n[d+15|0]=b;a:{b:{c:{d:{if(ze(a)){c=Sj(a)+ -1|0;e=p[a+4>>2];if((c|0)==(e|0)){break d}break b}e=10;c=10;b=q[a+11|0];if((b|0)!=10){break c}}El(a,c,1,c,c,0,0);b=e;if(ze(a)){break b}}c=a;cf(a,b+1|0);break a}c=p[a>>2];oe(a,e+1|0);b=e}a=b+c|0;ae(a,d+15|0);n[d+14|0]=0;ae(a+1|0,d+14|0);fb=d+16|0}function cU(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>2>>>0>=b>>>0){QT(a,b);break b}c=qb(a);c=An(d+8|0,se(a,Bb(a)+b|0),Bb(a),c);p[114610]=0;K(367,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(368,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Fh(c)}fb=d+32|0;return}a=I()|0;H()|0;Fh(c);L(a|0);E()}function bZ(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>4>>>0>=b>>>0){eX(a,b);break b}c=qb(a);c=dX(d+8|0,mq(a,gd(a)+b|0),gd(a),c);p[114610]=0;K(211,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(212,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}SB(c)}fb=d+32|0;return}a=I()|0;H()|0;SB(c);L(a|0);E()}function Jo(a,b,c,d){a:{if(p[a+480180>>2]==4){d=q[b+830|0];if(c){n[b+830|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){n[b+854|0]=c;break a}c=q[b+854|0];break a}if(c){n[b+830|0]=c;break a}c=q[b+830|0]}b:{if(!(n[b+872|0]&1)){break b}c=p[b+688>>2]-((c&255)<<2)|0;p[b+688>>2]=(c|0)>0?c:0;if(!(p[a+480180>>2]&1)){break b}p[b+88>>2]=p[b+88>>2]|2097152}}function we(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(!wb(a)|(c-b|0)<5){break a}Xn(b,c);e=c+ -4|0;c=Ib(a);f=c+wb(a)|0;while(1){b:{a=n[c|0];if(b>>>0>=e>>>0){break b}if((a|0)<1|(a|0)>=127|p[b>>2]==n[c|0]){c=(f-c|0)>1?c+1|0:c;b=b+4|0;continue}else{p[d>>2]=4;return}}break}if((a|0)<1|(a|0)>=127|p[e>>2]+ -1>>>0<n[c|0]>>>0){break a}p[d>>2]=4}}function gC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;p[d+12>>2]=b;a:{b:{c:{d:{if(ze(a)){c=Sj(a)+ -1|0;e=p[a+4>>2];if((c|0)==(e|0)){break d}break b}e=1;c=1;b=q[a+11|0];if((b|0)!=1){break c}}hC(a,c,1,c,c);b=e;if(ze(a)){break b}}c=a;cf(a,b+1|0);break a}c=p[a>>2];oe(a,e+1|0);b=e}a=(b<<2)+c|0;Je(a,d+12|0);p[d+8>>2]=0;Je(a+4|0,d+8|0);fb=d+16|0}function bQ(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=p[a>>2];b:{if(!b){break b}c=p[a+8>>2];if(!c){break b}d=p[a+12>>2];if(!d){break b}a=m[d|0](b)|0;e=ib;f=e;if((e|0)<0?1:(e|0)<=0?a>>>0<0:0){break b}if((m[c|0](b,0,0,0)|0)<=-1){break a}if((m[c|0](b,0,0,2)|0)<=-1){break a}m[d|0](b)|0;d=ib;m[c|0](b,a,f,0)|0;g=(d|0)>-1}return g}m[c|0](b,a,f,0)|0;return 0}function KFa(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(!b){break a}if(!Hb(a,b)){break a}while(1){n[c+11|0]=0;b:{if(d>>>0<b>>>0){Kf(a,c+11|0);e=n[c+11|0];f=e>>>31|0;break b}e=0-f|0;n[c+11|0]=e}n[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}p[c+4>>2]=p[c+12>>2];a=c+4|0;d=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24)}fb=c+16|0;return d}function Gca(a,b){a=a|0;b=b|0;var c=0;if(s[a+44>>2]<s[a+24>>2]){p[a+44>>2]=p[a+24>>2]}a:{if(s[a+8>>2]>=s[a+12>>2]){break a}if(me(b,-1)){Bm(a,p[a+8>>2],p[a+12>>2]+ -1|0,p[a+44>>2]);return pr(b)|0}if(!(q[a+48|0]&16)){if(!me(zm(b),n[p[a+12>>2]+ -1|0])){break a}}Bm(a,p[a+8>>2],p[a+12>>2]+ -1|0,p[a+44>>2]);c=zm(b);n[p[a+12>>2]]=c;return b|0}return-1}function xNa(a,b){if(!sNa(a,b)){a=fb-16|0;fb=a;n[b|0]=0;n[b+1|0]=0;n[b+2|0]=0;n[b+3|0]=0;n[b+4|0]=0;n[b+5|0]=0;n[b+6|0]=0;n[b+7|0]=0;n[b+24|0]=0;n[b+16|0]=0;n[b+17|0]=0;n[b+18|0]=0;n[b+19|0]=0;n[b+20|0]=0;n[b+21|0]=0;n[b+22|0]=0;n[b+23|0]=0;n[b+8|0]=0;n[b+9|0]=0;n[b+10|0]=0;n[b+11|0]=0;n[b+12|0]=0;n[b+13|0]=0;n[b+14|0]=0;n[b+15|0]=0;fb=a+16|0}}function mO(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=q[b|0]|q[b+1|0]<<8;b=NNa(q[a+30|0],0,37,0);c=ib;d=b;b=a+24|0;b=NNa(q[b|0]|q[b+1|0]<<8,0,192,0);d=d+b|0;c=ib+c|0;c=d>>>0<b>>>0?c+1|0:c;b=c;f=e;e=d;a=q[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=e>>>0<d>>>0?a+1|0:a;b=e;c=f+b|0;if(c>>>0<b>>>0){a=a+1|0}b=c+192|0;if(b>>>0<192){a=a+1|0}ib=a;return b}function hpa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;b=_b(b);a=gpa(a,gc(20,4),hk(e+8|0,b));f=p[a>>2];p[114610]=0;f=M(1380,f+14|0)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;_(1383,b|0,f|0,20421,c|0,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}h=_b(a),i=1,n[h+4|0]=i;fb=e+16|0;return}b=I()|0;H()|0;jK(a);L(b|0);E()}function Jh(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e+307;if((b|0)<2047){b=b+ -1023|0;break a}a=a*8.98846567431158e+307;b=((b|0)<3069?b:3069)+ -2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if((b|0)>-2045){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=((b|0)>-3066?b:-3066)+2044|0}f(0,0);f(1,b+1023<<20);return a*+g()}function J6(a,b,c,d,e){var f=0,g=0,h=0,i=w(0),j=0,k=0,l=0;if((d|0)>=1){while(1){f=q[b|0];g=0;a:{if(!f){break a}g=19>>>q[c+h|0]&3|4}b=b+1|0;l=v(f,3)+ -6|0;f=4;i=w(0);while(1){if(f&g){j=Kd(a,6);k=(j|0)/3|0;i=w(t[((j-v(k,3)|0)+l<<2)+50144>>2]*w(2097152>>>k|0))}t[e>>2]=i;e=e+4|0;f=f>>1;if(f){continue}break}h=h+1|0;if((h|0)!=(d|0)){continue}break}}}function Dca(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;b=_b(b);a=Gra(a,gc(40,4),hk(e+8|0,b));f=p[a>>2];p[114610]=0;f=M(1257,f+16|0)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;_(2108,b|0,f|0,38031,c|0,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}h=_b(a),i=1,n[h+4|0]=i;fb=e+16|0;return}b=I()|0;H()|0;kL(a);L(b|0);E()}function sja(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;b=_b(b);a=rja(a,gc(32,4),hk(e+8|0,b));f=p[a>>2];p[114610]=0;f=M(735,f+16|0)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;_(1622,b|0,f|0,32466,c|0,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}h=_b(a),i=1,n[h+4|0]=i;fb=e+16|0;return}b=I()|0;H()|0;iI(a);L(b|0);E()}function kJ(a,b){var c=0,d=0,e=0,f=0;if(b){Tsa(a+327720|0);Zw(a+131112|0,9.6377,.97);Zw(a+196648|0,8.5,.5);Zw(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(d=0,e=jJ(c,a),f=b,f?d:e)){gma(a+24|0,u[a+8>>3],q[a+16|0]);b=p[a+20>>2];p[c+16>>2]=p[a+16>>2];p[c+20>>2]=b;b=p[a+12>>2];p[c+8>>2]=p[a+8>>2];p[c+12>>2]=b;b=p[a+4>>2];p[c>>2]=p[a>>2];p[c+4>>2]=b}}function iU(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>>0>=b>>>0){GA(a,b);break b}c=qb(a);c=HA(d+8|0,Bl(a,Cc(a)+b|0),Cc(a),c);p[114610]=0;K(363,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(364,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Qp(c)}fb=d+32|0;return}a=I()|0;H()|0;Qp(c);L(a|0);E()}function dra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>2;p[e+8>>2]=p[a>>2];f=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(f){a=p[a+20>>2];c=f;g=d;while(1){g=(ub(q[b|0])|ub(q[b+1|0])<<8)+g|0;o[a>>1]=g;d=(ub(q[b+2|0])|ub(q[b+3|0])<<8)+d|0;o[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return f<<2}function ara(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>2;p[e+8>>2]=p[a>>2];f=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(f){a=p[a+20>>2];c=f;g=d;while(1){g=(ub(q[b+1|0])|ub(q[b|0])<<8)+g|0;o[a>>1]=g;d=(ub(q[b+3|0])|ub(q[b+2|0])<<8)+d|0;o[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return f<<2}function VY(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>>0>=b>>>0){_W(a,b);break b}c=qb(a);c=Vu(d+8|0,Bl(a,Cc(a)+b|0),Cc(a),c);p[114610]=0;K(213,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(209,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}$l(c)}fb=d+32|0;return}a=I()|0;H()|0;$l(c);L(a|0);E()}function yDa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;b=_b(b);a=xDa(a,gc(20,4),hk(e+8|0,b));f=p[a>>2];p[114610]=0;f=M(827,f+14|0)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;_(833,b|0,f|0,15161,c|0,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}h=_b(a),i=1,n[h+4|0]=i;fb=e+16|0;return}b=I()|0;H()|0;jP(a);L(b|0);E()}function PJa(a,b){var c=0,d=0;d=fb-32|0;fb=d;a:{b:{if(p[qb(a)>>2]-p[a+4>>2]>>>0>=b>>>0){LR(a,b);break b}c=qb(a);c=AT(d+8|0,Bl(a,Cc(a)+b|0),Cc(a),c);p[114610]=0;K(41,c|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}p[114610]=0;K(40,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Ht(c)}fb=d+32|0;return}a=I()|0;H()|0;Ht(c);L(a|0);E()}function AGa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;b=_b(b);a=zGa(a,gc(32,4),hk(e+8|0,b));f=p[a>>2];p[114610]=0;f=M(731,f+16|0)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;_(732,b|0,f|0,14646,c|0,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}h=_b(a),i=1,n[h+4|0]=i;fb=e+16|0;return}b=I()|0;H()|0;rQ(a);L(b|0);E()}function apa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;b=_b(b);a=$oa(a,kK(1),hk(e+8|0,b));f=p[a>>2];p[114610]=0;f=M(1385,f+16|0)|0;g=p[114610];p[114610]=0;a:{if((g|0)==1){break a}p[114610]=0;_(1387,b|0,f|0,20421,c|0,d|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}h=_b(a),i=1,n[h+4|0]=i;fb=e+16|0;return}b=I()|0;H()|0;hK(a);L(b|0);E()}function Vaa(a){var b=0,c=0;b=fb-16|0;fb=b;a:{b:{c:{if(a>>>0>=6){c=W(8)|0;p[114610]=0;b=J(85,b|0,39744)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}dc(c,b);p[114610]=0;N(2009,c|0,83568,2017);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(b);break b}fb=b+16|0;return p[(a<<24>>24<<2)+40448>>2]}a=I()|0;H()|0;X(c|0)}L(a|0)}E()}function kna(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;a:{if(!dx(a,b,1)){break a}e=p[b+656>>2];d=a+1074308|0;vb(c+8|0,d,31);b:{if(tb(c+8|0)){a=p[b+740>>2];if(a){break b}break a}a=p[b+740>>2]}vb(c+8|0,d,31);d=Zo(e+68|0,a-tb(c+8|0)|0,64,64)+ -32|0;a=p[b+684>>2];f=b,g=Pb(((v(d,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),p[f+684>>2]=g}fb=c+16|0}function Gq(a){var b=0,c=0,d=0,e=0,f=0;e=ve(a);a:{b:{if(!p[115396]|!q[a|0]){break b}b=LD(a,61);if(q[b|0]==61?b:0){break b}b=p[p[115396]>>2];if(!b){break b}while(1){c:{d=O5(a,b,e);b=p[115396];if(!d){d=p[b+(c<<2)>>2];f=d+e|0;if(q[f|0]==61){break c}}c=c+1|0;b=p[b+(c<<2)>>2];if(b){continue}break a}break}if(!d){break a}c=f+1|0}return c}return 0}function F6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;p[d+8>>2]=-1;p[d>>2]=-1;p[d+4>>2]=-1;if((c|0)>=1){while(1){h=b+e|0;f=q[h|0];a:{if(!f){f=0;break a}g=0;while(1){i=g<<2;if(!(t[i+a>>2]!=w(0)|t[(i|4)+a>>2]!=w(0))){g=g+2|0;if(g>>>0<f>>>0){continue}break a}break}p[((e>>>0)%3<<2)+d>>2]=e;f=q[h|0]}a=(f<<2)+a|0;e=e+1|0;if((e|0)!=(c|0)){continue}break}}}function vz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;p[f+12>>2]=c;vc(f+12|0,256);vc(f+12|0,65535);h=r[f+12>>1];ig(a,h);if(h){c=0;while(1){g=q[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=wk(a,c),j=g,o[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}fb=f+16|0;return 1}function Du(a,b,c,d){n[a+53|0]=1;a:{if(p[a+4>>2]!=(c|0)){break a}n[a+52|0]=1;c=p[a+16>>2];if(!c){p[a+36>>2]=1;p[a+24>>2]=d;p[a+16>>2]=b;if((d|0)!=1|p[a+48>>2]!=1){break a}n[a+54|0]=1;return}if((b|0)==(c|0)){c=p[a+24>>2];if((c|0)==2){p[a+24>>2]=d;c=d}if(p[a+48>>2]!=1|(c|0)!=1){break a}n[a+54|0]=1;return}n[a+54|0]=1;p[a+36>>2]=p[a+36>>2]+1}}function zla(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=yla(d+8|0,pk(a,Dd(a)+1|0),Dd(a),e);f=p[c+8>>2];p[114610]=0;N(1561,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+24;p[114610]=0;K(1562,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}UI(c);fb=d+32|0;return}a=I()|0;H()|0;UI(c);L(a|0);E()}function Wpa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=mpa(d+8|0,Ol(a,ne(a)+1|0),ne(a),e);f=p[c+8>>2];p[114610]=0;N(1371,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+32;p[114610]=0;K(1372,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}lK(c);fb=d+32|0;return}a=I()|0;H()|0;lK(c);L(a|0);E()}function El(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;if(-17-b>>>0>=c>>>0){i=Ib(a);a:{if(2147483623>b>>>0){p[h+8>>2]=b<<1;p[h+12>>2]=b+c;c=Ok(p[Uc(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=Si(j);if(e){uh(c,i,e)}d=(d-f|0)-e|0;if(d){uh((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){cg(a,i,b)}sf(a,c);sg(a,j);fb=h+16|0;return}tg();E()}function noa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=zna(d+8|0,se(a,Bb(a)+1|0),Bb(a),e);f=p[c+8>>2];p[114610]=0;N(1421,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+4;p[114610]=0;K(1422,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}DJ(c);fb=d+32|0;return}a=I()|0;H()|0;DJ(c);L(a|0);E()}function aua(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=cM(d+8|0,Ol(a,ne(a)+1|0),ne(a),e);f=p[c+8>>2];p[114610]=0;N(1180,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+32;p[114610]=0;K(1181,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}ns(c);fb=d+32|0;return}a=I()|0;H()|0;ns(c);L(a|0);E()}function _za(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=Eza(d+8|0,Fza(a,ak(a)+1|0),ak(a),e);f=p[c+8>>2];p[114610]=0;N(979,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+56;p[114610]=0;K(980,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}KN(c);fb=d+32|0;return}a=I()|0;H()|0;KN(c);L(a|0);E()}function _Ea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;if(q[a+40|0]){e=0}else{a:{b:{d=p[a+28>>2];if(d){if(!c){break a}d=m[d|0](p[a+24>>2],b,c)|0;if(!d){break b}while(1){e=d+e|0;if(e>>>0<d>>>0){f=f+1|0}c=c-d|0;if(!c){break a}b=b+d|0;d=m[p[a+28>>2]](p[a+24>>2],b,c)|0;if(d){continue}break}break b}n[a+40|0]=1;return 0}n[a+40|0]=1}}return e|0}function Yia(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=Xia(d+8|0,se(a,Bb(a)+1|0),Bb(a),e);f=p[c+8>>2];p[114610]=0;N(1635,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+4;p[114610]=0;K(1636,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}cI(c);fb=d+32|0;return}a=I()|0;H()|0;cI(c);L(a|0);E()}function Uma(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=Kma(d+8|0,se(a,Bb(a)+1|0),Bb(a),e);f=p[c+8>>2];p[114610]=0;N(1518,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+4;p[114610]=0;K(1519,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}hJ(c);fb=d+32|0;return}a=I()|0;H()|0;hJ(c);L(a|0);E()}function SAa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;a:{if(Fs(a)>>>0<b>>>0){qb(a);d=yy(c+32|0);p[114610]=0;K(937,d|0,b|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}ej(c+16|0,a);bk(c+8|0,a);p[114610]=0;N(938,d|0,c+16|0,c+8|0);b=p[114610];p[114610]=0;if((b|0)==1){break a}xy(a,d);ce(d)}fb=c+48|0;return}a=I()|0;H()|0;ce(d);L(a|0);E()}function Rba(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=i9(d+8|0,mq(a,gd(a)+1|0),gd(a),e);f=p[c+8>>2];p[114610]=0;N(2127,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+16;p[114610]=0;K(2128,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}$F(c);fb=d+32|0;return}a=I()|0;H()|0;$F(c);L(a|0);E()}function ML(a){n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+23|0]=0;n[a+24|0]=0;n[a+25|0]=0;n[a+26|0]=0;n[a+16|0]=0;n[a+17|0]=0;n[a+18|0]=0;n[a+19|0]=0;n[a+20|0]=0;n[a+21|0]=0;n[a+22|0]=0;n[a+23|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0}function Jra(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=iL(d+8|0,km(a,nc(a)+1|0),nc(a),e);f=p[c+8>>2];p[114610]=0;N(1255,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+12;p[114610]=0;K(1256,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}gs(c);fb=d+32|0;return}a=I()|0;H()|0;gs(c);L(a|0);E()}function Hba(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=c9(d+8|0,pk(a,Dd(a)+1|0),Dd(a),e);f=p[c+8>>2];p[114610]=0;N(2132,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+24;p[114610]=0;K(2133,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}ZF(c);fb=d+32|0;return}a=I()|0;H()|0;ZF(c);L(a|0);E()}function Dxa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=uxa(d+8|0,se(a,Bb(a)+1|0),Bb(a),e);f=p[c+8>>2];p[114610]=0;N(1058,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+4;p[114610]=0;K(1059,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}VM(c);fb=d+32|0;return}a=I()|0;H()|0;VM(c);L(a|0);E()}function Bya(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=my(d+8|0,km(a,nc(a)+1|0),nc(a),e);f=p[c+8>>2];p[114610]=0;N(1022,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+12;p[114610]=0;K(1017,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}ys(c);fb=d+32|0;return}a=I()|0;H()|0;ys(c);L(a|0);E()}function yP(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=a;f=+(v(a,d)>>>0)*2500;a:{if(c){break a}b:{if(!(!a|!b)){vc(e+12|0,10);a=q[p[e+12>>2]+15150|0];p[e+12>>2]=a;break b}if(a+ -1>>>0>9){break b}f=7338401.379310345/+(a>>>0);break a}f=+(a>>>0)*37878.78787878787}g=f;c:{if(f<4294967296&f>=0){a=~~g>>>0;break c}a=0}fb=e+16|0;return a}function vta(a,b,c){var d=0,e=0,f=0,g=0;e=p[a>>2];d=p[a+4>>2];if((e|0)<=(d|0)){f=a+14|0;g=a+12|0;while(1){p[a+8>>2]=p[a+12>>2];uta(a,g,f);e=p[a>>2];d=p[a+4>>2]-e|0;p[a+4>>2]=d;if((e|0)<=(d|0)){continue}break}}f=b;b=e-d|0;o[f>>1]=(v(o[a+12>>1],d)+v(b,o[a+8>>1])|0)/(e|0);o[c>>1]=(v(o[a+14>>1],d)+v(b,o[a+10>>1])|0)/(e|0);p[a+4>>2]=d+49716}function tJa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=rJa(d+8|0,pk(a,Dd(a)+1|0),Dd(a),e);f=p[c+8>>2];p[114610]=0;N(574,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+24;p[114610]=0;K(575,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}nR(c);fb=d+32|0;return}a=I()|0;H()|0;nR(c);L(a|0);E()}function fz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(q[a+20|0]){break a}b=(-1-b>>>0<c>>>0?-1-b|0:c)+b|0;if(b>>>0<=s[a+16>>2]){break a}b=nz(b,4096);GQ(a,b-p[a+16>>2]|0);d=a,e=(g=a,h=oc(a+4|0,p[a+16>>2]),i=b-p[a+16>>2]|0,f=p[p[a>>2]+48>>2],m[f](g|0,h|0,i|0)|0)+p[a+16>>2]|0,p[d+16>>2]=e;if(!(m[p[p[a>>2]+44>>2]](a)|0)){break a}n[a+20|0]=1}}function dha(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=AH(d+8|0,se(a,Bb(a)+1|0),Bb(a),e);f=p[c+8>>2];p[114610]=0;N(1762,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+4;p[114610]=0;K(1759,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yr(c);fb=d+32|0;return}a=I()|0;H()|0;yr(c);L(a|0);E()}function Lza(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=Kza(d+8|0,pk(a,Dd(a)+1|0),Dd(a),e);f=p[c+8>>2];p[114610]=0;N(988,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+24;p[114610]=0;K(989,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}MN(c);fb=d+32|0;return}a=I()|0;H()|0;MN(c);L(a|0);E()}function LEa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=IEa(d+8|0,pk(a,Dd(a)+1|0),Dd(a),e);f=p[c+8>>2];p[114610]=0;N(772,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+24;p[114610]=0;K(773,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}IP(c);fb=d+32|0;return}a=I()|0;H()|0;IP(c);L(a|0);E()}function KIa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=IIa(d+8|0,pk(a,Dd(a)+1|0),Dd(a),e);f=p[c+8>>2];p[114610]=0;N(608,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+24;p[114610]=0;K(609,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}eR(c);fb=d+32|0;return}a=I()|0;H()|0;eR(c);L(a|0);E()}function HKa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=EKa(d+8|0,pk(a,Dd(a)+1|0),Dd(a),e);f=p[c+8>>2];p[114610]=0;N(529,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+24;p[114610]=0;K(530,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}QR(c);fb=d+32|0;return}a=I()|0;H()|0;QR(c);L(a|0);E()}function Cja(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=Iw(d+8|0,se(a,Bb(a)+1|0),Bb(a),e);f=p[c+8>>2];p[114610]=0;N(1604,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+4;p[114610]=0;K(1597,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Dm(c);fb=d+32|0;return}a=I()|0;H()|0;Dm(c);L(a|0);E()}function zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jL(a);a:{if(!p[b+4>>2]){break a}c=p[b+4>>2];p[114610]=0;K(2180,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){c=p[b>>2];e=p[b>>2];f=v(p[b+4>>2],12);b=p[b+4>>2];p[114610]=0;Q(2181,a|0,c|0,e+f|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;TA(d);L(a|0);E()}return a|0}function tka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=qka(e,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){d=p[a+16>>2];f=p[b>>2];p[114610]=0;N(1581,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b>>2]+52|0;p[b>>2]=d;if((d|0)!=p[b+4>>2]){continue}break}}lc(b);fb=e+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function VJa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=qR(d+8|0,rR(a,si(a)+1|0),si(a),e);f=p[c+8>>2];p[114610]=0;N(560,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+48;p[114610]=0;K(561,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}ht(c);fb=d+32|0;return}a=I()|0;H()|0;ht(c);L(a|0);E()}function VD(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;e=b+16|0;a:{while(1){c=p[a+36>>2];f=m[p[p[c>>2]+20>>2]](c,p[a+40>>2],b+8|0,e,b+4|0)|0;c=-1;d=p[b+4>>2]-(b+8|0)|0;if((d|0)!=(Ii(b+8|0,1,d,p[a+32>>2])|0)){break a}b:{switch(f+ -1|0){case 1:break a;case 0:continue;default:break b}}break}c=Yq(p[a+32>>2])?-1:0}fb=b+16|0;return c|0}function Fx(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;a:{if(p[b+480180>>2]&64671904){b=q[c+4|0];n[e|0]=0;p[a>>2]=q[(b&15)+20768|0];n[a+4|0]=q[e|0];break a}n[e+15|0]=0;f=q[c+4|0];if(!(q[c+3|0]!=4|p[b+480180>>2]!=4)){n[e+15|0]=1;f=f<<1}vb(e,b+1074308|0,66);if(!(!d|!tb(e))){p[e>>2]=0;mi(a,e,e+15|0);break a}p[e>>2]=f<<4;mi(a,e,e+15|0)}fb=e+16|0}function FT(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(!b){break a}if(!Hb(a,b)){break a}while(1){n[c+11|0]=0;f=(c+12|0)+d|0;b:{if(d>>>0<b>>>0){Kf(a,c+11|0);e=q[c+11|0];break b}n[c+11|0]=0;e=0}n[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}p[c+4>>2]=p[c+12>>2];a=c+4|0;d=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24)}fb=c+16|0;return d}function DGa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=jE(d+8|0,km(a,nc(a)+1|0),nc(a),e);f=p[c+8>>2];p[114610]=0;N(730,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+12;p[114610]=0;K(205,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Kq(c);fb=d+32|0;return}a=I()|0;H()|0;Kq(c);L(a|0);E()}function Bta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=Ata(e,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){d=p[a+16>>2];f=p[b>>2];p[114610]=0;N(1178,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b>>2]+32|0;p[b>>2]=d;if((d|0)!=p[b+4>>2]){continue}break}}lc(b);fb=e+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function AIa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=dR(d+8|0,mq(a,gd(a)+1|0),gd(a),e);f=p[c+8>>2];p[114610]=0;N(611,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+16;p[114610]=0;K(612,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}et(c);fb=d+32|0;return}a=I()|0;H()|0;et(c);L(a|0);E()}function Y4(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=jE(d+8|0,km(a,nc(a)+1|0),nc(a),e);f=p[c+8>>2];p[114610]=0;N(204,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+12;p[114610]=0;K(205,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Kq(c);fb=d+32|0;return}a=I()|0;H()|0;Kq(c);L(a|0);E()}function WT(a,b,c){var d=0,e=0;c=XT(a,b,c);if(!c){return 0}if(!((q[a+550|0]|q[a+551|0]<<8|(q[a+552|0]<<16|q[a+553|0]<<24))!=1297110104?(q[a+550|0]|q[a+551|0]<<8|(q[a+552|0]<<16|q[a+553|0]<<24))!=1481920589:0)){c=b+236|0;b=0;while(1){e=q[(a+b|0)+554|0];d=Yc(c,b);o[d>>1]=r[d>>1]|e<<8;b=b+1|0;if((b|0)!=120){continue}break}c=674}return c}function PEa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=An(d+8|0,se(a,Bb(a)+1|0),Bb(a),e);f=p[c+8>>2];p[114610]=0;N(770,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+4;p[114610]=0;K(368,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Fh(c);fb=d+32|0;return}a=I()|0;H()|0;Fh(c);L(a|0);E()}function LLa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=Ft(d+8|0,Ai(a,fc(a)+1|0),fc(a),e);f=p[c+8>>2];p[114610]=0;N(381,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+2;p[114610]=0;K(380,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}vk(c);fb=d+32|0;return}a=I()|0;H()|0;vk(c);L(a|0);E()}function KU(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=mB(d+8|0,Ol(a,ne(a)+1|0),ne(a),e);f=p[c+8>>2];p[114610]=0;N(347,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+32;p[114610]=0;K(267,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}cq(c);fb=d+32|0;return}a=I()|0;H()|0;cq(c);L(a|0);E()}function zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=Eh(e,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){d=p[a+16>>2];f=p[b>>2];p[114610]=0;N(1604,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b>>2]+4|0;p[b>>2]=d;if((d|0)!=p[b+4>>2]){continue}break}}lc(b);fb=e+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function hC(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;if(1073741807-b>>>0>=c>>>0){g=Ib(a);a:{if(536870887>b>>>0){p[f+8>>2]=b<<1;p[f+12>>2]=b+c;c=Zl(p[Uc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=Lk(h);if(e){Rh(c,g,e)}d=d-e|0;if(d){e=e<<2;Rh(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){Un(g,b)}sf(a,c);sg(a,h);fb=f+16|0;return}tg();E()}function fsa(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=hs(d+8|0,se(a,Bb(a)+1|0),Bb(a),e);f=p[c+8>>2];p[114610]=0;N(411,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+4;p[114610]=0;K(96,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Wj(c);fb=d+32|0;return}a=I()|0;H()|0;Wj(c);L(a|0);E()}function XFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=VFa(e,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){d=p[a+16>>2];f=p[b>>2];p[114610]=0;N(709,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b>>2]+6|0;p[b>>2]=d;if((d|0)!=p[b+4>>2]){continue}break}}lc(b);fb=e+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function MU(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=UA(d+8|0,se(a,Bb(a)+1|0),Bb(a),e);f=p[c+8>>2];p[114610]=0;N(346,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+4;p[114610]=0;K(343,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Yp(c);fb=d+32|0;return}a=I()|0;H()|0;Yp(c);L(a|0);E()}function G0(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=Vu(d+8|0,Bl(a,Cc(a)+1|0),Cc(a),e);f=p[c+8>>2];p[114610]=0;N(210,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+1;p[114610]=0;K(209,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}$l(c);fb=d+32|0;return}a=I()|0;H()|0;$l(c);L(a|0);E()}function CK(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=p[a+1074392>>2];d=q[b+833|0];a:{if(e){break a}n[b+833|0]=0;d=0}a=p[a+1074416>>2];n[b+872|0]=q[b+872|0]|8;g=b;h=(c|0)>-1?0-d|0:d;f=(+(e>>>0)+1)*+(c|0)/+(a>>>0);b:{if(x(f)<2147483648){d=~~f;break b}d=-2147483648}p[g+876>>2]=h+(d+p[b+876>>2]|0);a=(a|0)==(e+1|0)?c:d;n[b+833|0]=(a|0)<0?0-a|0:a}function qGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=Eh(e,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){d=p[a+16>>2];f=p[b>>2];p[114610]=0;N(411,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b>>2]+4|0;p[b>>2]=d;if((d|0)!=p[b+4>>2]){continue}break}}lc(b);fb=e+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function nNa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=Fl(e,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){d=p[a+16>>2];f=p[b>>2];p[114610]=0;N(381,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b>>2]+2|0;p[b>>2]=d;if((d|0)!=p[b+4>>2]){continue}break}}lc(b);fb=e+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function YFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=Qs(e,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){d=p[a+16>>2];f=p[b>>2];p[114610]=0;N(571,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b>>2]+1|0;p[b>>2]=d;if((d|0)!=p[b+4>>2]){continue}break}}lc(b);fb=e+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function Vva(a,b){var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=qb(a);c=hs(d+8|0,se(a,Bb(a)+1|0),Bb(a),e);f=p[c+8>>2];p[114610]=0;N(95,e|0,f|0,b|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){break a}p[c+8>>2]=p[c+8>>2]+4;p[114610]=0;K(96,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Wj(c);fb=d+32|0;return}a=I()|0;H()|0;Wj(c);L(a|0);E()}function QIa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-32|0;fb=e;p[e+28>>2]=d;a:{if(q[a+8|0]){d=a+12|0;g=e,h=Cc(d)-c|0,p[g+24>>2]=h;a=p[Cb(e+24|0,e+28|0)>>2];g=e,h=Ub(d),p[g+24>>2]=h;f=lf(e+24|0,c);g=e,h=Ub(d),p[g+8>>2]=h;g=e,h=lf(e+8|0,c),p[g+16>>2]=h;ij(f,lf(e+16|0,a),b);break a}a=tIa(a,b,c,d)}fb=e+32|0;return a|0}function ON(a){var b=0;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=-28486832|q[a+63|0]!=26){break a}b=a+65|0;if(q[a- -64|0]&3|(q[a+66|0]|(q[b|0]!=1?q[b|0]!=16:0))){break a}b=a+78|0;if((q[b|0]|q[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((q[a|0]|q[a+1|0]<<8)>>>0>127){break a}a=Nza(b,a);return(q[a|0]|q[a+1|0]<<8)!=0}return 0}function Cv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-240|0;fb=f;p[f>>2]=a;g=1;a:{if((c|0)<2){break a}e=a;while(1){e=e+ -4|0;i=c+ -2|0;h=e-p[(i<<2)+d>>2]|0;if((m[b|0](a,h)|0)>=0){if((m[b|0](a,e)|0)>-1){break a}}a=(m[b|0](h,e)|0)>-1;e=a?h:e;p[(g<<2)+f>>2]=e;g=g+1|0;c=a?c+ -1|0:i;if((c|0)<2){break a}a=p[f>>2];continue}}IE(f,g);fb=f+240|0}function fra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c>>>2;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=ub(q[b|0])|ub(q[b+1|0])<<8,o[f>>1]=g;f=a,g=ub(q[b+2|0])|ub(q[b+3|0])<<8,o[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e<<2}function cra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c>>>2;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=ub(q[b+1|0])|ub(q[b|0])<<8,o[f>>1]=g;f=a,g=ub(q[b+3|0])|ub(q[b+2|0])<<8,o[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e<<2}function AU(a){var b=0;a:{b:{c:{d:{if((a|0)<=-1){a=W(8)|0;p[114610]=0;M(352,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break c}break d}if(56>a>>>0){break a}a=W(8)|0;p[114610]=0;M(352,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break b}}b=I()|0;H()|0;X(a|0);L(b|0);E()}ba(a|0,77368,265);E()}ba(a|0,77368,265);E()}return q[a+11680|0]}function lt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=Cl(e,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){d=qb(a);f=p[b+4>>2];p[114610]=0;N(571,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b+4>>2]+1|0;p[b+4>>2]=d;if((d|0)!=p[b+8>>2]){continue}break}}Db(b);fb=e+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function jz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=tp(e,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){d=qb(a);f=p[b+4>>2];p[114610]=0;N(709,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b+4>>2]+6|0;p[b+4>>2]=d;if((d|0)!=p[b+8>>2]){continue}break}}Db(b);fb=e+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function dU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=Cl(e,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){d=qb(a);f=p[b+4>>2];p[114610]=0;N(366,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b+4>>2]+1|0;p[b+4>>2]=d;if((d|0)!=p[b+8>>2]){continue}break}}Db(b);fb=e+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function dT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=he(e,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){d=qb(a);f=p[b+4>>2];p[114610]=0;N(411,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b+4>>2]+4|0;p[b+4>>2]=d;if((d|0)!=p[b+8>>2]){continue}break}}Db(b);fb=e+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function Rsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;qb(b);f=CL(a,c+8|0);a:{d=ng(b);if(!d){break a}p[114610]=0;K(1221,a|0,d|0);e=p[114610];p[114610]=0;if((e|0)!=1){e=p[b+4>>2];b=p[b>>2];p[114610]=0;Q(1222,a|0,b|0,e|0,d|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;Rx(f);L(a|0);E()}fb=c+16|0;return a|0}function Gt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=Gh(e,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){d=qb(a);f=p[b+4>>2];p[114610]=0;N(381,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b+4>>2]+2|0;p[b+4>>2]=d;if((d|0)!=p[b+8>>2]){continue}break}}Db(b);fb=e+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function uG(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=p[b+12>>2];p[c+8>>2]=p[b+8>>2];p[c+12>>2]=d;d=p[b+4>>2];p[c>>2]=p[b>>2];p[c+4>>2]=d;d=bQ(c);a:{if(d){eba(c+24|0,b);cu(c+32|0,c+24|0);break a}dba(c+16|0,b);cu(c+32|0,c+16|0)}b=a;a=Ql(c+40|0,c+32|0);bB(b,a);sb(a);sb(c+32|0);b:{if(!d){sb(c+16|0);break b}sb(c+24|0)}fb=c+48|0}function lW(a){var b=0,c=0,d=0,e=0;d=fb-32|0;fb=d;c=qb(a);b=mB(d+8|0,Ol(a,ne(a)+1|0),ne(a),c);e=p[b+8>>2];p[114610]=0;K(266,c|0,e|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[b+8>>2]=p[b+8>>2]+32;p[114610]=0;K(267,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}cq(b);fb=d+32|0;return}a=I()|0;H()|0;cq(b);L(a|0);E()}function ve(a){var b=0,c=0,d=0;a:{b:{b=a;if(!(b&3)){break b}if(!q[a|0]){return 0}while(1){b=b+1|0;if(!(b&3)){break b}if(q[b|0]){continue}break}break a}while(1){c=b;b=b+4|0;d=p[c>>2];if(!((d^-1)&d+ -16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=q[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function rH(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=(He(p[a+16>>2])|0)/5|0;b=rc(b,b>>31);p[a+4272>>2]=b;p[114610]=0;p[c+12>>2]=0;N(1647,a+4256|0,b<<1,c+12|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){b=O(71348)|0;if((H()|0)!=($(71348)|0)){break a}T(b|0)|0;p[a+4272>>2]=0;V()}p[a+4276>>2]=0;p[a+4268>>2]=0;fb=c+16|0;return}L(b|0);E()}function nH(a){var b=w(0),c=0,d=w(0),e=0;b=t[a+4224>>2];t[a+4260>>2]=D(w(w(1)-w(b*b)));n[a+4264|0]=t[a+4236>>2]>w(.5);c=a;d=w(p[a+4256>>2]<<1>>>0);b=w(t[a+4228>>2]*d);a:{if(b<w(4294967296)&b>=w(0)){e=~~b>>>0;break a}e=0}p[c+4248>>2]=e;c=a+4252|0;b=w(t[a+4232>>2]*d);b:{if(b<w(4294967296)&b>=w(0)){a=~~b>>>0;break b}a=0}p[c>>2]=a}function m8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if(e){i=c+4|0;while(1){g=0;if(d){while(1){f=p[Bf(b,g,h)>>2];Yb(c,g);f=(f+((hr(i)^-2147483648)>>>21|0)|0)+ -2147482624>>>12|0;f=f>>>0>491520?f:491520;j=sm(a,g,h),k=(f|0)<557055?f:557055,o[j>>1]=k;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function hT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;qb(b);f=$S(a,c+8|0);a:{d=Bb(b);if(!d){break a}p[114610]=0;K(404,a|0,d|0);e=p[114610];p[114610]=0;if((e|0)!=1){e=p[b+4>>2];b=p[b>>2];p[114610]=0;Q(408,a|0,b|0,e|0,d|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;us(f);L(a|0);E()}fb=c+16|0;return a|0}function P8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if(e){i=c+4|0;while(1){g=0;if(d){while(1){f=p[Bf(b,g,h)>>2];Yb(c,g);f=(f+((hr(i)^-2147483648)>>>21|0)|0)+ -2147482624>>>12|0;f=f>>>0>491520?f:491520;j=um(a,g,h),k=(f|0)<557055?f:557055,o[j>>1]=k;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function JN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;qb(b);f=HN(a,c+8|0);a:{d=Cc(b);if(!d){break a}p[114610]=0;K(564,a|0,d|0);e=p[114610];p[114610]=0;if((e|0)!=1){e=p[b+4>>2];b=p[b>>2];p[114610]=0;Q(993,a|0,b|0,e|0,d|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;Tp(f);L(a|0);E()}fb=c+16|0;return a|0}function Bw(a){var b=0,c=0,d=0,e=0;b=Kg(+t[a+4228>>2]*8)*.25+ -.25;u[a+4248>>3]=b;if(q[a+4240|0]){e=a;if(b<=45e-5){b=0}else{b=eo(b)*1.4426950408889634;d=B(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=.5849625007211562;if(b<.792481250360578){break a}c=1}b=Kg(c+d)*.5}u[e+4248>>3]=b}Dr(a)}function f6(a){var b=0,c=0;a:{b:{c:{if(p[a+1380>>2]!=-1){break c}b=re(a);if(p[a+96>>2]){break b}if((b|0)!=79){break a}if((re(a)|0)!=103){break a}if((re(a)|0)!=103){break a}if((re(a)|0)!=83){break a}if(!bF(a)){break b}if(!(n[a+1375|0]&1)){break c}n[a+1376|0]=0;p[a+1384>>2]=0;Wb(a,32);return 0}c=Kv(a)}return c}Wb(a,30);return 0}function WQ(a){a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=-28490681|q[a+68|0]!=13|(q[a+69|0]!=10|q[a+70|0]!=26)){break a}if(q[a+76|0]|((q[a+71|0]|q[a+72|0]<<8|(q[a+73|0]<<16|q[a+74|0]<<24))!=1397116231|q[a+75|0]!=1)){break a}a=a+116|0;if(10<=(q[a|0]|q[a+1|0]<<8)>>>0){break a}return(q[a|0]|q[a+1|0]<<8)!=0}return 0}function Jy(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;PO(a,b);vCa(b,c,e);xn(f,3,b);zc(f+16|0,f);p[114610]=0;J(369,d|0,f+16|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){a=d+32|0;pb(f+16|0);while(1){if((q[d|0]+ -1&255)>>>0<=30){n[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=Ky(b);fb=f+32|0;return a}a=I()|0;H()|0;pb(f+16|0);L(a|0);E()}function oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=kia(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(1650,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+2048|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function Pf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb+ -64|0;fb=d;a:{if(ke(a)>>>0<=b>>>0){break a}c=ke(a);if(c>>>0>b>>>0){while(1){c=c+ -1|0;e=c&65535;FI(a,e);if(e>>>0>b>>>0){continue}break}}}c=Ir(d+8|0,a);p[114610]=0;N(1582,a|0,b|0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){hl(c);fb=d- -64|0;return}a=I()|0;H()|0;hl(c);L(a|0);E()}function vm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=ur(a+60|0);p[a>>2]=76928;p[d>>2]=76948;p[114610]=0;e=a+8|0;P(175,a|0,76960,e|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){a:{p[a>>2]=76928;p[d>>2]=76948;p[114610]=0;P(176,e|0,b|0,c|8)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}return a|0}}a=I()|0;H()|0;xg(d);L(a|0);E()}function XR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;f=d+8|0;g=b;if(SR(b,d+24|0)){e=GKa(d+24|0)}ld(f,g,e);a=RR(a,d+24|0,d+8|0);sb(d+8|0);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}p[114610]=0;J(338,b|0,c-e|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}b=I()|0;H()|0;Ce(a);L(b|0);E()}fb=d+32|0}function AW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;b=Uf(d,b);p[114610]=0;N(253,d+16|0,b|0,c|0);e=p[114610];p[114610]=0;a:{b:{if((e|0)!=1){p[114610]=0;N(5,a|0,d+16|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}pb(d+16|0);pb(b);fb=d+32|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(d+16|0)}pb(b);L(a|0);E()}function r6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-1520|0;fb=f;q6(f+8|0,e);n[f+56|0]=1;p[f+48>>2]=a+b;p[f+40>>2]=a;a:{b:{if(!p6(f+8|0)){p[d>>2]=p[f+104>>2]?1:p[f+108>>2];break b}b=Jd(f+8|0,1512);if(b){g=c,h=p[ac(b,f+8|0,1512)+32>>2]-a|0,p[g>>2]=h;p[d>>2]=0;break a}kF(f+8|0)}b=0}fb=f+1520|0;return b|0}function IE(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=fb-256|0;fb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;p[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;ac(c,p[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;ac(p[g>>2],p[(c<<2)+a>>2],f);p[g>>2]=p[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=p[h>>2];continue}}fb=e+256|0}function Hz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;f=d+8|0;g=b;if(SR(b,d+24|0)){e=Dz(d+24|0)}ld(f,g,e);a=RR(a,d+24|0,d+8|0);sb(d+8|0);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}p[114610]=0;J(338,b|0,c-e|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}b=I()|0;H()|0;Ce(a);L(b|0);E()}fb=d+32|0}function qya(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=gN(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(1025,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+12|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function gR(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+14|0]=0;n[a+15|0]=0;n[a+16|0]=0;n[a+17|0]=0;n[a+18|0]=0;n[a+19|0]=0;n[a+20|0]=0;n[a+21|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;fb=b+16|0}function cGa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=aGa(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(744,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+48|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function aFa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=WEa(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(768,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+33|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function TI(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+16|0]=0;n[a+17|0]=0;n[a+18|0]=0;n[a+19|0]=0;n[a+20|0]=0;n[a+21|0]=0;n[a+22|0]=0;n[a+23|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;fb=b+16|0}function $ra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=gN(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(1238,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+12|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function ysa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Wl(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(1231,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+16|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Eh(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(1621,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+4|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function fia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Eh(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(1652,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+4|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function eBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=cBa(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(927,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+8|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function Roa(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-896|0;fb=d;b=Jb(a,0,66);p[b+72>>2]=0;p[b+76>>2]=0;p[b+68>>2]=256;o[b+66>>1]=65535;p[b+80>>2]=0;p[b+84>>2]=0;n[b+88|0]=1;e=b+229984|0;c=b+608|0;a=c;while(1){a=$J(a)+896|0;if((e|0)!=(a|0)){continue}break}a=Jb(d,0,896);Mna(c,((c+229376|0)-c|0)/896|0,$J(a));fb=a+896|0;return b|0}function RCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=GCa(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(882,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+20|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function CEa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=PB(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(418,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+16|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function yea(a){a=a|0;var b=0;p[114610]=0;S(2015,a|0);b=p[114610];p[114610]=0;if((b|0)!=1){return p[a+16>>2]}b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,34765,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)!=1){V();return-1}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function wAa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Eh(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(949,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+4|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function sMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Fl(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(425,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+2|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function fGa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Eh(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(743,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+4|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function cX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=PB(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(216,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+16|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function Tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=tp(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(1579,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+6|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function LDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Eh(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(825,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+4|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function Fxa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=he(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(1057,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+4|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function Fsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=$p(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(1228,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+8|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function CMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Fl(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(420,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+2|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function CDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Fl(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(832,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+2|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function mY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Xf(a,p[b+8>>2],e)){Cu(b,c,d);return}a:{if(!Xf(a,p[b>>2],e)){break a}if(!(p[b+20>>2]!=(c|0)?p[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}p[b+32>>2]=1;return}p[b+20>>2]=c;p[b+32>>2]=d;p[b+40>>2]=p[b+40>>2]+1;if(!(p[b+36>>2]!=1|p[b+24>>2]!=2)){n[b+54|0]=1}p[b+44>>2]=4}}function hU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Qs(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(365,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+1|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function fva(a,b,c,d){var e=0,f=0,g=0;a:{e=p[c>>2];f=p[d>>2];if(e|f){if(!b){break a}while(1){p[c>>2]=e-(((-2147483648-e>>>31|0)+ -1&255)+e>>8);p[d>>2]=p[d>>2]-(((-2147483648-f>>>31|0)+ -1&255)+f>>8);e=g<<3;p[e+a>>2]=p[c>>2];p[(e|4)+a>>2]=p[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}f=p[d>>2];e=p[c>>2];continue}}LM(a,b<<1)}}function ffa(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=p[a+4144>>2];f=p[a+4140>>2];if(c){h=o[a+4188>>1];while(1){d=g<<3;i=(d|4)+b|0;k=p[i>>2];d=b+d|0;j=p[d>>2]>>12;f=(v(j-f|0,h)>>15)+j|0;p[d>>2]=f;d=k>>12;e=(v(d-e|0,h)>>15)+d|0;p[i>>2]=e;g=g+1|0;if((g|0)!=(c|0)){continue}break}}p[a+4144>>2]=e;p[a+4140>>2]=f;return c}function dda(a){a=a|0;var b=0;p[114610]=0;S(2088,a|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){b=O(0)|0;H()|0;T(b|0)|0;p[114610]=0;Q(1989,37224,a|0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();a=0}return a|0}a=I()|0;H()|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;if((b|0)!=1){L(a|0);E()}a=O(0)|0;H()|0;rb(a);E()}function bT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Wl(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(418,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+16|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function ZW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Qs(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(218,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+1|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function UCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=he(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(880,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+4|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function PT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Eh(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(371,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+4|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function MDa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Qs(d,a+8|0,b);if(p[b>>2]!=p[b+4>>2]){while(1){c=p[a+16>>2];e=p[b>>2];p[114610]=0;K(38,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b>>2]+1|0;p[b>>2]=c;if((c|0)!=p[b+4>>2]){continue}break}}lc(b);fb=d+16|0;return}a=I()|0;H()|0;lc(b);L(a|0);E()}function JJa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=tp(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(569,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+6|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function JGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;Me(b);p[d+12>>2]=0;g=!ni(a,d+12|0);f=p[d+12>>2];a:{if(g|f>>>0>c>>>0){break a}if(!f){e=1;break a}c=0;while(1){b:{n[d+11|0]=0;if(!Mg(a,d+11|0)){break b}Gl(b,n[d+11|0]);e=1;c=c+1|0;if((c|0)!=p[d+12>>2]){continue}break a}break}e=0}fb=d+16|0;return e|0}function vL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;a:{if(fc(Po(a))>>>0<=b>>>0){break a}b:{c:{if(nc(a)>>>0>b>>>0){if(s[id(a,b)+4>>2]>c>>>0){break c}}if(!d){break a}Ox(a,b,c,1);break b}Wd(e+8|0,id(a,b),c);f=tb(e+8|0);if(f|!d){break a}Wd(e+8|0,id(a,b),c);Zd(e+8|0,1);wL(a,b,c)}f=0}fb=e+16|0;return f|0}function kC(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;d=wb(a);if(d>>>0>=0){f=Bc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=Ib(a);h=e;f=d;if(d){Pl(c+e|0,e,f);b=e>>>0<=b>>>0?d+e>>>0>b>>>0?b+c|0:b:b}Pl(h,b,c);b=c+d|0;Jg(a,b);n[g+15|0]=0;ae(b+e|0,g+15|0);break a}xu(a,f,(c+d|0)-f|0,d,0,0,c,b)}fb=g+16|0;return a}Yl();E()}function hW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=$p(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(270,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+8|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function cO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=he(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(949,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+4|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function XF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;p[e+40>>2]=c;p[e+44>>2]=b;p[e+36>>2]=d;b=p[a+8>>2];p[e+28>>2]=e+36;p[e+24>>2]=e+40;c=p[e+28>>2];p[e+8>>2]=p[e+24>>2];p[e+12>>2]=c;p[e+16>>2]=a;p[e+20>>2]=e+44;c=p[e+20>>2];p[e>>2]=p[e+16>>2];p[e+4>>2]=c;V8(b,e);p[a+4>>2]=p[a+4>>2]+p[e+36>>2];fb=e+48|0}function WF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;p[e+40>>2]=c;p[e+44>>2]=b;p[e+36>>2]=d;b=p[a+8>>2];p[e+28>>2]=e+36;p[e+24>>2]=e+40;c=p[e+28>>2];p[e+8>>2]=p[e+24>>2];p[e+12>>2]=c;p[e+16>>2]=a;p[e+20>>2]=e+44;c=p[e+20>>2];p[e>>2]=p[e+16>>2];p[e+4>>2]=c;U8(b,e);p[a+4>>2]=p[a+4>>2]+p[e+36>>2];fb=e+48|0}function Vga(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=He(p[a+16>>2]);b=rc(ONa(NNa(b,b>>31,3840,0),ib,1e3,0),ib);p[a+4276>>2]=b;p[114610]=0;p[c+12>>2]=0;N(1647,a+4260|0,b|0,c+12|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){b=O(71348)|0;if((H()|0)!=($(71348)|0)){break a}T(b|0)|0;p[a+4276>>2]=0;V()}fb=c+16|0;return}L(b|0);E()}function VF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;p[e+40>>2]=c;p[e+44>>2]=b;p[e+36>>2]=d;b=p[a+8>>2];p[e+28>>2]=e+36;p[e+24>>2]=e+40;c=p[e+28>>2];p[e+8>>2]=p[e+24>>2];p[e+12>>2]=c;p[e+16>>2]=a;p[e+20>>2]=e+44;c=p[e+20>>2];p[e>>2]=p[e+16>>2];p[e+4>>2]=c;E8(b,e);p[a+4>>2]=p[a+4>>2]+p[e+36>>2];fb=e+48|0}function UF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;p[e+40>>2]=c;p[e+44>>2]=b;p[e+36>>2]=d;b=p[a+8>>2];p[e+28>>2]=e+36;p[e+24>>2]=e+40;c=p[e+28>>2];p[e+8>>2]=p[e+24>>2];p[e+12>>2]=c;p[e+16>>2]=a;p[e+20>>2]=e+44;c=p[e+20>>2];p[e>>2]=p[e+16>>2];p[e+4>>2]=c;D8(b,e);p[a+4>>2]=p[a+4>>2]+p[e+36>>2];fb=e+48|0}function TF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;p[e+40>>2]=c;p[e+44>>2]=b;p[e+36>>2]=d;b=p[a+8>>2];p[e+28>>2]=e+36;p[e+24>>2]=e+40;c=p[e+28>>2];p[e+8>>2]=p[e+24>>2];p[e+12>>2]=c;p[e+16>>2]=a;p[e+20>>2]=e+44;c=p[e+20>>2];p[e>>2]=p[e+16>>2];p[e+4>>2]=c;r8(b,e);p[a+4>>2]=p[a+4>>2]+p[e+36>>2];fb=e+48|0}function SF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;p[e+40>>2]=c;p[e+44>>2]=b;p[e+36>>2]=d;b=p[a+8>>2];p[e+28>>2]=e+36;p[e+24>>2]=e+40;c=p[e+28>>2];p[e+8>>2]=p[e+24>>2];p[e+12>>2]=c;p[e+16>>2]=a;p[e+20>>2]=e+44;c=p[e+20>>2];p[e>>2]=p[e+16>>2];p[e+4>>2]=c;q8(b,e);p[a+4>>2]=p[a+4>>2]+p[e+36>>2];fb=e+48|0}function RS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Gh(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(420,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+2|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function QF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;p[e+40>>2]=c;p[e+44>>2]=b;p[e+36>>2]=d;b=p[a+8>>2];p[e+28>>2]=e+36;p[e+24>>2]=e+40;c=p[e+28>>2];p[e+8>>2]=p[e+24>>2];p[e+12>>2]=c;p[e+16>>2]=a;p[e+20>>2]=e+44;c=p[e+20>>2];p[e>>2]=p[e+16>>2];p[e+4>>2]=c;b8(b,e);p[a+4>>2]=p[a+4>>2]+p[e+36>>2];fb=e+48|0}function PF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-48|0;fb=e;p[e+40>>2]=c;p[e+44>>2]=b;p[e+36>>2]=d;b=p[a+8>>2];p[e+28>>2]=e+36;p[e+24>>2]=e+40;c=p[e+28>>2];p[e+8>>2]=p[e+24>>2];p[e+12>>2]=c;p[e+16>>2]=a;p[e+20>>2]=e+44;c=p[e+20>>2];p[e>>2]=p[e+16>>2];p[e+4>>2]=c;a8(b,e);p[a+4>>2]=p[a+4>>2]+p[e+36>>2];fb=e+48|0}function P6(a,b){var c=0,d=0,e=0,f=w(0),g=w(0),h=w(0),i=w(0);if((b|0)>=1){while(1){d=0;while(1){c=d<<2;e=c+a|0;c=c+48640|0;f=t[c>>2];g=t[e+72>>2];h=t[c+32>>2];c=(17-d<<2)+a|0;i=t[c>>2];t[e+72>>2]=w(f*g)-w(h*i);t[c>>2]=w(h*g)+w(f*i);d=d+1|0;if((d|0)!=8){continue}break}a=a+72|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function LMa(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;p[c+16>>2]=b;d=c,e=nMa(a,b),p[d+24>>2]=e;if(Ab(c+24|0,c+16|0)){p[c>>2]=p[c+24>>2];Rd(c);if(Ab(Rd(c),c+16|0)){while(1){if(!ll(p[c+24>>2],p[c>>2])){a=p[p[c>>2]>>2];d=p[Rd(c+24|0)>>2],e=a,p[d>>2]=e}if(Ab(Rd(c),c+16|0)){continue}break}}Rd(c+24|0)}fb=c+32|0;return p[c+24>>2]}function HGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;Me(b);n[d+15|0]=0;g=!Mg(a,d+15|0);f=q[d+15|0];a:{if(g|f>>>0>c>>>0){break a}if(!f){e=1;break a}c=0;while(1){b:{n[d+14|0]=0;if(!Mg(a,d+14|0)){break b}Gl(b,n[d+14|0]);e=1;c=c+1|0;if(q[d+15|0]!=(c&255)){continue}break a}break}e=0}fb=d+16|0;return e|0}function GA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Cl(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(365,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+1|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function D9(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;p[d+12>>2]=p[a+4>>2];c=p[b+4>>2];p[114610]=0;p[d+8>>2]=c;c=J(33,d+12|0,d+8|0)|0;e=p[114610];p[114610]=0;if((e|0)!=1){c=Jm(p[a>>2],p[b>>2],p[c>>2]);a:{if(c){break a}c=0;if(p[a+4>>2]==p[b+4>>2]){break a}c=s[a+4>>2]<s[b+4>>2]?-1:1}fb=d+16|0;return c}a=O(0)|0;H()|0;rb(a);E()}function LR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Cl(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(38,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+1|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function CT(a){var b=0,c=0,d=0;a:{if(q[a+110|0]>64|((q[a|0]|q[a+1|0]<<8)!=20042?(q[a|0]|q[a+1|0]<<8)!=26217:0)|(n[a+112|0]<0|q[a+111|0]>128)){break a}while(1){b=a+c|0;d=n[b+113|0];if(!(((d&255)>>>0<254?(d|0)<=-1:0)|(q[b+241|0]?0:(d|0)>=0)|q[b+369|0]>=64)){b=1;c=c+1|0;if((c|0)!=128){continue}break a}break}b=0}return b}function cJ(a){var b=0,c=0;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=-1641380927){break a}b=a+12|0;if(!(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))){break a}b=a+20|0;if(!(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))){break a}a=a+28|0;c=(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=0}return c}function bH(a){var b=0;p[a+4116>>2]=0;p[a+4132>>2]=0;p[a+4136>>2]=0;o[a+4128>>1]=0;p[a+4104>>2]=0;p[a+4108>>2]=0;b=a+4140|0;p[b>>2]=0;p[b+4>>2]=0;b=a+4148|0;p[b>>2]=0;p[b+4>>2]=0;aH(a+4164|0);aH(a+4156|0);Do(a+54060|0);Do(a+62252|0);Do(a+70444|0);Do(a+78636|0);Jb(a+4332|0,0,32768);gy(a+37100|0);Jb(a+37612|0,0,16384)}function wka(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;qb(b);f=xI(a,c+8|0);a:{d=Rf(b);if(!d){break a}p[114610]=0;K(683,a|0,d|0);e=p[114610];p[114610]=0;if((e|0)!=1){e=p[b+4>>2];b=p[b>>2];p[114610]=0;Q(1590,a|0,b|0,e|0,d|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;at(f);L(a|0);E()}fb=c+16|0;return a}function Oka(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;p[e+8>>2]=a;if((b|0)>=1){while(1){d=p[e+8>>2];a=c;f=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);n[d|0]=f;n[d+1|0]=f>>>8;n[d+2|0]=f>>>16;n[d+3|0]=f>>>24;a=q[a+4|0]|q[a+5|0]<<8;n[d+4|0]=a;n[d+5|0]=a>>>8;a=(b|0)>1;uk(e+8|0);b=b+ -1|0;if(a){continue}break}}fb=e+16|0}function Lw(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=Aka(e,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){d=qb(a);f=p[b+4>>2];p[114610]=0;N(1581,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b+4>>2]+52|0;p[b+4>>2]=d;if((d|0)!=p[b+8>>2]){continue}break}}Db(b);fb=e+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function JFa(a,b){var c=0,d=0,e=0;d=xi(a+8|0);p[114610]=0;c=M(548,b|0)|0;e=p[114610];p[114610]=0;a:{b:{if((e|0)==1){break b}p[114610]=0;N(421,a|0,b|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break b}a=p[a>>2];p[114610]=0;J(338,b|0,a|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;Gg(d);L(a|0);E()}}function Ita(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;qb(b);f=gM(a,c+8|0);a:{d=fc(b);if(!d){break a}p[114610]=0;K(921,a|0,d|0);e=p[114610];p[114610]=0;if((e|0)!=1){e=p[b+4>>2];b=p[b>>2];p[114610]=0;Q(1196,a|0,b|0,e|0,d|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;Bt(f);L(a|0);E()}fb=c+16|0;return a}function nK(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=qk(e,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){d=qb(a);f=p[b+4>>2];p[114610]=0;N(1382,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b+4>>2]+24|0;p[b+4>>2]=d;if((d|0)!=p[b+8>>2]){continue}break}}Db(b);fb=e+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function eva(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=p[a+96>>2];e=p[a+92>>2];if(d|e){if(c){while(1){f=g<<3;h=f+b|0;e=e-(((-2147483648-e>>>31|0)+ -1&255)+e>>8)|0;p[h>>2]=e+p[h>>2];f=(f|4)+b|0;d=d-(((-2147483648-d>>>31|0)+ -1&255)+d>>8)|0;p[f>>2]=d+p[f>>2];g=g+1|0;if((g|0)!=(c|0)){continue}break}}p[a+96>>2]=d;p[a+92>>2]=e}}function afa(){var a=0,b=0;p[114610]=0;a=Y(1988)|0;b=p[114610];p[114610]=0;a:{if((b|0)==1){a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;Q(1989,34032,0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();a=0}return a|0}b=I()|0;H()|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)!=1){L(b|0);E()}a=O(0)|0;H()|0;rb(a);E()}function _ea(){var a=0,b=0;p[114610]=0;a=Y(1992)|0;b=p[114610];p[114610]=0;a:{if((b|0)==1){a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;Q(1989,34060,0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();a=0}return a|0}b=I()|0;H()|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)!=1){L(b|0);E()}a=O(0)|0;H()|0;rb(a);E()}function Yx(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=Gn(e,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){d=qb(a);f=p[b+4>>2];p[114610]=0;N(1178,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b+4>>2]+32|0;p[b+4>>2]=d;if((d|0)!=p[b+8>>2]){continue}break}}Db(b);fb=e+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function Xqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>2;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b|0]);ub(q[b+1|0]);f=a,g=ub(q[b+2|0])|ub(q[b+3|0])<<8,o[f>>1]=g;a=a+2|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<2}function Wqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>2;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b+3|0]);ub(q[b+2|0]);f=a,g=ub(q[b+1|0])|ub(q[b|0])<<8,o[f>>1]=g;a=a+2|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return d<<2}function Oea(){var a=0,b=0;p[114610]=0;a=Y(2004)|0;b=p[114610];p[114610]=0;a:{if((b|0)==1){a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;Q(1989,34472,0,0,0);a=p[114610];p[114610]=0;if((a|0)==1){break a}V();a=0}return a|0}b=I()|0;H()|0;p[114610]=0;R(20);a=p[114610];p[114610]=0;if((a|0)!=1){L(b|0);E()}a=O(0)|0;H()|0;rb(a);E()}function W6(a,b,c){var d=0,e=0,f=0;d=q[a+769|0];e=v(d,72)+c|0;ac(e+2304|0,e,v(q[a+768|0]-d|0,72));if(q[a+768|0]){e=0;while(1){d=0;while(1){f=(d<<2)+c|0;t[f>>2]=t[f>>2]*t[b>>2];f=f+2304|0;t[f>>2]=t[f>>2]*t[b+12>>2];d=d+1|0;if((d|0)!=12){continue}break}b=b+24|0;c=c+72|0;e=e+1|0;if(e>>>0<q[a+768|0]){continue}break}}}function Gw(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b=he(e,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){d=qb(a);f=p[b+4>>2];p[114610]=0;N(1604,d|0,f|0,c|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}d=p[b+4>>2]+4|0;p[b+4>>2]=d;if((d|0)!=p[b+8>>2]){continue}break}}Db(b);fb=e+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function AM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;e=Sua(a);a=b+236|0;b=xs(a);a:{if((a|0)!=(b|0)){while(1){d=r[a>>1];o[c+14>>1]=d;if(d){p[114610]=0;N(1164,c|0,e|0,c+14|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}fb=c+16|0;return}a=I()|0;H()|0;ip(e);L(a|0);E()}function qia(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=nia(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(1650,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+2048|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function TT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=a;a=b+18|0;d=b+46|0;b=Tc(e,q[a|0]&2?16:8,1,0,(q[d|0]^-1)&1);if(!(!(q[a|0]&4)|c>>>0<532)){uA(b)}if(q[a|0]&8){lj(b,q[d|0]&4?5:4);return}if(!(q[a|0]&2|q[d|0]!=255)){lj(b,11);return}if(q[d|0]&2){n[b+2|0]=1}if(q[d|0]&4){lj(b,2)}if(!(!(q[d|0]&8)|!(q[a|0]&2))){lj(b,9)}}function s5(a,b){var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=a+8|0;nm(a,a+4|0,d);c=a+12|0;while(1){if((b|0)!=(c|0)){if(zd(c,d)){p[f+12>>2]=p[c>>2];g=c;while(1){a:{e=d;p[g>>2]=p[e>>2];if((a|0)==(e|0)){e=a;break a}g=e;d=e+ -4|0;if(zd(f+12|0,d)){continue}}break}p[e>>2]=p[f+12>>2]}d=c;c=c+4|0;continue}break}fb=f+16|0}function pna(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=a+1074308|0;vb(d+8|0,a,28);a:{if(tb(d+8|0)){p[c>>2]=p[c>>2]+o[b+788>>1];Vd(c,0,64);break a}vb(d+8|0,a,1);e=tb(d+8|0);a=o[b+788>>1];if(e){p[c>>2]=a+p[c>>2];Vd(c,0,256);break a}p[b+688>>2]=a+p[b+688>>2];Vd(b+688|0,0,256);p[c>>2]=p[b+688>>2];o[b+788>>1]=0}fb=d+16|0}function nV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-48|0;fb=e;In(a);p[a>>2]=77272;f=ih(e+40|0);iV(e+24|0,b,c,d);p[114610]=0;p[e+16>>2]=p[e+32>>2];b=p[e+28>>2];p[e+8>>2]=p[e+24>>2];p[e+12>>2]=b;P(287,a+12|0,f|0,e+8|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=e+48|0;return a|0}a=I()|0;H()|0;L(a|0);E()}function nMa(a,b){var c=0;c=fb-32|0;fb=c;p[c+16>>2]=b;p[c+24>>2]=a;a:{b:{if(!Ab(c+24|0,c+16|0)){break b}p[c+8>>2]=p[c+24>>2];if(!Ab(Rd(c+8|0),c+16|0)){break b}while(1){if(ll(p[c+24>>2],p[c+8>>2])){a=p[c+24>>2];break a}p[c+24>>2]=p[c+8>>2];if(Ab(Rd(c+8|0),c+16|0)){continue}break}}a=p[c+16>>2]}fb=c+32|0;return a}function mKa(a,b){a=a|0;b=b|0;var c=0;Ns(a,b);fj(b);a=q[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=q[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}n[b+5|0]=159;n[b+3|0]=20;return}if((a|0)!=64){break a}n[b+3|0]=0;n[b|0]=254;return}n[b+3|0]=20;n[b+5|0]=a&15|160;return}n[b+3|0]=0}}function iga(a,b,c){a=a|0;b=b|0;c=w(c);var d=0,f=0,g=0;d=fb-16|0;fb=d;t[d+12>>2]=c;if((b|0)<=6){Td(d+12|0,w(0));g=((b<<2)+a|0)+4208|0;f=p[d+12>>2];c=t[d+12>>2];a:{if(!((b|0)!=1|c>=w(1))){p[d+12>>2]=0;f=0;break a}if((b|0)!=4){break a}c=w($d(w(c*w(4)))*w(.25));t[d+12>>2]=c;f=(i(c),e(2))}p[g>>2]=f;vw(a)}fb=d+16|0}function gZ(a,b){var c=0,d=0,e=0;a:{b:{while(1){if(q[c+68592|0]!=(a|0)){d=87;c=c+1|0;if((c|0)!=87){continue}break b}break}d=c;if(c){break b}a=68688;break a}c=68688;while(1){e=q[c|0];a=c+1|0;c=a;if(e){continue}c=a;d=d+ -1|0;if(d){continue}break}}b=p[b+20>>2];if(b){b=F3(p[b>>2],p[b+4>>2],a)}else{b=0}return b?b:a}function Xga(a,b,c){a=a|0;b=b|0;c=w(c);var d=0,f=0,g=0;d=fb-16|0;fb=d;t[d+12>>2]=c;if((b|0)<=6){Td(d+12|0,w(0));g=((b<<2)+a|0)+4208|0;f=p[d+12>>2];c=t[d+12>>2];a:{if(!((b|0)!=3|c>=w(1))){p[d+12>>2]=0;f=0;break a}if((b|0)!=4){break a}c=w($d(w(c*w(4)))*w(.25));t[d+12>>2]=c;f=(i(c),e(2))}p[g>>2]=f;vw(a)}fb=d+16|0}function XAa(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;a:{if(!af(a,8)){break a}c=0;if(!Vz(a,16578,8)){break a}c=-1;if(!oj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))){break a}c=!((q[b+8|0]|q[b+9|0]<<8|(q[b+10|0]<<16|q[b+11|0]<<24))&-2139062144)}a=c;fb=b+16|0;return a|0}function Lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;sj(a,c+24|0);f=c,g=dd(p[c+24>>2],p[c+28>>2]),p[f+16>>2]=g;p[c+12>>2]=256;cl(b,p[Cb(c+16|0,c+12|0)>>2]);if(Bb(b)){while(1){p[c+16>>2]=0;po(a,c+16|0);e=p[c+16>>2];f=Fb(b,d),g=e,p[f>>2]=g;d=d+1|0;if(d>>>0<Bb(b)>>>0){continue}break}}fb=c+32|0}function ET(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(!b){break a}if(!Hb(a,b)){break a}f=1;while(1){n[c+13|0]=0;e=(c+14|0)+d|0;b:{if(d>>>0<b>>>0){Kf(a,c+13|0);d=q[c+13|0];break b}n[c+13|0]=0;d=0}n[e|0]=d;d=1;e=f;f=0;if(e){continue}break}o[c+10>>1]=r[c+14>>1];a=c+10|0;d=q[a|0]|q[a+1|0]<<8}fb=c+16|0;return d}function rya(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Sk(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(1025,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+12|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function dFa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=ZEa(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(768,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+33|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function bsa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Sk(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(1238,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+12|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function _qa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=(c>>>0)/3;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b+2|0]);f=a,g=ub(q[b+1|0])|ub(q[b|0])<<8,o[f>>1]=g;a=a+2|0;b=b+3|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return v(d,3)|0}function I6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a=jF(a,d+8|0);e=wb(b);f=wb(c);b=Ib(b);p[114610]=0;Q(195,a|0,b|0,e|0,e+f|0);b=p[114610];p[114610]=0;a:{if((b|0)!=1){b=Ib(c);p[114610]=0;P(196,a|0,b|0,f|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}}b=I()|0;H()|0;pb(a);L(b|0);E()}fb=d+16|0}function $qa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=(c>>>0)/3;p[e+8>>2]=p[a>>2];d=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(d){a=p[a+20>>2];c=d;while(1){ub(q[b|0]);f=a,g=ub(q[b+1|0])|ub(q[b+2|0])<<8,o[f>>1]=g;a=a+2|0;b=b+3|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return v(d,3)|0}function xja(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=he(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(1621,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+4|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function jZ(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;c=4;d=b+12|0;while(1){if(c){a:{b:{c:{e=hv(Ma(p[a>>2],d|0,c|0)|0);switch(e+1|0){case 0:break b;case 1:break c;default:break a}}Iu(116,68527);E()}if(p[114584]==27){continue}Iu(p[114584],68549);E()}d=d+e|0;c=c-e|0;continue}break}fb=b+16|0;return p[b+12>>2]}function gia(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=he(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(1652,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+4|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function dGa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=sR(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(744,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+48|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function ZH(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=p[a+4232>>2];b=(b>>>1)+(b>>>6)|0;p[a+4220>>2]=b;p[114610]=0;p[c+12>>2]=0;N(1647,a+4208|0,b<<1,c+12|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){b=O(71348)|0;if((H()|0)!=($(71348)|0)){break a}T(b|0)|0;p[a+4220>>2]=0;V()}p[a+4224>>2]=0;fb=c+16|0;return}L(b|0);E()}function Yba(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;qb(b);f=Xba(a,c+8|0);a:{d=gd(b);if(!d){break a}p[114610]=0;K(2122,a|0,d|0);e=p[114610];p[114610]=0;if((e|0)!=1){e=p[b+4>>2];b=p[b>>2];p[114610]=0;Q(2123,a|0,b|0,e|0,d|0);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;MG(f);L(a|0);E()}fb=c+16|0}function Q_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;p[e>>2]=c;a=Su(f+12|0,0,b,p[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}b=a+ -1|0;c=1;if(b>>>0>d-p[e>>2]>>>0){break a}c=f+12|0;while(1){if(b){a=q[c|0];d=p[e>>2];p[e>>2]=d+1;n[d|0]=a;b=b+ -1|0;c=c+1|0;continue}break}c=0}fb=f+16|0;return c|0}function uMa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Gh(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(425,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+2|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function jza(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;e=Ee(4);p[114610]=0;c=J(85,b|0,1434)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;d=J(86,e|0,c|0)|0;f=p[114610];p[114610]=0;if((f|0)==1){break b}Aya(a,d);pb(c);fb=b+16|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(c)}Nb(e);L(a|0);E()}function iGa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=he(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(743,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+4|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function hBa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=$p(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(927,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+8|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function eX(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Wl(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(216,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+16|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function dZ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;f=wb(a);if(f>>>0>=b>>>0){if(c){e=Bc(a);a:{if(e-f>>>0>=c>>>0){e=Ib(a);h=f-b|0;if(!h){break a}i=b+e|0;Pl(i+c|0,i,h);break a}El(a,e,(c+f|0)-e|0,f,b,0,c);e=p[a>>2]}ty(b+e|0,c,d);b=a;a=c+f|0;Jg(b,a);n[g+15|0]=0;ae(a+e|0,g+15|0)}fb=g+16|0;return}Yl();E()}function Q2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=w(0),f=0;d=fb-16|0;fb=d;a:{if((a|0)!=(b|0)){f=p[114584];p[114584]=0;de();e=t3(a,d+12|0);a=p[114584];b:{if(a){if(p[d+12>>2]!=(b|0)){break b}if((a|0)!=68){break a}p[c>>2]=4;break a}p[114584]=f;if(p[d+12>>2]==(b|0)){break a}}}p[c>>2]=4;e=w(0)}fb=d+16|0;return w(e)}function ODa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=he(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(825,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+4|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function Lka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=b;a:{if(Wi(a)>>>0>=b>>>0){f=d,g=of(a),p[f+8>>2]=g;Bka(p[a>>2],p[Cb(d+12|0,d+8|0)>>2],c);b=p[d+12>>2];e=p[d+8>>2];if(b>>>0>e>>>0){Lw(a,b-e|0,c);break a}EI(a,p[a>>2]+v(b,52)|0);break a}Kka(a);Jka(a,DI(a,b));Lw(a,b,c)}fb=d+16|0}function IN(a,b){a=a|0;b=b|0;var c=0;c=fb-48|0;fb=c;p[a>>2]=0;p[a+4>>2]=0;p[c+44>>2]=0;qb(b);Oc(a+8|0,c+44|0,c+40|0);if(p[b+4>>2]){Np(a,p[b+4>>2]);ej(c+32|0,b);bk(c+24|0,b);b=p[c+36>>2];p[c+16>>2]=p[c+32>>2];p[c+20>>2]=b;b=p[c+28>>2];p[c+8>>2]=p[c+24>>2];p[c+12>>2]=b;Aza(a,c+16|0,c+8|0)}fb=c+48|0;return a|0}function EDa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Gh(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(832,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+2|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function yNa(a,b){var c=0;vd(b,0);p[b+24>>2]=8363;c=a+13|0;p[b>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=a+17|0;p[b+4>>2]=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);a=a+21|0;a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);a=a>>>0>s[b>>2]?p[b+4>>2]?a:0:a;p[b+8>>2]=a;if(a){o[b+34>>1]=2;Ym(b)}}function rxa(a){var b=0,c=0;b=fb-80|0;fb=b;p[b+76>>2]=0;c=Mb(b- -64|0,17998);p[114610]=0;K(512,b+48|0,a|0);a=p[114610];p[114610]=0;a:{b:{c:{if((a|0)==1){break c}p[114610]=0;J(470,b+48|0,c|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break c}pb(c);break b}a=I()|0;H()|0;pb(c);break a}fb=b+80|0;return}L(a|0);E()}function _W(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=Cl(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(218,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+1|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function QT(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b=he(d,a,b);if(p[b+4>>2]!=p[b+8>>2]){while(1){c=qb(a);e=p[b+4>>2];p[114610]=0;K(371,c|0,e|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}c=p[b+4>>2]+4|0;p[b+4>>2]=c;if((c|0)!=p[b+8>>2]){continue}break}}Db(b);fb=d+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function $f(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=y(e);ef(d,e,0,0,0,c+81|0);c=(p[d+12>>2]^65536)+(16414-c<<16)|0;e=0+p[d+8>>2]|0;if(e>>>0<f>>>0){c=c+1|0}f=b&-2147483648|c;c=p[d+4>>2];b=p[d>>2]}p[h>>2]=b;p[g+4>>2]=c;p[a+8>>2]=e;p[a+12>>2]=f;fb=d+16|0}function u1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=p[15587];p[g+24>>2]=p[15586];p[g+28>>2]=h;h=p[15585];p[g+16>>2]=p[15584];p[g+20>>2]=h;h=p[15583];p[g+8>>2]=p[15582];p[g+12>>2]=h;h=p[15581];p[g>>2]=p[15580];p[g+4>>2]=h;a=Li(a,b,c,d,e,f,g,g+32|0);fb=g+32|0;return a|0}function tra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c>>>1;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=ub(q[b|0])^128,n[f|0]=g;f=a,g=ub(q[b+1|0])^128,n[f+1|0]=g;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e<<1}function sra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>1;p[e+8>>2]=p[a>>2];f=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(f){a=p[a+20>>2];c=f;g=d;while(1){g=ub(q[b|0])+g|0;n[a|0]=g;d=ub(q[b+1|0])+d|0;n[a+1|0]=d;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return f<<1}function pI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=b;a:{if(rd(a)>>>0>=b>>>0){f=d,g=Bb(a),p[f+8>>2]=g;oja(p[a>>2],p[Cb(d+12|0,d+8|0)>>2],c);b=p[d+12>>2];e=p[d+8>>2];if(b>>>0>e>>>0){Gw(a,b-e|0,c);break a}Jw(a,p[a>>2]+(b<<2)|0);break a}Rja(a);Qja(a,se(a,b));Gw(a,b,c)}fb=d+16|0}function Xr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;if(b){vb(e+8|0,a+1074308|0,73);k=tb(e+8|0)?c- -64|0:c;c=120;i=Go(a);l=i^-1;f=1;while(1){g=c>>>1|0;j=g+f|0;h=dg(a,j,k,d);a:{if(!(h>>>0>b>>>0&l|!h|h>>>0<b>>>0&i)){c=g;break a}f=j+1|0;c=(g^-1)+c|0}if(c){continue}break}}fb=e+16|0;return f}function Vpa(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=b;a:{if(Le(a)>>>0>=b>>>0){f=d,g=Dd(a),p[f+8>>2]=g;ppa(p[a>>2],p[Cb(d+12|0,d+8|0)>>2],c);b=p[d+12>>2];e=p[d+8>>2];if(b>>>0>e>>>0){nK(a,b-e|0,c);break a}b=p[a>>2]+v(b,24)|0;Dd(a);oK(a,b);bp(a);break a}rpa(a);qpa(a,pk(a,b));nK(a,b,c)}fb=d+16|0}function bla(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;e=(c-b|0)/6|0;a:{if(e>>>0<=ri(a)>>>0){p[d+12>>2]=c;if(e>>>0>Rf(a)>>>0){p[d+12>>2]=b;f=Rf(a);p[d+12>>2]=p[d+12>>2]+v(f,6);Ow(b,p[d+12>>2],p[a>>2]);Mw(a,p[d+12>>2],c,e-Rf(a)|0);break a}iz(a,Ow(b,c,p[a>>2]));break a}II(a);AQ(a,_y(a,e));Mw(a,b,c,e)}fb=d+16|0}function EJ(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=zi(b,c);a:{if(e>>>0<=Hf(a)>>>0){p[d+12>>2]=c;if(e>>>0>Cc(a)>>>0){p[d+12>>2]=b;f=d,g=Cc(a)+p[d+12>>2]|0,p[f+12>>2]=g;Ye(b,p[d+12>>2],p[a>>2]);ry(a,p[d+12>>2],c,e-Cc(a)|0);break a}vR(a,Ye(b,c,p[a>>2]));break a}eL(a);NR(a,Bl(a,e));ry(a,b,c,e)}fb=d+16|0}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=c+40|0;b=r[b>>1];n[d|0]=b;n[d+1|0]=b>>>8;zk(c+16|0,c+40|0);b=ub(p[c+16>>2]);zk(c+8|0,c+40|0);b=di(c+24|0,b,ub(p[c+8>>2]+2|0));p[114610]=0;J(1193,a|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);fb=c+48|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function fC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a=iw(a,d+8|0);e=ve(b);f=wb(c);p[114610]=0;Q(2842,a|0,b|0,e|0,e+f|0);b=p[114610];p[114610]=0;a:{if((b|0)!=1){b=Ib(c);p[114610]=0;P(2492,a|0,b|0,f|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}}b=I()|0;H()|0;pb(a);L(b|0);E()}fb=d+16|0}function _fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=_h(a,b,c,d);p[a+4208>>2]=1017370378;p[a+4212>>2]=0;p[a>>2]=81364;p[114610]=0;P(1639,a+44|0,2,2)|0;c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;S(1640,b|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}return a|0}a=I()|0;H()|0;Ge(b);L(a|0);E()}function Gd(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;Sl(b);b=z$(d+8|0,b);a:{a=a+16|0;if(Bb(a)>>>0<=c>>>0){p[114610]=0;K(2559,a|0,c+1|0);e=p[114610];p[114610]=0;if((e|0)==1){break a}}if(p[Fb(a,c)>>2]){Rl(p[Fb(a,c)>>2])}e=Cd(b);f=Fb(a,c),g=e,p[f>>2]=g;HC(b);fb=d+16|0;return}a=I()|0;H()|0;HC(b);L(a|0);E()}function ota(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;a:{if(!q[a+530|0]){break a}f=NNa(d,0,6169,0);d=ib;d=dd((d&65535)<<16|f>>>16,d>>>16|0);if(!c){break a}while(1){vta(p[a>>2],e+14|0,e+12|0);p[b>>2]=p[b>>2]+v(d,o[e+14>>1]);p[b+4>>2]=p[b+4>>2]+v(d,o[e+12>>1]);b=b+8|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0}function ULa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!af(a,7)){break b}c=0;if(!HS(a,12222)){break a}if(!af(a,1)){break b}c=-1;if(!Qc(a,zt(a))){break a}c=d+8|0;e=xLa(a,c);if(!e){pS(c)}c=-1;if(!e){break a}c=0;if(!CS(d+8|0)){break a}c=Ve(a,b,BS(d+8|0),ib);break a}c=-1}fb=d+16|0;return c|0}function GQ(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=a+4|0;a:{if(Cc(c)>>>0>=p[a+16>>2]+b>>>0){break a}if(!Cc(c)){nk(c,nz(p[a+16>>2]+b|0,65536));break a}f=d,g=Cc(c),p[f+12>>2]=g;e=BQ(d+12|0);a=p[a+16>>2]+b|0;if(e>>>0<a>>>0){nk(c,nz(a,65536));break a}f=d,g=Cc(c),p[f+8>>2]=g;nk(c,BQ(d+8|0))}fb=d+16|0}function BCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb+ -64|0;fb=c;b=-1;a:{if(!af(a,1084)){break a}dk(a,1080);XO(a,c+60|0);d=WO(c+40|0);b=0;if(!VO(c+60|0,d)){break a}dk(a,20);b=1;while(1){UO(a,c+8|0);e=Ky(c+8|0)+e|0;f=b&65535;b=b+1|0;if(f>>>0<31){continue}break}b=e>>>0<=s[d+4>>2]}fb=c- -64|0;return b|0}function isa(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;f=a+12|0;qM(d+8|0,f);sL(d,f);a:{if(!qs(d+8|0,d)|(c|0)==-1){break a}while(1){g=p[hsa(d+8|0)>>2];Ox(a,b,g,0);e=d+8|0;h=p[e+4>>2];p[d>>2]=p[e>>2];p[d+4>>2]=h;rL(e+4|0);sL(d,f);e=qs(d+8|0,d);if((c|0)==(g|0)){break a}if(e){continue}break}}fb=d+16|0}function voa(a,b){var c=0,d=0;a=Ue(a);c=wb(b);p[114610]=0;K(113,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)!=1){a:{if(wb(b)){while(1){c=q[cc(b,d)|0];p[114610]=0;K(112,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}d=d+1|0;if(d>>>0<wb(b)>>>0){continue}break}}return}}b=I()|0;H()|0;yc(a);L(b|0);E()}function qn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;p[f+12>>2]=c;vc(f+12|0,128);vc(f+12|0,65535);h=r[f+12>>1];ig(a,h);if(h){c=0;while(1){g=q[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=wk(a,c),j=g,o[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}fb=f+16|0}function lsa(a,b,c,d){var e=0;e=fb-32|0;fb=e;a:{if(q[d|0]){d=p[b+4>>2];p[e+24>>2]=p[b>>2];p[e+28>>2]=d;b=ki(c,b);c=p[e+28>>2];p[e+8>>2]=p[e+24>>2];p[e+12>>2]=c;ksa(a,e+8|0,b);break a}d=p[b+4>>2];p[e+16>>2]=p[b>>2];p[e+20>>2]=d;b=ki(c,b);c=p[e+20>>2];p[e>>2]=p[e+16>>2];p[e+4>>2]=c;jsa(a,e,b)}fb=e+32|0}function iva(a,b,c,d,e){var f=w(0),g=0,h=0,i=0;if(d){while(1){h=c;f=w(t[a>>2]*e);a:{if(w(x(f))<w(2147483648)){g=~~f;break a}g=-2147483648}p[h>>2]=g;h=c;f=w(t[b>>2]*e);b:{if(w(x(f))<w(2147483648)){g=~~f;break b}g=-2147483648}p[h+4>>2]=g;c=c+8|0;b=b+4|0;a=a+4|0;i=i+1|0;if((i|0)!=(d|0)){continue}break}}}function haa(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;a:{b:{if(Xh(a)){mo(b+24|0);break b}xm(b+8|0,a);p[114610]=0;K(2175,b+24|0,b+8|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}gf(b+8|0)}c=a+36|0;c:{if(Xh(a)){break c}c=p[b+24>>2]}a=Dd(c);Nj(b+24|0);fb=b+32|0;return a|0}a=I()|0;H()|0;gf(b+8|0);L(a|0);E()}function RAa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;f=p[a+4>>2];e=OAa(Ed(d+40|0,b),Ed(d+32|0,c))+p[a+4>>2]|0;p[a+4>>2]=e;if(!((e+ -1^f+ -1)>>>0<32?f:0)){g=p[a>>2];p[(e>>>0<33?g:(e+ -1>>>3&536870908)+g|0)>>2]=0}b=Ed(d+24|0,b);c=Ed(d+16|0,c);zn(d+8|0,a,f);NAa(d,b,c,d+8|0);fb=d+48|0}function P_(a){a=a|0;var b=0,c=0;b=p[a+8>>2];p[114610]=0;b=U(2575,0,0,4,b|0)|0;c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}b:{if(b){a=-1}else{a=p[a+8>>2];if(a){break b}a=1}return a|0}p[114610]=0;a=M(2576,a|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}return(a|0)==1|0}a=O(0)|0;H()|0;rb(a);E()}function Et(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;p[f+12>>2]=c;vc(f+12|0,256);vc(f+12|0,65535);h=r[f+12>>1];ig(a,h);if(h){c=0;while(1){g=q[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=wk(a,c),j=g,o[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}fb=f+16|0}function Dra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>1;p[e+8>>2]=p[a>>2];f=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(f){a=p[a+20>>2];c=f;while(1){g=ub(q[b|0])+d|0;d=g+ub(q[b+1|0])|0;o[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return f<<1}function wpa(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[114610]=0;M(1376,a+4|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;p[c+12>>2]=0;P(1377,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=_b(a),p[e>>2]=f;fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function ppa(a,b,c){var d=0,e=0,f=0;if(b){while(1){d=c;e=p[d+4>>2];p[a>>2]=p[d>>2];p[a+4>>2]=e;e=r[d+18>>1]|r[d+20>>1]<<16;f=r[d+14>>1]|r[d+16>>1]<<16;o[a+14>>1]=f;o[a+16>>1]=f>>>16;o[a+18>>1]=e;o[a+20>>1]=e>>>16;e=p[d+12>>2];p[a+8>>2]=p[d+8>>2];p[a+12>>2]=e;a=a+24|0;b=b+ -1|0;if(b){continue}break}}}function hka(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[114610]=0;M(1594,a+4|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;p[c+12>>2]=0;P(1595,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=_b(a),p[e>>2]=f;fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function foa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=b;a:{if(Hf(a)>>>0>=b>>>0){f=d,g=Cc(a),p[f+8>>2]=g;kj(p[a>>2],p[Cb(d+12|0,d+8|0)>>2],c);b=p[d+12>>2];e=p[d+8>>2];if(b>>>0>e>>>0){lt(a,b-e|0,c);break a}Vt(a,b+p[a>>2]|0);break a}eoa(a);Tt(a,Bl(a,b));lt(a,b,c)}fb=d+16|0}function bJ(a,b,c){var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;e=zi(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){cf(a,e);d=a;break a}g=Ok(e)+1|0;d=Si(g);sf(a,d);sg(a,g);oe(a,e)}if((b|0)!=(c|0)){while(1){ae(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}n[f+15|0]=0;ae(d,f+15|0);fb=f+16|0;return}tg();E()}function Tpa(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[114610]=0;M(1373,a+4|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;p[c+12>>2]=0;P(1374,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=_b(a),p[e>>2]=f;fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Pua(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[114610]=0;M(1165,a+4|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;p[c+12>>2]=0;P(1166,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=_b(a),p[e>>2]=f;fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Oma(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[114610]=0;M(1521,a+4|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;p[c+12>>2]=0;P(1522,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=_b(a),p[e>>2]=f;fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Lra(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[114610]=0;M(1253,a+4|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;p[c+12>>2]=0;P(1254,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=_b(a),p[e>>2]=f;fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function N2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if((a|0)!=(b|0)){f=p[114584];p[114584]=0;de();e=s3(a,d+12|0);a=p[114584];b:{if(a){if(p[d+12>>2]!=(b|0)){break b}if((a|0)!=68){break a}p[c>>2]=4;break a}p[114584]=f;if(p[d+12>>2]==(b|0)){break a}}}p[c>>2]=4;e=0}fb=d+16|0;return+e}function ura(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c>>>1;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=Qm(q[b|0]),n[f|0]=g;f=a,g=Qm(q[b+1|0]),n[f+1|0]=g;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e<<1}function jxa(a){var b=0,c=0,d=0;d=a+32|0;while(1){b=q[a|0];a:{b:{if((b+ -97&255)>>>0<=5){c=b+ -32|0;break b}c=99;c:{if((b|0)<=106){if(b+ -88>>>0<2){break c}if((b|0)==75){break b}break a}if(b+ -120>>>0<2){break c}if((b|0)==107){break b}break a}c=122}n[a|0]=c}a=a+1|0;if((d|0)!=(a|0)){continue}break}}function _Da(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[114610]=0;M(819,a+4|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;p[c+12>>2]=0;P(820,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=_b(a),p[e>>2]=f;fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function U5(a,b,c,d,e){var f=0,g=0,h=0,i=w(0),j=w(0);g=_E(a,b);a:{if((g|0)<0){break a}f=1;a=p[b>>2];h=(a|0)<(d|0)?a:d;if((h|0)<1){break a}a=v(a,g);d=0;while(1){f=(v(d,e)<<2)+c|0;j=w(t[p[b+28>>2]+(a+d<<2)>>2]+i);t[f>>2]=t[f>>2]+j;i=q[b+22|0]?j:i;f=1;d=d+1|0;if((h|0)!=(d|0)){continue}break}}return f}function Km(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{c:{d:{e:{switch(c|0){case 1:break b;case 3:break c;case 0:break d;case 2:break e;default:break a}}e=MK(a,b,d);if(e+ -251>>>0<5){break d}if(e){break a}}return LK(a,b,d)}e=LK(a,b,d);if(e+ -251>>>0<5){break b}if(e){break a}}e=MK(a,b,d)}return e}function Ki(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=fb-48|0;fb=c;a:{if(!b){b=1;if(od(a,5)){break a}b=EC(c+32|0);e=p[d>>2];f=p[a+8>>2];p[b+4>>2]=e-f;df(c,p[a+28>>2]);VC(c+16|0,c,p[d>>2],p[d+4>>2]);p[b+8>>2]=p[c+24>>2]}p[a>>2]=p[a>>2]|134217728;p[a+20>>2]=p[a+20>>2]+1;b=0}fb=c+48|0;return b|0}function KGa(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;p[114610]=0;M(728,a+4|0)|0;d=p[114610];p[114610]=0;a:{b:{if((d|0)!=1){p[114610]=0;p[c+12>>2]=0;P(729,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break b}break a}break a}e=a,f=_b(a),p[e>>2]=f;fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function $d(a){var b=w(0),c=w(0),d=0,f=0;d=(i(a),e(2));f=d>>>23&255;if(f>>>0<=149){if(f>>>0<=125){return w(a*w(0))}a=(d|0)>-1?a:w(-a);b=w(w(w(a+w(8388608))+w(-8388608))-a);a:{if(!(b>w(.5)^1)){c=w(w(a+b)+w(-1));break a}a=w(a+b);c=a;if(b<=w(-.5)^1){break a}c=w(a+w(1))}a=c;a=(d|0)>-1?a:w(-a)}return a}function wHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;mz(d+16|0,d+8|0,c);p[114610]=0;K(517,d|0,d+16|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;N(518,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yb(d+16|0);fb=d+32|0;return}a=I()|0;H()|0;yb(d+16|0);L(a|0);E()}function pm(a,b,c){var d=0,e=0,f=0;a:{if((b|0)==1&a>>>0<0|b>>>0<1){d=a;break a}while(1){d=QNa(a,b,10,0);e=ib;f=e;e=NNa(d,e,10,0);c=c+ -1|0;n[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c+ -1|0;a=(d>>>0)/10|0;n[c|0]=d-v(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function XKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;tl(d+16|0,d+8|0,c);p[114610]=0;K(517,d|0,d+16|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;N(518,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yb(d+16|0);fb=d+32|0;return}a=I()|0;H()|0;yb(d+16|0);L(a|0);E()}function Kd(a,b){var c=0,d=0,e=0,f=0;d=p[a+4>>2];c=d+b|0;p[a+4>>2]=c;if((c|0)<=p[a+8>>2]){c=d&7;e=c+b|0;b=e+ -8|0;a=p[a>>2]+(d>>3)|0;f=q[a|0]&255>>>c;a:{if((e|0)<9){c=0;d=b;break a}c=0;while(1){c=f<<b|c;e=(b|0)>8;f=q[a+1|0];d=b+ -8|0;b=d;a=a+1|0;if(e){continue}break}}a=f>>>0-d|c}else{a=0}return a}function qH(a,b,c){var d=0,e=0,f=0,g=0;if(w(x(a))<w(2147483648)){d=~~a}else{d=-2147483648}f=d&-2147483648;e=f?0-d|0:d;a:{if(!((e|0)<0|(b|0)<1)){while(1){d=b+ -1|0;e=e<<1;if((e|0)<0){break a}g=(b|0)>1;b=d;if(g){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return w((f?b^-1|f:b)|0)}function Vg(a){var b=0,c=0,d=0;c=ur(a+56|0);p[a>>2]=76744;p[c>>2]=76764;p[114610]=0;b=a+4|0;P(126,a|0,76776,b|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){a:{p[a>>2]=76744;p[c>>2]=76764;p[114610]=0;J(127,b|0,16)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}return a}}a=I()|0;H()|0;xg(c);L(a|0);E()}function OI(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{c=a+ -12|0;d:{if(c>>>0>28){break d}a=1;d=1<<c;if(d&270014517){break b}if(d&65792){break c}if((c|0)!=7){break d}b=b&240;if(!b|(b|0)==96|(b|0)==224){break b}}return 0}a=0;b=(b&240)+ -96|0;if(b>>>0<144){break a}}return a|0}return 297>>>(b>>>4&511)&1}function wCa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;tl(d+16|0,d+8|0,c);p[114610]=0;K(71,d|0,d+16|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;N(72,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yb(d+16|0);fb=d+32|0;return}a=I()|0;H()|0;yb(d+16|0);L(a|0);E()}function vua(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;e=Nz(b,c);a:{if(e>>>0<=If(a)>>>0){p[d+8>>2]=c;if(e>>>0>fc(a)>>>0){p[d+8>>2]=b;f=fc(a);p[d+8>>2]=p[d+8>>2]+(f<<1);ij(b,p[d+8>>2],p[a>>2]);sM(a,p[d+8>>2],c,e-fc(a)|0);break a}Gp(a,ij(b,c,p[a>>2]));break a}rM(a);Ay(a,Ai(a,e));sM(a,b,c,e)}fb=d+16|0}function poa(a,b){var c=0,d=0;c=b+4|0;d=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);c=p[a>>2]+20|0;if((d|0)==(q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24))){a=p[a>>2]+16|0;a=(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))==(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))}else{a=0}return a}function dNa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;gA(d+16|0,d+8|0,c);p[114610]=0;K(71,d|0,d+16|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;N(72,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yb(d+16|0);fb=d+32|0;return}a=I()|0;H()|0;yb(d+16|0);L(a|0);E()}function zDa(a,b,c){var d=0,e=0,f=0;d=Be(a);e=_b(a);a:{if(d){b:{while(1){c:{f=d+14|0;d:{if(jn(qb(a),c,f)){if(!p[d>>2]){break a}e=d;break d}if(!jn(qb(a),f,c)){break b}e=d+4|0;if(!p[d+4>>2]){break c}d=e;e=d}d=p[d>>2];continue}break}p[b>>2]=d;return e}p[b>>2]=d;return e}d=_b(a)}p[b>>2]=d;return d}function tja(a,b,c){var d=0,e=0,f=0;d=Be(a);e=_b(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(Hr(qb(a),c,f)){if(!p[d>>2]){break a}e=d;break d}if(!Hr(qb(a),f,c)){break b}e=d+4|0;if(!p[d+4>>2]){break c}d=e;e=d}d=p[d>>2];continue}break}p[b>>2]=d;return e}p[b>>2]=d;return e}d=_b(a)}p[b>>2]=d;return d}function lca(a){var b=0,c=0;b=fb-48|0;fb=b;Gk(b);p[114610]=0;K(246,b+32|0,b|0);c=p[114610];p[114610]=0;a:{b:{if((c|0)!=1){p[114610]=0;N(9,a|0,0,b+32|0);a=p[114610];p[114610]=0;if((a|0)==1){break b}pb(b+32|0);Se(b);fb=b+48|0;return}a=I()|0;H()|0;break a}a=I()|0;H()|0;pb(b+32|0)}Se(b);L(a|0);E()}function ipa(a,b,c){var d=0,e=0,f=0;d=Be(a);e=_b(a);a:{if(d){b:{while(1){c:{qb(a);f=d+14|0;d:{if(iK(c,f)){if(!p[d>>2]){break a}e=d;break d}qb(a);if(!iK(f,c)){break b}e=d+4|0;if(!p[d+4>>2]){break c}d=e;e=d}d=p[d>>2];continue}break}p[b>>2]=d;return e}p[b>>2]=d;return e}d=_b(a)}p[b>>2]=d;return d}function bpa(a,b,c){var d=0,e=0,f=0;d=Be(a);e=_b(a);a:{if(d){b:{while(1){c:{qb(a);f=d+16|0;d:{if(gK(c,f)){if(!p[d>>2]){break a}e=d;break d}qb(a);if(!gK(f,c)){break b}e=d+4|0;if(!p[d+4>>2]){break c}d=e;e=d}d=p[d>>2];continue}break}p[b>>2]=d;return e}p[b>>2]=d;return e}d=_b(a)}p[b>>2]=d;return d}function RK(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;e=-2147483648;e=!c|!(n[c+15|0]&1)?e:p[c+8>>2];a:{b:{if(!(!d|!(q[d+34|0]&32))){e=r[d+28>>1];break b}if((e|0)==-2147483648){break a}}ts(b,e,a);vb(f+8|0,a+1074308|0,10);if(!tb(f+8|0)|p[a+480208>>2]&16384){break a}p[b+88>>2]=p[b+88>>2]&-257}fb=f+16|0}function R7(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;p[d+24>>2]=c;a:{if((a|0)!=(b|0)){while(1){c=Mb(d+8|0,p[a>>2]);p[114610]=0;J(2208,d+24|0,c|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}pb(c);a=a+4|0;if((b|0)!=(a|0)){continue}break}c=p[d+24>>2]}fb=d+32|0;return c}a=I()|0;H()|0;pb(c);L(a|0);E()}function Iua(a,b,c){var d=0,e=0,f=0;d=Be(a);e=_b(a);a:{if(d){b:{while(1){c:{f=d+14|0;d:{if(Dn(qb(a),c,f)){if(!p[d>>2]){break a}e=d;break d}if(!Dn(qb(a),f,c)){break b}e=d+4|0;if(!p[d+4>>2]){break c}d=e;e=d}d=p[d>>2];continue}break}p[b>>2]=d;return e}p[b>>2]=d;return e}d=_b(a)}p[b>>2]=d;return d}function Hra(a,b,c){var d=0,e=0,f=0;d=Be(a);e=_b(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(is(qb(a),c,f)){if(!p[d>>2]){break a}e=d;break d}if(!is(qb(a),f,c)){break b}e=d+4|0;if(!p[d+4>>2]){break c}d=e;e=d}d=p[d>>2];continue}break}p[b>>2]=d;return e}p[b>>2]=d;return e}d=_b(a)}p[b>>2]=d;return d}function Hma(a,b,c){var d=0,e=0,f=0;d=Be(a);e=_b(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(fJ(qb(a),c,f)){if(!p[d>>2]){break a}e=d;break d}if(!fJ(qb(a),f,c)){break b}e=d+4|0;if(!p[d+4>>2]){break c}d=e;e=d}d=p[d>>2];continue}break}p[b>>2]=d;return e}p[b>>2]=d;return e}d=_b(a)}p[b>>2]=d;return d}function CW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;On(d+16|0,d+8|0,c);p[114610]=0;K(71,d|0,d+16|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;N(72,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yb(d+16|0);fb=d+32|0;return}a=I()|0;H()|0;yb(d+16|0);L(a|0);E()}function BGa(a,b,c){var d=0,e=0,f=0;d=Be(a);e=_b(a);a:{if(d){b:{while(1){c:{f=d+16|0;d:{if(jn(qb(a),c,f)){if(!p[d>>2]){break a}e=d;break d}if(!jn(qb(a),f,c)){break b}e=d+4|0;if(!p[d+4>>2]){break c}d=e;e=d}d=p[d>>2];continue}break}p[b>>2]=d;return e}p[b>>2]=d;return e}d=_b(a)}p[b>>2]=d;return d}function yT(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;p[d+12>>2]=c;vc(d+12|0,128);vc(d+12|0,65535);f=r[d+12>>1];ig(a,f);if(f){c=0;while(1){e=q[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=wk(a,c),h=e,o[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}fb=d+16|0}function yFa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;if(!p[a+300>>2]){return 0}if((m[p[a+304>>2]](p[a+296>>2],c,0,0)|0)>=0){while(1){a:{g=f;c=h;if(!d){break a}e=m[p[a+300>>2]](p[a+296>>2],b,d)|0;d=d-e|0;b=b+e|0;f=e+g|0;if(f>>>0<e>>>0){c=c+1|0}h=c;if(e){continue}}break}}return g|0}function qra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c>>>1;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=(ub(q[b|0])|ub(q[b+1|0])<<8)^32768,o[f>>1]=g;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e<<1}function nra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c>>>1;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=(ub(q[b+1|0])|ub(q[b|0])<<8)^32768,o[f>>1]=g;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e<<1}function hm(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;g=a;h=a;a:{if(!b){b=0;e=0;break a}d=b;b=y(b)^31;ef(c,d,0,0,0,112-b|0);b=(p[c+12>>2]^65536)+(b+16383<<16)|0;d=0+p[c+8>>2]|0;if(d>>>0<f>>>0){b=b+1|0}f=d;d=b;b=p[c+4>>2];e=p[c>>2]}p[h>>2]=e;p[g+4>>2]=b;p[a+8>>2]=f;p[a+12>>2]=d;fb=c+16|0}function f4(a){var b=0,c=0;b=fb-16|0;fb=b;c=Tq(461220);p[115315]=461276;p[115313]=a;p[115305]=56824;n[461272]=0;p[115317]=-1;Iq(b+8|0,c);a=p[p[115305]+8>>2];p[114610]=0;K(a|0,461220,b+8|0);a=p[114610];p[114610]=0;if((a|0)!=1){Gb(b+8|0);fb=b+16|0;return}a=I()|0;H()|0;Gb(b+8|0);Vk(c);L(a|0);E()}function d4(a){var b=0,c=0;b=fb-16|0;fb=b;c=yE(461284);p[115331]=461340;p[115329]=a;p[115321]=56964;n[461336]=0;p[115333]=-1;Iq(b+8|0,c);a=p[p[115321]+8>>2];p[114610]=0;K(a|0,461284,b+8|0);a=p[114610];p[114610]=0;if((a|0)!=1){Gb(b+8|0);fb=b+16|0;return}a=I()|0;H()|0;Gb(b+8|0);bo(c);L(a|0);E()}function Ox(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=Po(a);a:{if(fc(f)>>>0<=b>>>0){break a}if(Px(a,r[kc(f,b)>>1])>>>0<=c>>>0){break a}b:{if(nc(a)>>>0>b>>>0){if(s[id(a,b)+4>>2]>c>>>0){break b}}$i(a,0);if(nc(a)>>>0<=b>>>0){break a}}Wd(e+8|0,id(a,b),c);Zd(e+8|0,d);if(!d){break a}wL(a,b,c)}fb=e+16|0}function Ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=zi(b,c);d=Bc(a);if(f>>>0>d>>>0){g=d;h=f-d|0;d=wb(a);El(a,g,h,d,0,d,0)}d=Ib(a);if((b|0)!=(c|0)){while(1){ae(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}n[e+15|0]=0;ae(d,e+15|0);Jg(a,f);fb=e+16|0;return a|0}function mH(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=p[a+4256>>2];p[a+4240>>2]=b<<1;p[114610]=0;p[c+12>>2]=0;N(1647,a+4208|0,b<<2,c+12|0);b=p[114610];p[114610]=0;a:{if((b|0)==1){b=O(71348)|0;if((H()|0)!=($(71348)|0)){break a}T(b|0)|0;p[a+4240>>2]=0;V()}p[a+4244>>2]=0;fb=c+16|0;return}L(b|0);E()}function TM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=p[b+4>>2];p[c+8>>2]=p[b>>2];p[c+12>>2]=d;e=c,f=wb(a),p[e+4>>2]=f;p[c>>2]=p[c+12>>2];a=Jm(Ib(a),p[c+8>>2],p[Cb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=p[c+4>>2];d=p[c>>2];if(b>>>0<d>>>0){break a}a=b>>>0>d>>>0}fb=c+16|0;return a|0}function MBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;wO(d+16|0,c);p[114610]=0;K(517,d|0,d+16|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;N(518,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yb(d+16|0);fb=d+32|0;return}a=I()|0;H()|0;yb(d+16|0);L(a|0);E()}function Cua(a){var b=0,c=0,d=0;b=p[a+2496>>2];c=(b+1>>>0)%624|0;d=p[(c<<2)+a>>2];b=v(d&1,-1727483681)^(p[((b+397>>>0)%624<<2)+a>>2]^(d&2147483647|p[(b<<2)+a>>2]&-2147483648)>>>1);p[(p[a+2496>>2]<<2)+a>>2]=b;p[a+2496>>2]=c;a=b^b>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;return a>>>18^a}function Sya(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;Hya(d+16|0,c);p[114610]=0;K(71,d|0,d+16|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;N(72,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yb(d+16|0);fb=d+32|0;return}a=I()|0;H()|0;yb(d+16|0);L(a|0);E()}function DR(a,b,c){var d=0;d=fb-32|0;fb=d;p[d+16>>2]=b;p[d+24>>2]=a;p[d+8>>2]=c;a:{if(!Ab(d+24|0,d+16|0)){break a}while(1){a=p[d+24>>2];if(p[p[d+8>>2]>>2]==(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))){break a}ok(d+24|0);if(Ab(d+24|0,d+16|0)){continue}break}}fb=d+32|0;return p[d+24>>2]}function ypa(a){var b=0,c=0,d=0,e=0;c=a+1074412|0;a:{b:{b=a+484344|0;if(Cp(b,r[a+1074436>>1])){if(ZK(Rb(b,r[a+1074436>>1]))){break b}}p[a+1074408>>2]=p[a+480216>>2];a=p[a+480220>>2];break a}d=a+1074408|0,e=p[Rb(b,r[a+1074436>>1])+16>>2],p[d>>2]=e;a=p[Rb(b,r[a+1074436>>1])+20>>2]}p[c>>2]=a}function dKa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;yS(d+16|0,c);p[114610]=0;K(71,d|0,d+16|0);c=p[114610];p[114610]=0;a:{if((c|0)==1){break a}p[114610]=0;N(72,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yb(d+16|0);fb=d+32|0;return}a=I()|0;H()|0;yb(d+16|0);L(a|0);E()}function dE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=Tq(a);p[a+32>>2]=b;p[a>>2]=57064;Iq(d+8|0,e);p[114610]=0;b=M(2390,d+8|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){Gb(d+8|0);p[a+40>>2]=c;p[a+36>>2]=b;g=a,h=jm(b),n[g+44|0]=h;fb=d+16|0;return}a=I()|0;H()|0;Gb(d+8|0);Vk(e);L(a|0);E()}function cE(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=yE(a);p[a+32>>2]=b;p[a>>2]=57168;Iq(d+8|0,e);p[114610]=0;b=M(2391,d+8|0)|0;f=p[114610];p[114610]=0;if((f|0)!=1){Gb(d+8|0);p[a+40>>2]=c;p[a+36>>2]=b;g=a,h=jm(b),n[g+44|0]=h;fb=d+16|0;return}a=I()|0;H()|0;Gb(d+8|0);bo(e);L(a|0);E()}function LQ(a){var b=0,c=0,d=0,e=0,f=0;b=a+32|0;d=q[b|0]|q[b+1|0]<<8;b=a+38|0;e=q[b|0]|q[b+1|0]<<8;b=0;c=a+34|0;f=q[c|0]|q[c+1|0]<<8;a=a+36|0;c=q[a|0]|q[a+1|0]<<8;a=f+c|0;if(a>>>0<c>>>0){b=1}c=e+a|0;if(c>>>0<a>>>0){b=b+1|0}a=b<<2|c>>>30;b=c<<2;c=d+b|0;if(c>>>0<b>>>0){a=a+1|0}ib=a;return c}function Ge(a){a=a|0;var b=0,c=0;p[a>>2]=79824;b=p[a+12>>2];if(p[b>>2]==(a|0)){p[b>>2]=p[a+4>>2]}b=p[a+20>>2];if(b){p[b>>2]=0;p[a+20>>2]=0}b=p[a+4>>2];if(b){p[b+8>>2]=p[a+8>>2]}c=p[a+8>>2];if(c){p[c+4>>2]=b}p[a+4>>2]=0;p[a+8>>2]=0;b=a+44|0;Cr(b+36|0);Cr(b+24|0);Br(b+12|0);Br(b);return a|0}function vna(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;g=c<<2;while(1){p[e>>2]=0;f=((d<<11)+a|0)+16396|0;Dx(f,g+f|0,e);d=d+1|0;if((d|0)!=4){continue}break}d=0;while(1){p[(d<<2)+e>>2]=((d<<11)+a|0)+16396;d=d+1|0;if((d|0)!=4){continue}break}m[p[p[b>>2]+8>>2]](b,e,p[a+24632>>2],c);fb=e+16|0}function xQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(!q[a+20|0]){if(!(m[p[p[a>>2]+44>>2]](a)|0)){b=a+4|0;while(1){GQ(a,65536);c=a,d=(f=a,g=oc(b,p[a+16>>2]),h=65536,e=p[p[a>>2]+48>>2],m[e](f|0,g|0,h|0)|0)+p[a+16>>2]|0,p[c+16>>2]=d;if(!(m[p[p[a>>2]+44>>2]](a)|0)){continue}break}}n[a+20|0]=1}}function q5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a=p5(c+8|0,a);d=p[a>>2];e=p[a+4>>2];a=p[b+4>>2];p[c>>2]=p[b>>2];p[c+4>>2]=a;b=p[c+4>>2]+e|0;e=p[c>>2];d=d+e|0;if(d>>>0<e>>>0){b=b+1|0}p[c+16>>2]=d;p[c+20>>2]=b;a=Zj(c+24|0,c+16|0);b=p[a+4>>2];a=p[a>>2];fb=c+32|0;ib=b;return a|0}function pra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>1;p[e+8>>2]=p[a>>2];f=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(f){a=p[a+20>>2];c=f;while(1){d=(ub(q[b|0])|ub(q[b+1|0])<<8)+d|0;o[a>>1]=d;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return f<<1}function n5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a=m5(c+8|0,a);d=p[a>>2];e=p[a+4>>2];a=p[b+4>>2];p[c>>2]=p[b>>2];p[c+4>>2]=a;b=p[c+4>>2]+e|0;e=p[c>>2];d=d+e|0;if(d>>>0<e>>>0){b=b+1|0}p[c+16>>2]=d;p[c+20>>2]=b;a=Zj(c+24|0,c+16|0);b=p[a+4>>2];a=p[a>>2];fb=c+32|0;ib=b;return a|0}function mra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;p[e+12>>2]=c>>>1;p[e+8>>2]=p[a>>2];f=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(f){a=p[a+20>>2];c=f;while(1){d=(ub(q[b+1|0])|ub(q[b|0])<<8)+d|0;o[a>>1]=d;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return f<<1}function xta(a){p[a>>2]=0;p[a+4>>2]=0;p[a+68>>2]=0;p[a+72>>2]=0;p[a+24>>2]=0;p[a+28>>2]=0;o[a+20>>1]=511;p[a+16>>2]=-1;o[a+14>>1]=1;o[a+6>>1]=0;o[a+8>>1]=0;o[a+10>>1]=0;o[a+12>>1]=0;n[a+73|0]=0;n[a+74|0]=0;n[a+75|0]=0;n[a+76|0]=0;n[a+77|0]=0;n[a+78|0]=0;n[a+79|0]=0;n[a+80|0]=0;return a}function mua(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=b;a:{if(If(a)>>>0>=b>>>0){f=d,g=fc(a),p[f+8>>2]=g;Ry(p[a>>2],p[Cb(d+12|0,d+8|0)>>2],c);b=p[d+12>>2];e=p[d+8>>2];if(b>>>0>e>>>0){Gt(a,b-e|0,c);break a}Gp(a,p[a>>2]+(b<<1)|0);break a}rM(a);Ay(a,Ai(a,b));Gt(a,b,c)}fb=d+16|0}function bV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;p[e+12>>2]=d;d=0;if(s[a+16>>2]>c>>>0){d=p[a+4>>2];f=p[a+12>>2];p[e+8>>2]=p[a+16>>2]-c;d=(h=d,i=b,j=c+f|0,k=p[Cb(e+12|0,e+8|0)>>2],g=p[p[d>>2]+28>>2],m[g](h|0,i|0,j|0,k|0)|0)}fb=e+16|0;return d|0}function Q6(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=b;f=q[c|0];if(f){d=a;while(1){i=f<<1;g=0;while(1){p[e>>2]=p[d>>2];p[e+4>>2]=p[(f<<2)+d>>2];h=i<<2;p[e+8>>2]=p[h+d>>2];d=d+4|0;e=e+12|0;g=g+1|0;if((g|0)!=(f|0)){continue}break}d=d+h|0;f=q[c+3|0];c=c+3|0;if(f){continue}break}}ac(a,b,e-b|0)}function OW(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;a=jF(a,c+8|0);d=wb(b);e=ve(7063);b=Ib(b);p[114610]=0;Q(195,a|0,b|0,d|0,d+e|0);b=p[114610];p[114610]=0;a:{if((b|0)!=1){p[114610]=0;P(196,a|0,7063,e|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}}b=I()|0;H()|0;pb(a);L(b|0);E()}fb=c+16|0}function E3(){var a=0,b=0,c=0;a=fb-16|0;fb=a;a:{if(Sa(a+12|0,a+8|0)|0){break a}b=fd((p[a+12>>2]<<2)+4|0);p[115396]=b;if(!b){break a}b:{b=fd(p[a+8>>2]);if(b){c=p[115396];if(c){break b}}p[115396]=0;break a}p[(p[a+12>>2]<<2)+c>>2]=0;if(!(Ra(p[115396],b|0)|0)){break a}p[115396]=0}fb=a+16|0}function rra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c>>>1;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=ub(q[b|0])|ub(q[b+1|0])<<8,o[f>>1]=g;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e<<1}function ora(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c>>>1;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=ub(q[b+1|0])|ub(q[b|0])<<8,o[f>>1]=g;a=a+2|0;b=b+2|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e<<1}function nW(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c;f=wb(a);if(f>>>0>=b>>>0){if(c){g=Ib(a);e=f-b|0;p[d+8>>2]=e;c=p[Cb(d+12|0,d+8|0)>>2];p[d+12>>2]=c;e=e-c|0;if(e){b=b+g|0;Pl(b,b+c|0,e);c=p[d+12>>2]}b=a;a=f-c|0;Jg(b,a);n[d+7|0]=0;ae(a+g|0,d+7|0)}fb=d+16|0;return}Yl();E()}function Uba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-48|0;fb=d;p[d+44>>2]=b;Vi(d+8|0,0,c);b=d+24|0;p[b>>2]=p[d+44>>2];Wc(b+4|0,d+8|0);p[114610]=0;K(2126,a+4|0,d+24|0);a=p[114610];p[114610]=0;if((a|0)!=1){_s(d+24|0);pb(d+8|0);fb=d+48|0;return}a=I()|0;H()|0;_s(d+24|0);pb(d+8|0);L(a|0);E()}function ona(a,b){var c=0;c=fb-16|0;fb=c;a=a+1074308|0;vb(c+8|0,a,28);a:{b:{if(!tb(c+8|0)){vb(c,a,1);if(!tb(c)){break b}}p[b+684>>2]=p[b+692>>2]+o[b+790>>1];Vd(b+684|0,0,256);break a}p[b+692>>2]=p[b+692>>2]+o[b+790>>1];Vd(b+692|0,0,256);o[b+790>>1]=0;p[b+684>>2]=p[b+692>>2]}fb=c+16|0}function l2(a,b){var c=0,d=0;c=fb-16|0;fb=c;qc(c+8|0,a);p[114610]=0;a=M(2449,c+8|0)|0;d=p[114610];p[114610]=0;a:{if((d|0)==1){break a}p[114610]=0;U(2463,a|0,62096,62122,b|0)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}Gb(c+8|0);fb=c+16|0;return b}a=I()|0;H()|0;Gb(c+8|0);L(a|0);E()}function n8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;if(e){while(1){g=0;if(d){while(1){f=p[Bf(b,g,h)>>2];Yb(c,g);f=f+ -2147481600>>>12|0;f=f>>>0>491520?f:491520;i=sm(a,g,h),j=(f|0)<557055?f:557055,o[i>>1]=j;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function TC(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;b=he(d,a,b);c=p[b+4>>2];a:{while(1){if(p[b+8>>2]==(c|0)){break a}Nk(a);c=p[b+4>>2];p[114610]=0;ws(c);c=p[114610];p[114610]=0;if((c|0)!=1){c=p[b+4>>2]+4|0;p[b+4>>2]=c;continue}break}a=I()|0;H()|0;Db(b);L(a|0);E()}Db(b);fb=d+16|0}function Q8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;if(e){while(1){g=0;if(d){while(1){f=p[Bf(b,g,h)>>2];Yb(c,g);f=f+ -2147481600>>>12|0;f=f>>>0>491520?f:491520;i=um(a,g,h),j=(f|0)<557055?f:557055,o[i>>1]=j;g=g+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((h|0)!=(e|0)){continue}break}}}function MJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{if(!Ud(c)|(!d|p[b+480180>>2]!=16777216)|r[b+480192>>1]<d>>>0){break b}d=p[((d<<2)+b|0)+900380>>2];if(!d){break b}d=p[d+44>>2];if(!d){break b}o[e+14>>1]=c+ -61;$ja(a,d,e+14|0);break a}Zna(a,c,p[b>>2])}fb=e+16|0}function IY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a:{if(p[b>>2]){if(!Pc(c)){wu(c,70664)}e=p[b+4>>2];m[p[p[e>>2]+24>>2]](d,e,p[b>>2]);p[114610]=0;J(1251,c|0,d|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}pb(d)}Wc(a,c);fb=d+16|0;return}a=I()|0;H()|0;pb(d);L(a|0);E()}function yD(a,b,c){var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;e=Rs(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){cf(a,e);d=a;break a}g=Zl(e)+1|0;d=Lk(g);sf(a,d);sg(a,g);oe(a,e)}while(1){if((b|0)!=(c|0)){Je(d,b);d=d+4|0;b=b+4|0;continue}break}p[f+12>>2]=0;Je(d,f+12|0);fb=f+16|0;return}tg();E()}function G2(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=0;p[d+4>>2]=4;c=Ik(a,d+8|0,p[Cb(d+12|0,d+4|0)>>2])>>>0>=0;a=ib;if((a|0)>0?1:(a|0)>=0?c:0){p[d+4>>2]=4;p[Cb(d+12|0,d+4|0)>>2]}p[d+4>>2]=p[d+8>>2];a=d+4|0;p[b>>2]=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);fb=d+16|0}function M_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;while(1){a:{if((c|0)==(d|0)|g>>>0>=e>>>0){break a}f=1;b:{c:{h=L_(c,d-c|0,b,p[a+8>>2]);switch(h+2|0){case 0:case 1:break a;case 2:break b;default:break c}}f=h}g=g+1|0;i=f+i|0;c=c+f|0;continue}break}return i|0}function upa(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:Zoa(a,c);return;case 1:Toa(a,c);return;case 2:Noa(a,c);return;case 3:Co(a,c,1520);return;case 4:Co(a,c,2544);return;case 5:Co(a,c,3568);return;case 6:Co(a,c,4592);return;case 7:Co(a,c,5616);return;default:break a}}Lb(a)}function iha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;p[a+4>>2]=b;p[a>>2]=0;b=os(a+8|0,e);p[114610]=0;J(1760,a+20|0,d|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){p[a+32>>2]=0;p[a+36>>2]=0;n[a+42|0]=0;n[a+40|0]=0;n[a+41|0]=q[a+41|0]&240|c|8;return a|0}a=I()|0;H()|0;yb(b);L(a|0);E()}function JW(a){var b=0,c=0;c=fb-32|0;fb=c;a=Xc(a);p[114610]=0;S(236,c|0);b=p[114610];p[114610]=0;a:{b:{if((b|0)!=1){b=Ig(c);p[114610]=0;J(237,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break b}Se(c);fb=c+32|0;return}b=I()|0;H()|0;break a}b=I()|0;H()|0;Se(c)}pb(a);L(b|0);E()}function Ci(a,b){var c=0,d=0,e=0,f=0;if(b){c=p[a>>2];while(1){a:{if(c){d=p[a+4>>2];break a}p[a>>2]=8;c=p[a+12>>2];if((c|0)!=p[a+8>>2]){c=c+ -1|0;p[a+12>>2]=c}d=q[c|0];p[a+4>>2]=d;c=8}c=c+ -1|0;p[a>>2]=c;p[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function aEa(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=Rs(b,c);a:{if(e>>>0<=rd(a)>>>0){p[d+12>>2]=c;if(e>>>0>Bb(a)>>>0){p[d+12>>2]=b;oP(d+12|0,Bb(a));Ye(b,p[d+12>>2],p[a>>2]);Dp(a,p[d+12>>2],c,e-Bb(a)|0);break a}Rt(a,Ye(b,c,p[a>>2]));break a}nP(a);IDa(a,se(a,e));Dp(a,b,c,e)}fb=d+16|0}function Ska(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=Rs(b,c);a:{if(e>>>0<=rd(a)>>>0){p[d+12>>2]=c;if(e>>>0>Bb(a)>>>0){p[d+12>>2]=b;oP(d+12|0,Bb(a));Ye(b,p[d+12>>2],p[a>>2]);Dp(a,p[d+12>>2],c,e-Bb(a)|0);break a}nQ(a,Ye(b,c,p[a>>2]));break a}Rka(a);eT(a,se(a,e));Dp(a,b,c,e)}fb=d+16|0}function Mra(a){if(!(0x8000000000000000>a)){ib=2147483647;return-1}if(!(-0x8000000000000000<a)){ib=-2147483648;return 0}if(x(a)<0x8000000000000000){ib=x(a)>=1?a>0?~~z(B(a/4294967296),4294967295)>>>0:~~C((a- +(~~a>>>0>>>0))/4294967296)>>>0:0;return~~a>>>0}ib=-2147483648;return 0}function I4(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;d=d-c|0;a:{if(!d){b=a;break a}f=b-a|0;if((f|0)<(d|0)){break a}n[e+15|0]=q[c|0];g=1-d|0;while(1){a=Kn(a,f+g|0,e+15|0);if(!a){break a}if(!Jm(a,c,d)){b=a;break a}a=a+1|0;f=b-a|0;if((f|0)>=(d|0)){continue}break}}fb=e+16|0;return b}function yra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=Pb(Qm(q[b|0]),-64,63)<<1,n[f|0]=g;a=a+1|0;b=b+1|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e|0}function ah(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;g=rj(a,c);df(e+8|0,p[a+28>>2]);f=p[e+20>>2];p[e+24>>2]=p[e+16>>2];p[e+28>>2]=f;a:{b:{if(!g){f=-1;if(!od(a,5)){break b}break a}f=p[g+8>>2]}m[d|0](p[a+28>>2],b,f)}a=Ki(a,g,c,e+24|0);fb=e+32|0;return a|0}function LA(a,b,c,d){var e=0,f=0;b=p[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;p[a+1072>>2]=b;c=b+p[a+1076>>2]|0;p[a+1076>>2]=c;o[(p[a+1064>>2]<<1)+d>>1]=q[a+1080|0]?c:b;p[a+1060>>2]=p[a+1060>>2]+1;e=a,f=le(p[a+1056>>2])+p[a+1064>>2]|0,p[e+1064>>2]=f;p[a+1068>>2]=p[a+1068>>2]+ -1}function Id(a){var b=0,c=0,d=0,f=0;h(+a);b=e(1)|0;e(0)|0;f=b;b=b>>>20&2047;if(b>>>0<=1074){if(b>>>0<=1021){return a*0}a=(f|0)>-1?a:-a;c=a+4503599627370496+ -4503599627370496-a;a:{if(!(c>.5^1)){d=a+c+ -1;break a}a=a+c;d=a;if(c<=-.5^1){break a}d=a+1}a=d;a=(f|0)>-1?a:-a}return a}function vV(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+16|0]=0;n[a+17|0]=0;n[a+18|0]=0;n[a+19|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;fb=b+16|0}function g6(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;if((b|0)>=1){h=(b<<1)+a|0;i=-1;j=65536;while(1){g=(f<<1)+a|0;e=r[g>>1];if(!((i|0)>=(e|0)|e>>>0>=r[h>>1])){p[c>>2]=f;e=r[g>>1];i=e}if(!((j|0)<=(e|0)|e>>>0<=r[h>>1])){p[d>>2]=f;j=r[g>>1]}f=f+1|0;if((f|0)!=(b|0)){continue}break}}}function Tj(a,b,c,d){var e=0,f=0;a:{f=p[(v(b,896)+a|0)+1075640>>2];if(!f){break a}if(!gi(f)){break a}e=q[f+34|0];if(e+ -251>>>0<5|!e){break a}e=p[(v(e,160)+a|0)+906140>>2];if(!e){break a}m[p[p[e>>2]+88>>2]](e,f,c,d,b);if(c>>>0>250){break a}o[(v(b,896)+a|0)+1075846>>1]=65535}}function Pta(a,b){a=a|0;b=b|0;var c=0;c=fb-48|0;fb=c;n[c+40|0]=q[b|0];_p(c+16|0,c+40|0);b=ub(p[c+16>>2]);_p(c+8|0,c+40|0);b=di(c+24|0,b,ub(p[c+8>>2]+1|0));p[114610]=0;J(1193,a|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);fb=c+48|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function L7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;d=no(f+8|0,d);p[114610]=0;Z(2014,a+8|0,b|0,c|0,d|0,e|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){Nc(d);NF(a);b=MF(a+88|0);p[a>>2]=84280;p[b>>2]=84368;fb=f+16|0;return a|0}a=I()|0;H()|0;Nc(d);L(a|0);E()}function yMa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;p[a>>2]=0;p[a+4>>2]=0;if(!Hb(b,c)){c=pf(b)}p[a>>2]=c;d=p[b>>2];if(m[p[p[d>>2]+16>>2]](d)|0){c=a;a=p[b>>2];e=c,f=(m[p[p[a>>2]+20>>2]](a)|0)+p[b+8>>2]|0,p[e+4>>2]=f;return}d=a+8|0;nk(d,p[a>>2]);if(!cd(d)){Dg(b,oc(d,0),c)}}function xya(a,b){var c=0;c=fb-16|0;fb=c;a=eya(c,a,b);b=p[a+4>>2];if((b|0)!=p[a+8>>2]){while(1){n[b|0]=0;n[b+1|0]=0;n[b+2|0]=0;n[b+3|0]=0;n[b+4|0]=0;n[b+5|0]=0;n[b+6|0]=0;n[b+7|0]=0;n[b+8|0]=0;b=p[a+4>>2]+9|0;p[a+4>>2]=b;if(p[a+8>>2]!=(b|0)){continue}break}}Db(a);fb=c+16|0}function v8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=w(0);if(e){while(1){f=0;if(d){while(1){h=u[Tg(b,f,g)>>3];Yb(c,f);i=cj(Id(h*134217728));j=$m(a,f,g),k=w(+(i|0)*7.450580596923828e-9),t[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function u8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=w(0);if(e){while(1){f=0;if(d){while(1){h=u[Tg(b,f,g)>>3];nf(c,f);i=cj(Id(h*134217728));j=$m(a,f,g),k=w(+(i|0)*7.450580596923828e-9),t[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function T7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=w(0);if(e){while(1){f=0;if(d){while(1){h=u[Tg(b,f,g)>>3];Yb(c,f);i=cj(Id(h*134217728));j=Bf(a,f,g),k=w(+(i|0)*7.450580596923828e-9),t[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function S7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=w(0);if(e){while(1){f=0;if(d){while(1){h=u[Tg(b,f,g)>>3];nf(c,f);i=cj(Id(h*134217728));j=Bf(a,f,g),k=w(+(i|0)*7.450580596923828e-9),t[j>>2]=k;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function Kfa(a,b,c){a=a|0;b=b|0;c=w(c);var d=0,f=0;d=fb-16|0;fb=d;t[d+12>>2]=c;if((b|0)<=12){Td(d+12|0,w(0));f=((b<<2)+a|0)+4208|0;if((b|0)!=12){b=p[d+12>>2]}else{c=w($d(w(t[d+12>>2]*w(3)))*w(.3333333432674408));t[d+12>>2]=c;b=(i(c),e(2))}p[f>>2]=b;n[a+5046|0]=1}fb=d+16|0}function Xi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(!(b?0:!(p[a+480180>>2]&1))){e=p[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;o[c+480286>>1]=64;d=c+480280|0;p[d>>2]=p[d>>2]&-257;d=c+480284|0;c=(b&3)+ -1>>>0<2;o[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function hf(a,b){var c=0,d=0,e=0,f=0;c=wb(a);a:{if((c|0)!=(wb(b)|0)){break a}d=Ib(a);b=Ib(b);b:{if(!ze(a)){if(c){break b}return 1}return!Jm(d,b,c)}while(1){a=q[b|0];e=q[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c+ -1|0;if(c){continue}break}}return f}function KA(a,b,c,d){var e=0,f=0;b=p[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;p[a+1072>>2]=b;c=b+p[a+1076>>2]|0;p[a+1076>>2]=c;n[p[a+1064>>2]+d|0]=q[a+1080|0]?c:b;p[a+1060>>2]=p[a+1060>>2]+1;e=a,f=le(p[a+1056>>2])+p[a+1064>>2]|0,p[e+1064>>2]=f;p[a+1068>>2]=p[a+1068>>2]+ -1}function FH(a,b){var c=0,d=0;c=fb-16|0;fb=c;qc(c+8|0,a);p[114610]=0;a=M(21,c+8|0)|0;d=p[114610];p[114610]=0;a:{if((d|0)==1){break a}p[114610]=0;a=J(22,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}Gb(c+8|0);fb=c+16|0;return a}a=I()|0;H()|0;Gb(c+8|0);L(a|0);E()}function go(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+ -2.5050760253406863e-8)+(d*(d*27557313707070068e-22+ -.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+ -.16666666666666632)+a}return a-(d*(b*.5-e*f)-b+e*.16666666666666632)}function QJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;n[d+15|0]=1;n[d+14|0]=a>>>2;a=q[dh(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){n[d+13|0]=1;n[d+12|0]=((a+b|0)+ -2|0)/(b+ -1|0);a=q[dh(d+13|0,d+12|0)|0]}fb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function OMa(a,b){var c=0;c=fb-32|0;fb=c;p[c+16>>2]=b;p[c+24>>2]=a;a:{if(!Ab(c+24|0,c+16|0)){break a}p[c>>2]=p[c+24>>2];if(!Ab(te(c),c+16|0)){break a}while(1){if(ZS(p[c+24>>2],p[c>>2])){p[c+24>>2]=p[c>>2]}if(Ab(te(c),c+16|0)){continue}break}}fb=c+32|0;return p[c+24>>2]}function AZ(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;b=Eh(c,a+8|0,b);a=p[b>>2];a:{while(1){if(p[b+4>>2]==(a|0)){break a}a=p[b>>2];p[114610]=0;ws(a);a=p[114610];p[114610]=0;if((a|0)!=1){a=p[b>>2]+4|0;p[b>>2]=a;continue}break}a=I()|0;H()|0;lc(b);L(a|0);E()}lc(b);fb=c+16|0}function Ev(a){var b=0,c=0;a:{if(s[a+20>>2]<=s[a+28>>2]){break a}m[p[a+36>>2]](a,0,0)|0;if(p[a+20>>2]){break a}return-1}b=p[a+4>>2];c=p[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;m[p[a+40>>2]](a,b,b>>31,1)|0}p[a+28>>2]=0;p[a+16>>2]=0;p[a+20>>2]=0;p[a+4>>2]=0;p[a+8>>2]=0;return 0}function Eha(a){var b=w(0),c=0,d=0;b=w(1);c=p[a+20>>2];if(c){b=w(w(q[c+26|0])*w(.10000000149011612))}b=b<w(.10000000149011612)?w(1):b;c=a;if(m[p[p[a>>2]+132>>2]](a)|0){d=IH(p[a+16>>2]);a=p[a+16>>2];b=w(w(b*w(s[a+480232>>2]))/w(t[d+8>>2]*t[IH(a)+20>>2]))}t[c+4196>>2]=b}function Wta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;p[e+24>>2]=d;d=rj(a,c);df(e,p[a+28>>2]);f=p[e+12>>2];p[e+16>>2]=p[e+8>>2];p[e+20>>2]=f;a:{if(!d){b:{if(!od(a,5)){break b}break a}}Tta(e+24|0,p[a+28>>2],b)}a=Ki(a,d,c,e+16|0);fb=e+32|0;return a|0}function Mq(a,b){var c=0,d=0,e=0;c=-1;a:{if((a|0)==-1){break a}e=p[b+76>>2]>=0?1:e;b:{d=p[b+4>>2];c:{if(!d){eE(b);d=p[b+4>>2];if(!d){break c}}if(d>>>0>p[b+44>>2]+ -8>>>0){break b}}if(!e){break a}return-1}c=d+ -1|0;p[b+4>>2]=c;n[c|0]=a;p[b>>2]=p[b>>2]&-17;c=a}return c}function Hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;e=-1;d=a;a=c+8|0;d=sla(d,a);if(!d){TI(a)}a:{if(!d){break a}e=0;if(!XI(c+8|0)){break a}if(b){a=c+16|0;if(p[b>>2]!=(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))|p[b+4>>2]){break a}}e=1}fb=c+32|0;return e|0}function Ara(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=ub(q[b|0])^128,n[f|0]=g;a=a+1|0;b=b+1|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e|0}function vx(a,b){var c=0,d=0;a:{if(b){vx(a,p[b>>2]);vx(a,p[b+4>>2]);a=_b(a);p[114610]=0;c=M(1385,b+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;K(1386,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}Ks(a,b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function Vr(a,b){var c=0,d=0;a:{if(b){Vr(a,p[b>>2]);Vr(a,p[b+4>>2]);a=_b(a);p[114610]=0;c=M(1380,b+14|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;K(1381,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}fp(a,b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function $za(a,b){var c=0,d=0,e=0;e=fb-16|0;fb=e;c=e;p[c>>2]=a;d=p[a+4>>2];p[c+4>>2]=d;p[c+8>>2]=d+56;d=qb(a);a=p[c+4>>2];p[114610]=0;N(979,d|0,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+56;Db(c);fb=e+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function maa(a,b){a=a|0;b=b|0;var c=w(0),d=w(0);a:{if((b|0)<0){break a}a=a+24|0;if(r[p[a>>2]+480188>>1]<=(b|0)){break a}b=v(b,896);c=w(w(q[(b+p[a>>2]|0)+1075847|0])*w(.0078125));d=w(c*c);c=w(w(q[(b+p[a>>2]|0)+1075846|0])*w(.0078125));c=w(D(w(d+w(c*c))))}return w(c)}function eua(a){a=a|0;var b=0,c=0,d=0;c=fb-32|0;fb=c;b=255;a:{if(Ah(a)>>>0<=49){b=_x(c,p[a+12>>2]);p[114610]=0;K(1179,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}pl(b);Uo(a,Ah(a)+ -1&255);b=Ah(a)+ -1|0}fb=c+32|0;return b&255}a=I()|0;H()|0;pl(b);L(a|0);E()}function _z(a,b,c){var d=0,e=0;a=a+3|0;a=(q[a|0]|q[a+1|0]<<8)>>>v(c,3)|0;e=a>>>2&1|q[b+12|0]&-4;d=e|a<<1&2;n[b+12|0]=d;if(a&2){n[b+12|0]=d|4;return}n[b+12|0]=d&251;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=q[b+13|0]|q[b+14|0]<<8;n[b+15|0]=a;n[b+16|0]=a>>>8;n[b+12|0]=e|4}}function R3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!q[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=og(n[b|0]),e=p[p[a>>2]+52>>2],m[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=Ii(b,1,c,p[a+32>>2])}return c|0}function dz(a,b){var c=0,d=0;a:{if(b){dz(a,p[b>>2]);dz(a,p[b+4>>2]);a=_b(a);p[114610]=0;c=M(735,b+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;K(736,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}gh(a,b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function bz(a,b){var c=0,d=0;a:{if(b){bz(a,p[b>>2]);bz(a,p[b+4>>2]);a=_b(a);p[114610]=0;c=M(731,b+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;K(734,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}gh(a,b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function Oy(a,b){var c=0,d=0;a:{if(b){Oy(a,p[b>>2]);Oy(a,p[b+4>>2]);a=_b(a);p[114610]=0;c=M(827,b+14|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;K(828,a|0,c|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}fp(a,b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function zra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;p[e+12>>2]=c;p[e+8>>2]=p[a>>2];f=p[Cb(e+12|0,e+8|0)>>2];b=ub(b);if(f){a=p[a+20>>2];c=f;while(1){d=ub(q[b|0])+d|0;n[a|0]=d;a=a+1|0;b=b+1|0;c=c+ -1|0;if(c){continue}break}}fb=e+16|0;return f|0}function mFa(a,b,c){var d=0;d=fb-32|0;fb=d;p[d+16>>2]=b;p[d+24>>2]=a;p[d+8>>2]=c;a:{if(!Ab(d+24|0,d+16|0)){break a}while(1){a=p[d+24>>2];if(p[p[d+8>>2]>>2]==(q[a|0]|q[a+1|0]<<8)){break a}ok(d+24|0);if(Ab(d+24|0,d+16|0)){continue}break}}fb=d+32|0;return p[d+24>>2]}function cpa(a,b){var c=0,d=0,e=0;a:{if(q[a+4|0]){c=p[a>>2];p[114610]=0;d=M(1380,b+14|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}p[114610]=0;K(1381,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}}if(b){fp(p[a>>2],b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function Xoa(a,b){var c=0,d=0,e=0;a:{if(q[a+4|0]){c=p[a>>2];p[114610]=0;d=M(1385,b+16|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}p[114610]=0;K(1386,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}}if(b){Ks(p[a>>2],b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function WC(a){a=a|0;var b=0,c=0,d=0;p[a>>2]=62472;b=p[a+8>>2];p[114610]=0;c=Y(2445)|0;d=p[114610];p[114610]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=p[a+8>>2];p[114610]=0;ev(b);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=O(0)|0;H()|0;rb(a);E()}return a|0}function MQ(a){var b=0;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=778924148?(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=1297108297:0){break a}b=a+34|0;if((q[b|0]|q[b+1|0]<<8)>>>0>255){break a}a=a+36|0;return(q[a|0]|q[a+1|0]<<8)>>>0<4e3}return 0}function Bra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=p[a>>2];e=p[Cb(d+12|0,d+8|0)>>2];b=ub(b);if(e){a=p[a+20>>2];c=e;while(1){f=a,g=Qm(q[b|0]),n[f|0]=g;a=a+1|0;b=b+1|0;c=c+ -1|0;if(c){continue}break}}fb=d+16|0;return e|0}function WH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(2097151<b>>>0){tc(32587);E()}f=gc(d<<11,4)}p[a>>2]=f;c=(c<<11)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<11)+f|0,p[g>>2]=h;fb=e+16|0;return a|0}function UH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){tc(32587);E()}f=gc(d<<2,4)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a|0}function R5(a,b){var c=w(0),d=0,e=0,f=0,g=w(0);if((a|0)>=2){a=a>>1;d=(a|0)>1?a:1;e=1/+(a|0);a=0;while(1){c=w(Sh((+(a|0)*1.5707963705062866+.7853981852531433)*e));f=(a<<2)+b|0,g=w(Sh(+w(c*c)*1.5707963705062866)),t[f>>2]=g;a=a+1|0;if((d|0)!=(a|0)){continue}break}}}function Kx(a,b){var c=0,d=0;a:{if(b){Kx(a,p[b>>2]);Kx(a,p[b+4>>2]);a=_b(a);p[114610]=0;c=M(1257,b+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;K(1258,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Jx(b)}return}a=O(0)|0;H()|0;rb(a);E()}function HFa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=p[b+12>>2];p[c+8>>2]=p[b+8>>2];p[c+12>>2]=d;d=p[b+4>>2];p[c>>2]=p[b>>2];p[c+4>>2]=d;MKa(a,_P(c));p[a>>2]=76516;d=p[b+4>>2];p[a+296>>2]=p[b>>2];p[a+300>>2]=d;d=p[b+12>>2];p[a+304>>2]=p[b+8>>2];p[a+308>>2]=d;fb=c+16|0}function Cpa(a,b){var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;YK(b,c,c+96|0);b=0;while(1){d=b<<3;e=d+a|0;f=p[c+d>>2];d=p[(d|4)+c>>2];p[e>>2]=f;p[e+4>>2]=d&65535;b=b+1|0;if((b|0)!=12){continue}break}p[a+104>>2]=0;p[a+96>>2]=!(p[a+88>>2]|p[a+92>>2]);p[a+100>>2]=0;fb=c+96|0}function xC(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;p[b>>2]=0;n[c+15|0]=0;f=Mg(a,c+15|0);d=q[c+15|0];p[b>>2]=d>>>2;d=d&3;if(d){while(1){n[c+15|0]=0;g=Mg(a,c+15|0);e=e+1|0;p[b>>2]=p[b>>2]|q[c+15|0]<<(e<<3)+ -2;f=f&g;if((d|0)!=(e|0)){continue}break}}fb=c+16|0}function vGa(a,b){var c=0,d=0,e=0;a:{if(q[a+4|0]){c=p[a>>2];p[114610]=0;d=M(731,b+16|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}p[114610]=0;K(734,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}}if(b){gh(p[a>>2],b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function uDa(a,b){var c=0,d=0,e=0;a:{if(q[a+4|0]){c=p[a>>2];p[114610]=0;d=M(827,b+14|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}p[114610]=0;K(828,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}}if(b){fp(p[a>>2],b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function qja(a,b){var c=0,d=0,e=0;a:{if(q[a+4|0]){c=p[a>>2];p[114610]=0;d=M(735,b+16|0)|0;e=p[114610];p[114610]=0;if((e|0)==1){break a}p[114610]=0;K(736,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}}if(b){gh(p[a>>2],b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function To(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=$j(a,b);if((e|0)==255){break a}if(aj(a)){break a}b=ti(a+314|0,e);e=QL(e);if(!(f=0,g=!(n[Yb(b,10)|0]&1),h=d,h?f:g)){Yg(p[a>>2],e- -64&65535,PL(c,q[Yb(b,2)|0]))}if(d){break a}Yg(p[a>>2],e+67&65535,PL(c,q[Yb(b,3)|0]))}}function eKa(a){var b=0,c=0,d=0,e=0;if(!q[a+8|0]){if(q[a+24|0]){n[a+24|0]=0;c=a+40|0;while(1){d=ti(c,b),e=0,n[d+8|0]=e;b=b+1|0;if((b|0)!=16){continue}break}b=a+28|0;nk(b,0);CR(b)}b=a+12|0;nk(b,p[a+4>>2]);m[p[p[a>>2]+44>>2]](a,p[b>>2],0,p[a+4>>2])|0;n[a+8|0]=1}}function Kw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!of(a)){break a}while(1){if(!Ch(De(a,e))){break a}d=d+1|0;e=d&65535;if(of(a)>>>0>e>>>0){continue}break}}if(!((d&65535)>>>0>=r[p[p[a+12>>2]+8>>2]+10>>1]?c:0)){return(ag(a,d&65535,b)?d:-1)&65535}return 65535}function Kj(a){var b=0,c=0;a:{b=p[a+1396>>2];if((b|0)>24){break a}if(!b){p[a+1392>>2]=0}while(1){if(q[a+1376|0]?0:p[a+1384>>2]){break a}c=br(a);if((c|0)==-1){break a}b=p[a+1396>>2];p[a+1396>>2]=b+8;p[a+1392>>2]=p[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Iu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=W(16)|0;eC();a=Lc(c+8|0,a,85304);p[114610]=0;e=p[a+4>>2];p[c>>2]=p[a>>2];p[c+4>>2]=e;P(2845,d|0,c|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){ba(d|0,70712,2846);E()}a=I()|0;H()|0;X(d|0);L(a|0);E()}function G6(a){var b=0,c=0,d=w(0);if((a|0)<=128){return t[(a<<2)+48048>>2]}c=(a|0)<1024;a=c?a<<3:a;b=a<<1&64;d=w(w((a&63)-b|0)/w((a&-64)+b|0));return w(w(w(w(w(w(d*w(.2222222238779068))+w(1.3333333730697632))*d)+w(1))*(c?w(16):w(256)))*t[(a+b>>6<<2)+48048>>2])}function sK(a,b,c){a:{switch(b|0){case 0:XJ(a,c);return;case 1:Coa(a,c);return;case 2:voa(a,c);return;case 3:yo(a,c,1520);return;case 4:yo(a,c,2544);return;case 5:yo(a,c,3568);return;case 6:yo(a,c,4592);return;case 7:yo(a,c,5616);return;default:break a}}Ue(a)}function pY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Xf(a,p[b+8>>2],0)){Eu(b,c,d);return}e=p[a+12>>2];f=a+16|0;YB(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){YB(a,b,c,d);if(q[b+54|0]){break a}a=a+8|0;if(a>>>0<e>>>0){continue}break}}}function pV(a,b,c,d){var e=0,f=0,g=0;f=fb-48|0;fb=f;e=f+40|0;e=oV(f+24|0,hB(e,1),Lc(f+16|0,e,1));g=p[e>>2];p[114610]=0;U(285,g|0,b|0,c|0,d|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){Jn(a,Xb(p[e>>2]),Cd(e));aB(e);fb=f+48|0;return}a=I()|0;H()|0;aB(e);L(a|0);E()}function mJ(a,b){var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;if(p[a+4>>2]==p[b+4>>2]){d=p[a+4>>2];e=p[a>>2];p[c+24>>2]=e;p[c+28>>2]=d;f=p[b+4>>2];a=c;b=p[b>>2];p[a+16>>2]=b;p[a+20>>2]=f;p[a+8>>2]=e;p[a+12>>2]=d;p[a>>2]=b;p[a+4>>2]=f;d=!Nma(a+8|0,a)}fb=c+32|0;return d}function cNa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=dy(a);a:{if(!b){break a}p[114610]=0;K(404,a|0,b|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;N(405,a|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;us(d);L(a|0);E()}return a|0}function YGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;p[e+24>>2]=d;d=rj(a,c);df(e,p[a+28>>2]);f=p[e+12>>2];p[e+16>>2]=p[e+8>>2];p[e+20>>2]=f;a:{if(!d){b:{if(!od(a,5)){break b}break a}}Sta(p[a+28>>2],b,p[e+24>>2])}Ki(a,d,c,e+16|0);fb=e+32|0}function Ota(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;p[e+24>>2]=d;d=rj(a,c);df(e,p[a+28>>2]);f=p[e+12>>2];p[e+16>>2]=p[e+8>>2];p[e+20>>2]=f;a:{if(!d){b:{if(!od(a,5)){break b}break a}}Zta(p[a+28>>2],b,p[e+24>>2])}Ki(a,d,c,e+16|0);fb=e+32|0}function Mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;p[e+24>>2]=d;d=rj(a,c);df(e,p[a+28>>2]);f=p[e+12>>2];p[e+16>>2]=p[e+8>>2];p[e+20>>2]=f;a:{if(!d){b:{if(!od(a,5)){break b}break a}}Bja(p[a+28>>2],b,p[e+24>>2])}Ki(a,d,c,e+16|0);fb=e+32|0}function LBa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fA(a);a:{if(!b){break a}p[114610]=0;K(921,a|0,b|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;N(922,a|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;Bt(d);L(a|0);E()}return a|0}function Cta(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;o[d+10>>1]=0;p[d+4>>2]=2;c=Ik(a,d+10|0,p[Cb(d+12|0,d+4|0)>>2])>>>0>=0;a=ib;if((a|0)>0?1:(a|0)>=0?c:0){p[d+4>>2]=2;p[Cb(d+12|0,d+4|0)>>2]}o[d+4>>1]=r[d+10>>1];a=d+4|0;o[b>>1]=q[a|0]|q[a+1|0]<<8;fb=d+16|0}function vS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=rU(a);a:{if(!b){break a}p[114610]=0;K(467,a|0,b|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;N(468,a|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;NA(d);L(a|0);E()}return a|0}function r1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;p[g+8>>2]=b;qc(g,d);p[114610]=0;b=M(2449,g|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){Gb(g);oD(a,f+24|0,g+8|0,c,e,b);fb=g+16|0;return p[g+8>>2]}a=I()|0;H()|0;Gb(g);L(a|0);E()}function q1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;p[g+8>>2]=b;qc(g,d);p[114610]=0;b=M(2449,g|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){Gb(g);nD(a,f+16|0,g+8|0,c,e,b);fb=g+16|0;return p[g+8>>2]}a=I()|0;H()|0;Gb(g);L(a|0);E()}function pt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Xt(a);a:{if(!b){break a}p[114610]=0;K(564,a|0,b|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;N(565,a|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;Tp(d);L(a|0);E()}return a|0}function lZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=nZ(Ib(b));p[a>>2]=d;a:{if((d|0)<=-1){a=p[114584];fC(c,68497,b);b=Ib(c);p[114610]=0;K(2310,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;pb(c);L(a|0);E()}fb=c+16|0;return a|0}E()}function WY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;d=tq(a);e=wb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Ib(a);Rh(d+(e<<2)|0,b,c);b=c+e|0;Jg(a,b);p[f+12>>2]=0;Je(d+(b<<2)|0,f+12|0);break a}iC(a,d,(c+e|0)-d|0,e,e,0,c,b)}fb=f+16|0;return a|0}function PE(a,b){var c=0,d=0,i=0;h(+a);c=e(1)|0;d=e(0)|0;i=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=PE(a*0x10000000000000000,b);b=p[b>>2]+ -64|0}p[c>>2]=b;return a}p[b>>2]=c+ -1022;f(0,d|0);f(1,i&-2146435073|1071644672);a=+g()}return a}function Nja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;p[e+24>>2]=d;d=rj(a,c);df(e,p[a+28>>2]);f=p[e+12>>2];p[e+16>>2]=p[e+8>>2];p[e+20>>2]=f;a:{if(!d){b:{if(!od(a,5)){break b}break a}}mI(p[a+28>>2],b,p[e+24>>2])}Ki(a,d,c,e+16|0);fb=e+32|0}function IQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kz(a);a:{if(!b){break a}p[114610]=0;K(683,a|0,b|0);e=p[114610];p[114610]=0;if((e|0)!=1){p[114610]=0;N(684,a|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;at(d);L(a|0);E()}return a|0}function sua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;p[d+16>>2]=c;p[d+24>>2]=b;b=p[a>>2];e=d,f=Ub(a),p[e+8>>2]=f;b=b+(Ap(d+24|0,d+8|0)<<1)|0;if(Ab(d+24|0,d+16|0)){Gp(a,Ye(b+(Ap(d+16|0,d+24|0)<<1)|0,p[a+4>>2],b))}a=Ze(b);fb=d+32|0;return a|0}function jla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;p[d+16>>2]=c;p[d+24>>2]=b;b=p[a>>2];e=d,f=Ub(a),p[e+8>>2]=f;b=b+v(Kr(d+24|0,d+8|0),6)|0;if(Ab(d+24|0,d+16|0)){iz(a,Ow(b+v(Kr(d+16|0,d+24|0),6)|0,p[a+4>>2],b))}a=Ze(b);fb=d+32|0;return a|0}function jga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;zH(a,b,c,d);p[a+4232>>2]=1056964608;b=a+4224|0;p[b>>2]=1056964608;p[b+4>>2]=1048406533;b=a+4216|0;p[b>>2]=1020054733;p[b+4>>2]=1065353216;p[a+4208>>2]=1056964608;p[a+4212>>2]=1065353216;p[a>>2]=81132;return a|0}function Uaa(a,b){var c=0,d=0,e=0;c=fb-80|0;fb=c;p[c+40>>2]=p[b+32>>2];p[c>>2]=p[b+36>>2];e=p[Gf(c+40|0,c)>>2];a:{if(p[b+32>>2]==p[_o(c+40|0)+32>>2]){d=-1;if(p[b+36>>2]==p[_o(c)+36>>2]){break a}}d=0;if((e|0)<1){break a}d=(e+500|0)/1e3|0}p[a>>2]=d;fb=c+80|0}function M8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=Tq(a);p[a>>2]=76848;f=iw(a+32|0,d+8|0);p[a+48>>2]=c;p[a+44>>2]=0;p[114610]=0;K(182,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a|0}a=I()|0;H()|0;pb(f);Vk(e);L(a|0);E()}function BS(a){var b=0,c=0,d=0,e=0;b=a+5|0;c=q[b|0]|q[b+1|0]<<8;b=c+q[a+2|0]|0;if(b>>>0<c>>>0){d=1}c=d<<1|b>>>31;d=b<<1;b=c;e=d;a=a+3|0;a=q[a|0]|q[a+1|0]<<8;c=a>>>30|0;d=a<<2;e=e+d|0;a=b+c|0;a=e>>>0<d>>>0?a+1|0:a;b=e+47|0;if(b>>>0<47){a=a+1|0}ib=a;return b}function m3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=p[b>>2];g=p[d>>2];if((f|0)<(g|0)){break a}if((g|0)<(f|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function gr(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;p[b+12>>2]=12;p[b+8>>2]=32;if(p[Cb(b+12|0,b+8|0)>>2]){while(1){e=Ho(a);p[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<s[Cb(b+12|0,b+8|0)>>2]){continue}break}}fb=b+16|0;a=p[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function Yna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=fb-16|0;fb=e;CJ(d,b,c<<24>>24);fb=e+16|0;b=d;c=Ib(d);e=wb(d);p[114610]=0;P(196,a|0,c|0,e|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(b);fb=d+16|0;return a|0}a=I()|0;H()|0;pb(b);L(a|0);E()}function L1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;p[g+8>>2]=b;qc(g,d);p[114610]=0;b=M(21,g|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){Gb(g);rD(a,f+24|0,g+8|0,c,e,b);fb=g+16|0;return p[g+8>>2]}a=I()|0;H()|0;Gb(g);L(a|0);E()}function K1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;p[g+8>>2]=b;qc(g,d);p[114610]=0;b=M(21,g|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){Gb(g);qD(a,f+16|0,g+8|0,c,e,b);fb=g+16|0;return p[g+8>>2]}a=I()|0;H()|0;Gb(g);L(a|0);E()}function Jr(a,b,c){var d=0,e=0,f=0;d=fb-32|0;fb=d;a:{if(!(!b|!c)){e=Mb(d,b);p[114610]=0;N(1567,d+16|0,e|0,c|0);f=p[114610];p[114610]=0;if((f|0)==1){break a}xb(a+36|0,d+16|0);pb(d+16|0);pb(e)}fb=d+32|0;return(b|0)!=0&(c|0)!=0}a=I()|0;H()|0;pb(e);L(a|0);E()}function yma(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;d=gd(a);e=b,f=Ub(a),p[e+8>>2]=f;e=b,f=Vb(a),p[e>>2]=f;if(Ab(b+8|0,b)){c=+(d>>>0);while(1){a=p[b+8>>2];u[a>>3]=u[a>>3]/c;u[a+8>>3]=u[a+8>>3]/c;Ff(b+8|0);if(Ab(b+8|0,b)){continue}break}}fb=b+16|0}function p3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=n[b|0];g=n[d|0];if((f|0)<(g|0)){break a}if((g|0)<(f|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function JNa(a,b,c,d){var e=0,f=0,g=0,h=0;e=b;f=e>>31;e=e>>31;a=a^e;g=a-e|0;h=(b^f)-((a>>>0<e>>>0)+f|0)|0;e=d;f=e>>31;e=e>>31;a=c^e;e=QNa(g,h,a-e|0,(d^f)-((a>>>0<e>>>0)+f|0)|0);b=b^d;c=b>>31;a=b>>31;b=e^a;d=b-a|0;ib=(c^ib)-((b>>>0<a>>>0)+c|0)|0;return d}function zEa(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+16|0]=0;n[a+17|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;fb=b+16|0}function mr(a){var b=0,c=0;c=a+24|0;b=p[c>>2];p[114610]=0;M(1402,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){bd(a+68|0);gf(a+36|0);gg(a+32|0);th(c);Nc(a+4|0);Nc(a);return a}b=O(0)|0;H()|0;bd(a+68|0);gf(a+36|0);gg(a+32|0);th(c);Nc(a+4|0);Nc(a);rb(b);E()}function ela(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-32|0;fb=d;c=Qj(a);if(b){c=v(b,c);a:{b:{if(p[a+12>>2]!=(b|0)){break b}if((Rf(a)|0)!=(c|0)){break b}gla(a);break a}ch(d+8|0);c=IQ(d+16|0,c,d+8|0);cla(a,c);wl(c);p[a+12>>2]=b}a=1}else{a=0}fb=d+32|0;return a|0}function bj(a){a=a|0;var b=0,c=0;b=fb-48|0;fb=b;if(!cd(a)){qM(b+32|0,a);pM(b+24|0,a);c=p[b+36>>2];p[b+16>>2]=p[b+32>>2];p[b+20>>2]=c;c=p[b+28>>2];p[b+8>>2]=p[b+24>>2];p[b+12>>2]=c;pua(b+40|0,b+16|0,b+8|0);c=Nz(Ub(a),p[b+44>>2])}fb=b+48|0;return c&65535}function xFa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-48|0;fb=c;a:{if(!Hb(a,1)){break a}kFa(b);d=td(a);if(!d){break a}while(1){d=d+ -1|0;b:{if(!eFa(a,c+8|0)){break b}e=q[c+8|0];if(e>>>0>63){break b}ac(VP(b,e),c+8|0,33)}if(d&255){continue}break}}fb=c+48|0}function eE(a){var b=0,c=0;b=q[a+74|0];n[a+74|0]=b+ -1|b;if(s[a+20>>2]>s[a+28>>2]){m[p[a+36>>2]](a,0,0)|0}p[a+28>>2]=0;p[a+16>>2]=0;p[a+20>>2]=0;b=p[a>>2];if(b&4){p[a>>2]=b|32;return-1}c=p[a+44>>2]+p[a+48>>2]|0;p[a+8>>2]=c;p[a+4>>2]=c;return b<<27>>31}function Z7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=w(0);if(e){while(1){f=0;if(d){while(1){h=p[Bf(b,f,g)>>2];Yb(c,f);i=Bf(a,f,g),j=w(w(h|0)*w(7.450580596923828e-9)),t[i>>2]=j;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function Y7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=w(0);if(e){while(1){f=0;if(d){while(1){h=p[Bf(b,f,g)>>2];nf(c,f);i=Bf(a,f,g),j=w(w(h|0)*w(7.450580596923828e-9)),t[i>>2]=j;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function B8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=w(0);if(e){while(1){f=0;if(d){while(1){h=p[Bf(b,f,g)>>2];Yb(c,f);i=$m(a,f,g),j=w(w(h|0)*w(7.450580596923828e-9)),t[i>>2]=j;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function A8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=w(0);if(e){while(1){f=0;if(d){while(1){h=p[Bf(b,f,g)>>2];nf(c,f);i=$m(a,f,g),j=w(w(h|0)*w(7.450580596923828e-9)),t[i>>2]=j;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function dx(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;f=p[b+656>>2];d=0;a:{if(!f){break a}f=oA(f,c);d=a+1074308|0;vb(e+8|0,d,31);a=0;if(!tb(e+8|0)){vb(e,d,93);a=tb(e)^1}if(!(n[rJ(b,c)|0]&1)){d=0;if(!(n[f+12|0]&1)|a){break a}}d=cd(f)^1}fb=e+16|0;return d}function LK(a,b,c){var d=0,e=0;d=p[(v(b,896)+a|0)+1075072>>2];a:{if((d&1024)>>>10&(c|0)==1|d&67108864){break a}if(r[a+480188>>1]<=b>>>0){c=r[(v(b,896)+a|0)+1075792>>1];b=c?c+ -1|0:b}b=b&65535;if(b>>>0>126){break a}e=q[((b<<5)+a|0)+480288|0]}return e}function Fra(a,b){var c=0,d=0;a:{if(q[a+4|0]){a=p[a>>2];p[114610]=0;c=M(1257,b+16|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}p[114610]=0;K(1258,a|0,c|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}}if(b){Jx(b)}return}a=O(0)|0;H()|0;rb(a);E()}function a7(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=p[b+4>>2];h=p[b+8>>2];e=p[a+6144>>2];f=e-d|0;e=(e|0)>(d|0)?d:e;f=ac(c+12|0,(((f|0)>0?f:0)+a|0)+6156|0,e);i=p[b>>2]+(p[b+4>>2]/8|0)|0;b=(h-g|0)/8|0;ac(e+f|0,i,b);rF(c,f,b+e|0);return p[a+6144>>2]>=(d|0)}function VKa(a,b,c){var d=0;d=fb-32|0;fb=d;p[d+16>>2]=b;p[d+24>>2]=a;p[d+8>>2]=c;a:{if(!Ab(d+24|0,d+16|0)){break a}while(1){if((xk(p[d+24>>2])|0)==p[p[d+8>>2]>>2]){break a}ok(d+24|0);if(Ab(d+24|0,d+16|0)){continue}break}}fb=d+32|0;return p[d+24>>2]}function q0(a,b){a=a|0;b=b|0;var c=0,d=0;c=F$(a);a:{if(!b){break a}p[114610]=0;K(2554,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(2555,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;SC(c);L(a|0);E()}return a|0}function p1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=fb-16|0;fb=a;p[a+8>>2]=b;qc(a,d);p[114610]=0;b=M(2449,a|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){Gb(a);mD(f+20|0,a+8|0,c,e,b);fb=a+16|0;return p[a+8>>2]}b=I()|0;H()|0;Gb(a);L(b|0);E()}function loa(a){var b=0,c=0;c=a+946300|0;b=a+906300|0;while(1){a=p[b>>2];a:{if(!a){break a}if(!(m[p[p[a>>2]+112>>2]](a)|0)){break a}m[p[p[a>>2]+104>>2]](a,0);m[p[p[a>>2]+92>>2]](a);m[p[p[a>>2]+120>>2]](a)}b=b+160|0;if((c|0)!=(b|0)){continue}break}}function kDa(a,b){a=a|0;b=b|0;var c=0,d=0;c=WCa(a);a:{if(!b){break a}p[114610]=0;K(875,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(876,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;bP(c);L(a|0);E()}return a|0}function hDa(a,b){a=a|0;b=b|0;var c=0,d=0;c=TCa(a);a:{if(!b){break a}p[114610]=0;K(877,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(878,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;$O(c);L(a|0);E()}return a|0}function ZGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;p[e+24>>2]=d;d=rj(a,c);df(e,p[a+28>>2]);f=p[e+12>>2];p[e+16>>2]=p[e+8>>2];p[e+20>>2]=f;a:{if(!d){if(od(a,5)){break a}}zQ(p[a+28>>2],b,p[e+24>>2],0)}Ki(a,d,c,e+16|0);fb=e+32|0}function Oxa(a,b){a=a|0;b=b|0;var c=0,d=0;c=dy(a);a:{if(!b){break a}p[114610]=0;K(404,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(1055,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;us(c);L(a|0);E()}return a|0}function eba(a,b){var c=0,d=0,e=0;c=fb-48|0;fb=c;d=y9(c+24|0,gc(324,4),Lc(c+16|0,c+40|0,1));e=p[d>>2];p[114610]=0;J(2163,e|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){Jn(a,Xb(p[d>>2]),Cd(d));gG(d);fb=c+48|0;return}a=I()|0;H()|0;gG(d);L(a|0);E()}function _Ga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;p[e+24>>2]=d;d=rj(a,c);df(e,p[a+28>>2]);f=p[e+12>>2];p[e+16>>2]=p[e+8>>2];p[e+20>>2]=f;a:{if(!d){if(od(a,5)){break a}}RFa(p[a+28>>2],b,p[e+24>>2])}Ki(a,d,c,e+16|0);fb=e+32|0}function YMa(a,b){a=a|0;b=b|0;var c=0,d=0;c=cT(a);a:{if(!b){break a}p[114610]=0;K(406,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(407,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;aT(c);L(a|0);E()}return a|0}function Pn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;d=Bc(a);e=wb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Ib(a);uh(d+e|0,b,c);b=c+e|0;Jg(a,b);n[f+15|0]=0;ae(b+d|0,f+15|0);break a}xu(a,d,(c+e|0)-d|0,e,e,0,c,b)}fb=f+16|0;return a|0}function Cj(a,b,c,d){var e=0;if(d&2048){n[a|0]=43;a=a+1|0}if(d&512){n[a|0]=35;a=a+1|0}while(1){e=q[b|0];if(e){n[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}n[a|0]=b}function pz(a,b){a=a|0;b=b|0;var c=0,d=0;c=Xt(a);a:{if(!b){break a}p[114610]=0;K(564,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(673,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;Tp(c);L(a|0);E()}return a|0}function oq(a,b){var c=0,d=0;if(!a){return fd(b)}if(b>>>0>=4294967232){p[114584]=48;return 0}c=gY(a+ -8|0,b>>>0<11?16:b+11&-8);if(c){return c+8|0}c=fd(b);if(!c){return 0}d=p[a+ -4>>2];d=(d&3?-4:-8)+(d&-8)|0;ac(c,a,d>>>0<b>>>0?d:b);Nb(a);return c}function dba(a,b){var c=0,d=0,e=0;c=fb-48|0;fb=c;d=w9(c+24|0,gc(56,4),Lc(c+16|0,c+40|0,1));e=p[d>>2];p[114610]=0;J(2164,e|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){Jn(a,Xb(p[d>>2]),Cd(d));dG(d);fb=c+48|0;return}a=I()|0;H()|0;dG(d);L(a|0);E()}function Vna(a,b,c,d){var e=0;e=fb-16|0;fb=e;a:{b:{if((b|0)==(c|0)){b=a;a=Ib(d);di(b,a,wb(d)+a|0);break b}sK(e,c,d);p[114610]=0;N(115,a|0,b|0,e|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yc(e)}fb=e+16|0;return}a=I()|0;H()|0;yc(e);L(a|0);E()}function Qka(a,b,c){var d=0,e=0;if(b){while(1){d=c;e=q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24);n[a|0]=e;n[a+1|0]=e>>>8;n[a+2|0]=e>>>16;n[a+3|0]=e>>>24;d=q[d+4|0]|q[d+5|0]<<8;n[a+4|0]=d;n[a+5|0]=d>>>8;a=a+6|0;b=b+ -1|0;if(b){continue}break}}}function I1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=fb-16|0;fb=a;p[a+8>>2]=b;qc(a,d);p[114610]=0;b=M(21,a|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){Gb(a);pD(f+20|0,a+8|0,c,e,b);fb=a+16|0;return p[a+8>>2]}b=I()|0;H()|0;Gb(a);L(b|0);E()}function Hua(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;b=_b(b);a=Gua(a,gc(16,4),hk(d+8|0,b));e=p[a>>2];p[114610]=0;N(1168,b|0,e+14|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){f=_b(a),g=1,n[f+4|0]=g;fb=d+16|0;return}b=I()|0;H()|0;yM(a);L(b|0);E()}function Gma(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;b=_b(b);a=Fma(a,gc(28,4),hk(d+8|0,b));e=p[a>>2];p[114610]=0;N(1526,b|0,e+16|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){f=_b(a),g=1,n[f+4|0]=g;fb=d+16|0;return}b=I()|0;H()|0;eJ(a);L(b|0);E()}function fo(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+ -.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+ -2.7557314351390663e-7))-a*b))}function c2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;p[e+12>>2]=b;p[e+8>>2]=d;b=lh(e,e+12|0);p[114610]=0;a=P(2470,a|0,c|0,p[e+8>>2])|0;c=p[114610];p[114610]=0;if((c|0)!=1){ye(b);fb=e+16|0;return a|0}a=I()|0;H()|0;ye(b);L(a|0);E()}function DKa(a,b){a=a|0;b=b|0;var c=0,d=0;c=qA(a);a:{if(!b){break a}p[114610]=0;K(36,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(37,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;uT(c);L(a|0);E()}return a|0}function lJa(a,b){a=a|0;b=b|0;var c=0;b=fb-32|0;fb=b;c=-1;a:{if(!Cz(a,b+16|0)){break a}c=0;if(!lR(b+16|0)){break a}if(p[b+16>>2]==1179472708){c=-1;if(!Qc(a,4)){break a}}c=-1;if(!oj(a,b+8|0)){break a}c=p[b+8>>2]==1196314451}fb=b+32|0;return c|0}function de(){var a=0,b=0;a:{b:{if(n[461768]&1){break b}if(!nd(461768)){break b}p[114610]=0;a=P(2447,2147483647,62389,0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}p[115441]=a;md(461768)}return p[115441]}a=I()|0;H()|0;ge(461768);L(a|0);E()}function aW(a,b){var c=0,d=0,e=0;c=fb-48|0;fb=c;d=$V(c+24|0,gc(24,4),Lc(c+16|0,c+40|0,1));e=p[d>>2];p[114610]=0;J(273,e|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){Jn(a,Xb(p[d>>2]),Cd(d));vB(d);fb=c+48|0;return}a=I()|0;H()|0;vB(d);L(a|0);E()}function SL(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;if(q[a+530|0]){while(1){d=c&65535;ii(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}n[a+530|0]=0}n[b+15|0]=0;kj(a+4|0,18,b+15|0);Ry(a+22|0,18,20042);n[b+14|0]=255;kj(a+58|0,256,b+14|0);fb=b+16|0}function GFa(a){a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=(xk(14647)|0)){break a}a=a+4|0;if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))>>>0>259){break a}return(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))>>>0>255}return 0}function AD(a,b,c,d,e){var f=0;f=fb-144|0;fb=f;p[f+44>>2]=a;p[f+4>>2]=a;p[f>>2]=0;p[f+76>>2]=-1;p[f+8>>2]=(a|0)<0?-1:a+2147483647|0;Rg(f,0,0);c=PD(f,c,1,d,e);d=ib;if(b){p[b>>2]=((p[f+4>>2]+p[f+120>>2]|0)-p[f+8>>2]|0)+a}fb=f+144|0;ib=d;return c}function yla(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){tc(31689);E()}f=gc(v(d,24),4)}p[a>>2]=f;c=v(c,24)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,24)+f|0,p[g>>2]=h;fb=e+16|0;return a}function rJa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){tc(12706);E()}f=gc(v(d,24),4)}p[a>>2]=f;c=v(c,24)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,24)+f|0,p[g>>2]=h;fb=e+16|0;return a}function lqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;p[a>>2]=b;c=a+4|0;xpa(c,WK(Ee(229984),b+1074376|0));b=Ypa(a+8|0);d=a+20|0;vpa(d);p[114610]=0;S(1341,a|0);e=p[114610];p[114610]=0;if((e|0)!=1){return a|0}a=I()|0;H()|0;UK(d);qK(b);gg(c);L(a|0);E()}function lC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c+ -1|0;d=c<<2;p[d+a>>2]=p[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){p[d>>2]=p[b>>2];d=d+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}return a|0}function fO(a){var b=0,c=0,d=0,e=0,f=0;ib=0;d=q[a+4|0];e=q[a+92|0];b=a+94|0;f=q[b|0]|q[b+1|0]<<8;b=q[a+93|0];a=f+b|0;if(a>>>0<b>>>0){c=1}b=e+a|0;if(b>>>0<a>>>0){c=c+1|0}a=c<<2|b>>>30;c=b<<2;b=d+c|0;if(b>>>0<c>>>0){a=a+1|0}c=b+ -96|0;return c}function bFa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(130150524<b>>>0){tc(14703);E()}f=gc(v(d,33),1)}p[a>>2]=f;c=v(c,33)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,33)+f|0,p[g>>2]=h;fb=e+16|0;return a}function asa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(357913941<b>>>0){tc(20117);E()}f=gc(v(d,12),4)}p[a>>2]=f;c=v(c,12)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,12)+f|0,p[g>>2]=h;fb=e+16|0;return a}function Kza(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){tc(16860);E()}f=gc(v(d,24),4)}p[a>>2]=f;c=v(c,24)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,24)+f|0,p[g>>2]=h;fb=e+16|0;return a}function IIa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){tc(12852);E()}f=gc(v(d,24),4)}p[a>>2]=f;c=v(c,24)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,24)+f|0,p[g>>2]=h;fb=e+16|0;return a}function IEa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){tc(14703);E()}f=gc(v(d,24),4)}p[a>>2]=f;c=v(c,24)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,24)+f|0,p[g>>2]=h;fb=e+16|0;return a}function EKa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){tc(12489);E()}f=gc(v(d,24),4)}p[a>>2]=f;c=v(c,24)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,24)+f|0,p[g>>2]=h;fb=e+16|0;return a}function uoa(a,b,c){var d=0;d=fb-32|0;fb=d;p[d+16>>2]=b;p[d+24>>2]=a;p[d+8>>2]=c;a:{if(!Ab(d+24|0,d+16|0)){break a}while(1){if(poa(d+8|0,p[p[d+24>>2]>>2])){break a}Rd(d+24|0);if(Ab(d+24|0,d+16|0)){continue}break}}fb=d+32|0;return p[d+24>>2]}function pd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{c=r[a+20>>1];if(c){d=r[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=r[e+28>>1]+b|0;o[e+28>>1]=f;if((f&65535)>>>0>=2048){break a}c=c+1|0;if((g|0)!=(c|0)){continue}break}}return}o[a+20>>1]=c-d}function my(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(357913941<b>>>0){tc(17324);E()}f=gc(v(d,12),4)}p[a>>2]=f;c=v(c,12)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,12)+f|0,p[g>>2]=h;fb=e+16|0;return a}function cL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!c){break a}p[b+40>>2]=c;if(p[a+480180>>2]!=256){break a}p[d+12>>2]=c>>>4;p[d+8>>2]=1;e=b,f=p[Uc(d+12|0,d+8|0)>>2],p[e+40>>2]=f;e=b,f=SK(c&255),p[e+44>>2]=f}fb=d+16|0}function c9(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(178956970<b>>>0){tc(39412);E()}f=gc(v(d,24),8)}p[a>>2]=f;c=v(c,24)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,24)+f|0,p[g>>2]=h;fb=e+16|0;return a}function SFa(a,b,c){var d=0;d=fb-32|0;fb=d;p[d+28>>2]=c;n[d+27|0]=0;p[d+20>>2]=1;c=Ik(a,d+27|0,p[Cb(d+28|0,d+20|0)>>2])>>>0>=0;a=ib;if((a|0)>0?1:(a|0)>=0?c:0){p[d+16>>2]=1;p[Cb(d+28|0,d+16|0)>>2]}n[d+8|0]=q[d+27|0];n[b|0]=q[d+8|0];fb=d+32|0}function Eza(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(76695844<b>>>0){tc(16860);E()}f=gc(v(d,56),4)}p[a>>2]=f;c=v(c,56)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,56)+f|0,p[g>>2]=h;fb=e+16|0;return a}function BLa(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+16|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;fb=b+16|0}function qR(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(89478485<b>>>0){tc(12706);E()}f=gc(v(d,48),4)}p[a>>2]=f;c=v(c,48)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,48)+f|0,p[g>>2]=h;fb=e+16|0;return a}function jE(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(357913941<b>>>0){tc(6863);E()}f=gc(v(d,12),4)}p[a>>2]=f;c=v(c,12)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,12)+f|0,p[g>>2]=h;fb=e+16|0;return a}function hF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;if(4294967279>=d>>>0){a:{if(d>>>0<=10){cf(a,c);d=a;break a}f=Ok(d)+1|0;d=Si(f);sf(a,d);sg(a,f);oe(a,c)}uh(d,b,c);n[e+15|0]=0;ae(c+d|0,e+15|0);fb=e+16|0;return}tg();E()}function Ro(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(u[p[a+4>>2]+ -8>>3]-u[p[a>>2]>>3]);while(1){d=-Id(u[Fk(a,c)>>3]*131072*f);a:{if(x(d)<2147483648){e=~~d;break a}e=-2147483648}g=nf(b,c),h=e,p[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function zna(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){tc(20524);E()}f=gc(d<<2,4)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function uxa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){tc(17929);E()}f=gc(d<<2,1)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function tMa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(2147483647<b>>>0){tc(12065);E()}f=gc(d<<1,1)}p[a>>2]=f;c=(c<<1)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<1)+f|0,p[g>>2]=h;fb=e+16|0;return a}function gGa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){tc(14480);E()}f=gc(d<<2,1)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function Xia(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){tc(32491);E()}f=gc(d<<2,4)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function NDa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){tc(15083);E()}f=gc(d<<2,1)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function Kma(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){tc(30733);E()}f=gc(d<<2,4)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function GV(a){var b=0,c=0,d=0;b=fb-48|0;fb=b;c=FV(b+24|0,gc(16,4),Lc(b+16|0,b+40|0,1));d=p[c>>2];p[114610]=0;M(279,d|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){Jn(a,Xb(p[c>>2]),Cd(c));kB(c);fb=b+48|0;return}a=I()|0;H()|0;kB(c);L(a|0);E()}function DDa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(2147483647<b>>>0){tc(15083);E()}f=gc(d<<1,1)}p[a>>2]=f;c=(c<<1)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<1)+f|0,p[g>>2]=h;fb=e+16|0;return a}function uU(a,b){var c=0,d=0,e=0;p[a>>2]=0;p[a+4>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;if(p[b+16>>2]){QA(a,b);e=p[b+8>>2];b=p[b+12>>2];c=b;d=b>>31;b=b>>31;c=c+d|0;c=b+e>>>0<b>>>0?c+1|0:c;b=c^d;p[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}return a}function rma(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;a:{if(_f(a)>>>0<b>>>0){d=qb(a);b=iL(c+8|0,b,nc(a),d);p[114610]=0;K(1256,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}gs(b)}fb=c+32|0;return}a=I()|0;H()|0;gs(b);L(a|0);E()}function kha(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;a:{if(rd(a)>>>0<b>>>0){d=qb(a);b=AH(c+8|0,b,Bb(a),d);p[114610]=0;K(1759,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yr(b)}fb=c+32|0;return}a=I()|0;H()|0;yr(b);L(a|0);E()}function jca(a){var b=0,c=0;b=fb-48|0;fb=b;Gk(b+16|0);a:{if(p[b+28>>2]){c=p[b+28>>2];p[114610]=0;p[b+12>>2]=c;K(2118,a|0,b+12|0);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=I()|0;H()|0;Se(b+16|0);L(a|0);E()}Lb(a)}Se(b+16|0);fb=b+48|0}function fU(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(2147483647<b>>>0){tc(11736);E()}f=gc(d<<1,2)}p[a>>2]=f;c=(c<<1)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<1)+f|0,p[g>>2]=h;fb=e+16|0;return a}function fBa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(536870911<b>>>0){tc(16470);E()}f=gc(d<<3,1)}p[a>>2]=f;c=(c<<3)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<3)+f|0,p[g>>2]=h;fb=e+16|0;return a}function UR(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(2147483647<b>>>0){tc(12489);E()}f=gc(d<<1,1)}p[a>>2]=f;c=(c<<1)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<1)+f|0,p[g>>2]=h;fb=e+16|0;return a}function UA(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){tc(11561);E()}f=gc(d<<2,4)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function Oya(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;a:{if(_f(a)>>>0<b>>>0){d=qb(a);b=my(c+8|0,b,nc(a),d);p[114610]=0;K(1017,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}ys(b)}fb=c+32|0;return}a=I()|0;H()|0;ys(b);L(a|0);E()}function AH(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(1073741823<b>>>0){tc(33157);E()}f=gc(d<<2,4)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function jEa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;a:{if(If(a)>>>0<b>>>0){d=qb(a);b=Ft(c+8|0,b,fc(a),d);p[114610]=0;K(380,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}vk(b)}fb=c+32|0;return}a=I()|0;H()|0;vk(b);L(a|0);E()}function HZ(a){var b=0,c=0,d=0;b=p[a>>2];p[114610]=0;c=Y(2445)|0;d=p[114610];p[114610]=0;a:{if((d|0)==1){break a}if((b|0)!=(c|0)){a=p[a>>2];p[114610]=0;ev(a);a=p[114610];p[114610]=0;if((a|0)==1){break a}}return}a=O(0)|0;H()|0;rb(a);E()}function dva(a,b,c,d){var e=0,f=0,g=0,h=0;a:{if((d|0)==65536){break a}c=v(b,c);if(!c){break a}b=d;f=d>>31;d=0;while(1){e=p[a>>2];g=a,h=rc(ONa(NNa(e,e>>31,b,f),ib,65536,0),ib),p[g>>2]=h;a=a+4|0;d=d+1|0;if((c|0)!=(d|0)){continue}break}}}function dX(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){d=b;if(268435455<b>>>0){tc(6967);E()}f=gc(d<<4,4)}p[a>>2]=f;c=(c<<4)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<4)+f|0,p[g>>2]=h;fb=e+16|0;return a}function ada(a){a=a|0;if(s[a+44>>2]<s[a+24>>2]){p[a+44>>2]=p[a+24>>2]}a:{if(!(q[a+48|0]&8)){break a}if(s[a+16>>2]<s[a+44>>2]){Bm(a,p[a+8>>2],p[a+12>>2],p[a+44>>2])}if(s[a+12>>2]>=s[a+16>>2]){break a}return og(n[p[a+12>>2]])|0}return-1}function Yf(a,b,c){c=p[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=q[a|0];switch(c+ -43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(q[a+1|0]|32)!=120){break a}a=a+2|0}return a}function TFa(a,b){var c=0,d=0,e=0;c=xi(a+8|0);p[114610]=0;d=M(548,b|0)|0;e=p[114610];p[114610]=0;a:{if((e|0)==1){break a}p[114610]=0;N(421,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}return}a=I()|0;H()|0;Gg(c);L(a|0);E()}function SU(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;a:{if(rd(a)>>>0<b>>>0){d=qb(a);b=UA(c+8|0,b,Bb(a),d);p[114610]=0;K(343,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Yp(b)}fb=c+32|0;return}a=I()|0;H()|0;Yp(b);L(a|0);E()}function O5(a,b,c){var d=0,e=0,f=0;if(!c){return 0}d=q[a|0];a:{if(!d){break a}while(1){b:{e=q[b|0];if((e|0)!=(d|0)){break b}c=c+ -1|0;if(!c|!e){break b}b=b+1|0;d=q[a+1|0];a=a+1|0;if(d){continue}break a}break}f=d}return(f&255)-q[b|0]|0}function GL(a,b){var c=0,d=0;c=Asa(a);a:{if(!b){break a}p[114610]=0;K(1224,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(1225,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;AL(c);L(a|0);E()}return a}function rua(a,b){var c=0,d=0;c=fA(a);a:{if(!b){break a}p[114610]=0;K(921,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(1174,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;Bt(c);L(a|0);E()}return a}function pJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=p[a>>2];e=p[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=rc(ONa(NNa(d,d>>31,g,h),ib,256,0),ib);p[a+4>>2]=f-d;p[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function _ka(a,b){var c=0,d=0;c=kz(a);a:{if(!b){break a}p[114610]=0;K(683,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(1568,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;at(c);L(a|0);E()}return a}function _0(a,b,c,d,e,f){var g=0;g=fb-144|0;fb=g;p[g+28>>2]=g+132;kD(a,g+32|0,g+28|0,d,e,f);p[g+16>>2]=0;p[g+20>>2]=0;p[g+12>>2]=g+32;a=Z0(b,g+12|0,mP(b,p[c>>2]),g+16|0,p[a>>2]);if((a|0)==-1){am(62916);E()}p[c>>2]=(a<<2)+b;fb=g+144|0}function IAa(a,b){var c=0,d=0;c=EAa(a);a:{if(!b){break a}p[114610]=0;K(946,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(947,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;bO(c);L(a|0);E()}return a}function yJ(a,b){var c=0,d=0;a:{if(!(q[a+89|0]&16)){break a}c=p[a+656>>2];if(!c){break a}c=p[c>>2];if(c){d=a;a=p[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;p[d+696>>2]=a;p[b>>2]=(v(a,p[b>>2])|0)/65536;return}if(p[a+696>>2]){break a}p[b>>2]=0}}function mfa(a){var b=0;p[a>>2]=8;p[a+4>>2]=0;o[a+4128>>1]=0;b=a+4120|0;p[b>>2]=0;p[b+4>>2]=0;b=a+4112|0;p[b>>2]=0;p[b+4>>2]=0;p[a+4104>>2]=0;p[a+4108>>2]=0;Jb(a+4132|0,0,40);LM(a+8|0,1024);Jb(a+4172|0,0,49824);Jb(a+53996|0,0,32832)}function Wga(a){a=a|0;var b=0;m[p[p[a>>2]+124>>2]](a);vw(a);p[a+4236>>2]=0;n[a+4202|0]=1;b=m[p[p[a>>2]+188>>2]](a)|0;p[a+4272>>2]=0;t[a+4240>>2]=b?w(.5):w(1);b=p[a+4256>>2];p[a+4292>>2]=b;p[a+4288>>2]=b;p[a+4284>>2]=b;p[a+4280>>2]=b}function NHa(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;a:{if(b){Mb(c,b);break a}Lb(c)}p[114610]=0;K(669,c+16|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){Wc(a,c+16|0);pb(c+16|0);pb(c);fb=c+32|0;return a|0}a=I()|0;H()|0;pb(c);L(a|0);E()}function pW(a,b){var c=0,d=0;c=jW(a);a:{if(!b){break a}p[114610]=0;K(262,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(263,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;yB(c);L(a|0);E()}return a}function jna(a,b,c){var d=0;d=fb-16|0;fb=d;a:{b:{if(!b){b=a;a=Ib(c);di(b,a,wb(c)+a|0);break b}XJ(d,c);p[114610]=0;N(115,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yc(d)}fb=d+16|0;return}a=I()|0;H()|0;yc(d);L(a|0);E()}function XK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=fb-16|0;fb=a;d=p[b+104>>2];if(d){p[b+88>>2]=p[b+88>>2]&-131|128;d=p[d>>2];p[b+76>>2]=d;p[a+12>>2]=c<<8;p[a+8>>2]=d+ -1;c=d+(p[Cb(a+12|0,a+8|0)>>2]^-1)|0;p[b>>2]=0;p[b+4>>2]=c}fb=a+16|0}function H8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=w(0);e=fb-16|0;fb=e;f=p[a+4>>2];VF(a,b,c,d);g=t[a+28>>2];b=p[a+24>>2];p[e+8>>2]=p[a+20>>2];p[e+12>>2]=b;b=p[a+16>>2];p[e>>2]=p[a+12>>2];p[e+4>>2]=b;rca(e,f,c,d,g);fb=e+16|0}function qga(a,b,c){a=a|0;b=b|0;c=w(c);var d=0,f=0;d=fb-16|0;fb=d;t[d+12>>2]=c;if((b|0)<=4){Td(d+12|0,w(0));f=((b<<2)+a|0)+4220|0;if((b|0)!=4){b=p[d+12>>2]}else{c=$d(t[d+12>>2]);t[d+12>>2]=c;b=(i(c),e(2))}p[f>>2]=b;nH(a)}fb=d+16|0}function Xfa(a,b,c){a=a|0;b=b|0;c=w(c);var d=0,f=0;d=fb-16|0;fb=d;t[d+12>>2]=c;if((b|0)<=1){Td(d+12|0,w(0));f=((b<<2)+a|0)+4208|0;if((b|0)!=1){b=p[d+12>>2]}else{c=$d(t[d+12>>2]);t[d+12>>2]=c;b=(i(c),e(2))}p[f>>2]=b;lH(a)}fb=d+16|0}function So(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;c=Hsa(Ub(a),Vb(a));d=b,e=Ub(a),p[d+8>>2]=e;d=b,e=Vb(a),p[d>>2]=e;if(Ab(b+8|0,b)){c=-c;while(1){a=p[b+8>>2];c=u[a>>3]+c;u[a>>3]=c;Sx(b+8|0);if(Ab(b+8|0,b)){continue}break}}fb=b+16|0}function O3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!q[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((m[p[p[a>>2]+52>>2]](a,p[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=Ii(b,4,c,p[a+32>>2])}return c|0}function xf(a,b){var c=0,d=0,e=0,f=0;c=r[a+24>>1]<<17;e=r[a+20>>1];if(e){d=r[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-v(p[nf(b,r[c+28>>1])>>2],o[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function xV(a,b,c,d){var e=0;a:{if((a|0)==(b|0)){break a}while(1){e=c;if((e|0)!=(d|0)){while(1){if(m[26](n[a|0],n[e|0])|0){break a}e=e+1|0;if((e|0)!=(d|0)){continue}break}}a=a+1|0;if((b|0)!=(a|0)){continue}break}return b}return a}function mMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=-1;a:{if(!af(a,7)){break a}c=0;if(!HS(a,12168)){break a}c=d;e=ELa(a,d);if(!e){tS(c)}c=-1;if(!e){break a}c=0;if(!GS(d)){break a}c=Ve(a,b,FS(d),ib)}fb=d+16|0;return c|0}function Rg(a,b,c){var d=0,e=0,f=0,g=0;p[a+112>>2]=b;p[a+116>>2]=c;f=p[a+8>>2];g=p[a+4>>2];d=f-g|0;e=d>>31;p[a+120>>2]=d;p[a+124>>2]=e;if(!(!(b|c)|((e|0)<(c|0)?1:(e|0)<=(c|0)?d>>>0<=b>>>0:0))){p[a+104>>2]=b+g;return}p[a+104>>2]=f}function IB(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Mb(b,10940);a:{if(!wb(a)){break a}c=1;if((Nf(a,10946)|0)!=-1){break a}if((Nf(a,10948)|0)!=-1){break a}if((Nf(a,10952)|0)!=-1){break a}c=(Nf(a,10954)|0)!=-1}pb(a);fb=b+16|0;return c|0}function Ena(a,b,c){var d=0;d=fb-16|0;fb=d;a:{b:{if(!b){b=a;a=Ib(c);di(b,a,wb(c)+a|0);break b}sK(d,b,c);p[114610]=0;K(116,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}yc(d)}fb=d+16|0;return}a=I()|0;H()|0;yc(d);L(a|0);E()}function z1(a,b,c,d,e,f){a=m[p[p[a+8>>2]+8>>2]](a+8|0)|0;if((wb(a)|0)==(0-wb(a+12|0)|0)){p[e>>2]=p[e>>2]|4;return}a=Eq(c,d,a,a+24|0,f,e,0)-a|0;c=p[b>>2];if(!(a|(c|0)!=12)){p[b>>2]=0;return}if(!((a|0)!=12|(c|0)>11)){p[b>>2]=c+12}}function mJa(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;fb=b+16|0}function g1(a,b,c,d,e,f){a=m[p[p[a+8>>2]+8>>2]](a+8|0)|0;if((wb(a)|0)==(0-wb(a+12|0)|0)){p[e>>2]=p[e>>2]|4;return}a=Cq(c,d,a,a+24|0,f,e,0)-a|0;c=p[b>>2];if(!(a|(c|0)!=12)){p[b>>2]=0;return}if(!((a|0)!=12|(c|0)>11)){p[b>>2]=c+12}}function zMa(a,b,c){var d=0;d=xi(a+8|0);p[114610]=0;N(421,a|0,b|0,c|0);c=p[114610];p[114610]=0;a:{if((c|0)!=1){a=p[a>>2];p[114610]=0;J(338,b|0,a|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;Gg(d);L(a|0);E()}}function t5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=a;b=p[a+112>>2];if((b|0)>=11){f=a;d=378;while(1){FE(f);b=c+ -1|0;c=d+ -1|0;if((c|0)!=-1){b=b+1|0}d=c;c=b;if(d|b){continue}break}p[a+112>>2]=0;b=0}p[e+112>>2]=b+1;a=FE(a);return a|0}function kta(a,b,c){var d=0,e=0;b=$j(a,b);a:{if((b|0)==255){break a}if(aj(a)){break a}d=q[Yb(ti(a+314|0,b),10)|0];e=p[a>>2];a=d&-49;a=(c|0)<171?a|16:a;a=((c|0)>84?a|32:a)&255;Yg(e,ms(b)|192,a);d=(a>>>5&1)+(a<<27>>31)|0}return d}function GN(a,b){var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=p[a+4>>2];e=p[a>>2];p[c+24>>2]=e;p[c+28>>2]=d;f=p[b+4>>2];a=p[b>>2];p[c+16>>2]=a;p[c+20>>2]=f;p[c+8>>2]=e;p[c+12>>2]=d;p[c>>2]=a;p[c+4>>2]=f;a=iO(c+8|0,c);fb=c+32|0;return a}function DIa(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+7|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;fb=b+16|0}function jaa(a,b){a=a|0;b=b|0;var c=w(0);a:{if((b|0)<0){break a}a=a+24|0;if(r[p[a>>2]+480188>>1]<=(b|0)){break a}b=v(b,896);if(!(n[(b+p[a>>2]|0)+1075073|0]&1)){break a}c=w(w(q[(b+p[a>>2]|0)+1075846|0])*w(.0078125))}return w(c)}function iaa(a,b){a=a|0;b=b|0;var c=w(0);a:{if((b|0)<0){break a}a=a+24|0;if(r[p[a>>2]+480188>>1]<=(b|0)){break a}b=v(b,896);if(!(n[(b+p[a>>2]|0)+1075073|0]&1)){break a}c=w(w(q[(b+p[a>>2]|0)+1075847|0])*w(.0078125))}return w(c)}function dqa(a,b){var c=0;c=fb-2496|0;fb=c;YK(b,c,c+2496|0);b=ac(a,c,2496);p[b+2496>>2]=0;a:{if(p[b>>2]<=-1){break a}a=1;while(1){if(p[b+(a<<2)>>2]){break a}a=a+1|0;if((a|0)!=624){continue}break}p[b>>2]=-2147483648}fb=c+2496|0}function bua(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Gn(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1180,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+32;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Xpa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Gn(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1371,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+32;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Sba(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Wl(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(2127,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+16;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Kra(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Sk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1255,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+12;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Iba(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=qk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(2132,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+24;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Cya(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Sk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1022,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+12;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Ala(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=qk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1561,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+24;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function uJa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=qk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(574,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+24;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function sJ(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;p[b+12>>2]=7;p[b+8>>2]=32;if(p[Cb(b+12|0,b+8|0)>>2]){while(1){d=Ho(a);p[b+12>>2]=7;p[b+8>>2]=32;c=c+15|0;if(c>>>0<s[Cb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}fb=b+16|0;return c}function ooa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=he(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1421,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+4;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function oB(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;n[a+12|0]=0;n[a+13|0]=0;fb=b+16|0}function lR(a){if(!((q[a+8|0]|q[a+9|0]<<8|(q[a+10|0]<<16|q[a+11|0]<<24))==1179472708?(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))==1179011410:0)){return(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))==1179472708}return 1}function eha(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=he(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1762,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+4;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Zia(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=he(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1635,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+4;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function WJa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=sR(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(560,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+48;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Vma(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=he(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1518,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+4;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function TJa(a,b){var c=0,d=0;c=LJa(a);a:{if(!b){break a}p[114610]=0;K(562,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)!=1){p[114610]=0;K(563,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){break a}}a=I()|0;H()|0;wR(c);L(a|0);E()}}function Rr(a,b){var c=0;c=79388;a:{b:{c:{switch(b+ -2|0){default:if((b|0)==16777216){break a}if((b|0)!=32){break b}c=79404;break a;case 2:c=79400;break a;case 1:break b;case 0:break c}}c=79396;break a}c=79392}p[a>>2]=p[c>>2]}function Mza(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=qk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(988,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+24;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function MEa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=qk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(772,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+24;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function LIa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=qk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(608,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+24;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function IKa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=qk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(529,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+24;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Exa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=he(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1058,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+4;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function EGa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Sk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(730,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+12;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Dja(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=he(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(1604,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+4;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Bs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;if(b){e=Bc(a);d=wb(a);g=d+b|0;if(e-d>>>0<b>>>0){El(a,e,g-e|0,d,d,0,0)}e=d;d=Ib(a);ty(e+d|0,b,c);Jg(a,g);n[f+15|0]=0;ae(d+g|0,f+15|0)}fb=f+16|0;return a|0}function BIa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Wl(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(611,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+16;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function gsa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=he(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(411,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+4;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function _4(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Sk(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(204,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+12;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function RKa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Gh(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(521,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+2;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function MLa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Gh(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(381,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+2;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function LU(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Gn(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(347,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+32;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function INa(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=v(e,f);g=c&65535;h=a&65535;i=v(g,h);f=(i>>>16|0)+v(f,g)|0;e=(f&65535)+v(e,h)|0;a=(v(b,c)+j|0)+v(a,d)+(f>>>16)+(e>>>16)|0;b=i&65535|e<<16;ib=a;return b}function E9(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;b=ic(c+24|0,p[b>>2]);d=p[a>>2];a=p[d+4>>2];d=p[d>>2];p[c+16>>2]=d;p[c+20>>2]=a;e=p[b+4>>2];p[c+8>>2]=p[b>>2];p[c+12>>2]=e;p[c>>2]=d;p[c+4>>2]=a;a=xc(c+8|0,c);fb=c+32|0;return a}function tba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=d+8|0;p[e>>2]=83824;p[e>>2]=83780;p[114610]=0;a=U(2155,a|0,b|0,c|0,e|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a|0}a=I()|0;H()|0;L(a|0);E()}function t$(){var a=0;a:{b:{if(n[461792]&1){break b}if(!nd(461792)){break b}p[114610]=0;Y(2565)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}p[115447]=461784;md(461792)}return p[115447]}a=I()|0;H()|0;ge(461792);L(a|0);E()}function laa(a,b){a=a|0;b=b|0;var c=w(0);a:{if((b|0)<0){break a}a=a+24|0;if(r[p[a>>2]+480188>>1]<=(b|0)){break a}b=v(b,896);if(n[(b+p[a>>2]|0)+1075073|0]&1){break a}c=w(w(q[(b+p[a>>2]|0)+1075846|0])*w(.0078125))}return w(c)}function kaa(a,b){a=a|0;b=b|0;var c=w(0);a:{if((b|0)<0){break a}a=a+24|0;if(r[p[a>>2]+480188>>1]<=(b|0)){break a}b=v(b,896);if(n[(b+p[a>>2]|0)+1075073|0]&1){break a}c=w(w(q[(b+p[a>>2]|0)+1075847|0])*w(.0078125))}return w(c)}function hva(a,b,c){var d=0,e=0,f=0;c=c+ -1|0;if((c|0)>-1){while(1){d=c<<4;e=c<<3;f=e|4;p[(d|12)+a>>2]=p[f+b>>2];p[(d|8)+a>>2]=p[b+e>>2];p[(d|4)+a>>2]=p[a+f>>2];p[a+d>>2]=p[a+e>>2];d=(c|0)>0;c=c+ -1|0;if(d){continue}break}}}function ewa(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=he(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(95,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+4;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function Zxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=ke(b);c=bN(d+8|0,c);p[114610]=0;_(1031,a|0,b|0,0,e+ -1&65535,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){ce(c);fb=d+32|0;return}a=I()|0;H()|0;ce(c);L(a|0);E()}function P0(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=Cl(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(210,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+1;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function NU(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=he(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(346,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+4;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function LP(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;c=he(d,a,1);a=qb(a);e=p[c+4>>2];p[114610]=0;N(770,a|0,e|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[c+4>>2]=p[c+4>>2]+4;Db(c);fb=d+16|0;return}a=I()|0;H()|0;Db(c);L(a|0);E()}function IC(){var a=0;a:{b:{if(n[461780]&1){break b}if(!nd(461780)){break b}p[114610]=0;Y(2561)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}p[115444]=461772;md(461780)}return p[115444]}a=I()|0;H()|0;ge(461780);L(a|0);E()}function A3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d+8>>2]=c;e=-1;c=Fq(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=fd(c);p[f>>2]=a;if(!a){break a}e=Fq(a,c,b,p[d+12>>2])}fb=d+16|0;return e|0}function usa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;ssa(a);d=a;e=bn(a+12|0);n[a+30|0]=c;o[a+28>>1]=0;p[a+24>>2]=b;p[114610]=0;K(1233,a|0,1);b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;be(e);zL(d);L(a|0);E()}function mNa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -2|0;p[a+8>>2]=d;p[114610]=0;K(382,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}



function lD(a,b){var c=0,d=0;c=fb-32|0;fb=c;a:{if(Hf(a)>>>0<b>>>0){d=qb(a);b=Vu(c+8|0,b,Cc(a),d);p[114610]=0;K(209,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}$l(b)}fb=c+32|0;return}a=I()|0;H()|0;$l(b);L(a|0);E()}function kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a:{if(Bb(a)){while(1){Uf(c,p[Fb(a,d)>>2]+40|0);e=op(c,b);pb(c);if(e){a=p[Fb(a,d)>>2];break a}d=d+1|0;if(d>>>0<Bb(a)>>>0){continue}break}}a=0}fb=c+16|0;return a|0}function hia(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -2048|0;p[a+8>>2]=d;p[114610]=0;K(1651,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function br(a){var b=0;a:{b=q[a+1376|0];b:{if(!b){b=-1;if(p[a+1384>>2]){break b}if(!Jv(a)){break b}b=q[a+1376|0];if(!b){break a}}n[a+1376|0]=b+ -1;p[a+1400>>2]=p[a+1400>>2]+1;b=re(a)}return b}aa(50498,50416,1563,50518);E()}function Xna(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;p[a+480180>>2]=b;WJ(c,Bo(a));d=p[c+12>>2];b=a+1074316|0;p[b>>2]=p[c+8>>2];p[b+4>>2]=d;b=p[c+4>>2];p[a+1074308>>2]=p[c>>2];p[a+1074312>>2]=b;Rr(a+8|0,Bo(a));fb=c+16|0}function UY(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;if(1073741807>=b>>>0){a:{if(b>>>0<=1){cf(a,b);e=a;break a}f=Zl(b)+1|0;e=Lk(f);sf(a,e);sg(a,f);oe(a,b)}YY(e,b,c);p[d+12>>2]=0;Je((b<<2)+e|0,d+12|0);fb=d+16|0;return}tg();E()}function Sna(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(r[p[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!p[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if((b&65535)>>>0<=r[p[a+8>>2]+58>>1]){continue}break}}return c&65535}function Fg(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;n[a+8|0]=0;p[a>>2]=0;p[a+4>>2]=4194432;c=Mb(b,11931);p[114610]=0;J(378,a+9|0,c|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=b+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function $Y(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;if(1073741807>=c>>>0){a:{if(c>>>0<=1){cf(a,c);e=a;break a}f=Zl(c)+1|0;e=Lk(f);sf(a,e);sg(a,f);oe(a,c)}Rh(e,b,c);p[d+12>>2]=0;Je((c<<2)+e|0,d+12|0);fb=d+16|0;return}tg();E()}function yL(a,b){var c=0,d=0;c=fb-32|0;fb=c;a:{if(rd(a)>>>0<b>>>0){d=qb(a);b=hs(c+8|0,b,Bb(a),d);p[114610]=0;K(96,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Wj(b)}fb=c+32|0;return}a=I()|0;H()|0;Wj(b);L(a|0);E()}function x8(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=w(0);if(e){while(1){f=0;if(d){while(1){h=u[Tg(b,f,g)>>3];Yb(c,f);i=$m(a,f,g),j=w(h),t[i>>2]=j;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function koa(a){var b=0,c=0;c=a+946300|0;b=a+906300|0;while(1){a=p[b>>2];a:{if(!a){break a}if(m[p[p[a>>2]+112>>2]](a)|0){break a}m[p[p[a>>2]+104>>2]](a,1);m[p[p[a>>2]+116>>2]](a)}b=b+160|0;if((c|0)!=(b|0)){continue}break}}function Zma(a,b,c){var d=0;d=fb-32|0;fb=d;p[d+16>>2]=b;p[d+24>>2]=a;p[d+8>>2]=c;if(Ab(d+24|0,d+16|0)){while(1){a=m[117](n[p[d+24>>2]])|0;n[p[d+8>>2]]=a;bg(d+24|0);bg(d+8|0);if(Ab(d+24|0,d+16|0)){continue}break}}fb=d+32|0}function Yja(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=vja(a,b,Be(a),_b(a)),p[d+8>>2]=e;d=c,e=hj(a),p[d>>2]=e;a:{b:{if(!Ab(c+8|0,c)){break b}if(Hr(qb(a),b,$g(c+8|0))){break b}a=p[c+8>>2];break a}a=hj(a)}fb=c+16|0;return a}function U7(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=w(0);if(e){while(1){f=0;if(d){while(1){h=u[Tg(b,f,g)>>3];Yb(c,f);i=Bf(a,f,g),j=w(h),t[i>>2]=j;f=f+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((g|0)!=(e|0)){continue}break}}}function SJa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=0;a:{if(!a){break a}e=a|-16;if(!(a>>>0<16&c?0:b>>>0>=2)){break a}n[d+15|0]=1;n[d+14|0]=(a|0)/(b+ -1|0);e=q[dh(d+15|0,d+14|0)|0]}a=e;fb=d+16|0;return a&255}function GGa(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=uGa(a,b,Be(a),_b(a)),p[d+8>>2]=e;d=c,e=hj(a),p[d>>2]=e;a:{b:{if(!Ab(c+8|0,c)){break b}if(jn(qb(a),b,$g(c+8|0))){break b}a=p[c+8>>2];break a}a=hj(a)}fb=c+16|0;return a}function F0(a,b,c){var d=0;d=fb-32|0;fb=d;p[d+16>>2]=b;p[d+24>>2]=a;p[d+8>>2]=c;while(1){a:{a=Ab(d+24|0,d+16|0);if(!a){break a}if(!ll(p[d+24>>2],p[d+8>>2])){break a}Rd(d+24|0);Rd(d+8|0);continue}break}fb=d+32|0;return a^1}function Aca(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=yca(a,b,Be(a),_b(a)),p[d+8>>2]=e;d=c,e=hj(a),p[d>>2]=e;a:{b:{if(!Ab(c+8|0,c)){break b}if(is(qb(a),b,$g(c+8|0))){break b}a=p[c+8>>2];break a}a=hj(a)}fb=c+16|0;return a}function $Ga(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=2;e=p[a>>2];if((e|0)!=1){p[c+12>>2]=e>>>1;p[c+8>>2]=-1-p[a>>2];d=Cb(c+12|0,c+8|0);p[c+12>>2]=p[a>>2]+p[d>>2];p[c+8>>2]=p[b>>2];d=p[Cb(c+12|0,c+8|0)>>2]}fb=c+16|0;return d}function xla(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -24|0;p[a+8>>2]=d;p[114610]=0;K(1560,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function o_(a){a=a|0;a:{b:{if(n[461868]&1){break b}if(!nd(461868)){break b}p[114610]=0;R(2580);a=p[114610];p[114610]=0;if((a|0)==1){break a}p[115466]=462048;md(461868)}return p[115466]}a=I()|0;H()|0;ge(461868);L(a|0);E()}function lka(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -52|0;p[a+8>>2]=d;p[114610]=0;K(1438,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function l_(a){a=a|0;a:{b:{if(n[461876]&1){break b}if(!nd(461876)){break b}p[114610]=0;R(2582);a=p[114610];p[114610]=0;if((a|0)==1){break a}p[115468]=462224;md(461876)}return p[115468]}a=I()|0;H()|0;ge(461876);L(a|0);E()}function jya(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -12|0;p[a+8>>2]=d;p[114610]=0;K(1023,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function i_(a){a=a|0;a:{b:{if(n[461884]&1){break b}if(!nd(461884)){break b}p[114610]=0;R(2584);a=p[114610];p[114610]=0;if((a|0)==1){break a}p[115470]=462400;md(461884)}return p[115470]}a=I()|0;H()|0;ge(461884);L(a|0);E()}function hya(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -12|0;p[a+8>>2]=d;p[114610]=0;K(1024,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function f_(a){a=a|0;a:{b:{if(n[461892]&1){break b}if(!nd(461892)){break b}p[114610]=0;R(2586);a=p[114610];p[114610]=0;if((a|0)==1){break a}p[115472]=462704;md(461892)}return p[115472]}a=I()|0;H()|0;ge(461892);L(a|0);E()}function c_(a){a=a|0;a:{b:{if(n[461900]&1){break b}if(!nd(461900)){break b}p[114610]=0;R(2588);a=p[114610];p[114610]=0;if((a|0)==1){break a}p[115474]=463008;md(461900)}return p[115474]}a=I()|0;H()|0;ge(461900);L(a|0);E()}function Xra(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -12|0;p[a+8>>2]=d;p[114610]=0;K(1237,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function Psa(a){var b=0,c=0;c=Gsa(a);p[114610]=0;K(1221,a|0,2048);b=p[114610];p[114610]=0;a:{if((b|0)!=1){p[114610]=0;K(1223,a|0,2048);b=p[114610];p[114610]=0;if((b|0)!=1){break a}}a=I()|0;H()|0;Rx(c);L(a|0);E()}return a}function Dta(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -32|0;p[a+8>>2]=d;p[114610]=0;K(1195,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function Bpa(a,b){var c=0,d=0;a:{if(256<=b>>>0){break a}c=p[(v(b,896)+a|0)+1075640>>2];if(!c){break a}if(q[c+31|0]==17){a=r[(v(b,896)+a|0)+1075792>>1];return(a?a+ -1|0:b)&15}if(!gi(c)){break a}d=q[c+31|0]+ -1&15}return d}function $Z(a){a=a|0;a:{b:{if(n[461908]&1){break b}if(!nd(461908)){break b}p[114610]=0;R(2590);a=p[114610];p[114610]=0;if((a|0)==1){break a}p[115476]=463040;md(461908)}return p[115476]}a=I()|0;H()|0;ge(461908);L(a|0);E()}function yx(a,b){var c=0,d=0;c=v(b,896)+a|0;a:{if(p[c+1075072>>2]&134218752){break a}if(!Zi(c+1074984|0)){break a}b=q[p[(v(b,896)+a|0)+1075640>>2]+34|0];if((b+5&255)>>>0<6){break a}d=p[(v(b,160)+a|0)+906140>>2]}return d}function yna(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(1440,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function wIa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -16|0;p[a+8>>2]=d;p[114610]=0;K(426,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function vza(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -56|0;p[a+8>>2]=d;p[114610]=0;K(990,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function vJa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -48|0;p[a+8>>2]=d;p[114610]=0;K(573,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function uN(a,b,c){var d=0;d=fb-16|0;fb=d;n[d+15|0]=a;a=0;if(!(c>>>0>108|b>>>0>108|(c>>>0<25|b>>>0<25)|b>>>0>=c>>>0)){n[d+14|0]=(r[(b<<1)+20734>>1]-r[(c<<1)+20734>>1]|0)/5;a=q[hc(d+15|0,d+14|0)|0]}fb=d+16|0;return a&255}function txa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(1060,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function qJa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -24|0;p[a+8>>2]=d;p[114610]=0;K(572,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function pqa(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=(p[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(eo(b)+ -4.8737671609324025),u[d+8>>3]=e;wf(c+8|0,0,127);a=Ss(u[c+8>>3]);fb=c+16|0;return a|0}function jpa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -32|0;p[a+8>>2]=d;p[114610]=0;K(896,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function eia(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(1653,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function e9(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -16|0;p[a+8>>2]=d;p[114610]=0;K(2206,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function bha(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(1763,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function _M(a){var b=0,c=0,d=0;c=a- -64|0;d=q[c|0]|q[c+1|0]<<8;c=0;b=a+70|0;a=a+72|0;a=q[a|0]|q[a+1|0]<<8;b=(q[b|0]|q[b+1|0]<<8)+a|0;if(b>>>0<a>>>0){c=1}a=c<<2|b>>>30;b=b<<2;c=d+b|0;if(c>>>0<b>>>0){a=a+1|0}ib=a;return c}function Tia(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(1439,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function TEa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -33|0;p[a+8>>2]=d;p[114610]=0;K(769,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function REa(a){var b=0,c=0;c=fb-32|0;fb=c;a:{if(rd(a)>>>0<15){b=qb(a);b=An(c+8|0,15,Bb(a),b);p[114610]=0;K(368,a|0,b|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}Fh(b)}fb=c+32|0;return}a=I()|0;H()|0;Fh(b);L(a|0);E()}function Jza(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -24|0;p[a+8>>2]=d;p[114610]=0;K(986,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function Jma(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(1524,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function Jla(a,b){var c=0,d=0,e=0,f=0;c=a+1|0;d=a+2|0;e=a+3|0;f=a+4|0;VI(q[a|0]&15,q[c|0]&15,q[d|0]&15,q[e|0]&15,q[f|0]&15,a+5|0,b+48|0);VI(q[a|0]>>>4|0,q[c|0]>>>4|0,q[d|0]>>>4|0,q[e|0]>>>4|0,q[f|0]>>>4|0,a+35|0,b+68|0)}function HIa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -24|0;p[a+8>>2]=d;p[114610]=0;K(607,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function Era(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -12|0;p[a+8>>2]=d;p[114610]=0;K(348,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function EEa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -24|0;p[a+8>>2]=d;p[114610]=0;K(771,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function BKa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -24|0;p[a+8>>2]=d;p[114610]=0;K(528,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function $8(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -24|0;p[a+8>>2]=d;p[114610]=0;K(2207,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function yja(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(737,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function yV(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -32|0;p[a+8>>2]=d;p[114610]=0;K(276,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function y3(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -12|0;p[a+8>>2]=d;p[114610]=0;K(206,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function vAa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(950,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function tKa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -2|0;p[a+8>>2]=d;p[114610]=0;K(532,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function rMa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -2|0;p[a+8>>2]=d;p[114610]=0;K(422,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function qfa(a,b){var c=0,d=0;c=fb-32|0;fb=c;d=p[b+48>>2];a:{if(d&16){if(s[b+44>>2]<s[b+24>>2]){p[b+44>>2]=p[b+24>>2]}di(a,p[b+20>>2],p[b+44>>2]);break a}if(d&8){di(a,p[b+8>>2],p[b+16>>2]);break a}iw(a,c+8|0)}fb=c+32|0}function mW(a){var b=0,c=0,d=0;c=fb-16|0;fb=c;b=Gn(c,a,1);a=qb(a);d=p[b+4>>2];p[114610]=0;K(266,a|0,d|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[b+4>>2]=p[b+4>>2]+32;Db(b);fb=c+16|0;return}a=I()|0;H()|0;Db(b);L(a|0);E()}function eGa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(740,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function bBa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -8|0;p[a+8>>2]=d;p[114610]=0;K(924,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function Xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!Pc(c)){Fi(qI(a+52|0,b),c);break a}a=a+52|0;e=d,f=Hw(a,b),p[e+8>>2]=f;e=d,f=pi(a),p[e>>2]=f;if(!oi(d+8|0,d)){break a}Wja(a,p[d+8>>2])}fb=d+16|0}function UFa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -6|0;p[a+8>>2]=d;p[114610]=0;K(739,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function O_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;p[e+12>>2]=d;d=lh(e+8|0,e+12|0);p[114610]=0;a=ED(a,b,c);b=p[114610];p[114610]=0;if((b|0)!=1){ye(d);fb=e+16|0;return a|0}a=I()|0;H()|0;ye(d);L(a|0);E()}function KDa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(822,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function BDa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -2|0;p[a+8>>2]=d;p[114610]=0;K(829,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function Aqa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(107,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function Ad(a){var b=0,c=0,d=0;b=fb-32|0;fb=b;p[b+12>>2]=0;p[b+8>>2]=2558;c=p[b+12>>2];p[b>>2]=p[b+8>>2];p[b+4>>2]=c;d=p[b+4>>2];c=b+16|0;p[c+4>>2]=p[b>>2];p[c+8>>2]=d;p[c>>2]=a;r$(a,c);fb=b+32|0;return p[a+4>>2]+ -1|0}function $W(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -16|0;p[a+8>>2]=d;p[114610]=0;K(217,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function xaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=Sk(e,a,d);a=qb(a);p[114610]=0;Q(2182,a|0,b|0,c|0,d+4|0);a=p[114610];p[114610]=0;if((a|0)!=1){Db(d);fb=e+16|0;return}a=I()|0;H()|0;Db(d);L(a|0);E()}function xN(a){var b=0,c=0,d=0;c=a+32|0;d=q[c|0]|q[c+1|0]<<8;c=0;b=a+34|0;a=a+36|0;a=q[a|0]|q[a+1|0]<<8;b=(q[b|0]|q[b+1|0]<<8)+a|0;if(b>>>0<a>>>0){c=1}a=c<<1|b>>>31;b=b<<1;c=d+b|0;if(c>>>0<b>>>0){a=a+1|0}ib=a;return c}function nX(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -1|0;p[a+8>>2]=d;p[114610]=0;K(215,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function gU(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -1|0;p[a+8>>2]=d;p[114610]=0;K(361,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function eU(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -2|0;p[a+8>>2]=d;p[114610]=0;K(362,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function ap(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;if(4294967279>=c>>>0){a:{if(c>>>0<=10){cf(a,c);e=a;break a}f=Ok(c)+1|0;e=Si(f);sf(a,e);sg(a,f);oe(a,c)}uh(e,b,c);n[d+15|0]=0;ae(c+e|0,d+15|0);fb=d+16|0;return}tg();E()}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=Wl(e,a,d);a=qb(a);p[114610]=0;Q(2125,a|0,b|0,c|0,d+4|0);a=p[114610];p[114610]=0;if((a|0)!=1){Db(d);fb=e+16|0;return}a=I()|0;H()|0;Db(d);L(a|0);E()}function VLa(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -1|0;p[a+8>>2]=d;p[114610]=0;K(32,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function UL(a,b){a:{if(q[a+76|0]==(b|0)){break a}n[a+76|0]=b;if(b){b=0;if(r[a+24>>1]==15){o[a+20>>1]=0;b=1}p[a+8>>2]=0;p[a+16>>2]=b;return}b:{switch(p[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}p[a+16>>2]=3}}function MT(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(372,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function Kva(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;p[d+24>>2]=c;p[d+16>>2]=b;if(Ab(d+16|0,d+24|0)){while(1){p[d+12>>2]=p[p[d+16>>2]>>2];jy(a,d+12|0);Rd(d+16|0);if(Ab(d+16|0,d+24|0)){continue}break}}fb=d+32|0}function FU(a,b){var c=0,d=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}c=p[a+16>>2];d=p[a+8>>2]+ -4|0;p[a+8>>2]=d;p[114610]=0;K(349,c|0,d|0);c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function CJ(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;if(4294967279>=b>>>0){a:{if(b>>>0<=10){cf(a,b);e=a;break a}f=Ok(b)+1|0;e=Si(f);sf(a,e);sg(a,f);oe(a,b)}ty(e,b,c);n[d+15|0]=0;ae(b+e|0,d+15|0);fb=d+16|0;return}tg();E()}function ug(a){var b=0;p[114610]=0;a=M(1398,a|0)|0;b=p[114610];p[114610]=0;a:{if((b|0)==1){a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;a=0;if((b|0)==1){break a}}return a}a=O(0)|0;H()|0;rb(a);E()}function pZ(a){var b=0;p[114610]=0;a=M(2836,a|0)|0;b=p[114610];p[114610]=0;a:{if((b|0)==1){a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;R(20);b=p[114610];p[114610]=0;a=0;if((b|0)==1){break a}}return a}a=O(0)|0;H()|0;rb(a);E()}function Ym(a){a=a|0;vc(a+16|0,p[a>>2]);vc(a+8|0,p[a>>2]);if(s[a+12>>2]>=s[a+16>>2]){p[a+12>>2]=0;p[a+16>>2]=0;o[a+34>>1]=r[a+34>>1]&65511}if(s[a+4>>2]>=s[a+8>>2]){p[a+4>>2]=0;p[a+8>>2]=0;o[a+34>>1]=r[a+34>>1]&65529}}function DB(a){var b=0;a:{b=a+2|0;if(!(q[b|0]|q[b+1|0]<<8)){break a}a=a+4|0;if(!(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))){break a}return(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))>>>0<2147483649}return 0}function Bla(a,b,c){var d=0;d=fb-32|0;fb=d;p[d+16>>2]=b;p[d+24>>2]=a;p[d+8>>2]=c;if(Ab(d+24|0,d+16|0)){while(1){a=n[p[d+24>>2]];n[p[d+8>>2]]=a?a:32;bg(d+24|0);bg(d+8|0);if(Ab(d+24|0,d+16|0)){continue}break}}fb=d+32|0}function x9(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;In(a);p[a>>2]=83848;d=ih(c+8|0);b=ih(b);p[114610]=0;P(2203,a+12|0,d|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a|0}a=I()|0;H()|0;L(a|0);E()}function v9(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;In(a);p[a>>2]=83888;d=ih(c+8|0);b=ih(b);p[114610]=0;P(2205,a+12|0,d|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a|0}a=I()|0;H()|0;L(a|0);E()}function WZ(a){a=a|0;a:{b:{if(n[461940]&1){break b}if(!nd(461940)){break b}p[114610]=0;J(2593,461928,62664)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(461940)}return 461928}a=I()|0;H()|0;ge(461940);L(a|0);E()}function SZ(a){a=a|0;a:{b:{if(n[461972]&1){break b}if(!nd(461972)){break b}p[114610]=0;J(2593,461960,62712)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(461972)}return 461960}a=I()|0;H()|0;ge(461972);L(a|0);E()}function SH(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -2048|0;K(1651,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function OZ(a){a=a|0;a:{b:{if(n[462004]&1){break b}if(!nd(462004)){break b}p[114610]=0;J(2593,461992,62772)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(462004)}return 461992}a=I()|0;H()|0;ge(462004);L(a|0);E()}function Kv(a){var b=0;a:{b:{while(1){if(p[a+1380>>2]!=-1){break b}b=0;if(!ar(a)){break a}if(!(n[a+1375|0]&1)){continue}break}Wb(a,32);return 0}p[a+1396>>2]=0;p[a+1400>>2]=0;p[a+1384>>2]=0;n[a+1376|0]=0;b=1}return b}function KZ(a){a=a|0;a:{b:{if(n[462036]&1){break b}if(!nd(462036)){break b}p[114610]=0;J(2593,462024,62868)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(462036)}return 462024}a=I()|0;H()|0;ge(462036);L(a|0);E()}function wsa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -16|0;K(1232,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function ts(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;vb(d+8|0,c+1074308|0,102);a:{if(!tb(d+8|0)){break a}c=r[a+692>>1]+1|0;o[a+796>>1]=c;if(!(n[a+89|0]&1)){break a}o[a+796>>1]=c|32768}p[a+692>>2]=b;fb=d+16|0}function tW(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-32|0;fb=b;c=b+16|0;d=SV(a,c);if(!d){qB(c)}c=-1;a:{if(!d){break a}c=0;if(!EB(b+16|0)){break a}c=b;a=RV(a,b);if(!a){oB(c)}c=-1;if(!a){break a}c=DB(b)}fb=b+32|0;return c|0}function sya(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -12|0;K(1024,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;kt(a);e=p[b+4>>2];d=b+4|0;$P(qb(a),p[a>>2],c,d);f=c;c=b+8|0;HI(qb(a),f,p[a+4>>2],c);Qb(a,d);Qb(a+4|0,c);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];nt(a,Rf(a));return e|0}function _V(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;In(a);p[a>>2]=77064;d=ih(c+8|0);b=ih(b);p[114610]=0;P(275,a+12|0,d|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a|0}a=I()|0;H()|0;L(a|0);E()}function Xua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;kf(a);e=p[b+4>>2];d=b+4|0;ui(qb(a),p[a>>2],c,d);f=c;c=b+8|0;un(qb(a),f,p[a+4>>2],c);Qb(a,d);Qb(a+4|0,c);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];Vj(a,Bb(a));return e|0}function DL(a,b){var c=0,d=0,e=0,f=0;e=u[a+48>>3];c=u[a+40>>3];u[a+48>>3]=c;f=u[a+64>>3];d=u[a+56>>3];u[a+64>>3]=d;u[a+40>>3]=b;b=c*u[a+8>>3]+u[a>>3]*b+e*u[a+16>>3]-(f*u[a+32>>3]+d*u[a+24>>3]);u[a+56>>3]=b;return b}function Cla(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -24|0;K(1560,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function yxa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(1060,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function qm(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return w(b?-1/a:a)}function pL(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -12|0;K(1237,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function oZ(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=b>>>0>4?b:4;a=a?a:1;a:{while(1){if(!eY(c+12|0,b,a)){break a}d=p[115919];if(d){m[d|0]();continue}break}a=W(4)|0;Kk(a);ba(a|0,71348,2008);E()}fb=c+16|0;return p[c+12>>2]}function oK(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -24|0;K(1379,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function j9(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -16|0;K(2206,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function iN(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -12|0;K(1023,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function hM(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -32|0;K(1195,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function d9(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -24|0;K(2207,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function aha(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(1763,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function ZBa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -32|0;K(896,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function YZ(a){a=a|0;a:{b:{if(n[461924]&1){break b}if(!nd(461924)){break b}p[114610]=0;J(85,461912,62652)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(461924)}return 461912}a=I()|0;H()|0;ge(461924);L(a|0);E()}function UZ(a){a=a|0;a:{b:{if(n[461956]&1){break b}if(!nd(461956)){break b}p[114610]=0;J(85,461944,62700)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(461956)}return 461944}a=I()|0;H()|0;ge(461956);L(a|0);E()}function TR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;Ak(a);e=p[b+4>>2];d=b+4|0;ui(qb(a),p[a>>2],c,d);f=c;c=b+8|0;un(qb(a),f,p[a+4>>2],c);Qb(a,d);Qb(a+4|0,c);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];Ut(a,fc(a));return e|0}function Rza(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -24|0;K(986,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function QZ(a){a=a|0;a:{b:{if(n[461988]&1){break b}if(!nd(461988)){break b}p[114610]=0;J(85,461976,62748)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(461988)}return 461976}a=I()|0;H()|0;ge(461988);L(a|0);E()}function OIa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -24|0;K(607,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function OEa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -24|0;K(771,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function MZ(a){a=a|0;a:{b:{if(n[462020]&1){break b}if(!nd(462020)){break b}p[114610]=0;J(85,462008,62856)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(462020)}return 462008}a=I()|0;H()|0;ge(462020);L(a|0);E()}function Lma(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(1524,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function JKa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -24|0;K(528,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function Iza(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -56|0;K(990,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function Ina(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(1439,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function GJ(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -52|0;K(1438,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function Dsa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -8|0;K(1229,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function DJa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -24|0;K(572,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function DCa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -20|0;K(885,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function Ana(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(1440,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function z5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{if(!co(za(p[a+60>>2],b|0,c|0,d&255,e+8|0)|0)){b=p[e+12>>2];a=p[e+8>>2];break a}p[e+8>>2]=-1;p[e+12>>2]=-1;b=-1;a=-1}fb=e+16|0;ib=b;return a|0}function yKa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -2|0;K(532,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function xA(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=p[a+4>>2];f=e+b|0;p[a+4>>2]=f;if(!((f+ -1^e+ -1)>>>0<32?e:0)){g=p[a>>2];p[(f>>>0<33?g:(f+ -1>>>3&536870908)+g|0)>>2]=0}zn(d+8|0,a,e);Mp(d+8|0,b,c);fb=d+16|0}function vv(a){a=a|0;var b=0;p[a>>2]=56120;p[114610]=0;K(2313,a|0,0);b=p[114610];p[114610]=0;if((b|0)!=1){Gb(a+28|0);Nb(p[a+32>>2]);Nb(p[a+36>>2]);Nb(p[a+48>>2]);Nb(p[a+60>>2]);return a|0}a=O(0)|0;H()|0;rb(a);E()}function tR(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -48|0;K(573,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function jAa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;RN(a,c+11|0);if((q[c+11|0]|q[c+12|0]<<8|(q[c+13|0]<<16|q[c+14|0]<<24))==1414807888){RN(a,c+11|0);n[b|0]=1;a=0}else{a=1}a=aAa(a+(c+11|0)|0);fb=c+16|0;return a|0}function i3(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -12|0;K(206,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function aL(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=c&15;if(e){n[b+844|0]=e}c=c&240;if(c){n[b+843|0]=c>>>4}p[b+88>>2]=p[b+88>>2]|131072;vb(d+8|0,a+1074308|0,80);if(!(!e|!tb(d+8|0))){n[b+844|0]=q[b+844|0]<<2}fb=d+16|0}function XEa(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=130150524;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function XDa(a,b,c,d,e){var f=0,g=0;f=fb-32|0;fb=f;g=zDa(b,f+28|0,c);c=p[g>>2];n[f+27|0]=0;if(!c){yDa(f+8|0,b,d,e);ik(b,p[f+28>>2],g,p[f+8>>2]);c=Cd(f+8|0);n[f+27|0]=1;jP(f+8|0)}mi(a,Ic(f+8|0,c),f+27|0);fb=f+32|0}function Vja(a,b,c,d,e){var f=0,g=0;f=fb-32|0;fb=f;g=tja(b,f+28|0,c);c=p[g>>2];n[f+27|0]=0;if(!c){sja(f+8|0,b,d,e);ik(b,p[f+28>>2],g,p[f+8>>2]);c=Cd(f+8|0);n[f+27|0]=1;iI(f+8|0)}mi(a,Ic(f+8|0,c),f+27|0);fb=f+32|0}function Upa(a,b,c,d,e){var f=0,g=0;f=fb-32|0;fb=f;g=ipa(b,f+28|0,c);c=p[g>>2];n[f+27|0]=0;if(!c){hpa(f+8|0,b,d,e);ik(b,p[f+28>>2],g,p[f+8>>2]);c=Cd(f+8|0);n[f+27|0]=1;jK(f+8|0)}mi(a,Ic(f+8|0,c),f+27|0);fb=f+32|0}function Tm(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=1073741823;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function Spa(a,b,c,d,e){var f=0,g=0;f=fb-32|0;fb=f;g=bpa(b,f+28|0,c);c=p[g>>2];n[f+27|0]=0;if(!c){apa(f+8|0,b,d,e);ik(b,p[f+28>>2],g,p[f+8>>2]);c=Cd(f+8|0);n[f+27|0]=1;hK(f+8|0)}mi(a,Ic(f+8|0,c),f+27|0);fb=f+32|0}function RP(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -33|0;K(769,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function RB(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -16|0;K(217,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function QV(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -32|0;K(276,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function PH(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(1653,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function JS(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -16|0;K(426,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function JCa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(884,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function HU(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -12|0;K(348,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function HJa(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -6|0;K(570,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function HCa(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=214748364;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function Gea(a,b,c,d,e){var f=0,g=0;f=fb-32|0;fb=f;g=Hra(b,f+28|0,c);c=p[g>>2];n[f+27|0]=0;if(!c){Dca(f+8|0,b,d,e);ik(b,p[f+28>>2],g,p[f+8>>2]);c=Cd(f+8|0);n[f+27|0]=1;kL(f+8|0)}mi(a,Ic(f+8|0,c),f+27|0);fb=f+32|0}function DA(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=2147483647;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function CGa(a,b,c,d,e){var f=0,g=0;f=fb-32|0;fb=f;g=BGa(b,f+28|0,c);c=p[g>>2];n[f+27|0]=0;if(!c){AGa(f+8|0,b,d,e);ik(b,p[f+28>>2],g,p[f+8>>2]);c=Cd(f+8|0);n[f+27|0]=1;rQ(f+8|0)}mi(a,Ic(f+8|0,c),f+27|0);fb=f+32|0}function zza(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=76695844;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function zta(a,b){a=a|0;b=b|0;var c=0,d=0;d=a+808|0;c=a+16|0;while(1){c=yta(c)+44|0;if((d|0)!=(c|0)){continue}break}d=a+3832|0;c=a+808|0;while(1){c=xta(c)+84|0;if((d|0)!=(c|0)){continue}break}wta(a,b);return a|0}function yJa(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=89478485;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function uV(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -8|0;K(283,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function tT(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -2|0;K(382,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function tA(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(372,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function rO(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -8|0;K(924,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function qP(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(822,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function oQ(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(737,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function lq(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=268435455;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function lU(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -1|0;K(360,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function lQ(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -6|0;K(739,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function lP(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -2|0;K(829,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function kU(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -2|0;K(362,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function iQ(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(740,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function iB(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=134217727;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function hx(a,b){var c=0;c=p[b+24>>2];c=c?c:1;p[a+24628>>2]=c>>>0<512?c:512;a:{if(!(p[b+16>>2]!=p[a+24620>>2]|p[b+20>>2]!=p[a+24624>>2])){c=0;if(p[b+12>>2]==p[a+24616>>2]){break a}}c=1}ac(a+24604|0,b,40);BJ(a,c)}function hu(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=536870911;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function aE(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=357913941;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function YN(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(950,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function RL(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(107,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function PR(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=178956970;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function OS(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -2|0;K(422,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function NB(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -1|0;K(215,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function IA(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -1|0;K(361,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function Goa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;a=p[a+1304560>>2];a:{if(a){m[p[p[a>>2]+8>>2]](a,b,c);break a}if(p[19092]<(b|0)){break a}YJ(d+8|0,20431,20452,132);HB(d+24|0,d+8|0,b,20422,c)}fb=d+32|0}function GU(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -4|0;K(349,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function Fz(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=715827882;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function zI(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=82595524;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function lia(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=2097151;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function bva(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(!(!d|e==w(1))){while(1){if(c){i=b+g|0;f=0;while(1){h=Bf(a,f,i);t[h>>2]=t[h>>2]*e;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}}function ava(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(!(!d|e==w(1))){while(1){if(c){i=b+g|0;f=0;while(1){h=$m(a,f,i);t[h>>2]=t[h>>2]*e;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}}function _S(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=qb(a);p[114610]=0;c=c+ -1|0;K(32,d|0,c|0);d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function VV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;p[e+12>>2]=d;d=0;f=p[a+8>>2];if(f>>>0>c>>>0){p[e+8>>2]=f-c;d=Cb(e+8|0,e+12|0);a=p[a+4>>2]+c|0;d=p[d>>2];Ye(a,a+d|0,b)}fb=e+16|0;return d|0}function Pk(a,b){a=a|0;b=b|0;k2(a);p[a+28>>2]=b;tD(a+32|0);J1(a+44|0);p[a+72>>2]=0;p[a+76>>2]=0;p[a+64>>2]=0;p[a+56>>2]=0;p[a+60>>2]=0;p[a+80>>2]=0;p[a+84>>2]=0;p[a+88>>2]=0;p[a+92>>2]=0;p[a+96>>2]=0;return a|0}function gx(a,b){var c=0,d=0;c=p[b+4>>2];p[a+24648>>2]=p[b>>2];p[a+24652>>2]=c;d=p[b+20>>2];c=a+24664|0;p[c>>2]=p[b+16>>2];p[c+4>>2]=d;d=p[b+12>>2];c=a+24656|0;p[c>>2]=p[b+8>>2];p[c+4>>2]=d;AJ(a+24648|0);PJ(a)}function fya(){var a=0,b=0,c=0;a=fb-16|0;fb=a;p[a+12>>2]=477218588;p[114610]=0;p[a+8>>2]=2147483647;b=J(33,a+12|0,a+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=a+16|0;return p[b>>2]}a=O(0)|0;H()|0;rb(a);E()}function aAa(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;a:{b:{if(!a){a=0;break b}c=Mb(b,a);p[114610]=0;a=M(978,c|0)|0;d=p[114610];p[114610]=0;if((d|0)==1){break a}pb(c)}fb=b+16|0;return a}a=I()|0;H()|0;pb(c);L(a|0);E()}function Mta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;p[e>>2]=c;p[e+8>>2]=b;if(Ab(e+8|0,e)){while(1){Ep(a,p[d>>2],p[e+8>>2]);te(e+8|0);p[d>>2]=p[d>>2]+2;if(Ab(e+8|0,e)){continue}break}}fb=e+16|0}function uC(a){var b=0,c=0;b=fb-16|0;fb=b;Nk(a);p[b+12>>2]=1073741823;p[114610]=0;p[b+8>>2]=2147483647;a=Cb(b+12|0,b+8|0);c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function nm(a,b,c){var d=0,e=0;d=zd(b,a);e=zd(c,b);a:{b:{if(!d){d=0;if(!e){break a}Qb(b,c);d=1;if(!zd(b,a)){break a}Qb(a,b);break b}if(e){Qb(a,c);return 1}Qb(a,b);d=1;if(!zd(c,b)){break a}Qb(b,c)}d=2}return d}function Yq(a){var b=0;if(a){if(p[a+76>>2]<=-1){return Ev(a)}return Ev(a)}if(p[21324]){b=Yq(p[21324])}a=p[114605];if(a){while(1){if(s[a+20>>2]>s[a+28>>2]){b=Ev(a)|b}a=p[a+56>>2];if(a){continue}break}}return b}function Mpa(a){var b=0,c=0;b=fb-16|0;fb=b;o[b+12>>1]=0;p[b+8>>2]=0;jj(b+8|0);c=r[b+12>>1];n[a+814|0]=c;n[a+815|0]=c>>>8;c=p[b+8>>2];n[a+810|0]=c;n[a+811|0]=c>>>8;n[a+812|0]=c>>>16;n[a+813|0]=c>>>24;fb=b+16|0}function Jua(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=Iua(b,e+28|0,c);c=p[f>>2];n[e+27|0]=0;if(!c){Hua(e+8|0,b,d);ik(b,p[e+28>>2],f,p[e+8>>2]);c=Cd(e+8|0);n[e+27|0]=1;yM(e+8|0)}mi(a,Ic(e+8|0,c),e+27|0);fb=e+32|0}function Ima(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=Hma(b,e+28|0,c);c=p[f>>2];n[e+27|0]=0;if(!c){Gma(e+8|0,b,d);ik(b,p[e+28>>2],f,p[e+8>>2]);c=Cd(e+8|0);n[e+27|0]=1;eJ(e+8|0)}mi(a,Ic(e+8|0,c),e+27|0);fb=e+32|0}function Eu(a,b,c){var d=0;d=p[a+16>>2];if(!d){p[a+36>>2]=1;p[a+24>>2]=c;p[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(p[a+24>>2]!=2){break a}p[a+24>>2]=c;return}n[a+54|0]=1;p[a+24>>2]=2;p[a+36>>2]=p[a+36>>2]+1}}function CFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;p[d+12>>2]=c;e=d,f=mFa(Ub(b),Vb(b),d+12|0),p[e+8>>2]=f;e=d,f=Vb(b),p[e>>2]=f;a:{if(Ab(d+8|0,d)){Re(a,qb(p[d+8>>2]));break a}Hh(a)}fb=d+16|0}function AT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=DS(b)}p[a>>2]=f;c=c+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=b+f|0,p[g>>2]=h;fb=e+16|0;return a|0}function sV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=Ek(e+8|0,b);p[114610]=0;Q(284,a|0,b|0,c|0,d|0);a=p[114610];p[114610]=0;if((a|0)!=1){sb(b);fb=e+16|0;return}a=I()|0;H()|0;sb(b);L(a|0);E()}function pma(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=b,h=vh(a),p[g>>2]=h;vh(a);if(f>>>0>=60){Sb(a,4)}g=e,h=vh(a),p[g>>2]=h;Sb(a,4);b=vh(a);p[d>>2]=b;if((b|0)>=1){g=c,h=vh(a),p[g>>2]=h}}function kpa(a,b){var c=0;c=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=c;c=p[b+28>>2];p[a+24>>2]=p[b+24>>2];p[a+28>>2]=c;c=p[b+20>>2];p[a+16>>2]=p[b+16>>2];p[a+20>>2]=c;c=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=c}function gS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;p[d+12>>2]=c;e=d,f=VKa(Ub(b),Vb(b),d+12|0),p[e+8>>2]=f;e=d,f=Vb(b),p[e>>2]=f;a:{if(Ab(d+8|0,d)){Re(a,qb(p[d+8>>2]));break a}Hh(a)}fb=d+16|0}function bLa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;g=p[p[b>>2]+20>>2];f=p[c+12>>2];p[e+8>>2]=p[c+8>>2];p[e+12>>2]=f;f=p[c+4>>2];p[e>>2]=p[c>>2];p[e+4>>2]=f;m[g|0](a,b,e,d);fb=e+16|0}function Tfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;b=rc(ONa(NNa(d,d>>31,b,b>>31),ib,1e3,0),ib);p[a+16>>2]=0;p[a+12>>2]=b+c;kH(a,e);b=p[a+12>>2];p[f+12>>2]=0;pI(a,b,f+12|0);fb=f+16|0}function RJa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;p[c+12>>2]=1;p[c+8>>2]=a>>>4;b=Pb(128/(v(p[Gf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);n[c+7|0]=1;n[c+6|0]=a&15;a=q[dh(c+7|0,c+6|0)|0];fb=c+16|0;return a|b<<4&240}function PJ(a){var b=0,c=0;b=fb-544|0;fb=b;if(!(!(q[a+480210|0]&128)|!p[a+24668>>2])){BL(b,He(a));c=a+1304360|0;a=a+1074984|0;while(1){ac(a+112|0,b,538);a=a+896|0;if((c|0)!=(a|0)){continue}break}}fb=b+544|0}function Jz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;p[d+12>>2]=c;e=d,f=DR(Ub(b),Vb(b),d+12|0),p[e+8>>2]=f;e=d,f=Vb(b),p[e>>2]=f;a:{if(Ab(d+8|0,d)){Re(a,qb(p[d+8>>2]));break a}Hh(a)}fb=d+16|0}function Fy(a,b,c){var d=0;d=fb-16|0;fb=d;p[d>>2]=b;p[d+8>>2]=a;a:{if(!Ab(d+8|0,d)){break a}while(1){if(r[p[d+8>>2]>>1]==r[c>>1]){break a}te(d+8|0);if(Ab(d+8|0,d)){continue}break}}fb=d+16|0;return p[d+8>>2]}function Dua(a){var b=0,c=0,d=0;d=a;b=p[a+24>>2];c=0;a:{if(!b){break a}if(b){b=Xm(eo(+(b>>>0)*.00011957431543704412)*2215.9795828054475)}else{b=0}c=Pb(b,-16384,16383)}b=c;n[d+37|0]=b&127;n[a+36|0]=(b|0)/128}function vf(a,b,c,d,e){var f=0;f=fb-256|0;fb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Jb(f,b&255,d?c:256);if(!d){while(1){Fe(a,f,256);c=c+ -256|0;if(c>>>0>255){continue}break}}Fe(a,f,c)}fb=f+256|0}function kD(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;n[g+15|0]=0;n[g+14|0]=f;n[g+13|0]=e;n[g+12|0]=37;if(f){bh(g+13|0,g+14|0)}h=c,i=(Oa(b|0,rT(b,p[c>>2])|0,g+12|0,d|0,p[a>>2])|0)+b|0,p[h>>2]=i;fb=g+16|0}function d8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=w(0);e=fb-16|0;fb=e;f=p[a+4>>2];QF(a,b,c,d);g=t[a+24>>2];p[e+8>>2]=p[a+20>>2];b=p[a+16>>2];p[e>>2]=p[a+12>>2];p[e+4>>2]=b;sca(e,f,c,d,g);fb=e+16|0}function Pba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=p[a+24>>2];Pr(d,0,c);p[114610]=0;N(650,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(d);fb=d+16|0;return}a=I()|0;H()|0;pb(d);L(a|0);E()}function Hha(a){var b=0,c=0,d=0,e=0;b=KH(a);c=KH(a+12|0);d=JH(a+24|0);e=JH(a+36|0);p[114610]=0;P(1639,a|0,2,0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){return}a=I()|0;H()|0;Cr(e);Cr(d);Br(c);Br(b);L(a|0);E()}function HM(a,b){var c=0;c=q[a+822|0];a:{if(c){break a}c=kk(q[a+819|0]-p[a+772>>2]|0);if(!b|!p[a+656>>2]){break a}if(!c){c=0;break a}if(129<=c>>>0){break a}c=q[Yb(p[a+656>>2]+108|0,c+ -1|0)|0]}return c&255}function Cxa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d>>2]=4896;c=p[Cb(d+12|0,d)>>2];if(!Hb(a,c)){c=pf(a)}$y(d,b);Dg(a,p[d>>2],c);$y(d,b);Jb(p[d>>2]+c|0,0,4896-c|0);Sb(a,p[d+12>>2]);fb=d+16|0;return c}function BJ(a,b){var c=0;if(b){xo(a);c=a+24596|0;p[c>>2]=0;p[c+4>>2]=0;p[a+24588>>2]=0;p[a+24592>>2]=0;PJ(a)}AJ(a+24648|0);lfa(a+393352|0,b,p[a+24620>>2]);b=a+1304392|0;if(kd(b)){TL(p[b>>2],p[a+24620>>2])}}function xua(){var a=0;a:{b:{if(n[85356]&1){break b}if(!nd(85356)){break b}p[114610]=0;M(100,85328)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(85356)}return 85328}a=I()|0;H()|0;ge(85356);L(a|0);E()}function iJ(){var a=0;a:{b:{if(n[457304]&1){break b}if(!nd(457304)){break b}p[114610]=0;J(1523,88600,1)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(457304)}return}a=I()|0;H()|0;ge(457304);L(a|0);E()}function dw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;p[e+24>>2]=b;f=e,g=wd(a),p[f+16>>2]=g;b=Mn(e+24|0,e+16|0);dZ(a,b,c,d);f=e,g=wd(a),p[f+8>>2]=g;a=lf(e+8|0,b);fb=e+32|0;return a|0}function Yr(a,b){a=ac(a,b,88);p[a+88>>2]=p[b+88>>2];ac(a+92|0,b+92|0,576);p[a+668>>2]=p[b+668>>2];ac(a+672|0,b+672|0,52);Cx(a+724|0,b+724|0);Cx(a+736|0,b+736|0);Cx(a+748|0,b+748|0);ac(a+760|0,b+760|0,135)}function Xx(a){var b=0,c=0,d=0;b=r[a+20>>1];o[a+28>>1]=r[a+22>>1]<<1|(q[p[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=p[c>>2];if(d){Wm(d);VL(p[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function Wz(a){var b=0,c=0;b=fb-16|0;fb=b;qb(a);p[b+12>>2]=-1;p[114610]=0;p[b+8>>2]=2147483647;a=J(33,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return p[a>>2]}a=O(0)|0;H()|0;rb(a);E()}function rc(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;p[c+24>>2]=a;p[c+28>>2]=b;p[c+16>>2]=-2147483648;p[c+20>>2]=-1;p[c+8>>2]=2147483647;p[c+12>>2]=0;a=KQ(c+16|0,qz(c+24|0,c+8|0));fb=c+32|0;return p[a>>2]}function mB(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=hB(p[a+16>>2],b)}p[a>>2]=f;c=(c<<5)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<5)+f|0,p[g>>2]=h;fb=e+16|0;return a}function kO(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=Bc(a);a:{if(d>>>0>=c>>>0){d=Ib(a);Pl(d,b,c);n[e+15|0]=0;ae(c+d|0,e+15|0);Jg(a,c);break a}f=d;g=c-d|0;d=wb(a);xu(a,f,g,d,0,d,c,b)}fb=e+16|0;return a}function h4(){var a=0;a:{b:{if(n[461576]&1){break b}if(!nd(461576)){break b}p[114610]=0;M(2386,461572)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(461576)}return}a=I()|0;H()|0;ge(461576);L(a|0);E()}function Q0(a,b,c){var d=0;d=fb-32|0;fb=d;p[d+16>>2]=b;p[d+24>>2]=a;p[d+8>>2]=c;while(1){a=Ab(d+24|0,d+16|0);if(!(!a|q[p[d+24>>2]]!=q[p[d+8>>2]])){bg(d+24|0);bg(d+8|0);continue}break}fb=d+32|0;return a^1}function Hxa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d>>2]=263;c=p[Cb(d+12|0,d)>>2];if(!Hb(a,c)){c=pf(a)}WM(d,b);Dg(a,p[d>>2],c);WM(d,b);Jb(p[d>>2]+c|0,0,263-c|0);Sb(a,p[d+12>>2]);fb=d+16|0;return c}function CZ(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=tC(p[a+16>>2],b)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function yN(a){var b=0;a:{if((q[a+44|0]|q[a+45|0]<<8|(q[a+46|0]<<16|q[a+47|0]<<24))!=1297236819|q[a+29|0]!=16){break a}a=a+42|0;if((q[a|0]|q[a+1|0]<<8)!=2?(q[a|0]|q[a+1|0]<<8)!=1:0){break a}b=1}return b}function kAa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(b){Mb(c,b);break a}Lb(c)}p[114610]=0;N(13,a|0,4,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function gza(a,b){var c=0;c=fb-16|0;fb=c;p[c>>2]=b;p[c+8>>2]=a;if(Ab(c+8|0,c)){while(1){a=p[c+8>>2];if(q[a+3|0]==31){n[a+3|0]=20;n[a+5|0]=q[a+5|0]|128}uk(c+8|0);if(Ab(c+8|0,c)){continue}break}}fb=c+16|0}function Wp(a,b,c){a:{if(s[a+12>>2]<=b>>>0){a=W(8)|0;p[114610]=0;M(352,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}b=I()|0;H()|0;X(a|0);L(b|0);E()}n[p[a+8>>2]+b|0]=c;return}ba(a|0,77368,265);E()}function RQ(a){var b=0,c=0;b=a+36|0;c=NNa(q[b|0]|q[b+1|0]<<8,0,384,0);a=a+34|0;b=q[a|0]|q[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+ib|0;a=c>>>0<b>>>0?a+1|0:a;b=c+256|0;if(b>>>0<256){a=a+1|0}ib=a;return b}function Jd(a,b){var c=0,d=0,e=0;b=b+7&-8;p[a+8>>2]=b+p[a+8>>2];d=p[a+80>>2];a:{if(d){c=b;b=p[a+88>>2];e=c+b|0;c=0;if((e|0)>p[a+92>>2]){break a}p[a+88>>2]=e;return b+d|0}if(!b){return 0}c=fd(b)}return c}function EB(a){var b=0;b=a;if((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))==1129474426&(q[b+4|0]|q[b+5|0]<<8|(q[b+6|0]<<16|q[b+7|0]<<24))==1634291279){a=a+8|0;return(q[a|0]|q[a+1|0]<<8)==14}return 0}function oGa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;p[e+12>>2]=d;fz(a,c,d);d=0;f=p[a+16>>2];if(f>>>0>c>>>0){p[e+8>>2]=f-c;d=p[Cb(e+8|0,e+12|0)>>2];FGa(a,b,c,d)}fb=e+16|0;return d|0}function fS(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(b){Mb(c,b);break a}Lb(c)}p[114610]=0;N(13,a|0,2,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function eS(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(b){Mb(c,b);break a}Lb(c)}p[114610]=0;N(13,a|0,1,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function bEa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d>>2]=18;c=p[Cb(d+12|0,d)>>2];if(!Hb(a,c)){c=pf(a)}Wy(d,b);Dg(a,p[d>>2],c);Wy(d,b);Jb(p[d>>2]+c|0,0,18-c|0);Sb(a,p[d+12>>2]);fb=d+16|0;return c}function X8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;YF(b,c,d,t[a+28>>2]);XF(a,b,c,d);b=p[a+24>>2];p[e+8>>2]=p[a+20>>2];p[e+12>>2]=b;b=p[a+16>>2];p[e>>2]=p[a+12>>2];p[e+4>>2]=b;fb=e+16|0}function UJ(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(b){Mb(c,b);break a}Lb(c)}p[114610]=0;N(13,a|0,0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function SCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(HCa(a)>>>0<b>>>0){Vc();E()}qb(a);c=b;if(214748364<c>>>0){tc(15502);E()}c=gc(v(c,20),4);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=c+v(b,20)|0,p[d>>2]=e;ep(a);ep(a)}function Mka(a){var b=0,c=0,d=0;b=fb+ -64|0;fb=b;GI(a);d=of(a);c=Ir(b+8|0,a);p[114610]=0;N(1580,a|0,d|0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){hl(c);fb=b- -64|0;return}a=I()|0;H()|0;hl(c);L(a|0);E()}function Lha(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d>>2]=33;c=p[Cb(d+12|0,d)>>2];if(!Hb(a,c)){c=pf(a)}Xy(d,b);Dg(a,p[d>>2],c);Xy(d,b);Jb(p[d>>2]+c|0,0,33-c|0);Sb(a,p[d+12>>2]);fb=d+16|0;return c}function J_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;p[a+12>>2]=c;p[a+8>>2]=f;b=I_(c,d,a+12|0,f,g,a+8|0);p[e>>2]=p[a+12>>2];p[h>>2]=p[a+8>>2];fb=a+16|0;return b|0}function H_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;p[a+12>>2]=c;p[a+8>>2]=f;b=G_(c,d,a+12|0,f,g,a+8|0);p[e>>2]=p[a+12>>2];p[h>>2]=p[a+8>>2];fb=a+16|0;return b|0}function D_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;p[a+12>>2]=c;p[a+8>>2]=f;b=C_(c,d,a+12|0,f,g,a+8|0);p[e>>2]=p[a+12>>2];p[h>>2]=p[a+8>>2];fb=a+16|0;return b|0}function B_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;p[a+12>>2]=c;p[a+8>>2]=f;b=A_(c,d,a+12|0,f,g,a+8|0);p[e>>2]=p[a+12>>2];p[h>>2]=p[a+8>>2];fb=a+16|0;return b|0}function $Da(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d>>2]=40;c=p[Cb(d+12|0,d)>>2];if(!Hb(a,c)){c=pf(a)}Qy(d,b);Dg(a,p[d>>2],c);Qy(d,b);Jb(p[d>>2]+c|0,0,40-c|0);Sb(a,p[d+12>>2]);fb=d+16|0;return c}function wFa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b&63;if(gk(c)>>>0>d>>>0){jFa(VP(c,d),a)}a:{b:{if(b<<24>>24>=0){b=a+12|0;break b}b=a+12|0;if(cd(a)){break b}a=q[a+12|0]|1;break a}a=q[a+12|0]&-2}n[b|0]=a}function jma(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e>>2]=c;p[e+8>>2]=b;if(Ab(e+8|0,e)){while(1){ima(d,p[e+8>>2]);uk(e+8|0);if(Ab(e+8|0,e)){continue}break}}b=p[d+4>>2];p[a>>2]=p[d>>2];p[a+4>>2]=b;fb=e+16|0}function e4(){var a=0,b=0;b=ur(460544);p[115134]=55828;p[b>>2]=55848;p[115135]=0;p[114610]=0;K(2388,p[13954]+460536|0,461220);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=I()|0;H()|0;xg(b);L(a|0);E()}function c4(){var a=0,b=0;b=$D(460632);p[115156]=55876;p[b>>2]=55896;p[115157]=0;p[114610]=0;K(2389,p[13966]+460624|0,461284);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=I()|0;H()|0;xg(b);L(a|0);E()}function Uta(a,b){var c=0;c=fb+ -64|0;fb=c;b=Opa(c+16|0,b);b=Jpa(c,b,b+48|0);p[114610]=0;P(106,a|0,b|0,0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){be(b);fb=c- -64|0;return}a=I()|0;H()|0;be(b);L(a|0);E()}function U_(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;p[g+12>>2]=f;f=lh(g+8|0,g+12|0);p[114610]=0;a=GD(a,b,c,d,e);b=p[114610];p[114610]=0;if((b|0)!=1){ye(f);fb=g+16|0;return a}a=I()|0;H()|0;ye(f);L(a|0);E()}function R_(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;p[g+12>>2]=f;f=lh(g+8|0,g+12|0);p[114610]=0;a=FD(a,b,c,d,e);b=p[114610];p[114610]=0;if((b|0)!=1){ye(f);fb=g+16|0;return a}a=I()|0;H()|0;ye(f);L(a|0);E()}function uCa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-608|0;fb=c;b=c+8|0;d=XBa(a,b);if(!d){GO(b)}b=-1;a:{if(!d){break a}b=0;if(!OO(c+8|0)){break a}b=-1;if(!af(a,1024)){break a}b=tCa(a)}fb=c+608|0;return b|0}function mM(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;n[a+16|0]=0;c=_x(b,p[a+12>>2]);p[114610]=0;N(1176,a|0,1,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pl(c);fb=b+32|0;return}a=I()|0;H()|0;pl(c);L(a|0);E()}function cta(){var a=0;a:{b:{if(n[87556]&1){break b}if(!nd(87556)){break b}p[114610]=0;M(1210,87552)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(87556)}return}a=I()|0;H()|0;ge(87556);L(a|0);E()}function TAa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=rA(a);if(d>>>0>=b>>>0){a=Fs(a);if(a>>>0<d>>>1>>>0){p[c+12>>2]=a<<1;p[c+8>>2]=b+31&-32;d=p[Uc(c+12|0,c+8|0)>>2]}fb=c+16|0;return d|0}Vc();E()}function Gsa(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1227,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Asa(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1230,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function yU(a,b){a:{if(s[a+12>>2]<=b>>>0){a=W(8)|0;p[114610]=0;M(352,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}b=I()|0;H()|0;X(a|0);L(b|0);E()}return q[p[a+8>>2]+b|0]}ba(a|0,77368,265);E()}function jL(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1260,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function fta(){var a=0;a:{b:{if(n[85488]&1){break b}if(!nd(85488)){break b}p[114610]=0;M(108,85484)|0;a=p[114610];p[114610]=0;if((a|0)==1){break a}md(85488)}return}a=I()|0;H()|0;ge(85488);L(a|0);E()}function ZA(a){if(!((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=808603728|(q[a+4|0]+ -9&255)>>>0>6|((q[a+5|0]+ -9&255)>>>0>6|(q[a+6|0]+ -9&255)>>>0>6))){return(q[a+7|0]+ -9&255)>>>0<7}return 0}function WCa(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(879,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function UHa(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=674;p[c>>2]=674;d=p[Cb(c+12|0,c)>>2];if(!Hb(a,d)){d=pf(a)}kQ(c,b);Dg(a,p[c>>2],d);kQ(c,b);Jb(p[c>>2]+d|0,0,674-d|0);Sb(a,p[c+12>>2]);fb=c+16|0}function TCa(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(881,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function SGa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d>>2]=b;p[d+8>>2]=a;a:{if(!Ab(d+8|0,d)){break a}while(1){if(op(p[d+8>>2],c)){break a}kn(d+8|0);if(Ab(d+8|0,d)){continue}break}}fb=d+16|0;return p[d+8>>2]}function Pna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=fb-16|0;fb=c;mf(a,c+14|0);lz(b,r[c+14>>1],16777216);if(r[c+14>>1]){while(1){ni(a,Fb(b,d));d=d+1|0;if(d>>>0<r[c+14>>1]){continue}break}}kx(b);fb=c+16|0}function LJa(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(568,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function EAa(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(948,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function yy(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[b+12>>2]=0;p[114610]=0;P(936,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function rU(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(354,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function kz(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(708,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function jW(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(269,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function fA(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(409,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function eY(a,b,c){var d=0;a:{b:{if((b|0)==8){b=fd(c);break b}d=28;if(b&3|(RNa(b>>>2|0)|0)!=1){break a}d=48;if(-64-b>>>0<c>>>0){break a}b=fY(b>>>0>16?b:16,c)}if(!b){return 48}p[a>>2]=b;d=0}return d}function cT(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(417,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Xt(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(355,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function N_(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;p[b+12>>2]=a;a=lh(b+8|0,b+12|0);p[114610]=0;c=CD();d=p[114610];p[114610]=0;if((d|0)!=1){ye(a);fb=b+16|0;return c|0}b=I()|0;H()|0;ye(a);L(b|0);E()}function Hs(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(932,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function qd(a,b){var c=0;if(r[a+24>>1]!=(b&65535)){o[a+22>>1]=r[a+22>>1]+ -1&127;if(128>r[a+20>>1]){o[a+20>>1]=r[a+20>>1]+1}c=(r[a+22>>1]<<2)+a|0;o[c+28>>1]=0;o[c+26>>1]=b-r[a+24>>1];o[a+24>>1]=b}}function qA(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(31,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function dy(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(94,a+8|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function bCa(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e>>2]=b;p[e+8>>2]=a;if(Ab(e+8|0,e)){while(1){if(r[p[e+8>>2]>>1]==r[c>>1]){o[p[e+8>>2]>>1]=r[d>>1]}te(e+8|0);if(Ab(e+8|0,e)){continue}break}}fb=e+16|0}function Z0(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;p[f+12>>2]=e;e=lh(f+8|0,f+12|0);p[114610]=0;a=dv(a,b,c,d);b=p[114610];p[114610]=0;if((b|0)!=1){ye(e);fb=f+16|0;return a}a=I()|0;H()|0;ye(e);L(a|0);E()}function QJ(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=p[a>>2];a:{if(!b){break a}if(!(m[p[p[b>>2]+112>>2]](b)|0)){break a}m[p[p[b>>2]+92>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function EL(a,b,c,d,e,f){p[a+40>>2]=0;p[a+44>>2]=0;u[a+32>>3]=f;u[a+24>>3]=e;u[a+16>>3]=d;u[a+8>>3]=c;u[a>>3]=b;p[a+48>>2]=0;p[a+52>>2]=0;p[a+56>>2]=0;p[a+60>>2]=0;a=a- -64|0;p[a>>2]=0;p[a+4>>2]=0}function BC(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;p[f+12>>2]=e;e=lh(f+8|0,f+12|0);p[114610]=0;a=Zn(a,b,c,d);b=p[114610];p[114610]=0;if((b|0)!=1){ye(e);fb=f+16|0;return a}a=I()|0;H()|0;ye(e);L(a|0);E()}function uka(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=wI(b)}p[a>>2]=f;c=v(c,52)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,52)+f|0,p[g>>2]=h;fb=e+16|0;return a}function lg(a,b){a:{if(s[a+4>>2]<=b>>>0){a=W(8)|0;p[114610]=0;M(352,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}b=I()|0;H()|0;X(a|0);L(b|0);E()}return q[p[a>>2]+b|0]}ba(a|0,77368,265);E()}function kya(a,b){var c=0;c=fb-16|0;fb=c;p[a>>2]=0;p[a+4>>2]=0;p[c+12>>2]=0;p[114610]=0;P(1027,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Yxa(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=64;p[c>>2]=66;d=p[Cb(c+12|0,c)>>2];if(!Hb(a,d)){d=pf(a)}jt(c,b);Dg(a,p[c>>2],d);jt(c,b);Jb(p[c>>2]+d|0,0,66-d|0);Sb(a,p[c+12>>2]);fb=c+16|0}function Xba(a,b){var c=0;c=fb-16|0;fb=c;p[a>>2]=0;p[a+4>>2]=0;p[c+12>>2]=0;p[114610]=0;P(2124,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Wh(a){var b=0;b=32767;a:{if(a>=w(32766.5)){break a}b=32768;if(a<=w(-32767.5)){break a}a=w(a+w(.5));b:{if(w(x(a))<w(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Qba(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a=p[a+24>>2];Pr(c,0,b);p[114610]=0;N(650,a|0,1,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function Np(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(rA(a)>>>0<b>>>0){Vc();E()}qb(a);b=(b+ -1>>>5|0)+1|0;c=b;if(1073741823<b>>>0){tc(11804);E()}c=gc(c<<2,4);p[a+4>>2]=0;p[a>>2]=c;d=qb(a),e=b,p[d>>2]=e}function MK(a,b,c){var d=0,e=0;d=p[(v(b,896)+a|0)+1075640>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=p[(v(b,896)+a|0)+1075088>>2];if(!a){break b}if(q[a+35|0]&4){break a}}e=q[d+34|0]}return e}function Lq(a){var b=0;if(p[a+76>>2]<0){b=p[a+4>>2];if(b>>>0<s[a+8>>2]){p[a+4>>2]=b+1;return q[b|0]}return nv(a)}b=p[a+4>>2];a:{if(b>>>0<s[a+8>>2]){p[a+4>>2]=b+1;a=q[b|0];break a}a=nv(a)}return a}function Ky(a){var b=0,c=0;c=(q[a+24|0]>15)+(q[a+25|0]>64)|0;b=a+22|0;b=q[b|0]|q[b+1|0]<<8;a=a+26|0;a=q[a|0]|q[a+1|0]<<8;return c+((b<<24|b<<8&16711680)>>>15>>>0<(a<<8&16711680|a<<24)>>>16>>>0)|0}function xI(a,b){var c=0;c=fb-16|0;fb=c;p[a>>2]=0;p[a+4>>2]=0;p[c+12>>2]=0;p[114610]=0;P(1591,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function qC(a,b){var c=0,d=0;c=p[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}Nk(a);p[114610]=0;c=c+ -4|0;d=p[114610];p[114610]=0;if((d|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}p[a+4>>2]=b}function paa(a){a=a|0;var b=0;a=a+24|0;b=nG(p[a>>2]);if(b>>>0>=bj(Ob(p[a>>2]+484360|0))>>>0){return r[p[a>>2]+1074436>>1]}b=r[kc(Ob(p[a>>2]+484360|0),b)>>1];return(Cp(p[a>>2]+484344|0,b)?b:-1)|0}function iL(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=hL(b)}p[a>>2]=f;c=v(c,12)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,12)+f|0,p[g>>2]=h;fb=e+16|0;return a}function gM(a,b){var c=0;c=fb-16|0;fb=c;p[a>>2]=0;p[a+4>>2]=0;p[c+12>>2]=0;p[114610]=0;P(1197,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function aCa(a,b){var c=0,d=0;d=fb-16|0;fb=d;a:{if((a|0)==(b|0)){break a}c=a+1|0;if((c|0)==(b|0)){break a}while(1){a=q[a|0]<q[c|0]?c:a;c=c+1|0;if((c|0)!=(b|0)){continue}break}}fb=d+16|0;return a}function P7(a,b){var c=0;c=fb-16|0;fb=c;p[a>>2]=0;p[a+4>>2]=0;p[c+12>>2]=0;p[114610]=0;P(2209,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function KJa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Fz(a)>>>0<b>>>0){Vc();E()}qb(a);c=b;if(715827882<c>>>0){tc(12706);E()}c=gc(v(c,6),1);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=c+v(b,6)|0,p[d>>2]=e;nt(a,0)}function HLa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d>>2]=192;c=p[Cb(d+12|0,d)>>2];if(!Hb(a,c)){c=pf(a)}yt(d,b);Dg(a,p[d>>2],c);yt(d,b);Jb(p[d>>2]+c|0,0,192-c|0);Sb(a,p[d+12>>2]);fb=d+16|0}function CL(a,b){var c=0;c=fb-16|0;fb=c;p[a>>2]=0;p[a+4>>2]=0;p[c+12>>2]=0;p[114610]=0;P(1226,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function xAa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=ZN(b)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function vpa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1378,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function ssa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1234,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function soa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1418,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function sha(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1742,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function rha(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1743,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function qoa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1420,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function p7(a,b,c){var d=0;d=o7(a,b,c);if((d|0)==(b|0)){return b}a=d+2|0;if((b|0)!=(a|0)){while(1){if(r[a>>1]!=r[c>>1]){o[d>>1]=r[a>>1];d=d+2|0}a=a+2|0;if((b|0)!=(a|0)){continue}break}}return d}function mya(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1026,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function mpa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=kK(b)}p[a>>2]=f;c=(c<<5)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<5)+f|0,p[g>>2]=h;fb=e+16|0;return a}function kq(a,b,c){var d=0;d=fb-16|0;fb=d;a:{if(c){Mb(d,c);break a}Lb(d)}p[114610]=0;N(13,a|0,b|0,d|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(d);fb=d+16|0;return}a=I()|0;H()|0;pb(d);L(a|0);E()}function jua(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1177,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function ika(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1593,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function gha(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1761,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=1;a=a+32|0;if(s[p[b>>2]>>2]<Cc(a)>>>0){a=_l(d,oc(a,p[p[b>>2]>>2]),r[p[b>>2]+12>>1]);b=Ru(c,a);yb(a);e=b^1}fb=d+16|0;return e|0}function Zpa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1370,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Wma(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1517,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function VCa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Tm(a)>>>0<b>>>0){Vc();E()}qb(a);c=b;if(1073741823<c>>>0){tc(15502);E()}c=gc(c<<2,1);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=c+(b<<2)|0,p[d>>2]=e;Vj(a,0)}function SG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ee(12);b=p[b>>2];c=p[c>>2];p[114610]=0;b=P(2001,d|0,b|0,c|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){Pea(a,b);return}a=I()|0;H()|0;Nb(d);L(a|0);E()}function Nna(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1436,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Mua(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1167,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Loa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1401,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Lna(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1437,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Jba(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(2131,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Ixa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1056,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function HN(a,b){var c=0;c=fb-16|0;fb=c;p[a>>2]=0;p[a+4>>2]=0;p[c+12>>2]=0;p[114610]=0;P(994,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Gya(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1019,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Fla(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(1559,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function F$(a){var b=0,c=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[b+12>>2]=0;p[114610]=0;vC(a+16|0,b+12|0,b+8|0);c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function $S(a,b){var c=0;c=fb-16|0;fb=c;p[a>>2]=0;p[a+4>>2]=0;p[c+12>>2]=0;p[114610]=0;P(419,a+8|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function zsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(lq(a)>>>0<b>>>0){Vc();E()}qb(a);c=b;if(268435455<c>>>0){tc(20049);E()}c=gc(c<<4,8);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=c+(b<<4)|0,p[d>>2]=e;Vl(a,0)}function yBa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(923,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function ufa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(86224);if(!d){return 0}p[114610]=0;a=U(1965,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function sM(a,b,c,d){var e=0;e=fb-16|0;fb=e;d=Gh(e,a,d);a=qb(a);p[114610]=0;Q(1170,a|0,b|0,c|0,d+4|0);a=p[114610];p[114610]=0;if((a|0)!=1){Db(d);fb=e+16|0;return}a=I()|0;H()|0;Db(d);L(a|0);E()}function sJa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(576,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function qHa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(699,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function q6(a,b){var c=0;c=Jb(a,0,1512);if(b){a=p[b+4>>2];p[c+80>>2]=p[b>>2];p[c+84>>2]=a;a=a&-8;p[c+92>>2]=a;p[c+84>>2]=a}p[c+96>>2]=0;p[c+100>>2]=0;p[c+1420>>2]=-1;p[c+124>>2]=0;p[c+32>>2]=0}function oF(a,b){var c=0,d=0,e=0,f=w(0),g=w(0),h=0;if((b|0)>=1){h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=t[c>>2];g=t[e>>2];t[e>>2]=f+g;t[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}}function lFa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(763,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function i9(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=bG(b)}p[a>>2]=f;c=(c<<4)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<4)+f|0,p[g>>2]=h;fb=e+16|0;return a}function hs(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=fL(b)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function gxa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;p[d>>2]=36;c=p[Cb(d+12|0,d)>>2];if(!Hb(a,c)){c=pf(a)}Xp(d,b);Dg(a,p[d>>2],c);Xp(d,b);Jb(p[d>>2]+c|0,0,36-c|0);Sb(a,p[d+12>>2]);fb=d+16|0}function eEa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(818,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function dR(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=KS(b)}p[a>>2]=f;c=(c<<4)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<4)+f|0,p[g>>2]=h;fb=e+16|0;return a}function cQ(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=dQ(b)}p[a>>2]=f;c=v(c,6)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=v(b,6)+f|0,p[g>>2]=h;fb=e+16|0;return a}function cM(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=eM(b)}p[a>>2]=f;c=(c<<5)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<5)+f|0,p[g>>2]=h;fb=e+16|0;return a}function bAa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(977,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function _Y(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=tq(a);a:{if(d>>>0>=c>>>0){d=Ib(a);ZY(d,b,c);p[e+12>>2]=0;Je(d+(c<<2)|0,e+12|0);Jg(a,c);break a}f=a;a=wb(a);iC(f,d,c-d|0,a,0,a,c,b)}fb=e+16|0}function ZDa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(821,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Vxa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;p[e>>2]=c;p[e+8>>2]=b;if(Ab(e+8|0,e)){while(1){Uxa(d,p[e+8>>2]);uk(e+8|0);if(Ab(e+8|0,e)){continue}break}}aN(a,d);fb=e+16|0}function Uza(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(985,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function TKa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(520,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Su(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e+12>>2]=d;d=lh(e+8|0,e+12|0);p[114610]=0;a=Jj(a,b,c);b=p[114610];p[114610]=0;if((b|0)!=1){ye(d);fb=e+16|0;return a}a=I()|0;H()|0;ye(d);L(a|0);E()}function QMa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(416,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Og(a,b){var c=0,d=0;a=p[a>>2];b=Ad(b);c=b;d=a+16|0;if(Bb(d)>>>0>b>>>0){c=p[Fb(d,c)>>2]!=0}else{c=0}if(!c){a=W(4)|0;Am(a);p[a>>2]=71772;ba(a|0,71832,2564);E()}return p[Fb(a+16|0,b)>>2]}function L_(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e+12>>2]=d;d=lh(e+8|0,e+12|0);p[114610]=0;a=BD(a,b,c);b=p[114610];p[114610]=0;if((b|0)!=1){ye(d);fb=e+16|0;return a}a=I()|0;H()|0;ye(d);L(a|0);E()}function Ksa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(hu(a)>>>0<b>>>0){Vc();E()}qb(a);c=b;if(536870911<c>>>0){tc(20049);E()}c=gc(c<<3,8);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=c+(b<<3)|0,p[d>>2]=e;gu(a,0)}function KEa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(774,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Jta(a,b){var c=0,d=0;c=Ita(a,b);p[114610]=0;J(4,a+12|0,b+12|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){p[a+24>>2]=p[b+24>>2];o[a+28>>1]=r[b+28>>1];return}a=I()|0;H()|0;qf(c);L(a|0);E()}function JIa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(610,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Iw(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=jI(b)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function Ft(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=sT(b)}p[a>>2]=f;c=(c<<1)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<1)+f|0,p[g>>2]=h;fb=e+16|0;return a}function FKa(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(531,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function B9(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(2201,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function An(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=sA(b)}p[a>>2]=f;c=(c<<2)+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=(b<<2)+f|0,p[g>>2]=h;fb=e+16|0;return a}function uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4268);if(!d){return 0}p[114610]=0;a=U(1855,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function uba(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=p[b+12>>2];p[e+8>>2]=p[b+8>>2];p[e+12>>2]=f;f=p[b+4>>2];p[e>>2]=p[b>>2];p[e+4>>2]=f;sba(a,e,c);t[a+28>>2]=d;p[a>>2]=83960;fb=e+16|0;return a}function rba(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=p[b+12>>2];p[e+8>>2]=p[b+8>>2];p[e+12>>2]=f;f=p[b+4>>2];p[e>>2]=p[b>>2];p[e+4>>2]=f;qba(a,e,c);t[a+28>>2]=d;p[a>>2]=84064;fb=e+16|0;return a}function qU(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(356,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function o6(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;Ic(b+8|0,a+116|0);p[114610]=0;c=Ha(198,a|0)|0;a=H()|0;c=c|0;d=p[114610];p[114610]=0;if((d|0)!=1){fb=b+16|0;ib=a;return c}a=I()|0;H()|0;L(a|0);E()}function kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4296);if(!d){return 0}p[114610]=0;a=U(1879,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function iW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(hu(a)>>>0<b>>>0){Vc();E()}qb(a);c=b;if(536870911<c>>>0){tc(11120);E()}c=gc(c<<3,1);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=c+(b<<3)|0,p[d>>2]=e;gu(a,0)}function h5(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(203,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function gfa(a,b,c,d){var e=0,f=0,g=0;if(d){while(1){e=g<<3;f=e+a|0;p[f>>2]=p[f>>2]+v(p[b+e>>2]>>4,c);e=e|4;f=e+a|0;p[f>>2]=p[f>>2]+v(p[b+e>>2]>>4,c);g=g+1|0;if((g|0)!=(d|0)){continue}break}}}function dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4304);if(!d){return 0}p[114610]=0;a=U(1700,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function Sia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4268);if(!d){return 0}p[114610]=0;a=U(1637,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function Rfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(5048);if(!d){return 0}p[114610]=0;a=U(1915,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function R1(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(207,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4280);if(!d){return 0}p[114610]=0;a=U(1808,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function OU(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(345,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function J1(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[114610]=0;p[b+12>>2]=0;P(208,a+8|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4276);if(!d){return 0}p[114610]=0;a=U(1832,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4276);if(!d){return 0}p[114610]=0;a=U(1942,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function $ga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4296);if(!d){return 0}p[114610]=0;a=U(1775,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ug(4228);if(!d){return 0}p[114610]=0;a=U(1892,d|0,a|0,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;Nb(d);L(a|0);E()}function xEa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb+ -64|0;fb=d;c=d+8|0;e=RDa(a,c);if(!e){sP(c)}c=-1;a:{if(!e){break a}c=0;if(!GP(d+8|0)){break a}c=Ve(a,b,FP(d+8|0),ib)}fb=d- -64|0;return c|0}function oo(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Cd(b),p[d+12>>2]=e;p[114610]=0;P(2002,a|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function no(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Cd(b),p[d+12>>2]=e;p[114610]=0;P(2162,a|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function ni(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=0;a=Ik(a,c+12|0,4);p[c+8>>2]=p[c+12>>2];d=b;b=c+8|0;p[d>>2]=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);fb=c+16|0;return!ib&(a|0)==4}function m4(){var a=0,b=0;a=fb-16|0;fb=a;b=W(16)|0;a=l4(a+8|0);p[114610]=0;P(2338,b|0,56128,a|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){ba(b|0,56200,2339);E()}a=I()|0;H()|0;X(b|0);L(a|0);E()}function lx(a,b){var c=0;Gna(a,b);n[a+12|0]=q[b+12|0];c=q[b+13|0]|q[b+14|0]<<8|(q[b+15|0]<<16|q[b+16|0]<<24);n[a+13|0]=c;n[a+14|0]=c>>>8;n[a+15|0]=c>>>16;n[a+16|0]=c>>>24;n[a+17|0]=q[b+17|0]}function ina(a){var b=0,c=0,d=0,e=0,f=0;a:{b=p[a+656>>2];c=n[b+26|0];if(!c){break a}d=q[a+819|0];if(!d){break a}e=a,f=Pb(p[a+684>>2]+((v((q[b+27|0]^-1)+d|0,c)|0)/2|0)|0,0,256),p[e+684>>2]=f}}function eQ(a,b,c){a=a|0;b=b|0;c=c|0;a=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);n[b|0]=a;n[b+1|0]=a>>>8;n[b+2|0]=a>>>16;n[b+3|0]=a>>>24;a=q[c+4|0]|q[c+5|0]<<8;n[b+4|0]=a;n[b+5|0]=a>>>8}function Uf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=a;a:{if(!ze(b)){p[c+8>>2]=p[b+8>>2];e=p[b+4>>2];p[c>>2]=p[b>>2];p[c+4>>2]=e;break a}ap(a,p[b>>2],p[b+4>>2])}fb=d+16|0;return a|0}function FGa(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-32|0;fb=e;a=a+4|0;g=e,h=Ub(a),p[g+24>>2]=h;f=lf(e+24|0,c);g=e,h=Ub(a),p[g+8>>2]=h;g=e,h=lf(e+8|0,c),p[g+16>>2]=h;ij(f,lf(e+16|0,d),b);fb=e+32|0}function np(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Cd(b),p[d+12>>2]=e;p[114610]=0;P(727,a|0,c+12|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function UM(a){var b=0,c=0;a:{b:{b=a&240;if((b|0)!=192){if((b|0)==240){break b}c=3;if((b|0)!=208){break a}}c=2;break a}c=1;a=a+15&255;if(a>>>0>2){break a}return 131842>>>(a<<3)&255}return c}function N7(a,b){var c=0;a:{c=ve(a);if((c|0)==(wb(b)|0)){p[114610]=0;a=Z(344,b|0,0,-1,a|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}a=O(0)|0;H()|0;rb(a);E()}function Md(a,b){var c=0;a:{c=ve(b);if((c|0)==(wb(a)|0)){p[114610]=0;a=Z(344,a|0,0,-1,b|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}a=O(0)|0;H()|0;rb(a);E()}function Lba(a,b){var c=0;c=fb-48|0;fb=c;a:{if((b|0)==-1){gl(a,p[_o(c+8|0)+32>>2]);Vm(a,p[_o(c+8|0)+36>>2]);break a}if((b|0)<=0){gl(a,0);Vm(a,0);break a}b=v(b,1e3);gl(a,b);Vm(a,b)}fb=c+48|0}function yd(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;d=p[a>>2];e=a,f=(h=d,i=p[a+8>>2],j=Tb(c+8|0,b),g=p[p[d>>2]+32>>2],m[g](h|0,i|0,j|0)|0)+p[a+8>>2]|0,p[e+8>>2]=f;fb=c+16|0}function uIa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-112|0;fb=d;c=d+8|0;e=pIa(a,c);if(!e){_Q(c)}c=-1;a:{if(!e){break a}c=0;if(!bR(d+8|0)){break a}c=Ve(a,b,aR(d+8|0),ib)}fb=d+112|0;return c|0}function bY(a){var b=0;b=q[a+74|0];n[a+74|0]=b+ -1|b;b=p[a>>2];if(b&8){p[a>>2]=b|32;return-1}p[a+4>>2]=0;p[a+8>>2]=0;b=p[a+44>>2];p[a+28>>2]=b;p[a+20>>2]=b;p[a+16>>2]=b+p[a+48>>2];return 0}function WDa(a,b){var c=0,d=0;d=fb-16|0;fb=d;a:{if((a|0)==(b|0)){break a}c=a+8|0;if((c|0)==(b|0)){break a}while(1){a=kA(a,c)?c:a;c=c+8|0;if((c|0)!=(b|0)){continue}break}}fb=d+16|0;return a}function VC(a,b,c,d){var e=0;e=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=e;e=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=e;b=p[a+8>>2];d=p[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;p[a+8>>2]=b-c;p[a+12>>2]=d}function SIa(a,b){var c=0,d=0;d=fb-16|0;fb=d;a:{if((a|0)==(b|0)){break a}c=a+4|0;if((c|0)==(b|0)){break a}while(1){a=zd(c,a)?c:a;c=c+4|0;if((c|0)!=(b|0)){continue}break}}fb=d+16|0;return a}function Py(a,b){var c=0;a:{if(b){Py(a,p[b>>2]);Py(a,p[b+4>>2]);a=_b(a);p[114610]=0;K(826,a|0,b+14|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}Gi(a,b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function ND(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:n[a|0]=c;return;case 1:o[a>>1]=c;return;case 2:case 3:p[a>>2]=c;return;case 5:break b;default:break a}}p[a>>2]=c;p[a+4>>2]=d}}function EV(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;In(a);p[a>>2]=77168;p[114610]=0;P(281,a+12|0,b+8|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a|0}a=I()|0;H()|0;L(a|0);E()}function EU(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!WA(a,c+8|0)){break a}d=0;if(!RA(c+8|0)){break a}if(b){if(!DU(c+8|0,p[b>>2],p[b+4>>2])){break a}}d=1}fb=c+48|0;return d|0}function Dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=p[b>>2];a:{if((eh(b)|0)!=8){break a}d=c;if((q[d|0]|q[d+1|0]<<8|(q[d+2|0]<<16|q[d+3|0]<<24))!=1869112133){break a}ac(a+4260|0,c,eh(b));Gr(a)}}function ANa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-512|0;fb=d;c=d+8|0;e=vNa(a,c);if(!e){wT(c)}c=-1;a:{if(!e){break a}c=0;if(!CT(d+8|0)){break a}c=Ve(a,b,BT(d+8|0),ib)}fb=d+512|0;return c|0}function $la(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;a:{if(!oj(a,b+8|0)){break a}c=0;if(!_I(b+8|0)){break a}c=b;a=tN(a,b);if(!a){mR(c)}c=-1;if(!a){break a}c=ZI(b)}fb=b+16|0;return c|0}function zV(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Cd(b),p[d+12>>2]=e;p[114610]=0;P(282,a|0,c+12|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function xza(a,b){var c=0;FN(a,b);FN(a+12|0,b+12|0);qy(a+24|0,b+24|0);o[a+52>>1]=r[b+52>>1];c=p[b+48>>2];p[a+44>>2]=p[b+44>>2];p[a+48>>2]=c;c=p[b+40>>2];p[a+36>>2]=p[b+36>>2];p[a+40>>2]=c}function v1(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e+8>>2]=b;b=6;a:{b:{if(Pi(a,e+8|0)){break b}b=4;if((cm(d,Ij(a))|0)!=37){break b}b=2;if(!Pi(Uk(a),e+8|0)){break a}}p[c>>2]=p[c>>2]|b}fb=e+16|0}function m$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}b:{if(s[c>>2]>127){break b}if(!(r[Vn()+(p[c>>2]<<1)>>1]&b)){break b}c=c+4|0;continue}break}d=c}return d|0}function h1(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e+8>>2]=b;while(1){a:{if(!Pq(a,e+8|0)){break a}if(!Gj(d,8192,Rk(a))){break a}lm(a);continue}break}if(Fj(a,e+8|0)){p[c>>2]=p[c>>2]|2}fb=e+16|0}function dl(a,b){var c=0,d=w(0),e=0;e=o[a+28>>1];c=a+4|0;Bb(c);d=w(1);a:{if((e|0)>(b|0)){break a}if((r[a+28>>1]+Bb(c)<<16)+ -65536>>16<(b|0)){break a}d=t[Fb(c,b-o[a+28>>1]|0)>>2]}return d}function b1(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e+8>>2]=b;b=6;a:{b:{if(Fj(a,e+8|0)){break b}b=4;if((bm(d,Rk(a))|0)!=37){break b}b=2;if(!Fj(lm(a),e+8|0)){break a}}p[c>>2]=p[c>>2]|b}fb=e+16|0}function FG(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){if(N7(p[a>>2],p[d+8>>2])){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}fb=d+16|0;return a}function A1(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e+8>>2]=b;while(1){a:{if(!ao(a,e+8|0)){break a}if(!wg(d,8192,Ij(a))){break a}Uk(a);continue}break}if(Pi(a,e+8|0)){p[c>>2]=p[c>>2]|2}fb=e+16|0}function yia(a,b,c){a=a|0;b=b|0;c=w(c);var d=0,e=0,f=w(0);d=fb-16|0;fb=d;e=d,f=w(w(m[p[p[a>>2]+48>>2]](a,b))+c),t[e+12>>2]=f;Td(d+12|0,w(0));m[p[p[a>>2]+44>>2]](a,b,t[d+12>>2]);fb=d+16|0}function o$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=d;if(s[b>>2]<=127){e=r[Vn()+(p[b>>2]<<1)>>1]}else{e=0}o[a>>1]=e;d=d+2|0;b=b+4|0;continue}break}return c|0}function jNa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-48|0;fb=d;c=d+8|0;e=KMa(a,c);if(!e){YS(c)}c=-1;a:{if(!e){break a}c=0;if(!qT(d+8|0)){break a}c=Ve(a,b,pT(d+8|0),ib)}fb=d+48|0;return c|0}function Jk(a){var b=0,c=0;b=p[116044];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?(c|0)>=1:0){break a}if(a>>>0>jb()<<16>>>0){if(!(Ka(a|0)|0)){break a}}p[116044]=a;return b}p[114584]=48;return-1}function CNa(a){var b=0;b=q[a+15|0];n[a+15|0]=0;n[a+60|0]=b>>>1&2|b<<1&4|(q[a+60|0]&240|b&1);n[a+80|0]=b>>>4&2|b>>>2&4|(q[a+80|0]&240|b>>>3&1);n[a+100|0]=b>>>5&4|(q[a+100|0]&224|b>>>6&1)}function w6(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=0;a:{if(!u6(a,c,e+8|0,d,e+4|0,e+12|0)){break a}f=t6(a,b,(v(p[e+12>>2],6)+a|0)+412|0,p[c>>2],p[d>>2],p[e+4>>2],c)}a=f;fb=e+16|0;return a}function uma(a){var b=0,c=0,d=0,e=0;d=zt(a);b=d&63;a:{if(!(d&64)){break a}c=6;while(1){e=zt(a);b=(e&127)<<c|b;if(c>>>0>24){break a}c=c+7|0;if(e&128){continue}break}}return d&128?0-b|0:b}function Th(a,b){var c=0,d=0;c=q[a|0];d=q[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=q[b+1|0];c=q[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function Jea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;p[f+8>>2]=p[a+8>>2];g=p[a+4>>2];p[f>>2]=p[a>>2];p[f+4>>2]=g;a=QG(f,b,c,d,0,0,0,0,e);fb=f+16|0;return a|0}function Fea(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;d=c,e=Aca(a,b),p[d+24>>2]=e;d=c,e=hj(a),p[d+16>>2]=e;b=0;if(!ll(c+24|0,c+16|0)){zca(a,p[Ic(c+8|0,p[c+24>>2])>>2]);b=1}fb=c+32|0;return b}function Csa(a){var b=0,c=0,d=0;b=tsa(a)<<24;a=0;while(1){d=b<<1|c>>>31;c=c<<1;b=(b|0)>-1;c=b?c:c^-1798752855;b=b?d:d^-1382821323;a=a+1|0;if((a|0)!=8){continue}break}a=qsa(c,b);return a}function AY(){var a=0;p[114610]=0;a=p[114610];p[114610]=0;a:{if((a|0)!=1){a=p[115917];if(!a){break a}if(!aC(a+48|0)){break a}$B(p[a+12>>2]);E()}a=O(0)|0;H()|0;rb(a);E()}$B(p[21327]);E()}function vh(a){var b=0,c=0,d=0,e=0;d=td(a);b=d&63;a:{if(!(d&64)){break a}c=6;while(1){e=td(a);b=(e&127)<<c|b;if(c>>>0>24){break a}c=c+7|0;if(e&128){continue}break}}return d&128?0-b|0:b}function uLa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-1968|0;fb=d;c=d+8|0;e=rLa(a,c);if(!e){kS(c)}c=-1;a:{if(!e){break a}c=0;if(!oS(d+8|0)){break a}c=Ve(a,b,1024,0)}fb=d+1968|0;return c|0}function qpa(a,b){var c=0,d=0,e=0;if(PR(a)>>>0<b>>>0){Vc();E()}qb(a);c=b;if(178956970<c>>>0){tc(20320);E()}c=gc(v(c,24),8);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=c+v(b,24)|0,p[d>>2]=e;st(a,0)}function oEa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;p[c+8>>2]=b;d=c,e=Ub(a),p[d>>2]=e;b=Ts(c+8|0,c);b=p[a>>2]+(b<<2)|0;Rt(a,Ye(b+4|0,p[a+4>>2],b));a=Ze(b);fb=c+16|0;return a|0}function mV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-32|0;fb=d;p[d+24>>2]=b;dq(p[d+24>>2]);p[d+16>>2]=p[c+8>>2];b=p[c+4>>2];p[d+8>>2]=p[c>>2];p[d+12>>2]=b;lV(a,d+8|0);fb=d+32|0;return a|0}function _G(a,b){var c=0,d=0,e=0;if(a>w(.9999989867210388)){d=0}else{a=w(a*a);e=+a;c=qe(31415.926535897932/+b);d=Xm((32768-(D((1-c)*+w(a+a)+(c*c-1)*+w(a*a))+c*e)*32768)/(1-e))}return d}function Vra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(q[b+30|0]!=4){break a}d=b+31|0;if(q[d|0]&4|q[d|0]&2){break a}Tc(a,8,1,0,11);return}d=a;a=b+31|0;Tc(d,q[a|0]&4?16:8,q[a|0]&2|1,0,c^1)}function V6(a,b,c){var d=0,e=0,f=0;while(1){f=d;d=a+d|0;d=(f+Sv(d,c)|0)+jo(d)|0;if((d+4|0)>(b|0)){return(e|0)!=0}if(!ko(a,a+d|0)){return 0}e=e+1|0;if((e|0)!=10){continue}break}return 1}function xv(a,b,c,d,e){var f=0;f=yv(a,b,c,d);if(zd(e,d)){Qb(d,e);if(!zd(d,c)){return f+1|0}Qb(c,d);if(!zd(c,b)){return f+2|0}Qb(b,c);if(!zd(b,a)){return f+3|0}Qb(a,b);f=f+4|0}return f}function iv(a,b,c,d,e,f,g,h,i){var j=0;j=fb-16|0;fb=j;Of(j,b,c,d,e,f,g,h,i^-2147483648);b=p[j+4>>2];p[a>>2]=p[j>>2];p[a+4>>2]=b;b=p[j+12>>2];p[a+8>>2]=p[j+8>>2];p[a+12>>2]=b;fb=j+16|0}function Mya(a,b){a=a|0;b=b|0;var c=0,d=0;c=zya(a);a:{if(b){p[114610]=0;K(1018,a|0,b|0);d=p[114610];p[114610]=0;if((d|0)==1){break a}xya(a,b)}return a|0}a=I()|0;H()|0;ly(c);L(a|0);E()}function s9(a,b){var c=0,d=0;c=fb-32|0;fb=c;p[c+24>>2]=b;b=p[c+24>>2];d=p[b+12>>2];p[c+16>>2]=p[b+8>>2];p[c+20>>2]=d;d=p[b+4>>2];p[c+8>>2]=p[b>>2];p[c+12>>2]=d;HFa(a,c+8|0);fb=c+32|0}function o9(a,b){var c=0,d=0;c=fb-32|0;fb=c;p[c+24>>2]=b;b=p[c+24>>2];d=p[b+12>>2];p[c+16>>2]=p[b+8>>2];p[c+20>>2]=d;d=p[b+4>>2];p[c+8>>2]=p[b>>2];p[c+12>>2]=d;pFa(a,c+8|0);fb=c+32|0}function l4(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(n[458448]&1){break a}if(!nd(458448)){break a}md(458448)}Lc(b+8|0,1,85e3);c=p[b+12>>2];p[a>>2]=p[b+8>>2];p[a+4>>2]=c;fb=b+16|0;return a}function fq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=p[a>>2];b=(f=d,g=ub(b),h=p[a+8>>2],i=c,e=p[p[d>>2]+28>>2],m[e](f|0,g|0,h|0,i|0)|0);p[a+8>>2]=b+p[a+8>>2];return b|0}function Vu(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=Si(b)}p[a>>2]=f;c=c+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=b+f|0,p[g>>2]=h;fb=e+16|0;return a}function RFa(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=Xc(d);p[114610]=0;U(697,b|0,a|0,e|0,c|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){pb(e);fb=d+16|0;return}a=I()|0;H()|0;pb(e);L(a|0);E()}function N6(a){var b=0,c=0,d=0;c=a+72|0;while(1){a=1;while(1){b=(a<<2)+c|0;t[b>>2]=-t[b>>2];b=a>>>0<16;a=a+2|0;if(b){continue}break}c=c+144|0;a=d>>>0<30;d=d+2|0;if(a){continue}break}}function HA(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;p[e+12>>2]=0;Hc(a+12|0,d);if(b){f=FA(b)}p[a>>2]=f;c=c+f|0;p[a+8>>2]=c;p[a+4>>2]=c;g=Xb(a),h=b+f|0,p[g>>2]=h;fb=e+16|0;return a}function yya(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(fya()>>>0<b>>>0){Vc();E()}c=b;if(c>>>0>=477218589){tc(17324);E()}c=gc(v(c,9),1);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=c+v(b,9)|0,p[d>>2]=e}function cna(a,b,c,d){var e=0,f=0;ana(a,b,d);if((b|0)!=(c|0)){f=b-a>>1;e=b;while(1){if(vo(d,r[e>>1],r[a>>1])){oJ(e,a);bx(a,d,f,a)}e=e+2|0;if((e|0)!=(c|0)){continue}break}}$ma(a,b,d)}function b_(){var a=0;a:{if(n[463032]&1){break a}if(!nd(463032)){break a}a=463008;while(1){a=Lb(a)+12|0;if((a|0)!=463032){continue}break}md(463032)}Ec(463008,68184);Ec(463020,68187)}function _Z(){var a=0;a:{if(n[463064]&1){break a}if(!nd(463064)){break a}a=463040;while(1){a=Ue(a)+12|0;if((a|0)!=463064){continue}break}md(463064)}Rc(463040,68192);Rc(463052,68204)}function Wna(a){a=a|0;var b=0;b=1;a=p[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function VG(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;p[f+8>>2]=p[a+8>>2];g=p[a+4>>2];p[f>>2]=p[a>>2];p[f+4>>2]=g;c=UG(f,b,c,d,e,0,0,0,0);fb=f+16|0;return+c}function NLa(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Hb(a,120);a:{if(d){e=fb-16|0;fb=e;Zb(c+8|0,b,120);fb=e+16|0;yd(a,c+8|0);break a}a=fb-16|0;fb=a;vLa(b);fb=a+16|0}fb=c+16|0;return d}function Fua(a,b){var c=0;a:{if(q[a+4|0]){c=p[a>>2];p[114610]=0;K(826,c|0,b+14|0);c=p[114610];p[114610]=0;if((c|0)==1){break a}}if(b){Gi(p[a>>2],b,1)}return}a=O(0)|0;H()|0;rb(a);E()}function vHa(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;p[c+24>>2]=0;p[c+28>>2]=0;p[c+16>>2]=0;p[c+20>>2]=0;p[c+8>>2]=0;p[c+12>>2]=0;p[c>>2]=0;p[c+4>>2]=0;DQ(b,c,32);CQ(a,c);fb=c+32|0}function uBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,1030);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function qV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;p[e+24>>2]=d;p[e+28>>2]=c;pV(e+8|0,b,e+28|0,e+24|0);cu(e+16|0,e+8|0);Ql(a,e+16|0);sb(e+16|0);sb(e+8|0);fb=e+32|0}function pw(a){a=a|0;var b=0;a:{if(!a){a=W(8)|0;p[114610]=0;M(2028,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}b=I()|0;H()|0;X(a|0);L(b|0);E()}return}ba(a|0,83464,2017);E()}function k9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){a=p[d>>2];while(1){p[a>>2]=p[b>>2];Uf(a+4|0,b+4|0);a=p[d>>2]+16|0;p[d>>2]=a;b=b+16|0;if((c|0)!=(b|0)){continue}break}}}function ZI(a){var b=0;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=1179012417){b=0;if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=538987841){break a}}b=1}return b}function Xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;a=Ti(a);d=1;a:{if(!a){break a}d=(f=a,g=kh(c+8|0,b),e=p[p[a>>2]+72>>2],m[e](f|0,g|0)|0)}a=d;fb=c+16|0;return a|0}function OG(a){a=a|0;var b=0;a:{if(!a){a=W(8)|0;p[114610]=0;M(2016,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){break a}b=I()|0;H()|0;X(a|0);L(b|0);E()}return}ba(a|0,83452,2017);E()}function MHa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Es(c,b);p[114610]=0;N(650,a|0,4,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function KI(a,b){var c=0,d=0;d=a;c=b;if((a|0)!=(b|0)){bla(d,p[c>>2],p[c+4>>2])}p[a+12>>2]=p[b+12>>2];p[a+16>>2]=p[b+16>>2];p[a+20>>2]=p[b+20>>2];JI(a+24|0,b+24|0);Fi(a+36|0,b+36|0)}function AEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;c=0;a=m[p[p[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){p[d+8>>2]=a-b;c=p[Cb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function yZ(a,b){var c=0;a:{while(1){if(p[a+8>>2]==(b|0)){break a}p[a+8>>2]=p[a+8>>2]+ -4;p[114610]=0;c=p[114610];p[114610]=0;if((c|0)!=1){continue}break}a=O(0)|0;H()|0;rb(a);E()}}function vla(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,225);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function ula(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,326);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function sBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,274);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function pia(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=lia(a);if(d>>>0>=b>>>0){a=Oj(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function pGa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,554);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function pBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,106);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function nIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,771);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function kR(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;n[a+11|0]=0;fb=b+16|0}function cFa(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=XEa(a);if(d>>>0>=b>>>0){a=vl(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function a1(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=fb-128|0;fb=c;p[c+12>>2]=c+116;kD(a+8|0,c+16|0,c+12|0,e,f,g);a=uZ(c+16|0,p[c+12>>2],b);fb=c+128|0;return a|0}function Z5(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;Vi(b,0,a);p[114610]=0;a=M(202,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){pb(b);fb=b+16|0;return a|0}a=I()|0;H()|0;pb(b);L(a|0);E()}function YB(a,b,c,d){var e=0,f=0,g=0,h=0;f=p[a+4>>2];a=p[a>>2];g=a;h=b;e=0;a:{if(!c){break a}b=f>>8;e=b;if(!(f&1)){break a}e=p[b+p[c>>2]>>2]}m[p[p[a>>2]+28>>2]](g,h,e+c|0,f&2?d:2)}function XHa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,384);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function SDa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,284);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function LCa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,422);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function KKa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,136);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function ICa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,826);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function Fza(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=zza(a);if(d>>>0>=b>>>0){a=cn(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function $0(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=fb-416|0;fb=c;p[c+12>>2]=c+416;_0(a+8|0,c+16|0,c+12|0,e,f,g);a=tZ(c+16|0,p[c+12>>2],b);fb=c+416|0;return a|0}function zKa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,50);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function wla(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,73);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function uAa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,71);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function tla(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,60);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function tS(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+7|0]=0;n[a+8|0]=0;n[a+9|0]=0;n[a+10|0]=0;fb=b+16|0}function sNa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,25);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function rR(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=yJa(a);if(d>>>0>=b>>>0){a=zl(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function oBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,72);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function n6(){var a=0,b=0,c=0;while(1){b=a<<24;c=0;while(1){b=b>>31&79764919^b<<1;c=c+1|0;if((c|0)!=8){continue}break}p[(a<<2)+457312>>2]=b;a=a+1|0;if((a|0)!=256){continue}break}}function lBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,26);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function gIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,62);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function gBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=hu(a);if(d>>>0>=b>>>0){a=Di(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function _xa(a,b){var c=0;c=Hs(a);n[a+16|0]=0;o[a+14>>1]=0;o[a+12>>1]=b;p[114610]=0;N(1030,c|0,b|0,0);b=p[114610];p[114610]=0;if((b|0)!=1){return a}a=I()|0;H()|0;ce(c);L(a|0);E()}function Z6(a,b){var c=0,d=0,e=0,f=0,g=0;d=p[b+8>>2]>>>3|0;e=p[b+4>>2]+7>>>3|0;c=d-e|0;f=(c|0)>511;g=f?511:c;if((c|0)>=1){Ji(a+6156|0,((f?d+ -511|0:e)+b|0)+12|0,g)}p[a+6144>>2]=g}function TX(a,b,c,d,e,f,g,h,i,j,k,l,n,o,p,q){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;n=n|0;o=o|0;p=p|0;q=q|0;m[a|0](b,c,d,e,f,g,h,i,j,k,l,n,o,p,q)}function IMa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,37);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function Gy(a){var b=0,c=0,d=0;while(1){b=0;while(1){d=(q[Yb(((c<<4)+a|0)+(b<<2)|0,0)|0]>15)+d|0;b=b+1|0;if((b|0)!=4){continue}break}c=c+1|0;if((c|0)!=64){continue}break}return d}function EIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,15);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function DEa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,91);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function CLa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,17);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function CIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,34);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function Bha(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if($e(a)){while(1){d=Hl(a,c);e=Hl(a,c);p[b+12>>2]=0;Dx(d,e+2048|0,b+12|0);c=c+1|0;if(c>>>0<$e(a)>>>0){continue}break}}fb=b+16|0}function ADa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,42);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function wV(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;Zb(c+8|0,b,20);fb=d+16|0;b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function se(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=Tm(a);if(d>>>0>=b>>>0){a=rd(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function q4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=p[c+4>>2];c=p[c>>2];p[d>>2]=c;p[d+4>>2]=e;p[d+8>>2]=c;p[d+12>>2]=e;dC(a,d,b);p[a>>2]=56100;fb=d+16|0;return a|0}function pk(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=PR(a);if(d>>>0>=b>>>0){a=Le(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function n$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){if(s[c>>2]>127){break a}if(!(r[Vn()+(p[c>>2]<<1)>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function mq(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=lq(a);if(d>>>0>=b>>>0){a=Ih(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function km(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=aE(a);if(d>>>0>=b>>>0){a=_f(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function gO(a){var b=0;a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=441273424|q[a+5|0]!=16){break a}b=a+54|0;if(!q[b|0]|q[b|0]>32){break a}return q[a+4|0]>95}return 0}function cCa(a,b){var c=0,d=0;c=fb-16|0;fb=c;if(ze(a)){cg(a,p[a>>2],Sj(a))}p[a+8>>2]=p[b+8>>2];d=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=d;cf(b,0);n[c+15|0]=0;ae(b,c+15|0);fb=c+16|0}function bza(a){var b=0,c=0;b=fb-16|0;fb=b;if(tN(a,b+8|0)){a=b+8|0;a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);c=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}fb=b+16|0;return c}function bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=r[a+28>>1];o[d+8>>1]=e;f=d,g=(Bb(a+4|0)+e|0)+ -1|0,o[f+10>>1]=g;a=rI(a,b,c,d+8|0);fb=d+16|0;return a|0}function _y(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=Fz(a);if(d>>>0>=b>>>0){a=ri(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function Yw(a,b){a:{if(b){Yw(a,p[b>>2]);Yw(a,p[b+4>>2]);a=_b(a);p[114610]=0;K(1525,a|0,b+16|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}gJ(b)}return}a=O(0)|0;H()|0;rb(a);E()}function Ol(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=iB(a);if(d>>>0>=b>>>0){a=hh(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function N1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;p[g+8>>2]=624576549;p[g+12>>2]=1394948685;a=Mi(a,b,c,d,e,f,g+8|0,g+16|0);fb=g+16|0;return a|0}function Ls(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=fb-16|0;fb=c;d=a,e=(g=a,h=p[a+12>>2],i=Tb(c+8|0,b),f=p[p[a>>2]+32>>2],m[f](g|0,h|0,i|0)|0)+p[a+12>>2]|0,p[d+12>>2]=e;fb=c+16|0}function Lj(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){if(E9(d+8|0,a)){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}fb=d+16|0;return a}function DZ(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=uC(a);if(d>>>0>=b>>>0){a=Mk(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function DI(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=zI(a);if(d>>>0>=b>>>0){a=Wi(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function Bl(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=Wz(a);if(d>>>0>=b>>>0){a=Hf(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function Ai(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=DA(a);if(d>>>0>=b>>>0){a=If(a);if(a>>>0<d>>>1>>>0){p[c+8>>2]=a<<1;d=p[Uc(c+8|0,c+12|0)>>2]}fb=c+16|0;return d}Vc();E()}function sza(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-608|0;fb=d;c=d;e=nza(a,d);if(!e){AN(c)}c=-1;a:{if(!e){break a}c=0;if(!CN(d)){break a}c=Ve(a,b,BN(d),ib)}fb=d+608|0;return c|0}function qDa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=dP(d,b);b=fb-16|0;fb=b;MCa(d+8|0,dP(b,e));fb=b+16|0;nu(a,d+8|0);p[a+12>>2]=c;p[a+8>>2]=0;fb=d+16|0;return a|0}function mv(a,b){var c=0;c=ur(a+4|0);p[a>>2]=55924;p[c>>2]=55944;p[114610]=0;K(2388,p[13978]+a|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=I()|0;H()|0;xg(c);L(a|0);E()}function mf(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;o[c+14>>1]=0;a=Ik(a,c+14|0,2);o[c+12>>1]=r[c+14>>1];d=b;b=c+12|0;o[d>>1]=q[b|0]|q[b+1|0]<<8;fb=c+16|0;return!ib&(a|0)==2}function lv(a,b){var c=0;c=$D(a+4|0);p[a>>2]=55972;p[c>>2]=55992;p[114610]=0;K(2389,p[13990]+a|0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=I()|0;H()|0;xg(c);L(a|0);E()}function kua(a,b){a=a|0;b=b|0;var c=0;jua(a);c=a;n[a+16|0]=0;p[a+12>>2]=b;p[114610]=0;S(1175,a|0);b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;ps(c);L(a|0);E()}function fIa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-576|0;fb=d;c=d;e=ZHa(a,d);if(!e){PQ(c)}c=-1;a:{if(!e){break a}c=0;if(!SQ(d)){break a}c=Ve(a,b,RQ(d),ib)}fb=d+576|0;return c|0}function _Fa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;fz(a,b,c);c=0;a=p[a+16>>2];if(a>>>0>b>>>0){p[d+8>>2]=a-b;c=p[Cb(d+8|0,d+12|0)>>2]}fb=d+16|0;return c|0}function Z4(a,b){a=a|0;b=b|0;p[a+4>>2]=b;n[a|0]=0;if(tf(p[p[b>>2]+ -12>>2]+b|0)){if(p[(p[p[b>>2]+ -12>>2]+b|0)+72>>2]){Qq(p[(p[p[b>>2]+ -12>>2]+b|0)+72>>2])}n[a|0]=1}return a|0}function QHa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-192|0;fb=d;c=d;e=nGa(a,d);if(!e){jQ(c)}c=-1;a:{if(!e){break a}c=0;if(!MQ(d)){break a}c=Ve(a,b,LQ(d),ib)}fb=d+192|0;return c|0}function Q5(a,b){var c=0,d=0,e=0,f=0;if((a|0)>=8){c=a>>3;c=(c|0)>1?c:1;d=36-_k(a)|0;a=0;while(1){e=(a<<1)+b|0,f=Yk(a)>>>d<<2,o[e>>1]=f;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Pz(a){var b=0,c=0;b=fb-16|0;fb=b;if(aq(a,b+8|0)){a=b+8|0;a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);c=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}fb=b+16|0;return c}function Pu(a,b){var c=0,d=0;c=fb-16|0;fb=c;o[b>>1]=0;n[c+15|0]=0;Mg(a,c+15|0);d=q[c+15|0];o[b>>1]=d>>>1;if(d&1){n[c+15|0]=0;Mg(a,c+15|0);o[b>>1]=r[b>>1]|q[c+15|0]<<7}fb=c+16|0}function NAa(a,b,c,d){var e=0;e=fb-48|0;fb=e;a:{if(p[b+4>>2]==p[d+4>>2]){MAa(a,Ed(e+40|0,b),Ed(e+32|0,c),Ed(e+24|0,d));break a}LAa(a,Ed(e+16|0,b),Ed(e+8|0,c),Ed(e,d))}fb=e+48|0}function Haa(a,b){var c=0,d=0,e=0,f=0;c=P7(a,qb(b));p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];d=p[qb(b)>>2];e=qb(c),f=d,p[e>>2]=f;e=qb(b),f=0,p[e>>2]=f;p[b>>2]=0;p[b+4>>2]=0;return a}function E4(a,b){a=a|0;b=b|0;p[a+4>>2]=b;n[a|0]=0;if(tf(p[p[b>>2]+ -12>>2]+b|0)){if(p[(p[p[b>>2]+ -12>>2]+b|0)+72>>2]){sE(p[(p[p[b>>2]+ -12>>2]+b|0)+72>>2])}n[a|0]=1}return a|0}function t8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;YF(b,c,d,t[a+24>>2]);TF(a,b,c,d);p[e+8>>2]=p[a+20>>2];b=p[a+16>>2];p[e>>2]=p[a+12>>2];p[e+4>>2]=b;fb=e+16|0}function rta(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(1199,a|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function RY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;m[p[p[a>>2]+12>>2]](d+8|0,a,b);a=d+8|0;if(me(p[a+4>>2],p[c+4>>2])){a=p[a>>2]==p[c>>2]}else{a=0}fb=d+16|0;return a|0}function Qoa(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(1399,a|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Poa(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(1400,a|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function E0(a,b){var c=0,d=0;c=fb-16|0;fb=c;if(ze(a)){Un(p[a>>2],Sj(a))}p[a+8>>2]=p[b+8>>2];d=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=d;cf(b,0);p[c+12>>2]=0;Je(b,c+12|0);fb=c+16|0}function CI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!Cg(a,b)){break a}c=Kw(a,p[De(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=De(a,b);KI(De(a,c),b);d=c}return d|0}function wfa(a){a=a|0;var b=0,c=w(0);n[a+4202|0]=1;b=a,c=Rm(w(w(w(He(p[a+16>>2])>>>0)*w(20938023226335645e-21))+w(-.005025125574320555)),w(0),w(1)),t[b+4272>>2]=c;gH(a);fH(a)}function tP(a){var b=0;b=p[a+4>>2];if(!b){if(!_g(a)){while(1){a=p[a+8>>2];if(!_g(a)){continue}break}}return p[a+8>>2]}a=b;while(1){b=a;a=p[a>>2];if(a){continue}break}return b}function tG(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(2169,a|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function sG(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(2170,a|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function rG(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(2171,a|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function kca(a){var b=0,c=0;b=fb-32|0;fb=b;Gk(b);c=Ig(b);p[114610]=0;N(9,a|0,0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){Se(b);fb=b+32|0;return}a=I()|0;H()|0;Se(b);L(a|0);E()}function hI(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Ic(c+8|0,b);Vs(d);if(p[a>>2]==(b|0)){p[a>>2]=p[d>>2]}e=qb(a);p[e>>2]=p[e>>2]+ -1;pja(p[_b(a)>>2],b);fb=c+16|0;return p[d>>2]}function Txa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-80|0;fb=d;c=d;e=zxa(a,d);if(!e){gQ(c)}c=-1;a:{if(!e){break a}c=0;if(!$M(d)){break a}c=Ve(a,b,_M(d),ib)}fb=d+80|0;return c|0}function Sfa(a){var b=0,c=0;b=p[a+16>>2];c=b+ -1|0;p[a+16>>2]=c;if((b|0)<=0){p[a+16>>2]=c+p[a+12>>2]}b=p[a+20>>2];c=b+ -1|0;p[a+20>>2]=c;if((b|0)<=0){p[a+20>>2]=c+p[a+12>>2]}}function PY(a,b){var c=0,d=0,e=0;c=fb-1040|0;fb=c;e=p[114584];d=OY(TY(b,c+16|0),c+16|0);if(!q[d|0]){p[c>>2]=b;fv(c+16|0,1024,70892,c);d=c+16|0}p[114584]=e;Mb(a,d);fb=c+1040|0}function wza(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(83,a|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function wL(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;if(r[a+28>>1]!=(b|0)){ks(a+12|0);o[a+28>>1]=b}c=a+12|0;if(cd(c)){yL(c,Px(a,r[kc(Po(a),b)>>1]))}msa(c,d+12|0);fb=d+16|0}function rja(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(1623,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function pza(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(84,a|0,b+12|0,b+8|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function gpa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(1384,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function QBa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-128|0;fb=d;c=d;e=wBa(a,d);if(!e){vO(c)}c=-1;a:{if(!e){break a}c=0;if(!BO(d)){break a}c=Ve(a,b,256,0)}fb=d+128|0;return c|0}function Gua(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(1169,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Gra(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(1259,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Fma(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(1527,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function $oa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(1388,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function zGa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(733,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function y9(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(2202,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function xDa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(834,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function wga(a,b,c){var d=0;d=fb-16|0;fb=d;Lga(d,b,c);p[114610]=0;N(13,a|0,0,d|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(d);fb=d+16|0;return}a=I()|0;H()|0;pb(d);L(a|0);E()}function w9(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(2204,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function uW(a,b,c,d){var e=0;if(!d){return-1}b=(4294967295<b>>>0?0:b)+a|0;e=-1;a:{while(1){if((a|0)==(b|0)){break a}b=b+ -1|0;if(!Kn(c,d,b)){continue}break}e=b-a|0}return e}function nx(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(1431,a|0,c+12|0,c+8|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function bR(a){a:{if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=-28163770){break a}if(hd(a+44|0,12960,3)){break a}a=a+47|0;return(q[a|0]|q[a+1|0]<<8)>>>0>97}return 0}function Vza(a,b){a=a|0;b=b|0;var c=0,d=0;c=1;d=a;a=b+47|0;b=Tc(d,q[a|0]&4?16:8,1,0,0);a:{b:{if(q[a|0]&8){break b}c=2;if(q[a|0]&16){break b}if(q[a|0]&127){break a}}lj(b,c)}}function Rn(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=NNa(a,0,b,0);e=ib;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=fd(b);if(!(!a|!(q[a+ -4|0]&3))){Jb(a,0,b)}return a}function NQ(a,b){var c=0;c=fb-32|0;fb=c;p[c+24>>2]=a;p[c+28>>2]=b;p[c+16>>2]=0;p[c+20>>2]=0;p[c+8>>2]=-1;p[c+12>>2]=0;a=KQ(c+16|0,qz(c+24|0,c+8|0));fb=c+32|0;return p[a>>2]}function KB(a){var b=0;a:{if(!(s[a>>2]<=18285140|s[a>>2]>=18350592)){b=1;if(p[a>>2]!=18350080){break a}}a=p[a>>2];b=0;if(a>>>0<=18350592){break a}b=(a|0)!=(a&-256)}return b}function IJa(a,b){a=a|0;b=b|0;n[b|0]=0;n[b+1|0]=0;n[b+2|0]=0;n[b+3|0]=0;n[b+4|0]=0;n[b+5|0]=0;n[b+4|0]=6;n[b+5|0]=0;n[b|0]=67633152;n[b+1|0]=264192;n[b+2|0]=1032;n[b+3|0]=4}function Hsa(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c>>2]=b;p[c+8>>2]=a;if(Ab(c+8|0,c)){while(1){d=u[p[c+8>>2]>>3]+d;Sx(c+8|0);if(Ab(c+8|0,c)){continue}break}}fb=c+16|0;return d}function GC(a){a=a|0;var b=0,c=0;p[a>>2]=62400;b=a+16|0;while(1){if(c>>>0<Bb(b)>>>0){if(p[Fb(b,c)>>2]){Rl(p[Fb(b,c)>>2])}c=c+1|0;continue}break}pb(a+176|0);UC(b);return a|0}function Aba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;Lc(a+12|0,0,0);d=a+20|0;c=d;e=c+16|0;while(1){c=lk(c)+4|0;if((e|0)!=(c|0)){continue}break}FJ(d+16|0,b);p[a+40>>2]=1;return a|0}function zba(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(2139,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function yca(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;if(c){while(1){f=is(qb(a),c+16|0,b);d=f?d:c;c=p[(f?4:0)+c>>2];if(c){continue}break}}a=p[Ic(e+8|0,d)>>2];fb=e+16|0;return a}function xpa(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(1375,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function xba(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(2140,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function vja(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;if(c){while(1){f=Hr(qb(a),c+16|0,b);d=f?d:c;c=p[(f?4:0)+c>>2];if(c){continue}break}}a=p[Ic(e+8|0,d)>>2];fb=e+16|0;return a}function uGa(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;if(c){while(1){f=jn(qb(a),c+16|0,b);d=f?d:c;c=p[(f?4:0)+c>>2];if(c){continue}break}}a=p[Ic(e+8|0,d)>>2];fb=e+16|0;return a}function pta(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(1201,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function pga(a,b,c){var d=0;d=fb-16|0;fb=d;yw(d,b,c);p[114610]=0;N(13,a|0,0,d|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(d);fb=d+16|0;return}a=I()|0;H()|0;pb(d);L(a|0);E()}function oV(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(286,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function mp(a){var b=0,c=0;c=p[a+4>>2];b=p[c>>2];p[a+4>>2]=b;if(b){hn(b,a)}p[c+8>>2]=p[a+8>>2];a:{if(_g(a)){b=p[a+8>>2];break a}b=p[a+8>>2]+4|0}p[b>>2]=c;p[c>>2]=a;hn(a,c)}function lp(a){var b=0,c=0;c=p[a>>2];b=p[c+4>>2];p[a>>2]=b;if(b){hn(b,a)}p[c+8>>2]=p[a+8>>2];a:{if(_g(a)){b=p[a+8>>2];break a}b=p[a+8>>2]+4|0}p[b>>2]=c;p[c+4>>2]=a;hn(a,c)}function lha(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(1758,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function hoa(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(1423,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function fga(a,b,c){var d=0;d=fb-16|0;fb=d;Ar(d,b,c);p[114610]=0;N(13,a|0,0,d|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(d);fb=d+16|0;return}a=I()|0;H()|0;pb(d);L(a|0);E()}function Vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;p[c+12>>2]=b;d=c,e=DR(Ub(a),Vb(a),c+12|0),p[d+8>>2]=e;d=c,e=Vb(a),p[d>>2]=e;a=Ab(c+8|0,c);fb=c+16|0;return a|0}function Pea(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(2003,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Gaa(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(2177,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function FV(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(280,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Ega(a,b,c){var d=0;d=fb-16|0;fb=d;wH(d,b,c);p[114610]=0;N(13,a|0,0,d|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(d);fb=d+16|0;return}a=I()|0;H()|0;pb(d);L(a|0);E()}function Bba(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(2138,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function $V(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;P(274,a|0,d+12|0,c|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function xha(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;p[c+12>>2]=0;d=c+12|0;n[d|0]=b;n[d+1|0]=b>>>8;n[d+2|0]=b>>>16;n[d+3|0]=b>>>24;a=EH(a,c+12|0);fb=c+16|0;return a|0}function pe(a,b){var c=0;c=p[a>>2];p[a>>2]=b;a:{if(!c){break a}a=p[_b(a)>>2];p[114610]=0;S(a|0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){break a}a=O(0)|0;H()|0;rb(a);E()}}function o4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=Wn(d,a);FC(a,c);p[114610]=0;K(2313,b|0,1);a=p[114610];p[114610]=0;if((a|0)==1){a=I()|0;H()|0;Gb(d);L(a|0);E()}}function mK(a,b,c){a=a|0;b=b|0;c=c|0;a=p[c+4>>2];p[b>>2]=p[c>>2];p[b+4>>2]=a;a=p[c+20>>2];p[b+16>>2]=p[c+16>>2];p[b+20>>2]=a;a=p[c+12>>2];p[b+8>>2]=p[c+8>>2];p[b+12>>2]=a}function Xq(a,b){var c=0,d=0,e=0;e=a;a:{if(b>>>0<=31){c=p[a>>2];d=p[a+4>>2];break a}c=p[a+4>>2];p[a+4>>2]=0;p[a>>2]=c;b=b+ -32|0;d=0}p[e+4>>2]=d>>>b;p[a>>2]=d<<32-b|c>>>b}function Nx(a,b,c){var d=0,e=0,f=0;d=fb-32|0;fb=d;p[d+16>>2]=c;p[d+24>>2]=b;e=d,f=wd(a),p[e+8>>2]=f;b=a;a=Mn(d+24|0,d+8|0);nW(b,a,Mn(d+16|0,d+24|0));lf(d+8|0,a);fb=d+32|0}function KNa(a,b,c){var d=0,e=0;d=b>>31;e=a^d;a=b>>31;LNa(e-d|0,(b^a)-((e>>>0<d>>>0)+a|0)|0,c,0-(c>>>0<0)|0);ib=hb;b=d^gb;c=b-d|0;ib=(a^ib)-((b>>>0<d>>>0)+a|0)|0;return c}function qva(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(97,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function kW(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(268,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function k$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=p[b>>2];if(a>>>0<=127){a=p[vq()+(p[b>>2]<<2)>>2]}p[d>>2]=a;b=b+4|0;continue}break}return c|0}function i$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=p[b>>2];if(a>>>0<=127){a=p[uq()+(p[b>>2]<<2)>>2]}p[d>>2]=a;b=b+4|0;continue}break}return c|0}function fca(a){var b=0;b=fb-16|0;fb=b;kq(b,0,7349);p[114610]=0;N(9,a|0,0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);fb=b+16|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function dca(a){var b=0;b=fb-16|0;fb=b;kq(b,0,9345);p[114610]=0;N(9,a|0,0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);fb=b+16|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function RR(a,b,c){var d=0;d=q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24);b=q[b+4|0]|q[b+5|0]<<8|(q[b+6|0]<<16|q[b+7|0]<<24);p[a>>2]=d;p[a+4>>2]=b;Ml(a+8|0,c);return a}function JEa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=m[p[p[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Aya(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;p[c+12>>2]=b;P(90,a|0,c+12|0,c+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=c+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function nxa(a,b){a=a|0;b=b|0;var c=0,d=0;c=Ee(2500);p[114610]=0;b=P(92,c|0,b|0,0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){qva(a,b);return}a=I()|0;H()|0;Nb(c);L(a|0);E()}function mx(a){var b=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(1432,a|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function mo(a){var b=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(2176,a|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function iia(a,b){var c=0;c=fb-16|0;fb=c;Sja(c,b);p[114610]=0;N(13,a|0,0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function hd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=q[a|0];e=q[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c+ -1|0;if(c){continue}break a}break}f=d-e|0}return f}function dp(a,b,c){var d=0;d=q[a|0]|q[a+1|0]<<8;if(((d<<24|d<<8&16711680)>>>16|0)>=(b|0)){a=q[a|0]|q[a+1|0]<<8;a=((a<<24|a<<8&16711680)>>>16|0)<=(c|0)}else{a=0}return a}function Mha(a,b){var c=0;c=fb-16|0;fb=c;lja(c,b);p[114610]=0;N(13,a|0,0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function FM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;if((b|0)!=(c|0)){while(1){p[d+12>>2]=p[b>>2];jy(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}fb=d+16|0}function xc(a,b){var c=0,d=0;c=fb-16|0;fb=c;if(p[a+4>>2]==p[b+4>>2]){d=p[b+4>>2];b=p[b>>2];p[c>>2]=b;p[c+4>>2]=d;p[c+8>>2]=b;p[c+12>>2]=d;d=!D9(a,c)}fb=c+16|0;return d}function sxa(a,b){var c=0;c=fb-16|0;fb=c;xh(c+8|0,b);p[114610]=0;a=J(1061,a|0,c+8|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function r8(a,b){a:{switch(p[a+40>>2]){case 0:p8(b,a);return;case 2:Yv(b,qb(a));return;case 3:o8(b,Ig(a));return;case 1:Yv(b,qb(a));return;default:break a}}Yv(b,qb(a))}function q8(a,b){a:{switch(p[a+40>>2]){case 0:j8(b,a);return;case 2:Xv(b,qb(a));return;case 3:i8(b,Ig(a));return;case 1:Xv(b,qb(a));return;default:break a}}Xv(b,qb(a))}function pF(a){var b=0,c=0;a:{if(q[a|0]!=255){break a}b=q[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=q[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function boa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;p[114610]=0;a=J(1425,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a|0}a=I()|0;H()|0;L(a|0);E()}function b8(a,b){a:{switch(p[a+40>>2]){case 0:er(b,a);return;case 2:er(b,qb(a));return;case 3:_7(b,Ig(a));return;case 1:er(b,qb(a));return;default:break a}}er(b,qb(a))}function aia(a,b){var c=0;c=fb-16|0;fb=c;lI(c,b);p[114610]=0;N(13,a|0,0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function a8(a,b){a:{switch(p[a+40>>2]){case 0:W7(b,a);return;case 2:Wv(b,qb(a));return;case 3:V7(b,Ig(a));return;case 1:Wv(b,qb(a));return;default:break a}}Wv(b,qb(a))}function ZT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;p[a>>2]=0;p[a+4>>2]=0;p[d+12>>2]=0;Oc(a+8|0,d+12|0,d+8|0);if(b){Np(a,b);xA(a,b,q[c|0])}fb=d+16|0;return a|0}function Z9(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if((bj(Ob(p[a>>2]+484360|0))|0)<=(b|0)){break a}c=r[kc(Ob(p[a>>2]+484360|0),b)>>1]}return c|0}function Vq(a,b){var c=0,d=0,e=0;e=a;a:{if(b>>>0<=31){c=p[a+4>>2];d=p[a>>2];break a}c=p[a>>2];p[a+4>>2]=c;p[a>>2]=0;b=b+ -32|0;d=0}p[e>>2]=d<<b;p[a+4>>2]=c<<b|d>>>32-b}function Vha(a,b){var c=0;c=fb-16|0;fb=c;Nw(c,b);p[114610]=0;N(13,a|0,0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function V8(a,b){a:{switch(p[a+40>>2]){case 0:T8(b,a);return;case 2:$v(b,qb(a));return;case 3:R8(b,Ig(a));return;case 1:$v(b,qb(a));return;default:break a}}$v(b,qb(a))}function U8(a,b){a:{switch(p[a+40>>2]){case 0:N8(b,a);return;case 2:_v(b,qb(a));return;case 3:L8(b,Ig(a));return;case 1:_v(b,qb(a));return;default:break a}}_v(b,qb(a))}function TH(a,b){var c=0;c=fb-16|0;fb=c;eka(c,b);p[114610]=0;N(13,a|0,0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(c);fb=c+16|0;return}a=I()|0;H()|0;pb(c);L(a|0);E()}function Pja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Os(p[b>>2]),p[d+12>>2]=e;p[c+8>>2]=0;d=a,e=p[Mx(c+12|0,c+8|0,32344)>>2],p[d+36>>2]=e;qo(a);fb=c+16|0}function JV(a){var b=0;b=fb-16|0;fb=b;p[114610]=0;p[b+12>>2]=0;P(278,a|0,b+12|0,b+8|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function Ema(a,b){var c=0;c=fb-16|0;fb=c;xh(c+8|0,b);p[114610]=0;a=J(1528,a|0,c+8|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function E8(a,b){a:{switch(p[a+40>>2]){case 0:fr(b,a);return;case 2:fr(b,qb(a));return;case 3:C8(b,Ig(a));return;case 1:fr(b,qb(a));return;default:break a}}fr(b,qb(a))}function D8(a,b){a:{switch(p[a+40>>2]){case 0:z8(b,a);return;case 2:Zv(b,qb(a));return;case 3:y8(b,Ig(a));return;case 1:Zv(b,qb(a));return;default:break a}}Zv(b,qb(a))}function sta(a,b){a=a|0;b=b|0;var c=0;c=rta(a);n[a+530|0]=0;p[114610]=0;K(1198,a|0,b|0);b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;gg(c);L(a|0);E()}function rKa(a,b,c){var d=0;if((b|0)>=1){while(1){d=p[c>>2];n[a|0]=d;n[a+1|0]=d>>>8;n[a+2|0]=d>>>16;n[a+3|0]=d>>>24;a=a+4|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function qta(a,b){var c=0,d=0;c=Ee(3848);b=p[b>>2];p[114610]=0;b=J(1200,c|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){pta(a,b);return}a=I()|0;H()|0;Nb(c);L(a|0);E()}function ci(a,b,c){var d=0;d=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=d;d=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=d;u[a>>3]=u[a>>3]-u[c>>3];u[a+8>>3]=u[a+8>>3]-u[c+8>>3]}function O7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){e=p[d>>2];while(1){cz(a,e,b);e=p[d>>2]+12|0;p[d>>2]=e;b=b+12|0;if((c|0)!=(b|0)){continue}break}}}function ILa(a,b){var c=0;c=fb-16|0;fb=c;fb=c+16|0;return(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))>>>0<(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))>>>0?b:a}function $ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=p[b+24>>2];g=p[b+8>>2];h=p[b+4>>2];i=p[b>>2];e=p[b+12>>2]}else{e=0}XG(a,i,h,g,e,f,b,c,d)}function vW(a,b,c,d){var e=0,f=0;f=-1;a:{if(0>=b>>>0){break a}e=b;b=a;e=e+b|0;while(1){if(Kn(c,d,b)){b=b+1|0;if((e|0)!=(b|0)){continue}break a}break}f=b-a|0}return f}function roa(a,b){var c=0,d=0;c=Ee(532);b=p[b>>2];p[114610]=0;b=J(1419,c|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){hoa(a,b);return}a=I()|0;H()|0;Nb(c);L(a|0);E()}function pba(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;p[e+8>>2]=p[b+8>>2];f=p[b+4>>2];p[e>>2]=p[b>>2];p[e+4>>2]=f;oba(a,e,c);t[a+24>>2]=d;p[a>>2]=84136;fb=e+16|0;return a}function nba(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;p[e+8>>2]=p[b+8>>2];f=p[b+4>>2];p[e>>2]=p[b>>2];p[e+4>>2]=f;mba(a,e,c);t[a+24>>2]=d;p[a>>2]=84208;fb=e+16|0;return a}function hGa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;fz(a,b,c);a=p[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function H3(a,b,c){var d=0,e=0,f=0;e=p[a+84>>2];d=c+256|0;f=$q(e,0,d);d=f?f-e|0:d;c=d>>>0<c>>>0?d:c;ac(b,e,c);b=e+d|0;p[a+84>>2]=b;p[a+8>>2]=b;p[a+4>>2]=c+e;return c}function $U(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;c=0;a=p[a+16>>2];if(a>>>0>b>>>0){p[d+8>>2]=a-b;c=p[Cb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function p5(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;b=l5(b);fb=d+16|0;p[c+8>>2]=b;p[c+12>>2]=ib;b=p[c+12>>2];p[a>>2]=p[c+8>>2];p[a+4>>2]=b;fb=c+16|0;return a}function osa(a,b){var c=0,d=0,e=0;csa(a);ql(a,b);p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];c=p[qb(b)>>2];d=qb(a),e=c,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function m5(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fb-16|0;fb=d;b=k5(b);fb=d+16|0;p[c+8>>2]=b;p[c+12>>2]=ib;b=p[c+12>>2];p[a>>2]=p[c+8>>2];p[a+4>>2]=b;fb=c+16|0;return a}function lya(a,b){var c=0,d=0,e=0;c=kya(a,qb(b));p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];a=p[qb(b)>>2];d=qb(c),e=a,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function esa(a,b){var c=0,d=0,e=0;d=a;c=p[a+4>>2];e=c>>>8|0;a=p[a>>2];c=(c&255)<<24|a>>>8;a=(((a^b)&255)<<3)+85504|0;b=p[a>>2];a=p[a+4>>2]^e;p[d>>2]=b^c;p[d+4>>2]=a}function cca(a){var b=0;b=fb-16|0;fb=b;jq(b,0);p[114610]=0;N(9,a|0,0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);fb=b+16|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function c$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=n[b|0];if((a|0)>=0){a=p[vq()+(n[b|0]<<2)>>2]}n[d|0]=a;b=b+1|0;continue}break}return c|0}function bca(a){var b=0;b=fb-16|0;fb=b;jq(b,2);p[114610]=0;N(9,a|0,0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);fb=b+16|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function aca(a){var b=0;b=fb-16|0;fb=b;jq(b,3);p[114610]=0;N(9,a|0,0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);fb=b+16|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function Ysa(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;d=b,e=NNa(p[a>>2],p[a+4>>2],1e3,0),p[d>>2]=e;p[b+4>>2]=ib;c=Zj(b+8|0,b);a=p[c>>2];fb=b+16|0;ib=p[c+4>>2];return a}function VN(a){if(!((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))!=541938512|(q[a+8|0]|q[a+9|0]<<8|(q[a+10|0]<<16|q[a+11|0]<<24))!=1162627398)){return 1}return 0}function Tza(a,b){var c=0,d=0,e=0;Sza(a);ql(a,b);p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];c=p[qb(b)>>2];d=qb(a),e=c,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function TV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;c=0;a=p[a+8>>2];if(a>>>0>b>>>0){p[d+8>>2]=a-b;c=p[Cb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function QM(a){var b=0,c=0;a:{if(q[a|0]!=255){break a}b=q[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=q[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function Ela(a,b){var c=0,d=0,e=0;Dla(a);ql(a,b);p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];c=p[qb(b)>>2];d=qb(a),e=c,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function Dma(a,b){a:{if(q[a+4|0]){a=p[a>>2];p[114610]=0;K(1525,a|0,b+16|0);a=p[114610];p[114610]=0;if((a|0)==1){break a}}if(b){gJ(b)}return}a=O(0)|0;H()|0;rb(a);E()}function $_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=n[b|0];if((a|0)>=0){a=p[uq()+(n[b|0]<<2)>>2]}n[d|0]=a;b=b+1|0;continue}break}return c|0}function qqa(a,b){var c=0,d=0,e=0;eL(a);ql(a,b);p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];c=p[qb(b)>>2];d=qb(a),e=c,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function oka(a,b){var c=0;nka(a,b);p[a+20>>2]=p[b+20>>2];c=p[b+16>>2];p[a+12>>2]=p[b+12>>2];p[a+16>>2]=c;mka(a+24|0,b+24|0);Wc(a+36|0,b+36|0);p[a+48>>2]=p[b+48>>2]}function nka(a,b){var c=0,d=0,e=0;c=xI(a,qb(b));p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];a=p[qb(b)>>2];d=qb(c),e=a,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function mka(a,b){var c=0,d=0,e=0;c=$S(a,qb(b));p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];a=p[qb(b)>>2];d=qb(c),e=a,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function l5(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;d=b,e=NNa(p[a>>2],p[a+4>>2],1e6,0),p[d>>2]=e;p[b+4>>2]=ib;c=Zj(b+8|0,b);a=p[c>>2];fb=b+16|0;ib=p[c+4>>2];return a}function k5(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;d=b,e=NNa(p[a>>2],p[a+4>>2],1e9,0),p[d>>2]=e;p[b+4>>2]=ib;c=Zj(b+8|0,b);a=p[c>>2];fb=b+16|0;ib=p[c+4>>2];return a}function cla(a,b){var c=0,d=0,e=0;II(a);ql(a,b);p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];c=p[qb(b)>>2];d=qb(a),e=c,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function Yk(a){a=a>>>1&1431655765|a<<1&-1431655766;a=a>>>2&858993459|a<<2&-858993460;a=a>>>4&252645135|a<<4&-252645136;return SNa(a>>>8&16711935|a<<8&-16711936,16)}function Ue(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;P(114,a|0,b+8|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){Sm(a);fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Nua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=up(q[a|0]+b|0),n[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Lsa(a,b){var c=0,d=0,e=0;c=CL(a,qb(b));p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];a=p[qb(b)>>2];d=qb(c),e=a,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function Go(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(!(p[a+480208>>2]&16)){break a}vb(b+8|0,a+1074308|0,7);if(!tb(b+8|0)){break a}c=p[a+480180>>2]!=4}fb=b+16|0;return c}function Gna(a,b){var c=0,d=0,e=0;nP(a);ql(a,b);p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];c=p[qb(b)>>2];d=qb(a),e=c,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function Fta(a,b){var c=0,d=0,e=0;c=gM(a,qb(b));p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];a=p[qb(b)>>2];d=qb(c),e=a,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function Fba(a,b){var c=0,d=0,e=0;_8(a);ql(a,b);p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];c=p[qb(b)>>2];d=qb(a),e=c,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function vxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=bn(a);p[114610]=0;N(91,a|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;be(d);L(a|0);E()}function pua(a,b,c){a:{if(!qs(b,c)){break a}while(1){if(r[oua(b)>>1]!=65535){break a}jM(b+4|0);if(qs(b,c)){continue}break}}c=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=c}function mca(a){var b=0;b=fb-16|0;fb=b;xW(b);p[114610]=0;N(9,a|0,0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);fb=b+16|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function ica(a){var b=0;b=fb-16|0;fb=b;JW(b);p[114610]=0;N(9,a|0,0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);fb=b+16|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function hca(a){var b=0;b=fb-16|0;fb=b;IW(b);p[114610]=0;N(9,a|0,0,b|0);a=p[114610];p[114610]=0;if((a|0)!=1){pb(b);fb=b+16|0;return}a=I()|0;H()|0;pb(b);L(a|0);E()}function cva(a,b,c,d){var e=0;a:{if(d==w(1)){break a}c=v(b,c);if(!c){break a}e=+d;b=0;while(1){u[a>>3]=u[a>>3]*e;a=a+8|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Lb(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;P(14,a|0,b+8|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){Sm(a);fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function LG(a,b){var c=0,d=0,e=0,f=0;c=p[a+24>>2];if((c|0)==p[a+28>>2]){return e=a,f=og(b),d=p[p[a>>2]+52>>2],m[d](e|0,f|0)|0}p[a+24>>2]=c+1;n[c|0]=b;return og(b)}function JG(a){a=a|0;var b=0,c=0,d=0;b=Ee(1304568);p[114610]=0;c=M(2134,b|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){Bba(a,c);return}a=I()|0;H()|0;Nb(b);L(a|0);E()}function Hd(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=b;p[114610]=0;Yn(a,d+12|0,c);b=p[114610];p[114610]=0;if((b|0)!=1){fb=d+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function FN(a,b){var c=0,d=0,e=0;c=HN(a,qb(b));p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];a=p[qb(b)>>2];d=qb(c),e=a,p[d>>2]=e;d=qb(b),e=0,p[d>>2]=e;p[b>>2]=0;p[b+4>>2]=0}function $J(a){p[a>>2]=0;p[a+4>>2]=0;p[a+88>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;BL(a+112|0,48e3);p[a+668>>2]=0;jx(a+724|0);jx(a+736|0);jx(a+748|0);jj(a+810|0);return a}function rca(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;g=p[a+12>>2];p[f+8>>2]=p[a+8>>2];p[f+12>>2]=g;g=p[a+4>>2];p[f>>2]=p[a>>2];p[f+4>>2]=g;ava(f,b,c,d,e);fb=f+16|0}function nT(a){var b=0,c=0;a:{if(hd(a,12061,3)){break a}b=a+3|0;if(q[b|0]<8|q[b|0]>14){break a}a=a+40|0;if(q[b|0]>9?!(q[a|0]<33?q[a|0]:0):0){break a}c=1}return c}function jF(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;P(197,a|0,c+8|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){Sm(a);fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function iw(a,b){var c=0;c=fb-16|0;fb=c;p[114610]=0;P(150,a|0,c+8|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){Sm(a);fb=c+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function hZ(a,b){a=a|0;b=b|0;Am(a);p[a>>2]=71388;b=Ib(b);p[114610]=0;J(2838,a+4|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;L(a|0);E()}function ec(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=p[a>>2];a=(f=d,g=p[a+8>>2],h=Tb(c+8|0,b),e=p[p[d>>2]+32>>2],m[e](f|0,g|0,h|0)|0);fb=c+16|0;return a}function bt(a){var b=0;b=fb-16|0;fb=b;Lc(b+8|0,a,0);p[114610]=0;N(674,b+8|0,110,0);a=p[114610];p[114610]=0;if((a|0)!=1){fb=b+16|0;return}a=O(0)|0;H()|0;rb(a);E()}function _o(a){p[a+8>>2]=0;p[a+12>>2]=0;p[a>>2]=128;p[a+4>>2]=256;p[a+32>>2]=363;p[a+36>>2]=952;p[a+16>>2]=48e3;p[a+20>>2]=2;p[a+24>>2]=128;p[a+28>>2]=0;return a}function Xc(a){var b=0,c=0;b=fb-16|0;fb=b;p[114610]=0;P(1,a|0,b+8|0,b|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){Sm(a);fb=b+16|0;return a}a=O(0)|0;H()|0;rb(a);E()}function Sb(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Hb(a,b);if(c){p[a+8>>2]=p[a+8>>2]+b;return c|0}b=a;a=p[a>>2];d=b,e=m[p[p[a>>2]+24>>2]](a)|0,p[d+8>>2]=e;return c|0}function Ee(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=fd(a);if(b){break a}b=p[115919];if(b){m[b|0]();continue}break}a=W(4)|0;Kk(a);ba(a|0,71348,2008);E()}return b|0}function nua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;o[d+12>>1]=c;o[d+14>>1]=b;Lg(d+14|0,r[p[p[a+24>>2]+8>>2]+12>>1]);mua(a,r[d+14>>1],d+12|0);fb=d+16|0}function lma(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;f=ke(b);e=p[c+4>>2];c=p[c>>2];p[d>>2]=c;p[d+4>>2]=e;p[d+8>>2]=c;p[d+12>>2]=e;kma(a,b,f+ -1&65535,d);fb=d+16|0}function iY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;p[d+12>>2]=p[c>>2];a=m[p[p[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){p[c>>2]=p[d+12>>2]}fb=d+16|0;return a|0}function aBa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-80|0;fb=d;c=-1;a:{if(!IR(a,d+8|0)){break a}c=0;if(!oO(d+8|0)){break a}c=Ve(a,b,mO(d+8|0),ib)}fb=d+80|0;return c|0}function XM(a,b){var c=0;c=p[a+4>>2];a:{if((b|0)>=0){b=b+c|0;p[a>>2]=p[a>>2]+(b>>>3&536870908);break a}b=b+c|0;p[a>>2]=p[a>>2]+((b+ -31|0)/32<<2)}p[a+4>>2]=b&31}function Uv(a,b,c){b=(b+9|0)%12|0;a=((b|0)/-10|0)+a|0;return(((((((a|0)/4|0)+c|0)+v(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((v(b,306)+5|0)/10|0)|0)+ -1|0}function NO(a){if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))==1297239878){return(q[a+8|0]|q[a+9|0]<<8|(q[a+10|0]<<16|q[a+11|0]<<24))==1279545165}return 0}function Mma(a){iJ();Ye(219712,285248,a+131112|0);Ye(285248,350784,a+196648|0);Ye(350784,416320,a+262184|0);Ye(88624,219712,a+24|0);ac(a+327720|0,416320,40960)}function JY(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){eC();c=85304;break a}b:{if(n[463660]&1){break b}if(!nd(463660)){break b}md(463660)}c=85300}Lc(a,b,c)}function Ip(a,b,c){a=a|0;b=b|0;c=c|0;n[a+11|0]=c;n[a+10|0]=b;n[a+12|0]=q[a+12|0]&251;o[a+8>>1]=65535;p[a>>2]=0;p[a+4>>2]=0;n[a+12|0]=q[a+12|0]&252|1;return a|0}function HH(a,b){var c=0;c=fb-16|0;fb=c;p[c+12>>2]=b;p[c+8>>2]=127;b=Cb(c+12|0,c+8|0);t[p[a+20>>2]+144>>2]=w(w(s[b>>2])*w(-.007874015718698502))+w(1);fb=c+16|0}function zJa(a,b){a=a|0;b=b|0;var c=0;pR(a);c=b+4|0;xJa(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];si(a);zl(a);zl(a)}function pha(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=b+1304396|0;if(!kd(d)){oha(c+8|0);_J(d,Cd(c+8|0));Tr(c+8|0)}a=nha(p[d>>2],a,b);fb=c+16|0;return a|0}function mla(a,b,c){a:{if(!b){break a}if(c>>>0<b>>>0|s[p[Em(a)+8>>2]+40>>2]<b>>>0){break a}if(s[p[Em(a)+8>>2]+40>>2]<c>>>0){break a}p[a+20>>2]=c;p[a+16>>2]=b}}function lB(a){a=a|0;var b=0,c=0;b=Xc(a);p[114610]=0;M(277,a+12|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){JV(a+28|0);return a|0}a=I()|0;H()|0;pb(b);L(a|0);E()}function eZ(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(ze(a)){d=p[a>>2];n[c+15|0]=0;ae(b+d|0,c+15|0);oe(a,b);break a}n[c+14|0]=0;ae(a+b|0,c+14|0);cf(a,b)}fb=c+16|0}function am(a){a=a|0;var b=0;b=W(8)|0;p[114610]=0;J(2062,b|0,a|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){ba(b|0,71676,265);E()}a=I()|0;H()|0;X(b|0);L(a|0);E()}function _C(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=fb-16|0;fb=a;p[a+8>>2]=b;while(1){if(c>>>0<d>>>0){ZC(a+8|0,c);c=c+1|0;continue}break}fb=a+16|0;return p[a+8>>2]}function Dza(a,b){a=a|0;b=b|0;var c=0;PN(a);c=b+4|0;yza(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];ak(a);cn(a);cn(a)}function $Ea(a,b){a=a|0;b=b|0;var c=0;UP(a);c=b+4|0;VEa(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];gk(a);vl(a);vl(a)}function xBa(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;jBa(b,c);c=Hb(a,c<<3);if(c){e=fb-16|0;fb=e;Zb(d+8|0,p[b>>2],ng(b)<<3);fb=e+16|0;yd(a,d+8|0)}fb=d+16|0;return c}function tna(a){var b=0;a:{if(!p[a+16>>2]){break a}b=p[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=p[a+28>>2];if(a>>>0>4){break a}return 23>>>(a&31)&1}return 0}function ria(a,b){a=a|0;b=b|0;var c=0;RH(a);c=b+4|0;ui(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];$e(a);Oj(a);Oj(a)}function mm(a,b){var c=0;c=p[p[b>>2]+ -12>>2];p[114610]=0;b=p[(b+c|0)+24>>2];c=p[114610];p[114610]=0;if((c|0)!=1){p[a>>2]=b;return a}a=O(0)|0;H()|0;rb(a);E()}function k3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=p[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function fH(a){a=a|0;var b=0;p[a+4240>>2]=0;p[a+4244>>2]=0;b=a+4264|0;p[b>>2]=0;p[b+4>>2]=0;b=a+4256|0;p[b>>2]=0;p[b+4>>2]=0;a=a+4248|0;p[a>>2]=0;p[a+4>>2]=0}function K_(a){a=a|0;var b=0;a=p[a+8>>2];if(!a){return 1}p[114610]=0;a=M(2576,a|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=O(0)|0;H()|0;rb(a);E()}function GNa(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(!b){break a}if(!Hb(a,b)){break a}n[c+15|0]=0;Kf(a,c+15|0);n[c+8|0]=q[c+15|0];d=q[c+8|0]}fb=c+16|0;return d}function FNa(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(!b){break a}if(!Hb(a,b)){break a}n[c+15|0]=0;Kf(a,c+15|0);n[c+8|0]=q[c+15|0];d=n[c+8|0]}fb=c+16|0;return d}function D$(){var a=0,b=0;Bd(463120);p[115780]=62472;p[114610]=0;a=Y(2445)|0;b=p[114610];p[114610]=0;if((b|0)!=1){p[115782]=a;return}a=I()|0;H()|0;L(a|0);E()}function qh(a){var b=0,c=0;b=a*a;c=b*a;return w(c*(b*b)*(b*2718311493989822e-21+ -.00019839334836096632)+(c*(b*.008333329385889463+ -.16666666641626524)+a))}function n3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=n[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function jva(a,b,c,d,e){var f=0;if(d){while(1){t[b>>2]=w(p[a>>2])*e;t[c>>2]=w(p[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function S4(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e+12>>2]=d;d=wb(b);if(d>>>0<c>>>0){Yl();E()}b=Ib(b);p[e+4>>2]=d-c;ap(a,b+c|0,p[Cb(e+12|0,e+4|0)>>2]);fb=e+16|0}function Ppa(a){var b=0,c=0;b=250;c=a;a:{while(1){if(p[c>>2]){break a}c=c+4|0;b=b+ -32|0;if(b>>>0>31){continue}break}return(p[a+28>>2]&67108863)!=0}return 1}function Aw(a){var b=0,c=0,d=0;b=p[a+4284>>2];p[a+4272>>2]=p[a+4280>>2];p[a+4276>>2]=b;c=a,d=+w(w($ha(a+4296|0)|0)*w(-4.656612873077393e-10)),u[c+4280>>3]=d}function $ma(a,b,c){var d=0,e=0;d=b-a|0;if((d|0)>=3){d=d>>>1|0;while(1){oJ(a,b+ -2|0);bx(a,c,d+ -1|0,a);b=b+ -2|0;e=(d|0)>2;d=d+ -1|0;if(e){continue}break}}}function yf(a,b,c){a:{switch(b+ -1|0){case 0:if(c){return hi(a,1)}return hi(a,0);case 1:if(c){return hi(a,3)}return hi(a,2);default:break a}}return hi(a,4)}function s1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=m[p[p[a+8>>2]+20>>2]](a+8|0)|0;return Li(g,b,c,d,e,f,Ib(a),Ib(a)+(wb(a)<<2)|0)|0}function rW(a,b,c,d){var e=0;e=(4294967295<b>>>0?0:b)+a|0;b=-1;a:{while(1){if((a|0)==(e|0)){break a}e=e+ -1|0;if(Kn(c,d,e)){continue}break}b=e-a|0}return b}function qB(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0;n[a+8|0]=0;n[a+9|0]=0;fb=b+16|0}function ik(a,b,c,d){p[d+8>>2]=b;p[d>>2]=0;p[d+4>>2]=0;p[c>>2]=d;if(p[p[a>>2]>>2]){p[a>>2]=p[p[a>>2]>>2]}yGa(p[_b(a)>>2],p[c>>2]);a=qb(a);p[a>>2]=p[a>>2]+1}function iP(a){var b=0;a:{if(hd(a,15498,3)){break a}b=a+4|0;if((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))>>>0<423){break a}return q[a+3|0]<6}return 0}function hza(a,b){var c=0,d=0;if(ke(a)>>>0>b>>>0){while(1){if(Ch(De(a,c))){gza(Ub(De(a,c)),Vb(De(a,c)))}d=d+1|0;c=d&65535;if(c>>>0<=b>>>0){continue}break}}}function Xj(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;if(s[b+4>>2]<0){Hi(20276);E()}c=p[b>>2];p[d+8>>2]=p[b+4>>2];Lc(a,c,p[Cb(d+12|0,d+8|0)>>2]);fb=d+16|0}function TL(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;p[c+12>>2]=b;a:{if(aj(a)){qta(c+8|0,c+12|0);vs(a,c+8|0);gg(c+8|0);break a}_L(p[a>>2],b)}SL(a);fb=c+16|0}function Mt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;n[d+15|0]=b;n[d+14|0]=127;e=a,f=q[hc(d+15|0,d+14|0)|0]|(c?-128:0),n[e+21|0]=f;fb=d+16|0}function Lt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;n[d+15|0]=b;n[d+14|0]=127;e=a,f=q[hc(d+15|0,d+14|0)|0]|(c?-128:0),n[e+22|0]=f;fb=d+16|0}function Dg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=p[a>>2];return(f=d,g=ub(b),h=p[a+8>>2],i=c,e=p[p[d>>2]+28>>2],m[e](f|0,g|0,h|0,i|0)|0)|0}function C6(a,b,c,d){var e=0,f=0,g=w(0);if((b|0)>=1){while(1){f=(e<<2)+a|0;g=t[f>>2];t[f+2304>>2]=g*d;t[f>>2]=g*c;e=e+1|0;if((e|0)!=(b|0)){continue}break}}}function yga(a,b,c){a=a|0;b=b|0;c=w(c);var d=0;d=fb-16|0;fb=d;t[d+12>>2]=c;if((b|0)<=4){Td(d+12|0,w(0));p[((b<<2)+a|0)+4208>>2]=p[d+12>>2];pH(a)}fb=d+16|0}function xfa(a,b,c){a=a|0;b=b|0;c=w(c);var d=0;d=fb-16|0;fb=d;t[d+12>>2]=c;if((b|0)<=2){Td(d+12|0,w(0));p[((b<<2)+a|0)+4208>>2]=p[d+12>>2];gH(a)}fb=d+16|0}function sba(a,b,c){jr(a);p[a+8>>2]=c;p[a+4>>2]=0;p[a>>2]=84016;c=p[b+4>>2];p[a+12>>2]=p[b>>2];p[a+16>>2]=c;c=p[b+12>>2];p[a+20>>2]=p[b+8>>2];p[a+24>>2]=c}function qba(a,b,c){jr(a);p[a+8>>2]=c;p[a+4>>2]=0;p[a>>2]=84112;c=p[b+4>>2];p[a+12>>2]=p[b>>2];p[a+16>>2]=c;c=p[b+12>>2];p[a+20>>2]=p[b+8>>2];p[a+24>>2]=c}function pfa(a,b,c){a=a|0;b=b|0;c=w(c);var d=0;d=fb-16|0;fb=d;t[d+12>>2]=c;if((b|0)<=3){Td(d+12|0,w(0));p[((b<<2)+a|0)+4208>>2]=p[d+12>>2];eH(a)}fb=d+16|0}function bL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(p[a+480180>>2]&2){break a}}p[b+56>>2]=0;d=No(a,r[b+60>>1],p[b+48>>2],c,0)}return d|0}function ata(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+8>>2]=c;p[d>>2]=b;if(Ab(d,d+8|0)){while(1){KL(a,q[p[d>>2]]);bg(d);if(Ab(d,d+8|0)){continue}break}}fb=d+16|0}function aV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=p[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function _j(a,b){var c=0,d=0;a:{b=$j(a,b);if((b|0)==255){break a}if(aj(a)){break a}c=a+4|0;d=Yb(c,b);n[d|0]=q[d|0]&223;Yg(p[a>>2],ms(b)|176,q[Yb(c,b)|0])}}function Y9(a,b){a=a|0;b=b|0;var c=0;a:{if(!kr(b)){break a}a=a+24|0;if(!Cg(p[a>>2]+484344|0,b&65535)){break a}c=p[Rb(p[a>>2]+484344|0,b)+12>>2]}return c|0}function NE(a){var b=0,c=0,d=0;if(Sg(n[p[a>>2]])){while(1){b=p[a>>2];d=n[b|0];p[a>>2]=b+1;c=(v(c,10)+d|0)+ -48|0;if(Sg(n[b+1|0])){continue}break}}return c}function Kga(a,b,c){a=a|0;b=b|0;c=w(c);var d=0;d=fb-16|0;fb=d;t[d+12>>2]=c;if((b|0)<=5){Td(d+12|0,w(0));p[((b<<2)+a|0)+4208>>2]=p[d+12>>2];sH(a)}fb=d+16|0}function I2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;p[e+12>>2]=b;p[e+8>>2]=d;b=lh(e,e+12|0);a=MD(a,c,p[e+8>>2]);ye(b);fb=e+16|0;return a|0}function FEa(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=p[d>>2];while(1){c=c+ -24|0;JP(a,e+ -24|0,c);e=p[d>>2]+ -24|0;p[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function Eta(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=p[d>>2];while(1){c=c+ -32|0;dM(a,e+ -32|0,c);e=p[d>>2]+ -32|0;p[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function Dk(a,b){var c=0;c=p[p[b>>2]+ -12>>2];p[114610]=0;b=M(27,b+c|0)|0;c=p[114610];p[114610]=0;if((c|0)!=1){p[a>>2]=b;return a}a=O(0)|0;H()|0;rb(a);E()}function Dba(a,b){var c=0,d=0;c=Ee(44);p[114610]=0;b=J(2135,c|0,b|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){zba(a,b);return}a=I()|0;H()|0;Nb(c);L(a|0);E()}function CKa(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=p[d>>2];while(1){c=c+ -24|0;rn(a,e+ -24|0,c);e=p[d>>2]+ -24|0;p[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function nC(a,b){a=a|0;b=b|0;Am(a);p[a>>2]=71388;p[114610]=0;J(2838,a+4|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a|0}a=I()|0;H()|0;L(a|0);E()}function il(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=p[a+1074400>>2];d=p[a+1074416>>2];p[b+12>>2]=1;a=p[Uc(a+1074396|0,b+12|0)>>2];fb=b+16|0;return v(a,c+d|0)}function hr(a){var b=0,c=0,d=0;b=SNa(p[a>>2],1)^270549120;c=p[a+4>>2];d=(b+(c<<2)|0)+2019860093|0;p[a>>2]=d;b=a;a=v(SNa(d,16),5)+c|0;p[b+4>>2]=a;return a}function g9(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=p[d>>2];while(1){c=c+ -16|0;aG(a,e+ -16|0,c);e=p[d>>2]+ -16|0;p[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function Z3(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=p[d>>2];while(1){c=c+ -12|0;rv(a,e+ -12|0,c);e=p[d>>2]+ -12|0;p[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function UV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=p[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function Pv(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=w(w(t[((c&3)<<2)+43488>>2]*a)*w(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function Ii(a,b,c,d){var e=0,f=0;e=v(b,c);f=e;a:{if(p[d+76>>2]<=-1){a=Au(a,e,d);break a}a=Au(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function IFa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=-1;a:{if(!oj(a,d+8|0)){break a}c=0;if(!GFa(d+8|0)){break a}c=Ve(a,b,36,0)}fb=d+16|0;return c|0}function BV(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=p[d>>2];while(1){c=c+ -32|0;gB(a,e+ -32|0,c);e=p[d>>2]+ -32|0;p[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function Ao(a,b){var c=0;p[a>>2]=76688;p[a>>2]=77104;c=p[b+8>>2];p[a+4>>2]=p[b+4>>2];p[a+8>>2]=c;c=p[b+16>>2];p[a+12>>2]=p[b+12>>2];p[a+16>>2]=c;return a}function yIa(a,b){a=a|0;b=b|0;var c=0;Hk(a);c=b+4|0;xIa(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];Vl(a,gd(a))}function vZ(a,b,c){var d=0;d=fb-16|0;fb=d;q3(d,b,c,de());b=p[d+4>>2];p[a>>2]=p[d>>2];p[a+4>>2]=b;b=p[d+12>>2];p[a+8>>2]=p[d+8>>2];p[a+12>>2]=b;fb=d+16|0}function tCa(a){var b=0,c=0,d=0;b=fb-1024|0;fb=b;if(WBa(a,b)){d=a;a=p[a+12>>2];c=a-1024|0;p[d+12>>2]=c>>>0>a>>>0?0:c;c=Gy(b)>>>0<17}fb=b+1024|0;return c}function ska(a,b){a=a|0;b=b|0;var c=0;IJ(a);c=b+4|0;pka(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];yI(a,of(a))}function rm(a,b){var c=0,d=0;b=b+7&-8;d=p[a+80>>2];a:{if(d){b=p[a+92>>2]-b|0;c=0;if((b|0)<p[a+88>>2]){break a}p[a+92>>2]=b;return b+d|0}c=fd(b)}return c}function pya(a,b){a=a|0;b=b|0;var c=0;Ri(a);c=b+4|0;nya(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];$n(a,nc(a))}function oha(a){var b=0,c=0,d=0;b=Ee(12);p[114610]=0;c=M(1752,b|0)|0;d=p[114610];p[114610]=0;if((d|0)!=1){lha(a,c);return}a=I()|0;H()|0;Nb(b);L(a|0);E()}function nqa(a){if(!(w(2147483648)>a)){return 2147483647}if(!(w(-2147483648)<a)){return-2147483648}if(w(x(a))<w(2147483648)){return~~a}return-2147483648}function _ra(a,b){a=a|0;b=b|0;var c=0;Ri(a);c=b+4|0;Yra(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];$n(a,nc(a))}function YE(a,b,c,d,e,f){var g=0,h=0;g=p[a+32>>2];h=g+(c<<2)|0;a:{if(!q[a+23|0]){break a}h=g;g=d<<2;p[h+g>>2]=b;n[p[a+8>>2]+d|0]=e;b=c;h=f+g|0}p[h>>2]=b}function Wia(a,b){a=a|0;b=b|0;var c=0;kf(a);c=b+4|0;Uia(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];Vj(a,Bb(a))}function W3(a,b){a=a|0;b=b|0;var c=0,d=0;b=jv(b);p[a+36>>2]=b;c=a,d=Hm(b),p[c+44>>2]=d;c=a,d=jm(p[a+36>>2]),n[c+53|0]=d;if(p[a+44>>2]>=9){am(56916);E()}}function Hta(a,b){a=a|0;b=b|0;var c=0;Nl(a);c=b+4|0;Eta(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];bq(a,ne(a))}function HEa(a,b){a=a|0;b=b|0;var c=0;Bh(a);c=b+4|0;FEa(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];st(a,Dd(a))}function Dya(a,b){a=a|0;b=b|0;var c=0;Ri(a);c=b+4|0;iya(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];$n(a,nc(a))}function $3(a,b){a=a|0;b=b|0;var c=0,d=0;b=kv(b);p[a+36>>2]=b;c=a,d=Hm(b),p[c+44>>2]=d;c=a,d=jm(p[a+36>>2]),n[c+53|0]=d;if(p[a+44>>2]>=9){am(56916);E()}}function xp(a,b){a=a|0;b=b|0;var c=0;Bh(a);c=b+4|0;CKa(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];st(a,Dd(a))}function lpa(a,b){a=a|0;b=b|0;var c=0;Nl(a);c=b+4|0;ui(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];bq(a,ne(a))}function f$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=p[b>>2];n[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function dBa(a,b){a=a|0;b=b|0;var c=0;eq(a);c=b+4|0;ui(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];gu(a,ng(a))}function WFa(a,b){a=a|0;b=b|0;var c=0;kt(a);c=b+4|0;$P(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];nt(a,Rf(a))}function Uia(a,b,c,d){var e=0;if((b|0)!=(c|0)){e=p[d>>2];while(1){c=c+ -4|0;dI(a,e+ -4|0,c);e=p[d>>2]+ -4|0;p[d>>2]=e;if((b|0)!=(c|0)){continue}break}}}function OL(a){var b=0,c=0,d=0;b=a+26|0;c=q[b|0]+27|0;if(q[b|0]){while(1){c=q[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<q[b|0]){continue}break}}return c&65535}function Iea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=c,e=lL(b),p[d+16>>2]=e;Gea(c+24|0,a,b,c+16|0,c+8|0);a=$g(c+24|0);fb=c+32|0;return a+12|0}function zxa(a,b){var c=0,d=0;c=fb-16|0;fb=c;fQ(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function zZ(a,b){a=a|0;b=b|0;var c=0;JC(a);c=b+4|0;ui(Nk(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(sq(a),Xb(b));p[b>>2]=p[b+4>>2];sC(a,Bb(a))}function yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(aE(a)>>>0<b>>>0){Vc();E()}qb(a);c=hL(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=v(b,12)+c|0,p[d>>2]=e;$n(a,0)}function yLa(a,b){var c=0,d=0;c=fb-16|0;fb=c;_p(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function xxa(a,b){var c=0,d=0;c=fb-16|0;fb=c;Qy(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function xLa(a,b){var c=0,d=0;c=fb-16|0;fb=c;Uz(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function wLa(a,b){var c=0,d=0;c=fb-16|0;fb=c;Uz(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function wBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;uO(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function vya(a,b){var c=0,d=0;c=fb-16|0;fb=c;jN(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function vNa(a,b){var c=0,d=0;c=fb-16|0;fb=c;vT(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function vBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;uO(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function uza(a,b){var c=0,d=0;c=fb-16|0;fb=c;DN(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function uya(a,b){var c=0,d=0;c=fb-16|0;fb=c;jN(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function uNa(a,b){var c=0,d=0;c=fb-16|0;fb=c;vT(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function tza(a,b){var c=0,d=0;c=fb-16|0;fb=c;DN(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function sla(a,b){var c=0,d=0;c=fb-16|0;fb=c;SI(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function rh(a,b,c){p[b+12>>2]=p[b+12>>2]+c;p[b+8>>2]=p[b+8>>2]-c;c=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=c;c=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=c}function rLa(a,b){var c=0,d=0;c=fb-16|0;fb=c;jS(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function qla(a,b){var c=0,d=0;c=fb-16|0;fb=c;SI(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function qLa(a,b){var c=0,d=0;c=fb-16|0;fb=c;jS(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function pJa(a,b){var c=0,d=0;c=fb-16|0;fb=c;iA(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function pIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;ZQ(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function oIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;ZQ(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function nza(a,b){var c=0,d=0;c=fb-16|0;fb=c;zN(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function nJa(a,b){var c=0,d=0;c=fb-16|0;fb=c;US(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function nGa(a,b){var c=0,d=0;c=fb-16|0;fb=c;yt(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function nBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;tO(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function nA(a,b){a=a|0;b=b|0;var c=0;Hp(a);c=b+4|0;ui(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];dA(a,Cc(a))}function mza(a,b){var c=0,d=0;c=fb-16|0;fb=c;zN(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function mIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;XQ(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function mGa(a,b){var c=0,d=0;c=fb-16|0;fb=c;yt(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function jKa(a,b){var c=0,d=0;c=fb-16|0;fb=c;JR(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function jA(a,b){a=a|0;b=b|0;var c=0;Ak(a);c=b+4|0;ui(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];Ut(a,fc(a))}function iKa(a,b){var c=0,d=0;c=fb-16|0;fb=c;JR(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function iIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;TQ(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function iEa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=c,e=ih(b),p[d+16>>2]=e;XDa(c+24|0,a,b,c+16|0,c+8|0);a=Ws(c+24|0);fb=c+32|0;return a+2|0}function hJa(a,b){var c=0,d=0;c=fb-16|0;fb=c;zz(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function hIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;TQ(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function h9(a,b){a=a|0;b=b|0;var c=0;Hk(a);c=b+4|0;g9(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];Vl(a,gd(a))}function gJa(a,b){var c=0,d=0;c=fb-16|0;fb=c;zz(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function fqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=c,e=lL(b),p[d+16>>2]=e;Upa(c+24|0,a,b,c+16|0,c+8|0);a=Ws(c+24|0);fb=c+32|0;return a+4|0}function fJa(a,b){var c=0,d=0;c=fb-16|0;fb=c;Mz(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function fE(a,b){a=a|0;b=b|0;var c=0;Ri(a);c=b+4|0;Z3(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];$n(a,nc(a))}function dCa(a,b){var c=0,d=0;c=fb-16|0;fb=c;JO(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function bX(a,b){a=a|0;b=b|0;var c=0;Hk(a);c=b+4|0;ui(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];Vl(a,gd(a))}function b9(a,b){a=a|0;b=b|0;var c=0;Bh(a);c=b+4|0;a9(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];st(a,Dd(a))}function aqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=c,e=ih(b),p[d+16>>2]=e;Spa(c+24|0,a,b,c+16|0,c+8|0);a=$g(c+24|0);fb=c+32|0;return a+8|0}function _ya(a,b){var c=0,d=0;c=fb-16|0;fb=c;HO(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function _sa(a,b){var c=0,d=0;c=fb-16|0;fb=c;JL(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function _Ba(a,b){var c=0,d=0;c=fb-16|0;fb=c;HO(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function ZHa(a,b){var c=0,d=0;c=fb-16|0;fb=c;OQ(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function ZFa(a,b){var c=0,d=0;c=fb-16|0;fb=c;fQ(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function YHa(a,b){var c=0,d=0;c=fb-16|0;fb=c;OQ(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function XBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;FO(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function Wg(a,b){a=a|0;b=b|0;var c=0;kf(a);c=b+4|0;ui(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];Vj(a,Bb(a))}function WLa(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;pU(b,c);c=Hb(a,c);if(c){e=fb-16|0;fb=e;Zb(d+8|0,p[b>>2],Cc(b));fb=e+16|0;yd(a,d+8|0)}fb=d+16|0;return c}function Vya(a,b){var c=0,d=0;c=fb-16|0;fb=c;XQ(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function TDa(a,b){var c=0,d=0;c=fb-16|0;fb=c;rP(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function TBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;FO(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function SEa(a,b){var c=0,d=0;c=fb-16|0;fb=c;Xy(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function RDa(a,b){var c=0,d=0;c=fb-16|0;fb=c;rP(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function OFa(a,b){var c=0,d=0;c=fb-16|0;fb=c;YP(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function NIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;fR(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function NEa(a,b){var c=0,d=0;c=fb-16|0;fb=c;Xz(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function MIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;fR(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function M1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=m[p[p[a+8>>2]+20>>2]](a+8|0)|0;return Mi(g,b,c,d,e,f,Ib(a),Ib(a)+wb(a)|0)|0}function LV(a,b){a=a|0;b=b|0;var c=0;Nl(a);c=b+4|0;BV(qb(a),p[a>>2],p[a+4>>2],c);Qb(a,c);Qb(a+4|0,b+8|0);Qb(qb(a),Xb(b));p[b>>2]=p[b+4>>2];bq(a,ne(a))}function KMa(a,b){var c=0,d=0;c=fb-16|0;fb=c;XS(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function Jc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(s[a+8>>2]<b>>>0){d=p[a>>2];c=0;if(m[p[p[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}p[a+8>>2]=b;c=1}return c|0}function JMa(a,b){var c=0,d=0;c=fb-16|0;fb=c;XS(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function IGa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=c,e=ih(b),p[d+16>>2]=e;CGa(c+24|0,a,b,c+16|0,c+8|0);a=$g(c+24|0);fb=c+32|0;return a+4|0}function Hi(a){var b=0;b=W(8)|0;p[114610]=0;J(214,b|0,a|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){ba(b|0,71608,24);E()}a=I()|0;H()|0;X(b|0);L(a|0);E()}function Gxa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{if(q[d|0]){Bxa(a,Ed(e+8|0,b),ki(c,b));break a}Axa(a,Ed(e,b),ki(c,b))}fb=e+16|0}function GMa(a,b){var c=0,d=0;c=fb-16|0;fb=c;VS(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function FMa(a,b){var c=0,d=0;c=fb-16|0;fb=c;VS(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function FLa(a,b){var c=0,d=0;c=fb-16|0;fb=c;Xz(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function ELa(a,b){var c=0,d=0;c=fb-16|0;fb=c;sS(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function DU(a,b,c){a=a+4|0;a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);return!c&(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))+ -8>>>0<=b>>>0|0<c>>>0}function DLa(a,b){var c=0,d=0;c=fb-16|0;fb=c;sS(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function CJa(a,b){var c=0,d=0;c=fb-16|0;fb=c;jt(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function BJa(a,b){var c=0,d=0;c=fb-16|0;fb=c;jt(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function BEa(a,b){var c=0,d=0;c=fb-16|0;fb=c;Wy(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function BAa(a,b){var c=0,d=0;c=fb-16|0;fb=c;$N(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function AAa(a,b){var c=0,d=0;c=fb-16|0;fb=c;$N(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function $ya(a,b){var c=0,d=0;c=fb-16|0;fb=c;zk(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function $Fa(a,b){var c=0,d=0;c=fb-16|0;fb=c;$y(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function $Ba(a,b){var c=0,d=0;c=fb-16|0;fb=c;JO(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function z9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){Jb(p[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function tc(a){var b=0;b=W(8)|0;p[114610]=0;J(23,b|0,a|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){ba(b|0,71556,24);E()}a=I()|0;H()|0;X(b|0);L(a|0);E()}function tN(a,b){var c=0,d=0;c=fb-16|0;fb=c;jh(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function r3(a,b,c){var d=0;d=fb-16|0;fb=d;av(d,b,c,2);b=p[d+4>>2];p[a>>2]=p[d>>2];p[a+4>>2]=b;b=p[d+12>>2];p[a+8>>2]=p[d+8>>2];p[a+12>>2]=b;fb=d+16|0}function qI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;d=c,e=ih(b),p[d+16>>2]=e;Vja(c+24|0,a,b,c+16|0,c+8|0);a=$g(c+24|0);fb=c+32|0;return a+4|0}function pFa(a,b){var c=0;xHa(a);p[a>>2]=76572;c=p[b+4>>2];p[a+24>>2]=p[b>>2];p[a+28>>2]=c;c=p[b+12>>2];p[a+32>>2]=p[b+8>>2];p[a+36>>2]=c;n[a+40|0]=0}function iZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=ve(b);d=Ee(c+13|0);p[d+8>>2]=0;p[d+4>>2]=c;p[d>>2]=c;e=a,f=ac(d+12|0,b,c+1|0),p[e>>2]=f;return a|0}function eu(a,b){var c=0,d=0;c=fb-16|0;fb=c;du(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function aq(a,b){var c=0,d=0;c=fb-16|0;fb=c;jh(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function Y_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=n[b|0];n[e|0]=(a|0)>-1?a:d;e=e+1|0;b=b+1|0;continue}break}return c|0}function Wba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(lq(a)>>>0<b>>>0){Vc();E()}qb(a);c=bG(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=(b<<4)+c|0,p[d>>2]=e;Vl(a,0)}function WU(a,b){var c=0,d=0;c=fb-16|0;fb=c;du(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function Uu(a){var b=0,c=0;p[114610]=0;c=Y(2566)|0;b=p[114610];p[114610]=0;if((b|0)!=1){b=a;a=p[c>>2];p[b>>2]=a;Sl(a);return}a=O(0)|0;H()|0;rb(a);E()}function SV(a,b){var c=0,d=0;c=fb-16|0;fb=c;pB(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function SJ(a){if(p[a+480224>>2]==2){return+s[a+1074420>>2]*1e-4}return+s[a+24620>>2]*60/(+s[a+1074404>>2]*+(v(p[a+1074408>>2],p[a+1074416>>2])>>>0))}function RV(a,b){var c=0,d=0;c=fb-16|0;fb=c;nB(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function Pp(a,b){var c=0,d=0;c=fb-16|0;fb=c;zk(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function Ooa(a){p[a>>2]=0;p[a+4>>2]=0;p[a+32>>2]=0;p[a+36>>2]=1072693248;p[a+24>>2]=0;p[a+28>>2]=0;p[a+16>>2]=0;p[a+20>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0}function OV(a,b){var c=0,d=0;c=fb-16|0;fb=c;pB(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function NV(a,b){var c=0,d=0;c=fb-16|0;fb=c;nB(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function NMa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(lq(a)>>>0<b>>>0){Vc();E()}qb(a);c=KS(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=(b<<4)+c|0,p[d>>2]=e;Vl(a,0)}function Kf(a,b){var c=0,d=0;c=fb-16|0;fb=c;_p(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function KBa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Lf(b);Lf(b);break a}a=kg(b);kg(b)}if(a){while(1){if(a&1){Sb(b,260)}a=a>>>1|0;if(a){continue}break}}}function JU(a,b){var c=0,d=0;c=fb-16|0;fb=c;Xp(c+8|0,b);b=zb(c+8|0);d=ed(a,Tb(c,c+8|0));if((b|0)==(d|0)){Qc(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function IU(a,b){var c=0,d=0;c=fb-16|0;fb=c;Xp(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function HP(a,b){var c=0,d=0;c=fb-16|0;fb=c;xz(c+8|0,b);b=zb(c+8|0);d=ec(a,Tb(c,c+8|0));if((b|0)==(d|0)){Sb(a,zb(c+8|0))}fb=c+16|0;return(b|0)==(d|0)}function DAa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Tm(a)>>>0<b>>>0){Vc();E()}qb(a);c=ZN(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=(b<<2)+c|0,p[d>>2]=e;Vj(a,0)}function Bma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=d;d=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=d;Tx(a,u[c>>3])}



function A9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){Jb(p[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function lza(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!hO(a,d)){break a}c=0;if(!yN(d)){break a}c=Ve(a,b,xN(d),ib)}fb=d+96|0;return c|0}function ed(a,b){var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;a=(e=a,f=p[a+12>>2],g=Tb(c+8|0,b),d=p[p[a>>2]+32>>2],m[d](e|0,f|0,g|0)|0);fb=c+16|0;return a}function eT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Tm(a)>>>0<b>>>0){Vc();E()}qb(a);c=fL(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=(b<<2)+c|0,p[d>>2]=e;Vj(a,0)}function cya(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-48|0;fb=d;c=-1;a:{if(!sN(a,d)){break a}c=0;if(!eN(d)){break a}c=Ve(a,b,dN(d),ib)}fb=d+48|0;return c|0}function ana(a,b,c){var d=0,e=0;b=b-a|0;if((b|0)>=3){d=b>>1;b=(d+ -2|0)/2|0;while(1){bx(a,c,d,(b<<1)+a|0);e=(b|0)>0;b=b+ -1|0;if(e){continue}break}}}function Zya(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-48|0;fb=d;c=-1;a:{if(!sN(a,d)){break a}c=0;if(!rN(d)){break a}c=Ve(a,b,qN(d),ib)}fb=d+48|0;return c|0}function Me(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(ze(a)){c=p[a>>2];n[b+15|0]=0;ae(c,b+15|0);oe(a,0);break a}n[b+14|0]=0;ae(a,b+14|0);cf(a,0)}fb=b+16|0}function KAa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!hO(a,d)){break a}c=0;if(!gO(d)){break a}c=Ve(a,b,fO(d),ib)}fb=d+96|0;return c|0}function J0(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(ze(a)){c=p[a>>2];p[b+12>>2]=0;Je(c,b+12|0);oe(a,0);break a}p[b+8>>2]=0;Je(a,b+8|0);cf(a,0)}fb=b+16|0}function E$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(uC(a)>>>0<b>>>0){Vc();E()}c=tC(Nk(a),b);p[a>>2]=c;p[a+4>>2]=c;d=sq(a),e=(b<<2)+c|0,p[d>>2]=e;sC(a,0)}function Ay(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(DA(a)>>>0<b>>>0){Vc();E()}qb(a);c=sT(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=(b<<1)+c|0,p[d>>2]=e;Ut(a,0)}function AQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Fz(a)>>>0<b>>>0){Vc();E()}qb(a);c=dQ(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=v(b,6)+c|0,p[d>>2]=e;nt(a,0)}function tZ(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+8>>2]=c;while(1){if((a|0)!=(b|0)){kE(d+8|0,p[a>>2]);a=a+4|0;continue}break}fb=d+16|0;return p[d+8>>2]}function qKa(a){var b=0;b=p[a+4>>2];a=p[a>>2];p[114610]=0;a=J(533,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a}a=O(0)|0;H()|0;rb(a);E()}function kKa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,64);a:{if(d){Mz(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;hKa(b);fb=a+16|0}fb=c+16|0;return d}function jba(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=p[a+4>>2];a=p[a>>2];p[b>>2]=a;p[b+4>>2]=c;p[b+8>>2]=a;p[b+12>>2]=c;a=Tma(b);fb=b+16|0;return a|0}function j5(a,b){a=a|0;b=b|0;var c=0,d=0;c=p[a+40>>2];while(1){if(c){c=c+ -1|0;d=c<<2;m[p[p[a+32>>2]+d>>2]](b,a,p[d+p[a+36>>2]>>2]);continue}break}}function bta(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,27);a:{if(d){JL(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;Usa(b);fb=a+16|0}fb=c+16|0;return d}function XLa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;c=0;if(Kf(a,d+8|0)){p[d+4>>2]=q[d+8|0];c=ALa(a,b,p[Cb(d+4|0,d+12|0)>>2])}fb=d+16|0;return c}function VU(a,b){a=a|0;b=b|0;var c=0;b=fb-48|0;fb=b;c=-1;a:{if(!WA(a,b+8|0)){break a}c=0;if(!cJ(b+8|0)){break a}c=vma(a,b+8|0)}fb=b+48|0;return c|0}function UMa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,16);a:{if(d){US(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;EMa(b);fb=a+16|0}fb=c+16|0;return d}function TIa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,64);a:{if(d){Mz(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;FIa(b);fb=a+16|0}fb=c+16|0;return d}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=p[b>>2];p[a>>2]=d;p[p[d+ -12>>2]+a>>2]=p[b+4>>2];p[a+4>>2]=0;tr(p[p[a>>2]+ -12>>2]+a|0,c);return a|0}function JX(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;return m[a|0](b,c,d,e,f,g,h,i,j,k,l)|0}function $x(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(!ue(a)){break a}Ym(a);if(c){nla(a,b)}if((Vp(a)|0)==2){zua(a,b);return}if((Vp(a)|0)!=1){break a}yua(a,b)}}function uZ(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+8>>2]=c;while(1){if((a|0)!=(b|0)){lE(d+8|0,n[a|0]);a=a+1|0;continue}break}fb=d+16|0;return p[d+8>>2]}function uX(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;return Nea(a,b,c,d,e,f,g,h,i,j,k,l)|0}function qsa(a,b){var c=0,d=0,e=0;while(1){d=d<<1|c>>>31;c=a&1|c<<1;a=(b&1)<<31|a>>>1;b=b>>>1|0;e=e+1|0;if((e|0)!=64){continue}break}ib=d;return c}function nAa(a){var b=0;b=p[a+4>>2];a=p[a>>2];p[114610]=0;a=J(79,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a}a=O(0)|0;H()|0;rb(a);E()}function kxa(a){var b=0,c=0;wQ(a);a:{while(1){c=a+b|0;if(q[c|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Jb(c,0,32-b|0)}}function kY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Xf(a,p[b+8>>2],f)){Du(b,c,d,e);return}a=p[a+8>>2];m[p[p[a>>2]+20>>2]](a,b,c,d,e,f)}function ama(a,b){a=a|0;b=b|0;var c=0;if(!(q[b+14|0]&48|q[b+17|0]!=173)){Tc(a,8,1,0,11);return}c=a;a=b+14|0;Tc(c,q[a|0]&16?16:8,q[a|0]&32?3:1,0,2)}function _La(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;c=0;if(Kf(a,d+8|0)){p[d+4>>2]=q[d+8|0];c=wS(a,b,p[Cb(d+4|0,d+12|0)>>2])}fb=d+16|0;return c}function _A(a){var b=0;b=p[a+4>>2];a=p[a>>2];p[114610]=0;a=J(288,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a}a=O(0)|0;H()|0;rb(a);E()}function ZLa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;c=0;if(Kf(a,d+8|0)){p[d+4>>2]=q[d+8|0];c=rS(a,b,p[Cb(d+4|0,d+12|0)>>2])}fb=d+16|0;return c}function YO(a){var b=0;b=p[a+4>>2];a=p[a>>2];p[114610]=0;a=J(883,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a}a=O(0)|0;H()|0;rb(a);E()}function YLa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;c=0;if(Kf(a,d+8|0)){p[d+4>>2]=q[d+8|0];c=qS(a,b,p[Cb(d+4|0,d+12|0)>>2])}fb=d+16|0;return c}function XE(a,b){a:{b:{if(q[a+23|0]){a=1;if((b|0)!=255){break b}aa(52110,50416,1165,52125);E()}if((b|0)!=255){break a}a=0}return a}return b>>>0>10}function XCa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,2);a:{if(d){zk(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;KCa(b);fb=a+16|0}fb=c+16|0;return d}function Vx(a,b,c){var d=0,e=0,f=0;d=$j(a,b);if((d|0)!=255){e=Yc(a+22|0,d),f=c,o[e>>1]=f;a=a+58|0;e=Yb(a,b),f=255,n[e|0]=f;e=Yb(a,c),f=d,n[e|0]=f}}function SKa(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;c=0;if(Kf(a,d+8|0)){p[d+4>>2]=q[d+8|0];c=WR(a,b,p[Cb(d+4|0,d+12|0)>>2])}fb=d+16|0;return c}function R9(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-32|0;fb=h;iG(h+8|0,b,c,d,e,f,g);Wc(a,h+20|0);Um(h+8|0);fb=h+32|0}function OKa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,8);a:{if(d){du(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;sKa(b);fb=a+16|0}fb=c+16|0;return d}function MMa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,3);a:{if(d){iA(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;pMa(b);fb=a+16|0}fb=c+16|0;return d}function F9(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;d=p[b+4>>2];p[c+8>>2]=p[b>>2];p[c+12>>2]=d;ap(a,p[c+8>>2],p[c+12>>2]);fb=c+32|0;return a|0}function C$(){var a=0;Bd(463344);p[114610]=0;M(2560,463352)|0;a=p[114610];p[114610]=0;if((a|0)!=1){p[115836]=65468;return}a=I()|0;H()|0;L(a|0);E()}function Bv(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=d&1?a*c:c;if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function B$(){var a=0;Bd(463360);p[114610]=0;M(2560,463368)|0;a=p[114610];p[114610]=0;if((a|0)!=1){p[115840]=65624;return}a=I()|0;H()|0;L(a|0);E()}function ABa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,6);a:{if(d){xz(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;tBa(b);fb=a+16|0}fb=c+16|0;return d}function zb(a){var b=0;b=p[a+4>>2];a=p[a>>2];p[114610]=0;a=J(34,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a}a=O(0)|0;H()|0;rb(a);E()}function yza(a,b,c,d){if((b|0)!=(c|0)){a=p[d>>2];while(1){c=c+ -56|0;xza(a+ -56|0,c);a=p[d>>2]+ -56|0;p[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function yv(a,b,c,d){var e=0;e=nm(a,b,c);if(zd(d,c)){Qb(c,d);if(!zd(c,b)){return e+1|0}Qb(b,c);if(!zd(b,a)){return e+2|0}Qb(a,b);e=e+3|0}return e}function pka(a,b,c,d){if((b|0)!=(c|0)){a=p[d>>2];while(1){c=c+ -52|0;oka(a+ -52|0,c);a=p[d>>2]+ -52|0;p[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function o7(a,b,c){a:{if((a|0)==(b|0)){break a}c=r[c>>1];while(1){if((c|0)==r[a>>1]){break a}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function nya(a,b,c,d){if((b|0)!=(c|0)){a=p[d>>2];while(1){c=c+ -12|0;lya(a+ -12|0,c);a=p[d>>2]+ -12|0;p[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function lH(a){var b=0;b=(He(p[a+16>>2])>>>0)/(ji(w(t[a+4208>>2]*w(999)))+1>>>0)|0;b=b>>>0>2?b:2;p[a+4216>>2]=b;p[a+4220>>2]=b>>>1;vc(a+4224|0,b)}function eh(a){var b=0;b=p[a+4>>2];a=p[a>>2];p[114610]=0;a=J(29,a|0,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a}a=O(0)|0;H()|0;rb(a);E()}function _Ja(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;o[b+14>>1]=1;c=b,d=qt(a),o[c+12>>1]=d;a=r[Bi(b+14|0,b+12|0)>>1];fb=b+16|0;return a+ -1&65535}function WK(a,b){var c=0,d=0;c=ac(a,b,602);a=0;while(1){d=v(a,896);Yr((d+c|0)+608|0,(b+d|0)+608|0);a=a+1|0;if((a|0)!=256){continue}break}return c}function S9(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-32|0;fb=h;iG(h+8|0,b,c,d,e,f,g);Wc(a,h+8|0);Um(h+8|0);fb=h+32|0}function QCa(a,b,c){var d=0;d=xi(a+8|0);p[114610]=0;N(421,a|0,b|0,c|0);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=I()|0;H()|0;Gg(d);L(a|0);E()}function xIa(a,b,c,d){if((b|0)!=(c|0)){a=p[d>>2];while(1){c=c+ -16|0;Ml(a+ -16|0,c);a=p[d>>2]+ -16|0;p[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function s6(a,b){var c=0;b=b<<1;c=a+1092|0;a:{b:{if((b|0)==p[a+112>>2]){break b}c=0;if((b|0)!=p[a+116>>2]){break a}c=a+1096|0}c=p[c>>2]}return c}function ko(a,b){var c=0;a:{if(!pF(b)|(q[b+1|0]^q[a+1|0])>>>0>1){break a}b=q[b+2|0];a=q[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Yra(a,b,c,d){if((b|0)!=(c|0)){a=p[d>>2];while(1){c=c+ -12|0;qy(a+ -12|0,c);a=p[d>>2]+ -12|0;p[d>>2]=a;if((b|0)!=(c|0)){continue}break}}}function Mg(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;n[c+15|0]=0;a=Ik(a,c+15|0,1);n[c+8|0]=q[c+15|0];n[b|0]=q[c+8|0];fb=c+16|0;return!ib&(a|0)==1}function MD(a,b,c){var d=0;d=fb-144|0;fb=d;d=Jb(d,0,144);p[d+76>>2]=-1;p[d+44>>2]=a;p[d+32>>2]=2414;p[d+84>>2]=a;a=J3(d,b,c);fb=d+144|0;return a}function qw(a){a=a|0;var b=0,c=0;p[a>>2]=81568;b=a+4960|0;c=a+4504|0;while(1){b=b+ -24|0;Ef(b);if((b|0)!=(c|0)){continue}break}Ge(a);return a|0}function nv(a){var b=0,c=0;b=fb-16|0;fb=b;c=-1;a:{if(eE(a)){break a}if((m[p[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=q[b+15|0]}fb=b+16|0;return c}function iJa(a,b){a=a|0;b=b|0;var c=0;a=Tc(a,8,1,0,1);c=2;b=b+13|0;a:{if(!(q[b|0]&64)){c=0;if(!(q[b|0]&2)){break a}}lj(a,c)}if(q[b|0]&4){Az(a)}}function Tt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Wz(a)>>>0<b>>>0){Vc();E()}qb(a);c=FA(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=b+c|0,p[d>>2]=e;dA(a,0)}function Po(a){var b=0,c=0,d=0;c=q[a+30|0];d=Ah(p[a+24>>2]+484360|0);b=p[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Ob(b)}return li(b,q[a+30|0])}function O6(a,b,c,d){if(d){nF(a,b,48704,d);b=v(d,36)+b|0;a=v(d,72)+a|0}if((c|0)==2){D6(a,b,32-d|0);return}nF(a,b,v((c|0)==3,72)+48704|0,32-d|0)}function Nn(a,b){var c=0;c=a;a=b+4|0;return gW(c,q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24),q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))}function NR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Wz(a)>>>0<b>>>0){Vc();E()}qb(a);c=DS(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=b+c|0,p[d>>2]=e;dA(a,0)}function LJ(a,b,c){n[a+6|0]=255;p[a+16>>2]=0;o[a+4>>1]=0;p[a>>2]=0;if(!((b|0)==65535|(c|0)==-1)){p[a+8>>2]=c;p[a+16>>2]=2;o[a+12>>1]=b}return a}function Jpa(a,b,c){var d=0;d=bn(a);p[114610]=0;N(109,a|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){return a}a=I()|0;H()|0;be(d);L(a|0);E()}function Hy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;o[d+14>>1]=b;o[d+12>>1]=c;if((b|0)!=(c|0)){bCa(Ub(a),Vb(a),d+14|0,d+12|0)}fb=d+16|0}function Gm(a,b,c){a:{if((a|0)==(b|0)){break a}c=q[c|0];while(1){if((c|0)==q[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function wxa(a,b,c){a=a|0;b=b|0;c=c|0;a=q[c|0]|q[c+1|0]<<8|(q[c+2|0]<<16|q[c+3|0]<<24);n[b|0]=a;n[b+1|0]=a>>>8;n[b+2|0]=a>>>16;n[b+3|0]=a>>>24}function Twa(a,b,c){var d=0;d=bn(a);p[114610]=0;N(93,a|0,b|0,c|0);b=p[114610];p[114610]=0;if((b|0)!=1){return a}a=I()|0;H()|0;be(d);L(a|0);E()}function Bu(a,b,c,d,e,f){var g=0,h=0,i=0;g=p[a+4>>2];h=g>>8;a=p[a>>2];i=a;if(g&1){h=p[p[d>>2]+h>>2]}m[p[p[a>>2]+20>>2]](i,b,c,d+h|0,g&2?e:2,f)}function q3(a,b,c,d){d=fb-16|0;fb=d;r3(d,b,c);b=p[d+4>>2];p[a>>2]=p[d>>2];p[a+4>>2]=b;b=p[d+12>>2];p[a+8>>2]=p[d+8>>2];p[a+12>>2]=b;fb=d+16|0}function lHa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,12);a:{if(d){zz(c+8|0,b);yd(a,c+8|0);break a}n[c+7|0]=0;kj(b,12,c+7|0)}fb=c+16|0;return d}function jMa(a,b){var c=0;c=fb-16|0;fb=c;p[a>>2]=0;p[a+4>>2]=0;p[c+12>>2]=0;Oc(a+8|0,c+12|0,c+8|0);if(b){Np(a,b);xA(a,b,0)}fb=c+16|0;return a}function epa(a,b){var c=0,d=0,e=0;d=q[a|0];e=q[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(e>>>0<d>>>0){break a}c=r[a+2>>1]<r[b+2>>1]}return c}function Pha(a){a=a|0;var b=0;b=fb-16|0;fb=b;MH(b+8|0,a,0);if(eh(b+8|0)){a=p[a+20>>2];p[a+148>>2]=-1;EJ(a+4|0,p[b+8>>2],p[b+12>>2])}fb=b+16|0}function OY(a,b){a:{b:{switch(a+1|0){case 0:a=p[114584];break;case 1:break a;default:break b}}b=70688;if((a|0)==28){break a}La();E()}return b}function B3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=p[a+20>>2];d=p[a+16>>2]-e|0;d=d>>>0>c>>>0?c:d;ac(e,b,d);p[a+20>>2]=d+p[a+20>>2];return c|0}function mma(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;o[a+4>>1]=0;p[a>>2]=b;vb(c+8|0,b+1074308|0,0);d=a,e=tb(c+8|0),n[d+6|0]=e;fb=c+16|0;return a}function cY(a,b,c,d){var e=0,f=0;f=d&65535;d=d>>>16&32767;a:{if((d|0)!=32767){e=4;if(d){break a}return a|c|(b|f)?3:2}e=!(a|c|(b|f))}return e}function BT(a){var b=0,c=0;c=NNa(q[a+111|0],0,1536,0);b=ib;a=NNa(q[a+110|0],0,25,0);c=c+a|0;b=ib+b|0;b=c>>>0<a>>>0?b+1|0:b;a=c;ib=b;return a}function $5(a,b,c){var d=0,e=0;if((b|0)>=1){d=(b<<2)+a|0;while(1){p[(e<<2)+a>>2]=d;d=c+d|0;e=e+1|0;if((e|0)!=(b|0)){continue}break}}return a}function sCa(a){var b=0,c=0,d=0;c=a+20|0;while(1){d=b;b=n[a|0];b=d+((b&255)!=0&(b|0)<32)|0;a=a+1|0;if((c|0)!=(a|0)){continue}break}return b}function rCa(a){var b=0,c=0,d=0;c=a+22|0;while(1){d=b;b=n[a|0];b=d+((b&255)!=0&(b|0)<32)|0;a=a+1|0;if((c|0)!=(a|0)){continue}break}return b}function oO(a){a:{if(hd(a,16574,3)|q[a+3|0]>31|(n[a+27|0]<0|q[a+32|0]>64)){break a}a=a+33|0;if(q[a|0]>32){break a}return q[a|0]!=0}return 0}function hja(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;if(!od(a,4)){Nu(a)}c=b,d=Ub(a+44|0),p[c>>2]=d;a=p[Ld(b+8|0,b)>>2];fb=b+16|0;return a|0}function gja(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;if(!od(a,4)){Nu(a)}c=b,d=Vb(a+44|0),p[c>>2]=d;a=p[Ld(b+8|0,b)>>2];fb=b+16|0;return a|0}function cj(a){if(!(2147483647>a)){return 2147483647}if(!(-2147483648<a)){return-2147483648}if(x(a)<2147483648){return~~a}return-2147483648}function NP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;return(e=a,f=p[c>>2],g=b,h=zb(c),d=p[p[a>>2]+28>>2],m[d](e|0,f|0,g|0,h|0)|0)|0}function Isa(){var a=0,b=0,c=0,d=0;while(1){b=(a<<3)+85504|0;c=b,d=Csa(a&255),p[c>>2]=d;p[b+4>>2]=ib;a=a+1|0;if((a|0)!=256){continue}break}}function Dr(a){var b=0;b=u[a+4248>>3]/+(He(p[a+16>>2])>>>0);u[a+4264>>3]=b;if(q[a+4240|0]){u[a+4264>>3]=b*.016666666666666666*u[a+4288>>3]}}function qq(a,b,c,d,e){var f=0,g=0,h=0;f=p[a+4>>2];g=f>>8;a=p[a>>2];h=a;if(f&1){g=p[p[c>>2]+g>>2]}m[p[p[a>>2]+24>>2]](h,b,c+g|0,f&2?d:2,e)}function ph(a){var b=0;a=a*a;b=a*a;return w(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+ -.001388676377460993))}function pKa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-624|0;fb=b;d=-1;c=a;a=b+8|0;c=jKa(c,a);if(!c){KR(a)}if(c){d=MR(b+8|0)}fb=b+624|0;return d|0}function gva(a,b){var c=0,d=0;if(b){while(1){d=c<<3;p[(c<<2)+a>>2]=(p[(d|4)+a>>2]+p[a+d>>2]|0)/2;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function gNa(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(Hb(a,256)){d=fb-16|0;fb=d;Zb(c+8|0,b,256);fb=d+16|0;yd(a,c+8|0);break a}AC(b)}fb=c+16|0}function dd(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;p[c+8>>2]=a;p[c+12>>2]=b;p[c>>2]=-1;p[c+4>>2]=0;a=mA(c+8|0,c);fb=c+16|0;return p[a>>2]}function aza(a){var b=0,c=0;b=fb-16|0;fb=b;if($ya(a,b+8|0)){a=b+8|0;a=q[a|0]|q[a+1|0]<<8;c=(a<<24|a<<8&16711680)>>>16|0}fb=b+16|0;return c}function Zza(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-160|0;fb=b;d=-1;c=a;a=b+8|0;c=uza(c,a);if(!c){EN(a)}if(c){d=ON(b+8|0)}fb=b+160|0;return d|0}function X_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-16|0;fb=a;p[a+12>>2]=e;p[a+8>>2]=d-c;b=Cb(a+12|0,a+8|0);fb=a+16|0;return p[b>>2]}function Qsa(a){var b=0,c=0;b=fb-16|0;fb=b;c=p[a+4>>2];p[b>>2]=p[a>>2];p[b+4>>2]=c;c=Zj(b+8|0,b);a=p[c>>2];fb=b+16|0;ib=p[c+4>>2];return a}function Pya(a,b){a=a|0;b=b|0;var c=0;c=nc(a);if(c>>>0<b>>>0){Eya(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+v(b,12)|0;nc(a);iN(a,b);zs(a)}}function Oia(a,b){a=a|0;b=b|0;var c=0;c=$e(a);if(c>>>0<b>>>0){uia(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<11)|0;$e(a);SH(a,b);XH(a)}}function Jka(a,b){var c=0,d=0,e=0;if(zI(a)>>>0<b>>>0){Vc();E()}qb(a);c=wI(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=v(b,52)+c|0,p[d>>2]=e;yI(a,0)}function IHa(a,b){a=a|0;b=b|0;var c=0;c=si(a);if(c>>>0<b>>>0){oHa(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+v(b,48)|0;si(a);tR(a,b);ER(a)}}function EE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){p[d>>2]=p[b>>2];d=d+4|0;b=b+4|0;c=c+ -1|0;if(c){continue}break}}return a|0}function $G(a){var b=0,c=w(0);if(!a){return w(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=w(Kg(b-TNa(b+.5)))}else{c=w(0)}return c}function xCa(a,b,c){var d=0;if((a|0)!=(b|0)){while(1){d=q[a|0];n[c|0]=d>>>0>32?d:32;c=c+1|0;a=a+1|0;if((b|0)!=(a|0)){continue}break}}}



function vFa(a,b){a=a|0;b=b|0;var c=0;c=gd(a);if(c>>>0<b>>>0){hFa(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<4)|0;gd(a);JS(a,b);QB(a)}}function kk(a){a=a|0;var b=0;b=fb-16|0;fb=b;p[b+12>>2]=a;p[b+8>>2]=0;p[b+4>>2]=255;a=q[Gf(b+8|0,Yd(b+12|0,b+4|0))|0];fb=b+16|0;return a|0}function fua(a,b){var c=0,d=0,e=0;if(iB(a)>>>0<b>>>0){Vc();E()}qb(a);c=eM(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=(b<<5)+c|0,p[d>>2]=e;bq(a,0)}function dpa(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=b;b=p[c+8>>2];b=r[b>>1]|r[b+2>>1]<<16;o[a+4>>1]=0;o[a>>1]=b;o[a+2>>1]=b>>>16;fb=c+16|0}function SK(a){a=49-(v(q[(a>>>4|0)+20304|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return rc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function RHa(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1042;p[c+4>>2]=2;wga(a,b,c);fb=c+32|0}function Qja(a,b){var c=0,d=0,e=0;if(Tm(a)>>>0<b>>>0){Vc();E()}qb(a);c=jI(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=(b<<2)+c|0,p[d>>2]=e;Vj(a,0)}function Nia(a,b){a=a|0;b=b|0;var c=0;c=Bb(a);if(c>>>0<b>>>0){tia(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<2)|0;Bb(a);PH(a,b);Hg(a)}}function Mc(a){var b=0;b=fb-16|0;fb=b;p[b+12>>2]=a;p[b+8>>2]=-32768;p[b+4>>2]=32767;a=o[Gf(b+8|0,Yd(b+12|0,b+4|0))>>1];fb=b+16|0;return a}function Lu(a,b){Am(a);p[a>>2]=71368;p[114610]=0;J(2838,a+4|0,b|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){return}a=I()|0;H()|0;L(a|0);E()}function IDa(a,b){var c=0,d=0,e=0;if(Tm(a)>>>0<b>>>0){Vc();E()}qb(a);c=sA(b);p[a>>2]=c;p[a+4>>2]=c;d=qb(a),e=(b<<2)+c|0,p[d>>2]=e;Vj(a,0)}function B5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=p[b>>2]+15&-16;p[c>>2]=b+16;d=a,e=Av(p[b>>2],p[b+4>>2],p[b+8>>2],p[b+12>>2]),u[d>>3]=e}function zp(a){var b=0,c=0;b=fb-16|0;fb=b;if(Pp(a,b+8|0)){a=b+8|0;a=q[a|0]|q[a+1|0]<<8;c=(a<<24|a<<8&16711680)>>>16|0}fb=b+16|0;return c}function sHa(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1042;p[c+4>>2]=2;dr(a,b,c);fb=c+32|0}function qza(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1042;p[c+4>>2]=2;Yz(a,b,c);fb=c+32|0}function pxa(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1058;p[c+4>>2]=3;cP(a,b,c);fb=c+32|0}function dJa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-32|0;fb=b;d=-1;c=a;a=b+8|0;c=NIa(c,a);if(!c){gR(a)}if(c){d=jR(b+8|0)}fb=b+32|0;return d|0}function _pa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;if(b>>>0>=250){Hi(20388);E()}vb(d+8|0,a,b);Zd(d+8|0,c);fb=d+16|0;return a|0}function Zja(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1058;p[c+4>>2]=1;dr(a,b,c);fb=c+32|0}function YKa(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1058;p[c+4>>2]=2;Ar(a,b,c);fb=c+32|0}function V9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;jG(g+8|0,b,c,d,e,f);Wc(a,g+20|0);Um(g+8|0);fb=g+32|0}function SLa(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1025;p[c+4>>2]=2;Yz(a,b,c);fb=c+32|0}function Pfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=p[b>>2];p[a>>2]=d;p[p[d+ -12>>2]+a>>2]=p[b+4>>2];tr(p[p[a>>2]+ -12>>2]+a|0,c);return a|0}function H7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=aw(a+8|0,b,c,d,2);if(16>a>>>0){a=q[a+32176|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function G7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=aw(a+8|0,b,c,d,3);if(43>a>>>0){a=q[a+32128|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function FFa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-16|0;fb=b;d=-1;c=a;a=b+8|0;c=NEa(c,a);if(!c){uS(a)}if(c){d=WP(b+8|0)}fb=b+16|0;return d|0}function E5(a,b,c,d){if(a|b){while(1){c=c+ -1|0;n[c|0]=q[(a&15)+55552|0]|d;a=(b&15)<<28|a>>>4;b=b>>>4|0;if(a|b){continue}break}}return c}function y$(a,b){a=a|0;b=b|0;var c=0;c=Bb(a);if(c>>>0<b>>>0){v$(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<2)|0;Bb(a);qC(a,b);QC(a)}}function sca(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;p[f+8>>2]=p[a+8>>2];g=p[a+4>>2];p[f>>2]=p[a>>2];p[f+4>>2]=g;bva(f,b,c,d,e);fb=f+16|0}function mj(a){var b=0;b=a+28|0;a=b;if((q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))>>>0>=128){a=q[b|0]^-128}else{a=255}return a&255}function lLa(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=274;p[c+4>>2]=0;Yz(a,b,c);fb=c+32|0}function kqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;if(b>>>0>=43){Hi(20388);E()}vb(d+8|0,a,b);Zd(d+8|0,c);fb=d+16|0;return a|0}function jqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;if(b>>>0>=16){Hi(20388);E()}uj(d+8|0,a,b);Zd(d+8|0,c);fb=d+16|0;return a|0}function XW(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1058;p[c+4>>2]=2;Tw(a,b,c);fb=c+32|0}function W9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;jG(g+8|0,b,c,d,e,f);Wc(a,g+8|0);Um(g+8|0);fb=g+32|0}function T9(a,b,c){b=Uf(a,b);p[114610]=0;J(120,a+12|0,c|0)|0;a=p[114610];p[114610]=0;if((a|0)!=1){return}a=I()|0;H()|0;pb(b);L(a|0);E()}function Sd(a,b){a=a|0;b=b|0;return(q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24))==(q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))|0}function S6(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1025;p[c+4>>2]=2;dr(a,b,c);fb=c+32|0}function Ps(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1058;p[c+4>>2]=2;wH(a,b,c);fb=c+32|0}function Ny(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1058;p[c+4>>2]=2;cP(a,b,c);fb=c+32|0}function GB(a){a=a|0;var b=0;a=Xc(a);p[114610]=0;J(238,a|0,7090)|0;b=p[114610];p[114610]=0;if((b|0)==1){b=I()|0;H()|0;pb(a);L(b|0);E()}}function Eb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;if(b>>>0>=110){Hi(12352);E()}vb(d+8|0,a,b);Zd(d+8|0,c);fb=d+16|0;return a|0}function $Ha(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=257;p[c+4>>2]=0;Tw(a,b,c);fb=c+32|0}function $6(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1025;p[c+4>>2]=4;dr(a,b,c);fb=c+32|0}function mja(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=0;p[d+8>>2]=c;p[d+4>>2]=4;Ik(a,d+12|0,p[Cb(d+8|0,d+4|0)>>2]);p[b>>2]=0;fb=d+16|0}function Yoa(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+8>>2]=b;b=p[c+8>>2];d=p[b+4>>2];b=p[b>>2];p[a+8>>2]=0;p[a>>2]=b;p[a+4>>2]=d;fb=c+16|0}function YW(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=290;p[c+4>>2]=0;Tw(a,b,c);fb=c+32|0}function Qc(a,b){var c=0,d=0,e=0;c=af(a,b);if(c){p[a+12>>2]=p[a+12>>2]+b;return c}d=a,e=m[p[p[a>>2]+24>>2]](a)|0,p[d+12>>2]=e;return c}function Kb(a,b){var c=0,d=0,e=0;d=a;e=a;c=p[a+4>>2]+p[b+4>>2]|0;b=p[b>>2];a=b+p[a>>2]|0;if(a>>>0<b>>>0){c=c+1|0}p[e>>2]=a;p[d+4>>2]=c}function I3(a,b){var c=0;c=fb-16|0;p[c+12>>2]=a;p[c+8>>2]=a;if(b>>>0>=2){a=((b<<2)+a|0)+ -4|0;p[c+8>>2]=a}p[c+8>>2]=a+4;return p[a>>2]}function $pa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;if(!(!a|!b)){c=Zr(a);a=Rpa(a,b);c=v(Zr(b),(c|0)/(a|0)|0)}fb=d+16|0;return c|0}function pS(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;fb=b+16|0}function Sha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Ud(c&255))){OH(a,8,w(0))}a=Ti(a);if(a){m[p[p[a>>2]+88>>2]](a,b,c,d,e)}}function PCa(a){var b=0;b=fb-16|0;fb=b;p[b+12>>2]=a;p[b+8>>2]=-128;p[b+4>>2]=127;a=n[Gf(b+8|0,Yd(b+12|0,b+4|0))|0];fb=b+16|0;return a}function Mp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(!b){break a}if(c){LT(Ed(d+8|0,a),b);break a}KT(Ed(d,a),b)}fb=d+16|0}function Lf(a){var b=0,c=0;b=fb-16|0;fb=b;if(aq(a,b+8|0)){a=b+8|0;c=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24)}fb=b+16|0;return c}function JB(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Mb(a,10940);c=0;a:{if(!wb(b)){break a}c=(Nf(b,10950)|0)!=-1}pb(b);fb=a+16|0;return c|0}function z6(a){p[a+1420>>2]=0;p[a+992>>2]=0;p[a+1504>>2]=0;p[a+1508>>2]=0;p[a+1412>>2]=0;p[a+1416>>2]=0;n[a+1377|0]=0;p[a+1064>>2]=0}function Vd(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=p[a>>2];if((d|0)<(b|0)){p[a>>2]=b;return}if((d|0)<=(c|0)){break a}p[a>>2]=c}}function Te(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;p[f+12>>2]=c;p[f+8>>2]=e;c=lh(f,f+12|0);a=Fq(a,b,d,p[f+8>>2]);ye(c);fb=f+16|0;return a}function Ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=of(a);if(d>>>0<b>>>0){Fka(a,b-d|0,c);return}if(d>>>0>b>>>0){EI(a,p[a>>2]+v(b,52)|0)}}function HR(a){var b=0;b=a;if((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))==1179468868){return(q[a+4|0]+ -1&255)>>>0<10}return 0}function Fpa(a,b){n[a+860|0]=b;n[a+832|0]=b;n[a+831|0]=b;n[a+829|0]=b;n[a+828|0]=b;o[a+800>>1]=b;n[a+846|0]=b>>>4;n[a+847|0]=b<<2&60}function En(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=p[a>>2];if(d>>>0<b>>>0){p[a>>2]=b;return}if(d>>>0<=c>>>0){break a}p[a>>2]=c}}function uHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Rf(a);if(d>>>0<b>>>0){eHa(a,b-d|0,c);return}if(d>>>0>b>>>0){iz(a,p[a>>2]+v(b,6)|0)}}function sLa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(Hb(a,512)){Tz(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;pLa(b);fb=a+16|0}fb=c+16|0}function jBa(a,b){var c=0;c=ng(a);if(c>>>0<b>>>0){iBa(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<3)|0;ng(a);rO(a,b);Di(a);ng(a)}}function ZAa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(Hb(a,128)){YP(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;YAa(b);fb=a+16|0}fb=c+16|0}function Sma(a,b){var c=0;c=78880;while(1){if(p[c>>2]==(b|0)){UJ(a,p[c+8>>2]);return}c=c+12|0;if((c|0)!=78928){continue}break}Xc(a)}function Qta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=ne(a);if(d>>>0<b>>>0){Nta(a,b-d|0,c);return}if(d>>>0>b>>>0){lM(a,p[a>>2]+(b<<5)|0)}}function KW(){var a=0,b=0;a=fb-16|0;fb=a;p[a+8>>2]=19464961;a:{if(KB(a+8|0)){break a}if(JB()){break a}b=IB()^1}fb=a+16|0;return b|0}function Aia(a){a=a|0;a=fb-16|0;fb=a;p[a+12>>2]=1869112133;fb=a+16|0;a=a+12|0;return q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24)}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;p[d>>2]=c;p[d+8>>2]=b;dq(p[d+8>>2]);s9(a,p[d>>2]);fb=d+16|0;return a|0}function tv(a){a=a|0;var b=0;b=p[a+12>>2];if((b|0)==p[a+16>>2]){return m[p[p[a>>2]+40>>2]](a)|0}p[a+12>>2]=b+1;return og(n[b|0])|0}function tI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Bb(a);if(d>>>0<b>>>0){gka(a,b-d|0,c);return}if(d>>>0>b>>>0){Jw(a,p[a>>2]+(b<<2)|0)}}function p9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;p[d>>2]=c;p[d+8>>2]=b;dq(p[d+8>>2]);o9(a,p[d>>2]);fb=d+16|0;return a|0}function ZV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;p[d>>2]=c;p[d+8>>2]=b;dq(p[d+8>>2]);YV(a,p[d>>2]);fb=d+16|0;return a|0}function Tn(a,b){a=a|0;b=b|0;var c=0;c=Cc(a);if(c>>>0<b>>>0){VY(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+b|0;Cc(a);NB(a,b);gp(a)}}function ye(a){a:{a=p[a>>2];if(a){p[114610]=0;cv(a);a=p[114610];p[114610]=0;if((a|0)==1){break a}}return}a=O(0)|0;H()|0;rb(a);E()}function kZ(a){var b=0;b=p[a>>2];p[114610]=0;M(2837,b|0)|0;b=p[114610];p[114610]=0;if((b|0)!=1){return a}a=O(0)|0;H()|0;rb(a);E()}function ZR(a,b,c,d,e){n[a+4|0]=b;n[a|0]=1869112133;n[a+1|0]=7301219;n[a+2|0]=28520;n[a+3|0]=111;n[a+7|0]=e;n[a+6|0]=d;n[a+5|0]=c}function Uja(a,b){var c=0,d=0;c=fb-16|0;fb=c;p[c+8>>2]=b;b=p[c+8>>2];d=hI(a,b);a=_b(a);_s($g(c+8|0));gh(a,b,1);fb=c+16|0;return d}function Rra(a,b){var c=0;c=fb-16|0;fb=c;a:{if(Hb(a,7)){Uz(c+8|0,b);yd(a,c+8|0);break a}a=fb-16|0;fb=a;Ora(b);fb=a+16|0}fb=c+16|0}function RT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=SNa(0-SNa(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function $I(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=q[a|0];if(d>>>0<b>>>0){n[a|0]=b;return}if(d>>>0<=c>>>0){break a}n[a|0]=c}}function zE(a,b,c,d,e){if(d>>>0<=b>>>0){if(!e){return d}b=a+b|0;c=I4(a+d|0,b,c,c+e|0);a=(b|0)==(c|0)?-1:c-a|0}else{a=-1}return a}function qy(a,b){var c=0,d=0;p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];p[a+8>>2]=p[b+8>>2];p[b>>2]=0;p[b+4>>2]=0;c=qb(b),d=0,p[c>>2]=d}function oba(a,b,c){jr(a);p[a+8>>2]=c;p[a+4>>2]=0;p[a>>2]=84184;c=p[b+4>>2];p[a+12>>2]=p[b>>2];p[a+16>>2]=c;p[a+20>>2]=p[b+8>>2]}function mba(a,b,c){jr(a);p[a+8>>2]=c;p[a+4>>2]=0;p[a>>2]=84256;c=p[b+4>>2];p[a+12>>2]=p[b>>2];p[a+16>>2]=c;p[a+20>>2]=p[b+8>>2]}function UX(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;m[a|0](b,c,d,e,f,g,h,i,j,k)}function Nt(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;e=p[b+4>>2];d=p[b>>2];n[c+15|0]=0;d=Gm(d,d+e|0,c+15|0);di(a,p[b>>2],d);fb=c+16|0}function Eoa(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=p[a>>2];if(b){Eha(b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function h$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){p[d>>2]=n[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function ZY(a,b,c){a:{if(c){p[114610]=0;lC(a,b,c);a=p[114610];p[114610]=0;if((a|0)==1){break a}}return}a=O(0)|0;H()|0;rb(a);E()}function YY(a,b,c){a:{if(b){p[114610]=0;mC(a,c,b);a=p[114610];p[114610]=0;if((a|0)==1){break a}}return}a=O(0)|0;H()|0;rb(a);E()}function Ti(a){var b=0,c=0;b=mj(p[a+20>>2]);if(!(b>>>0>249|b>>>0<=q[a+4200|0])){c=p[(p[a+16>>2]+v(b,160)|0)+906300>>2]}return c}function Rh(a,b,c){a:{if(c){p[114610]=0;EE(a,b,c);a=p[114610];p[114610]=0;if((a|0)==1){break a}}return}a=O(0)|0;H()|0;rb(a);E()}function Mv(a,b,c){var d=0;d=p[a+32>>2];if(d+c>>>0>s[a+40>>2]){p[a+96>>2]=1;return 0}ac(b,d,c);p[a+32>>2]=p[a+32>>2]+c;return 1}function LL(a,b,c){a=a|0;b=b|0;c=c|0;if((b|0)!=(c|0)){while(1){KL(a,q[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function KM(a){var b=0;b=p[a+16>>2];a=p[a+32>>2];b=NNa(b,b>>31,a,a>>31)+5e5|0;a=ib;return rc(ONa(b,b>>>0<5e5?a+1|0:a,1e6,0),ib)}function JM(a){var b=0;b=p[a+16>>2];a=p[a+36>>2];b=NNa(b,b>>31,a,a>>31)+5e5|0;a=ib;return rc(ONa(b,b>>>0<5e5?a+1|0:a,1e6,0),ib)}function D4(a,b){var c=0;c=p[a+24>>2];if((c|0)==p[a+28>>2]){return m[p[p[a>>2]+52>>2]](a,b)|0}p[a+24>>2]=c+4;p[c>>2]=b;return b}function Ag(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;if(b>>>0>=110){Hi(12596);E()}vb(c+8|0,a,b);Zd(c+8|0,0);fb=c+16|0;return a|0}function zHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Cc(a);if(d>>>0<b>>>0){jHa(a,b-d|0,c);return}if(d>>>0>b>>>0){Vt(a,p[a>>2]+b|0)}}function tX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return Mea(a,b,c,d,e,f,g,h,i,j)|0}function sX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;return Kea(a,b,c,d,e,f,g,h,i,j)|0}function rsa(a,b){var c=0;c=nc(a);if(c>>>0<b>>>0){nsa(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+v(b,12)|0;nc(a);pL(a,b);zs(a)}}function rpa(a){var b=0,c=0;if(p[a>>2]){Dd(a);pK(a);bp(a);Eo(qb(a),p[a>>2],Le(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function qD(a,b,c,d,e,f){a=m[p[p[a+8>>2]+4>>2]](a+8|0)|0;a=Eq(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){p[b>>2]=((a|0)/12|0)%12}}function nD(a,b,c,d,e,f){a=m[p[p[a+8>>2]+4>>2]](a+8|0)|0;a=Cq(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){p[b>>2]=((a|0)/12|0)%12}}function lIa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-160|0;fb=b;c=-1;d=b;a=iIa(a,b);if(!a){UQ(d)}if(a){c=WQ(b)}fb=b+160|0;return c|0}function gua(a){var b=0,c=0;if(p[a>>2]){ne(a);iM(a);pu(a);gh(qb(a),p[a>>2],hh(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function eoa(a){var b=0,c=0;if(p[a>>2]){Cc(a);JA(a);gp(a);cg(qb(a),p[a>>2],Hf(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function csa(a){var b=0,c=0;if(p[a>>2]){nc(a);qL(a);zs(a);nh(qb(a),p[a>>2],_f(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function a6(a){a:{if((re(a)|0)!=79){break a}if((re(a)|0)!=103){break a}if((re(a)|0)!=103){break a}return(re(a)|0)==83}return 0}function __(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){n[d|0]=q[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function Uya(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-208|0;fb=b;c=-1;d=b;a=vya(a,b);if(!a){kN(d)}if(a){c=pN(b)}fb=b+208|0;return c|0}function Sza(a){var b=0,c=0;if(p[a>>2]){Dd(a);NN(a);bp(a);Mf(qb(a),p[a>>2],Le(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function Kka(a){var b=0,c=0;if(p[a>>2]){of(a);HJ(a);AI(a);ix(qb(a),p[a>>2],Wi(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function Dla(a){var b=0,c=0;if(p[a>>2]){Dd(a);WI(a);bp(a);Mf(qb(a),p[a>>2],Le(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function DNa(a,b,c,d){if((xk(11872)|0)==(b|0)){Sb(d,c);return}if(!JT(a,b,c,d)){Sb(d,c);return}if((xk(11877)|0)==(b|0)){CNa(a)}}function $L(a,b,c,d,e){p[a+12>>2]=e;p[a+8>>2]=d;p[a+4>>2]=c;p[a>>2]=b;if(b){oe(b,a)}if(c){oe(c,a)}if(d){oe(d,a)}if(e){oe(e,a)}}function $B(a){p[114610]=0;R(a|0);a=p[114610];p[114610]=0;if((a|0)!=1){p[114610]=0;E()}a=O(0)|0;H()|0;T(a|0)|0;p[114610]=0;E()}function zU(a,b,c,d){var e=0,f=0;e=(b|0)/8|0;a=e+a|0;f=lg(d,a);return(lg(d,a+1|0)<<8|f<<16|lg(d,a+2|0))<<(b-(e<<3)|0)+8>>32-c}function zAa(a,b){var c=0;c=Bb(a);if(c>>>0<b>>>0){yAa(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<2)|0;Bb(a);YN(a,b);Hg(a)}}function wMa(a,b){var c=0;c=fc(a);if(c>>>0<b>>>0){vMa(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<1)|0;fc(a);OS(a,b);Fp(a)}}function mqa(a){n[a+26|0]=0;o[a+24>>1]=0;p[a+16>>2]=0;p[a+20>>2]=-1;p[a+8>>2]=-1;p[a+12>>2]=-1;p[a>>2]=0;p[a+4>>2]=0;return a}function kGa(a,b){var c=0;c=Bb(a);if(c>>>0<b>>>0){jGa(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<2)|0;Bb(a);iQ(a,b);Hg(a)}}function _8(a){var b=0,c=0;if(p[a>>2]){Dd(a);_F(a);bp(a);Eo(qb(a),p[a>>2],Le(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function TY(a,b){var c=0;a=gZ(a,p[21199]);c=ve(a);if(c>>>0>=1024){ac(b,a,1023);n[b+1023|0]=0;return 68}ac(b,a,c+1|0);return 0}function QDa(a,b){var c=0;c=Bb(a);if(c>>>0<b>>>0){PDa(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<2)|0;Bb(a);qP(a,b);Hg(a)}}function GDa(a,b){var c=0;c=fc(a);if(c>>>0<b>>>0){FDa(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<1)|0;fc(a);lP(a,b);Fp(a)}}function BI(a){a=a|0;var b=0,c=0;b=ke(a);while(1){c=b;if(c&65535){b=c+ -1|0;if(!Cg(a,b&65535)){continue}}break}return c&65535}function yE(a){p[a>>2]=55760;Uu(a+4|0);p[a+24>>2]=0;p[a+28>>2]=0;p[a+16>>2]=0;p[a+20>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;return a}function woa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+1304392|0;if(!kd(c)){roa(b+8|0,a+24620|0);ZJ(c,Cd(b+8|0));Sr(b+8|0)}fb=b+16|0}function qY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Xf(a,p[b+8>>2],0)){Eu(b,c,d);return}a=p[a+8>>2];m[p[p[a>>2]+28>>2]](a,b,c,d)}function qN(a){var b=0,c=0;b=q[a+33|0];c=b>>>24|0;a=q[a+31|0]?1120:1056;b=a+(b<<8)|0;c=b>>>0<a>>>0?c+1|0:c;a=b;ib=c;return a}function mC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){p[d>>2]=b;d=d+4|0;c=c+ -1|0;if(c){continue}break}}return a|0}function fNa(a,b){a=a|0;b=b|0;var c=0,d=0;b=fb-48|0;fb=b;c=-1;d=b;a=GMa(a,b);if(!a){WS(d)}if(a){c=nT(b)}fb=b+48|0;return c|0}function eK(a){a=a|0;p[a>>2]=0;xi(a+4|0);p[a+152>>2]=0;p[a+156>>2]=0;p[a+144>>2]=0;p[a+148>>2]=0;Jb(a+16|0,0,128);return a|0}function e5(a){a=a|0;var b=0;if((m[p[p[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=p[a+12>>2];p[b+12>>2]=a+1;return og(n[a|0])|0}function dk(a,b){var c=0;a:{if(s[a+12>>2]<b>>>0){c=0;if(m[p[p[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}p[a+12>>2]=b;c=1}return c}function X9(a,b){var c=0;c=fb-32|0;fb=c;n[c+16|0]=44;p[c+8>>2]=-1;p[c+12>>2]=0;p[c>>2]=1058;p[c+4>>2]=1;Gha(a,b,c);fb=c+32|0}function Tq(a){p[a>>2]=55696;Uu(a+4|0);p[a+24>>2]=0;p[a+28>>2]=0;p[a+16>>2]=0;p[a+20>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;return a}function LFa(a,b){var c=0;a:{if(!b){break a}if(!Hb(a,b)){break a}if(b>>>0<=3){return KFa(a,b)}c=Lf(a);Sb(a,b+ -4|0)}return c}function Jf(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=lg(d,a);return((lg(d,a+1|0)<<8|e<<16|lg(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function Bna(a,b){var c=0,d=0;p[a>>2]=p[b>>2];c=b+4|0;d=a+4|0;if((c|0)!=(d|0)){EJ(d,p[c>>2],p[c+4>>2])}ac(a+16|0,b+16|0,144)}function rD(a,b,c,d,e,f){a=m[p[p[a+8>>2]>>2]](a+8|0)|0;a=Eq(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){p[b>>2]=((a|0)/12|0)%7}}function oD(a,b,c,d,e,f){a=m[p[p[a+8>>2]>>2]](a+8|0)|0;a=Cq(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){p[b>>2]=((a|0)/12|0)%7}}function oCa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,1024);a:{if(d){EO(c+8|0,b);yd(a,c+8|0);break a}DO(b)}fb=c+16|0;return d}function lV(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Ek(c+8|0,p[b>>2]);hV(d,a,p[p[b+4>>2]>>2],p[p[b+8>>2]>>2]);sb(a);fb=c+16|0}function k4(a,b){p[a+20>>2]=0;p[a+24>>2]=b;p[a+12>>2]=0;p[a+4>>2]=4098;p[a+8>>2]=6;p[a+16>>2]=!b;Jb(a+32|0,0,40);Uu(a+28|0)}function f7(a){a=a|0;var b=0;if(!a){return-2}b=p[a+28>>2];if(!b){return 0}m[p[a+36>>2]](p[a+40>>2],b);p[a+28>>2]=0;return 0}function WBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=af(a,1024);a:{if(d){EO(c+8|0,b);Ls(a,c+8|0);break a}DO(b)}fb=c+16|0;return d}function Os(a){a=a|0;var b=0;b=fb-16|0;fb=b;p[b+12>>2]=a;p[b+8>>2]=2147483647;a=p[Cb(b+12|0,b+8|0)>>2];fb=b+16|0;return a|0}function Nr(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(c>b*1e-7){continue}break}return+b}function NFa(a,b){var c=0;a:{if(!b){break a}if(!Hb(a,b)){break a}if(b>>>0<=3){return FT(a,b)}c=Lf(a);Sb(a,b+ -4|0)}return c}function MFa(a,b){var c=0;a:{if(!b){break a}if(!Hb(a,b)){break a}if(b>>>0<=1){return ET(a,1)}c=kg(a);Sb(a,b+ -2|0)}return c}function Hya(a,b){var c=0;c=fb-16|0;fb=c;b=q[b|0]|q[b+1|0]<<8;o[c+14>>1]=(b<<24|b<<8&16711680)>>>16;aia(a,c+14|0);fb=c+16|0}function BZ(a,b){var c=0;c=gd(a);if(c>>>0<b>>>0){bZ(a,b-c|0);return}if(c>>>0>b>>>0){b=p[a>>2]+(b<<4)|0;gd(a);RB(a,b);QB(a)}}function vIa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(Hb(a,6)){xz(c+8|0,b);yd(a,c+8|0);break a}n[c+7|0]=0;kj(b,6,c+7|0)}fb=c+16|0}function tAa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(Hb(a,5)){Xz(c+8|0,b);yd(a,c+8|0);break a}n[c+7|0]=0;kj(b,5,c+7|0)}fb=c+16|0}function t3(a,b){var c=0,d=w(0);c=fb-16|0;fb=c;av(c,a,b,0);d=OD(p[c>>2],p[c+4>>2],p[c+8>>2],p[c+12>>2]);fb=c+16|0;return d}function lNa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(Hb(a,3)){iA(c+8|0,b);yd(a,c+8|0);break a}n[c+7|0]=0;kj(b,3,c+7|0)}fb=c+16|0}function kFa(a){var b=0;b=gk(a);if(b>>>0<64){fFa(a,64-b|0);return}if(b>>>0>64){b=p[a>>2]+2112|0;gk(a);RP(a,b);vl(a);gk(a)}}function jJ(a,b){var c=0;if(!(q[a|0]!=q[b|0]|u[a+8>>3]!=u[b+8>>3]|q[a+16|0]!=q[b+16|0])){c=p[a+20>>2]==p[b+20>>2]}return c}function IM(a){a=a|0;p[a+700>>2]=0;o[a+862>>1]=0;p[a+688>>2]=0;p[a>>2]=0;p[a+4>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;p[a+16>>2]=0}function HMa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(Hb(a,4)){jh(c+8|0,b);yd(a,c+8|0);break a}n[c+7|0]=0;kj(b,4,c+7|0)}fb=c+16|0}function By(a){p[a>>2]=0;p[a+4>>2]=0;p[a+24>>2]=0;p[a+28>>2]=0;p[a+16>>2]=0;p[a+20>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;return a}function zBa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,32);a:{if(d){tO(c+8|0,b);yd(a,c+8|0);break a}sO(b)}fb=c+16|0;return d}function xx(a,b){var c=0;c=fb-16|0;fb=c;vb(c+8|0,a+1074308|0,7);a=tb(c+8|0);fb=c+16|0;return p[(b<<2)+(a?25248:26272)>>2]}function wx(a,b){var c=0;c=fb-16|0;fb=c;vb(c+8|0,a+1074308|0,7);a=tb(c+8|0);fb=c+16|0;return p[(b<<2)+(a?26272:25248)>>2]}function wK(a,b){var c=0;c=fb-16|0;fb=c;vb(c+8|0,a+1074308|0,7);a=tb(c+8|0);fb=c+16|0;return p[(b<<2)+(a?25120:25184)>>2]}function vK(a,b){var c=0;c=fb-16|0;fb=c;vb(c+8|0,a+1074308|0,7);a=tb(c+8|0);fb=c+16|0;return p[(b<<2)+(a?25184:25120)>>2]}function cZ(a,b){var c=0,d=0;c=fb-16|0;fb=c;n[c+15|0]=0;d=-1;if(b>>>0>0){b=Kn(a,b,c+15|0);d=b?b-a|0:-1}fb=c+16|0;return d}function _ua(a){if(!(w(4294967296)>a)){return-1}if(!(w(0)<a)){return 0}if(a<w(4294967296)&a>=w(0)){return~~a>>>0}return 0}function Wu(a,b,c){c=p[c>>2];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=p[a>>2]){break a}}else{a=b}return a}a=a+4|0;continue}}function Koa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+128e3|0;while(1){Fna(a);a=a+32|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function wM(a,b,c,d,e,f,g){n[a+17|0]=g;n[a+16|0]=f;p[a+12>>2]=e;p[a+8>>2]=d;p[a+4>>2]=c;p[a>>2]=b;if(d){uM(a,1);uM(a,0)}}function wJa(a,b){p[114610]=0;N(25,a|0,v(b,48)|0,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function vM(a,b,c,d,e,f,g){n[a+17|0]=g;n[a+16|0]=f;p[a+12>>2]=e;p[a+8>>2]=d;p[a+4>>2]=c;p[a>>2]=b;if(d){tM(a,1);tM(a,0)}}function tpa(a,b){p[114610]=0;N(25,a|0,v(b,24)|0,8);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function sqa(a){if(!(w(65535)>a)){return 65535}if(!(w(0)<a)){return 0}if(a<w(4294967296)&a>=w(0)){return~~a>>>0}return 0}function rV(a){a=a|0;var b=0;a:{if(!me(-1,p[a+76>>2])){a=p[a+76>>2];break a}b=a;a=FH(a,32);p[b+76>>2]=a}return a<<24>>24}function kT(a,b){a=a|0;b=b|0;var c=0;c=fc(a);if(c>>>0<b>>>0){TMa(a,b-c|0);return}if(c>>>0>b>>>0){Gp(a,p[a>>2]+(b<<1)|0)}}function eG(a,b){p[114610]=0;N(25,a|0,v(b,324)|0,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function _I(a){var b=0;b=a;if((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))==1179011410){return Dz(a)>>>0>80}return 0}function Vsa(a){var b=0,c=0;a=a<<24;while(1){b=a<<1;a=(a|0)>-1?b:b^79764919;c=c+1|0;if((c|0)!=8){continue}break}return a}function VBa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+1024|0;while(1){UBa(a);a=a+16|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function UEa(a,b){p[114610]=0;N(25,a|0,v(b,33)|0,1);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function SBa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(af(a,2)){zk(c+8|0,b);Ls(a,c+8|0);break a}n[c+7|0]=0;TS(b,c+7|0)}fb=c+16|0}function Rj(a,b,c){var d=0;d=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=d;d=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=d;Ww(a,c)}function QGa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Hb(a,4);a:{if(d){jh(c+8|0,b);yd(a,c+8|0);break a}ZP(b)}fb=c+16|0;return d}function Opa(a,b){var c=0,d=0,e=0;while(1){d=(c<<2)+a|0,e=Wua(b),p[d>>2]=e;c=c+1|0;if((c|0)!=12){continue}break}return a}function Kna(a,b){p[114610]=0;N(25,a|0,v(b,52)|0,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function HDa(a,b){p[114610]=0;N(25,a|0,v(b,20)|0,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function GKa(a){a=a+4|0;a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function DMa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(Hb(a,2)){zk(c+8|0,b);yd(a,c+8|0);break a}n[c+7|0]=0;TS(b,c+7|0)}fb=c+16|0}function D5(a,b,c){if(a|b){while(1){c=c+ -1|0;n[c|0]=a&7|48;a=(b&7)<<29|a>>>3;b=b>>>3|0;if(a|b){continue}break}}return c}function $M(a){var b=0;b=a+68|0;if(!(!(q[b|0]|q[b+1|0]<<8)|(q[b|0]|q[b+1|0]<<8)>>>0>127)){return!hd(a,17901,17)}return 0}function ud(a){var b=0;b=fb-16|0;fb=b;p[b+12>>2]=83600;p[b+8>>2]=83704;p[a>>2]=p[b+12>>2];p[a+4>>2]=p[b+8>>2];fb=b+16|0}function tB(a,b){p[114610]=0;N(25,a|0,v(b,24)|0,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function s3(a,b){var c=0,d=0;c=fb-16|0;fb=c;av(c,a,b,1);d=Av(p[c>>2],p[c+4>>2],p[c+8>>2],p[c+12>>2]);fb=c+16|0;return d}function oE(a){var b=0;b=p[a+12>>2];if((b|0)==p[a+16>>2]){return m[p[p[a>>2]+40>>2]](a)|0}p[a+12>>2]=b+4;return p[b>>2]}function ioa(a,b){a=a|0;b=b|0;if(b>>>0>255){return 20461}a=p[((b<<2)+a|0)+900380>>2];if(!a){return 20461}return a+492|0}function ii(a,b,c){a:{if(($j(a,b)|0)==255){break a}_j(a,b);To(a,b,0,0);if(!c){break a}a=Yb(a+58|0,b);n[a|0]=q[a|0]|128}}function dya(a,b){p[114610]=0;N(25,a|0,v(b,9)|0,1);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function a5(a){a=a|0;var b=0;if((m[p[p[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=p[a+12>>2];p[b+12>>2]=a+4;return p[a>>2]}function WP(a){var b=0;b=a;if((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))==1279544644){return q[a+4|0]<32}return 0}function Vf(a,b){a=a|0;b=b|0;var c=0;c=Bb(a);if(c>>>0<b>>>0){cU(a,b-c|0);return}if(c>>>0>b>>>0){Rt(a,p[a>>2]+(b<<2)|0)}}function Tta(a,b,c){var d=0;kT(c,p[a>>2]);if(p[a>>2]){while(1){bM(b,kc(c,d));d=d+1|0;if(d>>>0<s[a>>2]){continue}break}}}function Td(a,b){var c=w(0);a:{if(b>w(1)){break a}c=t[a>>2];if(!(c>=b)){t[a>>2]=b;return}if(c<=w(1)){break a}t[a>>2]=1}}function MR(a){var b=0;a:{if(hd(a,12667,20)){break a}b=a+25|0;if(!q[b|0]|q[b|0]>8){break a}return n[a+47|0]>-1}return 0}function Lya(a,b){a=a|0;b=b|0;var c=0;o[a+34>>1]=0;c=fb-16|0;fb=c;wya(a+43|0);fb=c+16|0;p[a+20>>2]=0;vd(a,b);return a|0}function LN(a,b){p[114610]=0;N(25,a|0,v(b,56)|0,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function KV(a){p[a>>2]=0;p[a+4>>2]=0;p[a+24>>2]=0;p[a+28>>2]=0;p[a+16>>2]=0;p[a+20>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;lB(a)}function GJa(a,b){p[114610]=0;N(25,a|0,v(b,6)|0,1);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function Foa(a,b){xb(a,b);xb(a+12|0,b+12|0);xb(a+24|0,b+24|0);xb(a+36|0,b+36|0);xb(a+48|0,b+48|0);p[a+60>>2]=p[b+60>>2]}function D3(a,b){p[114610]=0;N(25,a|0,v(b,12)|0,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function re(a){var b=0;b=p[a+32>>2];a:{if(b>>>0>=s[a+40>>2]){p[a+96>>2]=1;a=0;break a}p[a+32>>2]=b+1;a=q[b|0]}return a}function hKa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a- -64|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function Wsa(){var a=0,b=0,c=0;while(1){b=(a<<2)+87568|0,c=Vsa(a&255),p[b>>2]=c;a=a+1|0;if((a|0)!=256){continue}break}}function Gz(a){a=a|0;var b=0;b=fb-16|0;fb=b;p[b+12>>2]=a;p[b+8>>2]=65535;a=r[Cb(b+12|0,b+8|0)>>1];fb=b+16|0;return a|0}function FIa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a- -64|0;while(1){eA(a);a=a+2|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function $ua(a,b,c){var d=0;d=64;p[a+764>>2]=64;if(b){d=r[b+32>>1];p[a+764>>2]=d}if(c){p[a+764>>2]=v(p[c+4>>2],d)>>>6}}function xZ(a){var b=0,c=0,d=0;c=p[a+4>>2];b=p[a>>2];a=p[a+8>>2];b=b+(a>>1)|0;d=b;if(a&1){c=p[c+p[b>>2]>>2]}m[c|0](d)}function wP(a){a=a|0;var b=0;b=fb-16|0;fb=b;o[b+14>>1]=a;o[b+12>>1]=255;a=q[rf(b+14|0,b+12|0)|0];fb=b+16|0;return a|0}function vLa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+120|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function pLa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+512|0;while(1){vt(a);a=a+4|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function iS(a){var b=0;b=a;if((q[b|0]|q[b+1|0]<<8|(q[b+2|0]<<16|q[b+3|0]<<24))==810369604){return q[a+4|0]<4}return 0}function dc(a,b){var c=0;Am(a);p[a+4>>2]=0;p[a>>2]=83556;c=a;a=fd(wb(b)+1|0);p[c+4>>2]=a;if(a){ac(a,Ib(b),wb(b)+1|0)}}function YAa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+128|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function RBa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+512|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function PS(a,b){a=a|0;b=b|0;var c=0;c=p[b+4>>2];if(c){Zb(a,c,p[b>>2]);return}b=b+8|0;if(!cd(b)){Ei(a,b);return}Df(a)}function zpa(a){if(!(w(255)>a)){return 255}if(!(w(0)<a)){return 0}if(a<w(4294967296)&a>=w(0)){return~~a>>>0}return 0}function wya(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+22|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function rNa(a,b){var c=0;c=fb-16|0;fb=c;o[c+12>>1]=65535;o[c+14>>1]=b;qNa(a,r[rf(12e3,c+14|0)>>1],c+12|0);fb=c+16|0}function rBa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+32|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function jia(a,b){p[114610]=0;N(25,a|0,b<<11,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function Usa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+27|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function UBa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+16|0;while(1){vt(a);a=a+4|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function SE(a,b,c){var d=0,e=0,f=0;e=c*c;u[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;u[b>>3]=d*d+(c*c-e+(c+c)*d)}



function Qpa(a,b,c){var d=0;if((b|0)>=1){while(1){p[a>>2]=p[c>>2];a=a+4|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function Ona(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+20|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function Jsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=$p(e,a,d);un(qb(a),b,c,d+4|0);Db(d);fb=e+16|0}function IZ(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+256|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function EMa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+16|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function CCa(a){var b=0,c=0;b=fb-16|0;fb=b;if(Pp(a,b+8|0)){a=b+8|0;c=(q[a|0]|q[a+1|0]<<8)<<16>>16}fb=b+16|0;return c}function Aoa(a,b){var c=0;c=fb-16|0;fb=c;Sn(c+8|0,kh(c,b));zoa(a,c+8|0);p[a+16>>2]=0;p[a+12>>2]=0;fb=c+16|0;return a}function $j(a,b){a=a+58|0;if(n[Yb(a,b)|0]<0){return 255}if(q[Yb(a,b)|0]!=255){a=q[Yb(a,b)|0]&127}else{a=255}return a}function xMa(a,b){p[114610]=0;N(25,a|0,b<<1,1);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function vsa(a,b){p[114610]=0;N(25,a|0,b<<4,8);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function tBa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+6|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function sZ(a){var b=0;b=a+8|0;if(!p[b>>2]){m[p[p[a>>2]+16>>2]](a);return}if((mu(b)|0)==-1){m[p[p[a>>2]+16>>2]](a)}}function sKa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+8|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function ry(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=Cl(e,a,d);un(qb(a),b,c,d+4|0);Db(d);fb=e+16|0}function qu(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;p[c>>2]=p[b>>2];d=c,e=p[b>>2]+_A(b)|0,p[d+4>>2]=e;eW(a,c);fb=c+16|0}function pMa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+3|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function nk(a,b){a=a|0;b=b|0;var c=0;c=Cc(a);if(c>>>0<b>>>0){PJa(a,b-c|0);return}if(c>>>0>b>>>0){vR(a,p[a>>2]+b|0)}}function lta(a,b){p[114610]=0;N(25,a|0,b<<2,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function lGa(a,b){p[114610]=0;N(25,a|0,b<<2,1);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function fM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=Gh(e,a,d);un(qb(a),b,c,d+4|0);Db(d);fb=e+16|0}function YBa(a,b){p[114610]=0;N(25,a|0,b<<5,8);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function UD(a,b,c,d,e,f,g,h,i){p[a>>2]=b;p[a+4>>2]=c;p[a+8>>2]=d;p[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function PFa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+4|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function P1(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b+ -1|0;if(a>>>0>=b>>>0){break a}bh(a,b);a=a+1|0;continue}}}function Ora(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+7|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function O1(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b+ -4|0;if(a>>>0>=b>>>0){break a}Qb(a,b);a=a+4|0;continue}}}function Mw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=tp(e,a,d);HI(qb(a),b,c,d+4|0);Db(d);fb=e+16|0}function KCa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a+2|0;while(1){Xe(a);a=a+1|0;if((c|0)!=(a|0)){continue}break}fb=b+16|0}function Fha(a){a=a|0;var b=0,c=0;p[p[a+20>>2]>>2]=a;c=p[a+12>>2];b=p[c>>2];p[a+4>>2]=b;if(b){p[b+8>>2]=a}p[c>>2]=a}function Dp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=he(e,a,d);un(qb(a),b,c,d+4|0);Db(d);fb=e+16|0}function Bsa(a,b){p[114610]=0;N(25,a|0,b<<3,8);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function yta(a){p[a+16>>2]=0;p[a+20>>2]=0;p[a+36>>2]=0;n[a+40|0]=1;p[a+24>>2]=0;p[a+28>>2]=0;o[a+32>>1]=0;return a}function vha(a,b){var c=0;c=fb-16|0;fb=c;kI(c+8|0,Tb(c,b));nu(a,c+8|0);p[a+12>>2]=0;p[a+8>>2]=0;fb=c+16|0;return a}function tV(a,b){p[114610]=0;N(25,a|0,b<<3,1);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function jU(a,b){p[114610]=0;N(25,a|0,b<<1,2);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function fB(a,b){p[114610]=0;N(25,a|0,b<<5,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function dla(a,b,c){var d=0;if((b|0)>=1){while(1){n[a|0]=q[c|0];a=a+1|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function _ia(a,b){a=a|0;b=b|0;var c=0;a:{if(Bb(a)>>>0>511){break a}if(!kd(b)){break a}c=p[b>>2];eI(a,b)}return c|0}function Rka(a){var b=0,c=0;if(p[a>>2]){ks(a);Ie(qb(a),p[a>>2],rd(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function Rja(a){var b=0,c=0;if(p[a>>2]){bi(a);Ie(qb(a),p[a>>2],rd(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function OB(a,b){p[114610]=0;N(25,a|0,b<<4,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function NT(a,b){p[114610]=0;N(25,a|0,b<<2,2);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function Hia(a,b,c){a=a|0;b=b|0;c=w(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=tK(w(c*w(255))),n[d|0]=e;Gr(a)}}function u5(a,b){p[114610]=0;N(25,a|0,b|0,1);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function rM(a){var b=0,c=0;if(p[a>>2]){Bp(a);Cn(qb(a),p[a>>2],If(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function qNa(a,b,c){var d=0;d=fc(a);if(d>>>0<b>>>0){pNa(a,b-d|0,c);return}if(d>>>0>b>>>0){Gp(a,p[a>>2]+(b<<1)|0)}}function pHa(a,b,c){var d=0;d=fb-16|0;fb=d;kGa(b,c);c=Hb(a,c<<2);if(c){az(d+8|0,b);yd(a,d+8|0)}fb=d+16|0;return c}function oH(a){a=a|0;p[a+4244>>2]=0;p[a+4248>>2]=0;p[a+4228>>2]=0;p[a+4232>>2]=0;a=a+4252|0;p[a>>2]=0;p[a+4>>2]=0}function nP(a){var b=0,c=0;if(p[a>>2]){OP(a);Kt(qb(a),p[a>>2],rd(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function lxa(a){a=a|0;var b=0;b=RM(a);if((b|0)!=(a|0)){while(1){kxa(a);a=a+32|0;if((b|0)!=(a|0)){continue}break}}}function lE(a,b){a=a|0;b=b|0;var c=0;c=p[a>>2];a:{if(!c){break a}if(!me(LG(c,b),-1)){break a}p[a>>2]=0}return a|0}function kE(a,b){a=a|0;b=b|0;var c=0;c=p[a>>2];a:{if(!c){break a}if(!me(D4(c,b),-1)){break a}p[a>>2]=0}return a|0}function gW(a,b,c){a:{if(Cc(a)>>>0<=b>>>0){break a}if(Cc(a)>>>0<c>>>0){break a}return Cc(a)-b>>>0>=c>>>0}return 0}function es(a){var b=0;b=1;a:{switch(q[a+3|0]+ -4|0){default:b=q[a+2|0]==11;break;case 0:case 2:break a}}return b}function eL(a){var b=0,c=0;if(p[a>>2]){fs(a);cg(qb(a),p[a>>2],Hf(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function dma(a,b){a=a|0;b=b|0;n[b+38|0]=q[a+202|0];n[b+39|0]=q[a+203|0];n[b+40|0]=q[a+204|0];n[b+41|0]=q[a+205|0]}function cEa(a,b,c){var d=0;d=fb-16|0;fb=d;QDa(b,c);c=Hb(a,c<<2);if(c){az(d+8|0,b);yd(a,d+8|0)}fb=d+16|0;return c}function aka(a){var b=0;b=fb-16|0;fb=b;o[b+14>>1]=a;o[b+12>>1]=32767;a=o[rf(b+14|0,b+12|0)>>1];fb=b+16|0;return a}function YDa(a,b,c){var d=0;d=fb-16|0;fb=d;GDa(b,c);c=Hb(a,c<<1);if(c){NS(d+8|0,b);yd(a,d+8|0)}fb=d+16|0;return c}function Uj(a,b){var c=0;c=b&15;if(c){n[a+844|0]=c<<2}b=b&240;if(b){n[a+843|0]=b>>>4}p[a+88>>2]=p[a+88>>2]|131072}function PMa(a,b,c){var d=0;d=fb-16|0;fb=d;wMa(b,c);c=Hb(a,c<<1);if(c){NS(d+8|0,b);yd(a,d+8|0)}fb=d+16|0;return c}function MGa(a,b,c){var d=0;d=Bb(a);if(d>>>0<b>>>0){rGa(a,b-d|0,c);return}if(d>>>0>b>>>0){nQ(a,p[a>>2]+(b<<2)|0)}}function Ln(a,b){var c=0;c=fb-16|0;fb=c;Sn(c+8|0,kh(c,b));nu(a,c+8|0);p[a+12>>2]=0;p[a+8>>2]=0;fb=c+16|0;return a}function II(a){var b=0,c=0;if(p[a>>2]){LI(a);mt(qb(a),p[a>>2],ri(a));b=qb(a),c=0,p[b>>2]=c;p[a>>2]=0;p[a+4>>2]=0}}function CAa(a,b,c){var d=0;d=fb-16|0;fb=d;zAa(b,c);c=Hb(a,c<<2);if(c){az(d+8|0,b);yd(a,d+8|0)}fb=d+16|0;return c}function $K(a,b){var c=0;c=b&15;if(c){n[a+847|0]=c<<2}b=b&240;if(b){n[a+846|0]=b>>>4}p[a+88>>2]=p[a+88>>2]|262144}function wf(a,b,c){var d=0;a:{if(b>c){break a}d=u[a>>3];if(!(d>=b)){u[a>>3]=b;return}if(d<=c){break a}u[a>>3]=c}}function tsa(a){var b=0,c=0;while(1){b=a&1|b<<1;a=(a&254)>>>1|0;c=c+1|0;if((c|0)!=8){continue}break}return b&255}function JDa(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;fb=b+16|0}function zG(a){var b=0;a:{while(1){if(!p[(b<<2)+a>>2]){break a}b=b+1|0;if((b|0)!=4){continue}break}b=4}return b}function xk(a){a=q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function vq(){var a=0;p[114610]=0;a=p[114610];p[114610]=0;if((a|0)!=1){return p[14748]}a=O(0)|0;H()|0;rb(a);E()}function vKa(a,b,c){if((a|0)!=(b|0)){while(1){OR(c,a);c=c+2|0;a=a+2|0;if((b|0)!=(a|0)){continue}break}}return c}function uq(){var a=0;p[114610]=0;a=p[114610];p[114610]=0;if((a|0)!=1){return p[15136]}a=O(0)|0;H()|0;rb(a);E()}function rJ(a,b){a:{switch(b+ -1|0){default:return a+724|0;case 0:return a+736|0;case 1:break a}}return a+748|0}function lea(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=Mb(b,38051);dc(a,c);pb(c);p[a>>2]=83536;fb=b+16|0;return a|0}function Yo(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=p[a>>2];p[c+8>>2]=p[c+8>>2]+(b<<2);fb=c+16|0;return p[c+8>>2]}function Vn(){var a=0;p[114610]=0;a=p[114610];p[114610]=0;if((a|0)!=1){return p[14552]}a=O(0)|0;H()|0;rb(a);E()}function Rz(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;p[c+12>>2]=b;b=a;a=Mb(c,p[c+12>>2]);Cy(b,a);pb(a);fb=c+16|0}function Ng(a){a:{a=p[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function DY(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=p[Ic(b+8|0,p[a+4>>2])>>2],d=1,n[c|0]=d;n[p[a+8>>2]]=1;fb=b+16|0}function Cna(a,b,c){var d=0;if((b|0)>=1){while(1){Bna(a,c);a=a+160|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function Bea(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=Mb(b,38032);dc(a,c);pb(c);p[a>>2]=83516;fb=b+16|0;return a|0}function yQ(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(c+1|0){case 0:case 2:mh(a,b);return;default:break a}}SFa(a,b,c)}function sI(a){var b=0;b=fb-16|0;fb=b;p[b+12>>2]=a;p[b+8>>2]=32767;a=o[Cb(b+12|0,b+8|0)>>1];fb=b+16|0;return a}function qs(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=p[a+4>>2];p[c>>2]=p[b+4>>2];a=Ab(c+8|0,c);fb=c+16|0;return a}function pD(a,b,c,d,e){b=Nh(b,c,d,e,4);if(!(q[d|0]&4)){p[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)+ -1900}}function ot(a,b){var c=0;c=fb-16|0;fb=c;p[c+12>>2]=(v(a,b)>>>0)/255;Vd(c+12|0,0,15);fb=c+16|0;return q[c+12|0]}function mD(a,b,c,d,e){b=Mh(b,c,d,e,4);if(!(q[d|0]&4)){p[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)+ -1900}}function kM(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(c+1|0){case 0:case 3:bM(a,b);return;default:break a}}Cta(a,b,c)}function gJ(a){p[114610]=0;N(25,a|0,28,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function Zd(a,b){var c=0;c=p[a+4>>2];if(b){a=p[a>>2];p[a>>2]=p[a>>2]|c;return}a=p[a>>2];p[a>>2]=p[a>>2]&(c^-1)}function Xf(a,b,c){if(!c){return p[a+4>>2]==p[b+4>>2]}if((a|0)==(b|0)){return 1}return!Th(p[a+4>>2],p[b+4>>2])}function S3(a,b){a=a|0;b=b|0;var c=0,d=0;m[p[p[a>>2]+24>>2]](a)|0;b=kv(b);p[a+36>>2]=b;c=a,d=jm(b),n[c+44|0]=d}function P3(a,b){a=a|0;b=b|0;var c=0,d=0;m[p[p[a>>2]+24>>2]](a)|0;b=jv(b);p[a+36>>2]=b;c=a,d=jm(b),n[c+44|0]=d}function Mna(a,b,c){var d=0;if((b|0)>=1){while(1){Yr(a,c);a=a+896|0;d=(b|0)>1;b=b+ -1|0;if(d){continue}break}}}function Jx(a){p[114610]=0;N(25,a|0,40,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function GZ(a,b){p[114610]=0;ov(a,b<<2,4);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function EY(a){var b=0;a:{a=p[a+8>>2];b=q[a|0];if((b|0)!=1){if(b&2){break a}n[a|0]=2;a=1}else{a=0}return a}E()}function rC(a,b,c){p[114610]=0;pC(a,b,c);a=p[114610];p[114610]=0;if((a|0)!=1){return}a=O(0)|0;H()|0;rb(a);E()}function QO(a,b){n[a+6|0]=255;p[a+16>>2]=0;o[a+4>>1]=0;p[a>>2]=0;if(!(b<0)){u[a+8>>3]=b;p[a+16>>2]=3}return a}function NCa(a){if(!(4294967295>a)){return-1}if(!(0<a)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function Fm(a){var b=0;while(1){if(q[b+32192|0]==(a|0)){return b}b=b+1|0;if(b>>>0<43){continue}break}return 0}function zca(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=b;b=p[c+8>>2];hI(a,b);_b(a);Um($g(c+8|0));Jx(b);fb=c+16|0}function rqa(a){if(!(65535>a)){return 65535}if(!(0<a)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function opa(a,b){var c=0;if(!b){return a}while(1){c=b;b=(a>>>0)%(b>>>0)|0;a=c;if(b){continue}break}return c}function oA(a,b){a:{switch(b+ -1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function cl(a,b){var c=0;c=Bb(a);if(c>>>0<b>>>0){cka(a,b-c|0);return}if(c>>>0>b>>>0){Jw(a,p[a>>2]+(b<<2)|0)}}function ay(a){Mua(a);n[a+12|0]=0;n[a+13|0]=0;n[a+14|0]=0;n[a+15|0]=0;n[a+16|0]=65280;n[a+17|0]=255;return a}function Vo(a,b){a=a|0;b=b|0;if(fc(a)>>>0>b>>>0){a=Cg(p[a+24>>2]+484344|0,r[wk(a,b)>>1])}else{a=0}return a|0}function GI(a){var b=0;if(of(a)){while(1){FI(a,b&65535);b=b+1|0;if(of(a)>>>0>(b&65535)>>>0){continue}break}}}function AP(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;o[c+14>>1]=b;if((qt(a)|0)!=65535){zS(a,c+14|0)}fb=c+16|0}function wKa(a,b,c){if((a|0)!=(b|0)){while(1){c=c+ -2|0;b=b+ -2|0;OR(c,b);if((a|0)!=(b|0)){continue}break}}}function uE(a){var b=0;b=p[a+12>>2];if((b|0)==p[a+16>>2]){return m[p[p[a>>2]+36>>2]](a)|0}return og(n[b|0])}function lF(a,b,c,d){t[d+4>>2]=c+a;a=w(a+w(c*w(-.5)));b=w(b*w(.8660253882408142));t[d+8>>2]=a-b;t[d>>2]=a+b}function ixa(a){var b=0;b=RM(a);if((b|0)!=(a|0)){while(1){jxa(a);a=a+32|0;if((b|0)!=(a|0)){continue}break}}}function en(a){var b=0;b=fb-16|0;fb=b;p[b+12>>2]=a;p[b+8>>2]=255;a=q[Cb(b+12|0,b+8|0)|0];fb=b+16|0;return a}function XMa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;p[c>>2]=b;p[c+8>>2]=a;oMa(p[c+8>>2],p[c>>2]);fb=c+16|0}function Uua(a){var b=0,c=0;b=a+108|0;a=0;while(1){c=Yb(b,a);a=a+1|0;n[c|0]=a;if(a>>>0<128){continue}break}}function Ug(a,b){var c=0;c=a;b=p[a+16>>2]+b|0;a=p[a+12>>2];b=(b|0)%(a|0)|0;return t[sc(c,(b>>31&a)+b|0)>>2]}function NH(a){a=a|0;var b=0,c=0,d=0;b=u[a+4264>>3]*+s[p[a+16>>2]+1074376>>2];c=a,d=b-TNa(b),u[c+4256>>3]=d}function KX(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return m[a|0](b,c,d,e,f,g,h)|0}function tDa(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(oj(a,b+8|0)){c=iP(b+8|0)}fb=b+16|0;return c|0}function sF(a){var b=0;b=p[(q[a+2|0]&12)+42388>>2];a=q[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function oLa(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(oj(a,b+8|0)){c=iS(b+8|0)}fb=b+16|0;return c|0}function lf(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=p[a>>2];p[c+8>>2]=p[c+8>>2]+b;fb=c+16|0;return p[c+8>>2]}function gKa(a,b){a=a|0;b=b|0;var c=0;b=fb-80|0;fb=b;c=-1;if(IR(a,b+8|0)){c=HR(b+8|0)}fb=b+80|0;return c|0}function Sv(a,b){var c=0;c=(v(v(Qv(a),Rv(a)),125)>>>0)/(sF(a)>>>0)|0;a=(q[a+1|0]&6)==6?c&-4:c;return a?a:b}function Ho(a){var b=0,c=0,d=0;b=a;a=p[a>>2];c=b,d=ub(v(a,214013)+2531011|0),p[c>>2]=d;return a>>>16&32767}function spa(a){var b=0,c=0;Vr(a,Be(a));b=qb(a),c=0,p[b>>2]=c;b=a,c=_b(a),p[b>>2]=c;b=_b(a),c=0,p[b>>2]=c}function mCa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(af(a,512)){Tz(c+8|0,b);Ls(a,c+8|0);break a}CO(b)}fb=c+16|0}function ku(a,b){a=a|0;b=b|0;var c=0;b=b+ -1|0;c=1085;a:{if(b>>>0>4){break a}c=p[(b<<2)+76372>>2]}Mb(a,c)}function kg(a){var b=0,c=0;b=fb-16|0;fb=b;if(Pp(a,b+8|0)){a=b+8|0;c=q[a|0]|q[a+1|0]<<8}fb=b+16|0;return c}function kCa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(Hb(a,512)){Tz(c+8|0,b);yd(a,c+8|0);break a}CO(b)}fb=c+16|0}function k2(a){p[a>>2]=0;p[a+4>>2]=0;p[a+20>>2]=0;o[a+16>>1]=65535;p[a+8>>2]=0;p[a+12>>2]=0;p[a+24>>2]=11}function e6(a,b,c,d,e){var f=0;e=e-d|0;f=e>>31;a=(v(a-b|0,f^e+f)|0)/(c-b|0)|0;return((e|0)<0?0-a|0:a)+d|0}function cW(a,b,c,d){if(!d|0>=b>>>0){a=-1}else{b=a+b|0;c=xV(a,b,c,c+d|0);a=(b|0)==(c|0)?-1:c-a|0}return a}function _U(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(oj(a,b+8|0)){c=ZA(b+8|0)}fb=b+16|0;return c|0}function Ns(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Dl(c+8|0,a);p[c+4>>2]=p[c+8>>2];Ms(c+4|0,b);fb=c+16|0}function Ir(a,b){kz(a);p[a+20>>2]=0;p[a+12>>2]=0;p[a+16>>2]=0;ux(a+24|0);Lb(a+36|0);p[a+48>>2]=b;return a}function CC(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;p[e>>2]=c;p[h>>2]=f;return 3}function Bua(a,b){var c=0;a=Aua(a,b);a:{if(!a){break a}b=pZ(a);if(!b){break a}c=Jb(b,0,a)- -64|0}return c}function x$(a,b,c){var d=0;d=fb-16|0;fb=d;if(b>>>0>=12){Hi(6934);E()}uj(d+8|0,a,b);Zd(d+8|0,c);fb=d+16|0}function wh(a,b,c){var d=0,e=0,f=0,g=0;d=u[c>>3];e=u[b>>3];f=u[c+8>>3];g=u[b+8>>3];ol(a,d*e-f*g,e*f+d*g)}function pE(a){var b=0;b=p[a+12>>2];if((b|0)==p[a+16>>2]){return m[p[p[a>>2]+36>>2]](a)|0}return p[b>>2]}function lz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;MGa(a,b,d+12|0);kx(a);fb=d+16|0}function Wf(a,b){var c=0,d=0;c=p[a>>2];d=p[b>>2];ib=p[a+4>>2]-(p[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function VL(a){o[a+70>>1]=q[((r[p[a+4>>2]+22>>1]<<4|r[p[a+4>>2]+20>>1]>>>6)&65535)+19904|0]>>>r[a+68>>1]}function UDa(a){if(!(255>a)){return 255}if(!(0<a)){return 0}if(a<4294967296&a>=0){return~~a>>>0}return 0}function MM(a,b,c){if((b|0)!=(c|0)){while(1){esa(a,ub(q[b|0]));b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function HHa(a,b){a=a|0;b=b|0;var c=0;a=$Fa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,4896);fb=c+16|0}return a|0}function DBa(a,b){a=a|0;b=b|0;var c=0;a=uBa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,1030);fb=c+16|0}return a|0}function $ha(a){var b=0,c=0,d=0;while(1){b=Ho(a)^b<<15;d=c>>>0<17;c=c+15|0;if(d){continue}break}return b}function pDa(a,b){a=a|0;b=b|0;var c=0;a=LCa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,422);fb=c+16|0}return a|0}function pCa(a){var b=0,c=0;b=fb-1024|0;fb=b;if(Ey(a,b)){jg(a,1024);c=Gy(b)>>>0<17}fb=b+1024|0;return c}function oJ(a,b){var c=0;c=fb-16|0;fb=c;o[c+14>>1]=r[a>>1];o[a>>1]=r[b>>1];o[b>>1]=r[c+14>>1];fb=c+16|0}function jDa(a,b){a=a|0;b=b|0;var c=0;a=ICa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,826);fb=c+16|0}return a|0}function fP(a,b){var c=0;c=s[a>>2]<s[b>>2];a=p[a+4>>2];b=p[b+4>>2];return(a|0)<(b|0)?1:(a|0)<=(b|0)?c:0}function Tla(a,b){a=a|0;b=b|0;var c=0;a=vla(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,225);fb=c+16|0}return a|0}function Qb(a,b){var c=0;c=fb-16|0;fb=c;p[c+12>>2]=p[a>>2];p[a>>2]=p[b>>2];p[b>>2]=p[c+12>>2];fb=c+16|0}function Pla(a,b){a=a|0;b=b|0;var c=0;a=ula(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,326);fb=c+16|0}return a|0}function NBa(a,b){a=a|0;b=b|0;var c=0;a=sBa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,274);fb=c+16|0}return a|0}function Jn(a,b,c){var d=0;d=fb-16|0;fb=d;a=Df(a);p[a+4>>2]=c;p[a>>2]=b;p[d+4>>2]=b;p[d>>2]=b;fb=d+16|0}function JBa(a,b){a=a|0;b=b|0;var c=0;a=pBa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,106);fb=c+16|0}return a|0}function FI(a,b){if(of(a)>>>0>b>>>0){a=De(a,b);p[a+20>>2]=0;p[a+12>>2]=0;p[a+16>>2]=0;LI(a);Me(a+36|0)}}function ACa(a,b){var c=0;c=fb-16|0;fb=c;a:{if(af(a,4)){jh(c+8|0,b);Ls(a,c+8|0);break a}ZP(b)}fb=c+16|0}function zya(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;p[a+4>>2]=0;p[b+12>>2]=0;ws(a+8|0);fb=b+16|0;return a}function xM(a){var b=0,c=0;while(1){c=(b<<2)+a|0;b=b+1|0;p[c+68>>2]=b<<11;if((b|0)!=9){continue}break}}function wua(a,b){if((a|0)!=(b|0)){vua(a,Ub(b),Vb(b));Fi(a+12|0,b+12|0);o[a+28>>1]=r[b+28>>1]}return a}function w4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return m[p[p[a>>2]+20>>2]](a,b,c,d,e,f)|0}function vDa(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=b;b=r[p[c+8>>2]>>1];o[a+2>>1]=0;o[a>>1]=b;fb=c+16|0}function pU(a,b){var c=0;c=Cc(a);if(c>>>0<b>>>0){iU(a,b-c|0);return}if(c>>>0>b>>>0){Vt(a,p[a>>2]+b|0)}}function kEa(a,b){a=a|0;b=b|0;var c=0;a=ADa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,42);fb=c+16|0}return a|0}function cv(a){a=a|0;var b=0;b=p[21199];if(a){p[21199]=(a|0)==-1?458380:a}return((b|0)==458380?-1:b)|0}function ZIa(a,b){a=a|0;b=b|0;var c=0;a=CIa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,34);fb=c+16|0}return a|0}function Wla(a,b){a=a|0;b=b|0;var c=0;a=wla(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,73);fb=c+16|0}return a|0}function V4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return m[p[p[a>>2]+16>>2]](a,b,c,d,e,f)|0}function T_(a,b,c){var d=0;if(p[a>>2]){while(1){mh(b,c+d|0);d=d+1|0;if(d>>>0<s[a>>2]){continue}break}}}function R4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return m[p[p[a>>2]+24>>2]](a,b,c,d,e,f)|0}function Nxa(a,b){a=a|0;b=b|0;var c=0;a=xxa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,40);fb=c+16|0}return a|0}function Nla(a,b){a=a|0;b=b|0;var c=0;a=tla(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,60);fb=c+16|0}return a|0}function M4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return m[p[p[a>>2]+28>>2]](a,b,c,d,e,f)|0}function IBa(a,b){a=a|0;b=b|0;var c=0;a=oBa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,72);fb=c+16|0}return a|0}function GAa(a,b){a=a|0;b=b|0;var c=0;a=uAa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,71);fb=c+16|0}return a|0}function G4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return m[p[p[a>>2]+44>>2]](a,b,c,d,e,f)|0}function FY(a){var b=0,c=0;b=fb-16|0;fb=b;if(!q[p[Ic(b+8|0,p[a+4>>2])>>2]]){c=EY(a)}fb=b+16|0;return c}function DP(a,b){a=a|0;b=b|0;var c=0;a=SDa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,284);fb=c+16|0}return a|0}function BFa(a,b){a=a|0;b=b|0;var c=0;a=DEa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,91);fb=c+16|0}return a|0}function sp(a,b){a=a|0;b=b|0;var c=0;a=fJa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,64);fb=c+16|0}return a|0}function r$(a,b){var c=0,d=0;c=fb-16|0;fb=c;if(p[a>>2]!=-1){d=c+8|0;Ic(d,b);Ic(c,d);rZ(a,c)}fb=c+16|0}function n1(a,b,c,d,e){b=Mh(b,c,d,e,2);c=p[d>>2];if(!(c&4|b+ -1>>>0>30)){p[a>>2]=b;return}p[d>>2]=c|4}function l1(a,b,c,d,e){b=Mh(b,c,d,e,2);c=p[d>>2];if(!(c&4|b+ -1>>>0>11)){p[a>>2]=b;return}p[d>>2]=c|4}function j1(a,b,c,d,e){b=Mh(b,c,d,e,2);c=p[d>>2];if(!(c&4|(b|0)>12)){p[a>>2]=b+ -1;return}p[d>>2]=c|4}function dS(a,b){a=a|0;b=b|0;var c=0;a=zKa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,50);fb=c+16|0}return a|0}function Rv(a){var b=0;b=q[a+1|0];return q[(v(b>>>1&3,15)+v(b>>>3&1,45)+(q[a+2|0]>>>4)|0)+42385|0]<<1}function Px(a,b){if(Cg(p[a+24>>2]+484344|0,b)){a=p[Rb(p[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}function G1(a,b,c,d,e){b=Nh(b,c,d,e,2);c=p[d>>2];if(!(c&4|b+ -1>>>0>30)){p[a>>2]=b;return}p[d>>2]=c|4}function E1(a,b,c,d,e){b=Nh(b,c,d,e,2);c=p[d>>2];if(!(c&4|b+ -1>>>0>11)){p[a>>2]=b;return}p[d>>2]=c|4}function C1(a,b,c,d,e){b=Nh(b,c,d,e,2);c=p[d>>2];if(!(c&4|(b|0)>12)){p[a>>2]=b+ -1;return}p[d>>2]=c|4}function uS(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;fb=b+16|0}function t1(a){var b=0;b=fb-16|0;fb=b;p[a>>2]=0;a=a+32|0;lD(a,32);n[b+15|0]=0;c1(a,b+15|0);fb=b+16|0}function UGa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a=p[Ic(c+8|0,GGa(a,b))>>2];fb=c+16|0;return a|0}function Tua(a){var b=0;a:{b=n[a|0];if((b|0)<-32){n[a|0]=-32;return}if((b|0)<=32){break a}n[a|0]=32}}function Ll(a){n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;n[a+6|0]=0;n[a+7|0]=0}function Iia(a,b){a=a|0;b=b|0;return w((b|0)<=3?w(w(q[(a+b|0)+4264|0])*w(.003921568859368563)):w(0))}function pT(a){var b=0;b=q[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;if(b>>>0<2624){a=a+1|0}ib=a;return b}function kA(a,b){var c=0,d=0;c=p[a+4>>2];d=p[b+4>>2];return(c|0)==(d|0)&s[a>>2]<s[b>>2]|c>>>0<d>>>0}function Wo(a){a=a|0;var b=0;Zm(a);b=Bua(p[a>>2],Fn(a));p[a+20>>2]=b;if(!b){return 0}return sk(a)|0}function Wc(a,b){var c=0;c=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=c;p[a+8>>2]=p[b+8>>2];Sm(b);return a}function Qua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;Jua(d+8|0,b,c,c);zM(a,d+8|0);fb=d+16|0}function Pma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;Ima(d+8|0,b,c,c);zM(a,d+8|0);fb=d+16|0}function Nka(a,b){a=a|0;b=b|0;n[b|0]=0;n[b+1|0]=0;n[b+2|0]=0;n[b+3|0]=0;n[b+4|0]=0;n[b+5|0]=0;jj(b)}function Hw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a=p[Ic(c+8|0,Yja(a,b))>>2];fb=c+16|0;return a|0}function EH(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;jh(c+8|0,b);a=wha(a,c+8|0);fb=c+16|0;return a|0}function rEa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;o[c+14>>1]=b;Ry(a+236|0,128,c+14|0);fb=c+16|0}function p$(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(r[Vn()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function k1(a,b,c,d,e){b=Mh(b,c,d,e,3);c=p[d>>2];if(!(c&4|(b|0)>365)){p[a>>2]=b;return}p[d>>2]=c|4}function jCa(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(Cz(a,b)){c=NO(b)}fb=b+16|0;return c|0}function hg(a){var b=0;b=a+44|0;Hk(b);if(p[b>>2]){RB(b,p[b>>2]);Gi(qb(b),p[b>>2],Ih(b))}eB(a+32|0)}function ei(a){a=a|0;var b=0,c=0;while(1){c=b&65535;Doa(a,c);b=b+1|0;if(c>>>0<126){continue}break}}function dna(a,b,c,d,e){a:{if((e|0)==128|c>>>0<2){break a}pJ(a,d,e);if(c>>>0<4){break a}pJ(b,d,e)}}function VX(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;m[a|0](b,c,d,e,f,g,h)}function Eca(a,b){a=a|0;b=b|0;var c=0;c=p[a+4>>2];b=Ib(b);if(c){m[c|0](b,p[a+8>>2]);return}sr(b,a)}function D1(a,b,c,d,e){b=Nh(b,c,d,e,3);c=p[d>>2];if(!(c&4|(b|0)>365)){p[a>>2]=b;return}p[d>>2]=c|4}function zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;m[p[p[b>>2]+8>>2]](b,c);d=a;a=b+4|0;Wn(d,a);FC(a,c)}function y1(a,b,c,d,e){b=Nh(b,c,d,e,2);c=p[d>>2];if(!(c&4|(b|0)>60)){p[a>>2]=b;return}p[d>>2]=c|4}function wNa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;xT(c+8|0,a);Op(c+8|0,b);fb=c+16|0;return a|0}function tHa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;wA(c,a);a=hf(c,b);pb(c);fb=c+16|0;return a|0}function pg(a,b,c){a=a|0;b=b|0;c=c|0;Je(a,b);b=p[c+4>>2];p[a+4>>2]=p[c>>2];p[a+8>>2]=b;return a|0}function m1(a,b,c,d,e){b=Mh(b,c,d,e,2);c=p[d>>2];if(!(c&4|(b|0)>23)){p[a>>2]=b;return}p[d>>2]=c|4}function jX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return m[a|0](b,c,d,e,f,g)|0}function i1(a,b,c,d,e){b=Mh(b,c,d,e,2);c=p[d>>2];if(!(c&4|(b|0)>59)){p[a>>2]=b;return}p[d>>2]=c|4}function gya(a,b,c){a=a|0;b=b|0;c=c|0;a=p[c+4>>2];p[b>>2]=p[c>>2];p[b+4>>2]=a;p[b+8>>2]=p[c+8>>2]}function fF(a){var b=0;b=+((a&2097151)>>>0);return w(Jh(+w((a|0)>-1?b:-b),(a>>>21&1023)+ -788|0))}function f1(a,b,c,d,e){b=Mh(b,c,d,e,2);c=p[d>>2];if(!(c&4|(b|0)>60)){p[a>>2]=b;return}p[d>>2]=c|4}function cza(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;_T(c,a);a=hf(c,b);pb(c);fb=c+16|0;return a|0}function bh(a,b){var c=0;c=fb-16|0;fb=c;n[c+15|0]=q[a|0];n[a|0]=q[b|0];n[b|0]=q[c+15|0];fb=c+16|0}function Qha(a,b,c){a=a|0;b=b|0;c=c|0;a=Ti(a);if(!a){return 0}return m[p[p[a>>2]+96>>2]](a,b,c)|0}function Nsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=u[b+8>>3];d=Gv(u[b>>3]);e=Sh(c);ol(a,d*qe(c),d*e)}function Ifa(a,b){a=a|0;b=b|0;Tq(a);p[a>>2]=76848;Lb(a+32|0);p[a+48>>2]=b;p[a+44>>2]=0;return a|0}function Hca(a,b){if(a){b=m[p[p[b>>2]+8>>2]](b)|0;a:{if(b){b=Pd(b);break a}b=Pd(34085)}p[a>>2]=b}}function F1(a,b,c,d,e){b=Nh(b,c,d,e,2);c=p[d>>2];if(!(c&4|(b|0)>23)){p[a>>2]=b;return}p[d>>2]=c|4}function B1(a,b,c,d,e){b=Nh(b,c,d,e,2);c=p[d>>2];if(!(c&4|(b|0)>59)){p[a>>2]=b;return}p[d>>2]=c|4}function yO(a){var b=0,c=0;b=1;c=p[a>>2];a:{if((c|0)>=1){b=120;if((c|0)<121){break a}}p[a>>2]=b}}function xGa(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=b;o[a>>1]=r[p[c+8>>2]>>1];Xc(a+4|0);fb=c+16|0}function x1(a,b,c,d,e){b=Nh(b,c,d,e,1);c=p[d>>2];if(!(c&4|(b|0)>6)){p[a>>2]=b;return}p[d>>2]=c|4}function vI(a){lka(a,p[a+4>>2]);if(p[a>>2]){ix(p[a+16>>2],p[a>>2],(p[Xb(a)>>2]-p[a>>2]|0)/52|0)}}function ht(a){vJa(a,p[a+4>>2]);if(p[a>>2]){oR(p[a+16>>2],p[a>>2],(p[Xb(a)>>2]-p[a>>2]|0)/48|0)}}function e1(a,b,c,d,e){b=Mh(b,c,d,e,1);c=p[d>>2];if(!(c&4|(b|0)>6)){p[a>>2]=b;return}p[d>>2]=c|4}function dN(a){var b=0;b=q[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;if(b>>>0<259){a=a+1|0}ib=a;return b}function aU(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Pt(c+8|0,a);Op(c+8|0,b);fb=c+16|0;return a|0}function UT(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;vA(c+8|0,a);Op(c+8|0,b);fb=c+16|0;return a|0}function SP(a){TEa(a,p[a+4>>2]);if(p[a>>2]){QP(p[a+16>>2],p[a>>2],(p[Xb(a)>>2]-p[a>>2]|0)/33|0)}}function MI(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=p[a>>2];HQ(c+8|0,b);fb=c+16|0;return p[c+8>>2]}function KN(a){vza(a,p[a+4>>2]);if(p[a>>2]){sy(p[a+16>>2],p[a>>2],(p[Xb(a)>>2]-p[a>>2]|0)/56|0)}}function CH(a){a=a|0;var b=0;b=p[a>>2];if(b){m[p[p[b>>2]+8>>2]](b);p[a>>2]=0}a=a+4|0;fs(a);CR(a)}function vo(a,b,c){a=p[a>>2]+1074984|0;return p[(a+v(b,896)|0)+680>>2]>p[(a+v(c,896)|0)+680>>2]}function uKa(a,b){var c=0;c=fb-16|0;fb=c;p[c>>2]=b;p[c+8>>2]=a;a=Ap(c,c+8|0);fb=c+16|0;return a}function qma(a,b){a=a|0;b=b|0;vh(a);vh(a);a:{if(b>>>0>=60){Sb(a,4);break a}vh(a)}return vh(a)|0}function oua(a){var b=0;b=fb-16|0;fb=b;p[b+8>>2]=p[a+4>>2];a=p[jM(b+8|0)>>2];fb=b+16|0;return a}function oga(a){a=a|0;var b=0,c=0;n[a+4202|0]=1;b=a,c=He(p[a+16>>2]),p[b+4256>>2]=c;nH(a);mH(a)}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;m[p[p[b>>2]+16>>2]](a,b,p[c+8>>2],p[c+12>>2],0,d)}function k8(a,b){var c=0;c=p[a+4>>2];p[a+8>>2]=p[a+8>>2]-b;p[a>>2]=p[a>>2]+(v(b,c)<<1);return a}function jY(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Xf(a,p[b+8>>2],f)){Du(b,c,d,e)}}function hsa(a){var b=0;b=fb-16|0;fb=b;p[b+8>>2]=p[a+4>>2];a=p[rL(b+8|0)>>2];fb=b+16|0;return a}function fla(a,b,c){var d=0;d=fb-16|0;fb=d;p[d>>2]=b;p[d+8>>2]=a;Oka(a,Kr(d,d+8|0),c);fb=d+16|0}function aA(a,b){a=a|0;b=b|0;var c=0;a=Pp(a,b);if(!a){c=fb-16|0;fb=c;eA(b);fb=c+16|0}return a|0}function Xs(a){UFa(a,p[a+4>>2]);if(p[a>>2]){mt(p[a+16>>2],p[a>>2],(p[Xb(a)>>2]-p[a>>2]|0)/6|0)}}function X7(a,b){var c=0;c=p[a+4>>2];p[a+8>>2]=p[a+8>>2]-b;p[a>>2]=p[a>>2]+(v(b,c)<<2);return a}function Oha(a,b){a=a|0;b=b|0;b=fb-16|0;fb=b;Ei(b,p[a+20>>2]+4|0);LH(a,Ed(b+8|0,b),0);fb=b+16|0}function Kua(a,b){var c=0;c=fb-16|0;fb=c;p[c>>2]=b;p[c+8>>2]=a;a=Ts(c,c+8|0);fb=c+16|0;return a}function Fia(a){a=a|0;var b=0,c=0;n[a+4202|0]=1;b=a,c=He(p[a+16>>2]),p[b+4232>>2]=c;Gr(a);ZH(a)}function AHa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;FQ(c,b);Wc(a,c);pb(c);fb=c+16|0;return a|0}function zCa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Wc(c,b);Cy(d,a);pb(a);fb=c+16|0}function sr(a,b){a=a|0;b=b|0;b=fb-16|0;fb=b;p[b>>2]=a;a=p[13902];LE(a,34171,b);Yq(a);fb=b+16|0}function rs(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=p[a+24>>2];d=a,e=ek(Kg(b)*+(c>>>0)),p[d+24>>2]=e}function qka(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=v(c,52)+d;return a}function kia(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=(c<<11)+d;return a}function gLa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;m[p[p[b>>2]+16>>2]](a,b,c,d,e,f)}function aGa(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=v(c,48)+d;return a}function WEa(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=v(c,33)+d;return a}function JE(a){var b=0;b=MNa(p[a>>2]+ -1|0);if(!b){a=MNa(p[a+4>>2]);return a?a+32|0:0}return b}function BR(a,b){return(Pb((v(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Pb((v(a&15,b)>>>0)/15|0,1,15))&255}function xJa(a,b,c,d){a=c-b|0;c=p[d>>2]+v((a|0)/-48|0,48)|0;p[d>>2]=c;if((a|0)>=1){ac(c,b,a)}}function kfa(a){var b=0;b=p[19193];p[a>>2]=b;p[p[b+ -12>>2]+a>>2]=p[19196];rr(a+4|0);return a}function iya(a,b,c,d){a=c-b|0;c=p[d>>2]+v((a|0)/-12|0,12)|0;p[d>>2]=c;if((a|0)>=1){ac(c,b,a)}}function ifa(a,b){if(!p[a+4116>>2]){an(a+8|0,b,a+4104|0,a+4108|0)}p[a+4116>>2]=1;return a+8|0}function gla(a){var b=0,c=0;b=fb-16|0;fb=b;c=Ub(a);a=Vb(a);ch(b+8|0);fla(c,a,b+8|0);fb=b+16|0}function gN(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=v(c,12)+d;return a}function cBa(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=(c<<3)+d;return a}function VFa(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=v(c,6)+d;return a}function VEa(a,b,c,d){a=c-b|0;c=p[d>>2]+v((a|0)/-33|0,33)|0;p[d>>2]=c;if((a|0)>=1){ac(c,b,a)}}function QY(a,b,c){a=a|0;b=b|0;c=c|0;if(me(a,p[b+4>>2])){a=p[b>>2]==(c|0)}else{a=0}return a|0}function Aua(a,b){if(a+ -1>>>0<=268435455){a=a+208|0;NNa(b,0,a,0);return ib?0:v(a,b)}return 0}function Ata(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=(c<<5)+d;return a}function Aj(a){var b=0;b=fb-16|0;fb=b;a=p[Ic(b+8|0,Ib(a)+(wb(a)<<2)|0)>>2];fb=b+16|0;return a}function z4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return m[p[p[a>>2]+24>>2]](a,b,c,d,e)|0}function wha(a,b){var c=0;c=fb-16|0;fb=c;Sn(c+8|0,kh(c,b));a=qha(a,c+8|0);fb=c+16|0;return a}function rn(a,b,c){a=a|0;b=b|0;c=c|0;a=p[c+4>>2];p[b>>2]=p[c>>2];p[b+4>>2]=a;Ml(b+8|0,c+8|0)}function op(a,b){var c=0;c=wb(a);if((c|0)==(wb(b)|0)){a=!Jm(Ib(a),Ib(b),c)}else{a=0}return a}function nja(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=0;po(a,c+8|0);p[b>>2]=p[c+8>>2];fb=c+16|0}function nZ(a){var b=0;b=fb-16|0;fb=b;p[b>>2]=0;a=hv(Na(a|0,32768,b|0)|0);fb=b+16|0;return a}function fX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=m[a|0](b,c,d,e)|0;ja(ib|0);return a|0}function fK(a,b){a=a|0;b=b|0;aK(a);aK(a+368680|0);if(b){kJ(a,1);return a|0}Mma(a);return a|0}function a9(a,b,c,d){a=c-b|0;c=p[d>>2]+v((a|0)/-24|0,24)|0;p[d>>2]=c;if((a|0)>=1){ac(c,b,a)}}function Zaa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Sn(c+8|0,kh(c,b));Ln(a,c+8|0);fb=c+16|0}function Uoa(a){a=a|0;var b=0;p[a>>2]=0;b=fb-16|0;fb=b;Ona(a+9|0);fb=b+16|0;Fg(a);return a|0}function Tna(a){var b=0;b=fb-16|0;fb=b;p[b+12>>2]=0;Rr(b+12|0,a);fb=b+16|0;return p[b+12>>2]}function Qea(a,b,c){a=a|0;b=b|0;c=c|0;mw(a);p[a+8>>2]=c;p[a+4>>2]=b;p[a>>2]=83484;return a|0}function PB(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=(c<<4)+d;return a}function Ok(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b+ -1|0;a=(a|0)==11?b:a}else{a=10}return a}function Ik(a,b,c){var d=0;d=fb-16|0;fb=d;Zb(d+8|0,ub(b),c);a=YR(a,d+8|0);fb=d+16|0;return a}function Hja(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){nja(a,b);return}mja(a,b,c)}function HD(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(p[b>>2]){continue}break}return b-a>>2}function Fo(a,b,c){a=il(a)-p[a+1074392>>2]|0;if(a>>>0>=2){c=w(w(w(c-b)/w(a>>>0))+b)}return c}function Fl(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=(c<<1)+d;return a}function F8(a){var b=0;b=p[19239];p[a>>2]=b;p[p[b+ -12>>2]+a>>2]=p[19242];rr(a+8|0);return a}function Eh(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=(c<<2)+d;return a}function Doa(a,b){if(b>>>0<=126){Fg(((b<<5)+a|0)+480280|0);_m((v(b,896)+a|0)+1074984|0,a,b)}}function DT(a){var b=0;b=fb-16|0;fb=b;a=Kf(a,b+15|0);fb=b+16|0;return(a?q[b+15|0]:0)<<24>>24}function DC(a){a=a|0;var b=0;p[a>>2]=62420;b=p[a+8>>2];if(!(!b|!q[a+12|0])){Nb(b)}return a|0}function A4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return m[p[p[a>>2]+16>>2]](a,b,c,d,e)|0}function v4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return m[p[p[a>>2]+32>>2]](a,b,c,d,e)|0}function oja(a,b,c){if(b){while(1){p[a>>2]=p[c>>2];a=a+4|0;b=b+ -1|0;if(b){continue}break}}}function kH(a,b){var c=0;c=p[a+12>>2];if((c|0)>=1){p[a+20>>2]=(p[a+16>>2]+(b+c|0)|0)%(c|0)}}function gA(a,b,c){a=a|0;b=b|0;c=c|0;b=fb-16|0;fb=b;n[b+15|0]=q[c|0];TH(a,b+15|0);fb=b+16|0}function eB(a){var b=0;Hp(a);b=a;if(p[b>>2]){NB(b,p[b>>2]);cg(qb(b),p[b>>2],Hf(b))}return a}function aK(a){p[a+20>>2]=0;n[a+16|0]=7;p[a+8>>2]=1889785610;p[a+12>>2]=1072630333;n[a|0]=3}function _Ka(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Eg(c,1,a);CA(c,b);fb=c+16|0;return a|0}function ZKa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;tt(c,1,a);CA(c,b);fb=c+16|0;return a|0}function VDa(a,b,c){if(b){while(1){o[a>>1]=r[c>>1];a=a+2|0;b=b+ -1|0;if(b){continue}break}}}function Rea(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;XG(a,b,c,d,e,0,0,f,g)}function Jxa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;ap(a,b,c);fb=d+16|0;return a|0}function HI(a,b,c,d){a=c-b|0;if((a|0)>=1){ac(p[d>>2],b,a);p[d>>2]=p[d>>2]+v((a>>>0)/6|0,6)}}function Fr(a){hia(a,p[a+4>>2]);if(p[a>>2]){QH(p[a+16>>2],p[a>>2],p[Xb(a)>>2]-p[a>>2]>>11)}}function Ex(a){var b=0;p[a+72>>2]=0;p[a+76>>2]=0;b=p[a+68>>2];p[a+80>>2]=b;p[a+84>>2]=b<<12}function rB(a,b){var c=0,d=0;yp(a);p[a>>2]=77104;p[a+4>>2]=p[b>>2];c=a,d=eh(b),p[c+8>>2]=d}function pO(a){bBa(a,p[a+4>>2]);if(p[a>>2]){fu(p[a+16>>2],p[a>>2],p[Xb(a)>>2]-p[a>>2]>>3)}}function nj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;CJ(a,b,c);fb=d+16|0;return a|0}function hE(a){var b=0;b=p[a>>2];if(b){if(!me(uE(b),-1)){return!p[a>>2]}p[a>>2]=0}return 1}function gE(a){var b=0;b=p[a>>2];if(b){if(!me(pE(b),-1)){return!p[a>>2]}p[a>>2]=0}return 1}function dka(a,b,c){var d=0;d=fb-16|0;fb=d;p[Ic(d+8|0,sz(xl(a),xl(b),xl(c)))>>2];fb=d+16|0}function di(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;bJ(a,b,c);fb=d+16|0;return a|0}function YA(a){a=a|0;var b=0;b=p[a>>2];return ub((m[p[p[b>>2]+20>>2]](b)|0)+p[a+8>>2]|0)|0}function Uka(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){ni(a,b);return}xD(a,b,c)}function Qla(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+38|0;Tc(c,(q[a|0]|q[a+1|0]<<8)&4?16:8,1,0,0)}function Lla(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+40|0;Tc(c,(q[a|0]|q[a+1|0]<<8)&4?16:8,1,0,0)}function Hb(a,b){a=a|0;b=b|0;var c=0;c=p[a>>2];return m[p[p[c>>2]+36>>2]](c,p[a+8>>2],b)|0}function Ei(a,b){a=a|0;b=b|0;var c=0,d=0;p[a>>2]=p[b>>2];c=a,d=p[b>>2]+Cc(b)|0,p[c+4>>2]=d}function $P(a,b,c,d){a=c-b|0;c=p[d>>2]+v((a|0)/-6|0,6)|0;p[d>>2]=c;if((a|0)>=1){ac(c,b,a)}}function zt(a){var b=0;b=fb-16|0;fb=b;a=yLa(a,b+15|0);fb=b+16|0;return(a?q[b+15|0]:0)&255}function w5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;p[a>>2]=d;p[a+4>>2]=b-v(c,d)}function r4(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){Ku(a,c);return}Mb(a,56017)}function qIa(a,b){var c=0;a=nIa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,771);fb=c+16|0}return a}function od(a,b){var c=0;c=fb-16|0;fb=c;uj(c+8|0,a+24|0,b);a=tb(c+8|0);fb=c+16|0;return a}function nw(a){a=a|0;var b=0;p[a>>2]=83556;b=p[a+4>>2];if(b){Nb(b);p[a+4>>2]=0}return a|0}function kNa(a,b,c){if(b){while(1){n[a|0]=q[c|0];a=a+1|0;b=b+ -1|0;if(b){continue}break}}}function h6(a,b){a=a|0;b=b|0;a=r[a>>1];b=r[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}



function fv(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e+12>>2]=d;a=Fq(a,b,c,d);fb=e+16|0;return a}function _Ha(a,b){var c=0;a=XHa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,384);fb=c+16|0}return a}function Wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ti(a);if(a){m[p[p[a>>2]+76>>2]](a,b,c,d)}}function VHa(a,b){var c=0;a=pGa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,554);fb=c+16|0}return a}function Uha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ti(a);if(a){m[p[p[a>>2]+80>>2]](a,b,c,d)}}function Tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Ti(a);if(a){m[p[p[a>>2]+84>>2]](a,b,c,d)}}function Bca(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=b;Wc(a,p[c+8>>2]);Lb(a+12|0);fb=c+16|0}function yha(a,b,c){a=a|0;b=b|0;c=c|0;Ed(a,b);b=p[c+4>>2];p[a+8>>2]=p[c>>2];p[a+12>>2]=b}function tm(a,b,c){b=k8(b,c);c=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=c;p[a+8>>2]=p[b+8>>2]}function td(a){var b=0;b=fb-16|0;fb=b;a=Kf(a,b+15|0);fb=b+16|0;return(a?q[b+15|0]:0)&255}function po(a,b){var c=0;c=fb-16|0;fb=c;jh(c+8|0,b);Eja(a,c+8|0);jh(c,b);zb(c);fb=c+16|0}function oX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;m[a|0](b,c,d,e,f,g)}function lo(a,b,c){b=X7(b,c);c=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=c;p[a+8>>2]=p[b+8>>2]}function jf(a){var b=0;b=fb-16|0;fb=b;a=p[Ic(b+8|0,Ib(a)+wb(a)|0)>>2];fb=b+16|0;return a}function jIa(a,b){var c=0;a=gIa(a,b);if(!a){c=fb-16|0;fb=c;Jb(b,0,62);fb=c+16|0}return a}function We(a){var b=0;b=a+24|0;while(1){b=pb(b+ -12|0);if((b|0)!=(a|0)){continue}break}}function Ura(a,b,c){var d=0;d=fb-16|0;fb=d;if(!xt(a,b)){b=xt(c,a)?c:a}fb=d+16|0;return b}function Ul(a){var b=0;b=a+36|0;while(1){b=pb(b+ -12|0);if((b|0)!=(a|0)){continue}break}}function SNa(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}function LB(a){var b=0;b=a+48|0;while(1){b=pb(b+ -12|0);if((b|0)!=(a|0)){continue}break}}function Gta(a,b){Fta(a,b);Wc(a+12|0,b+12|0);o[a+28>>1]=r[b+28>>1];p[a+24>>2]=p[b+24>>2]}function ENa(a){var b=0,c=0;b=fb-16|0;fb=b;if(Kf(a,b+8|0)){c=q[b+8|0]}fb=b+16|0;return c}function m_(a){a=a|0;a=462216;while(1){a=pb(a+ -12|0);if((a|0)!=462048){continue}break}}function kh(a,b){var c=0,d=0;p[a>>2]=p[b>>2];c=a,d=p[b>>2]+eh(b)|0,p[c+4>>2]=d;return a}function jj(a){n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;return a}function j_(a){a=a|0;a=462392;while(1){a=yc(a+ -12|0);if((a|0)!=462224){continue}break}}function g_(a){a=a|0;a=462688;while(1){a=pb(a+ -12|0);if((a|0)!=462400){continue}break}}function d_(a){a=a|0;a=462992;while(1){a=yc(a+ -12|0);if((a|0)!=462704){continue}break}}function dP(a,b){var c=0,d=0;p[a>>2]=p[b>>2];c=a,d=p[b>>2]+YO(b)|0,p[c+4>>2]=d;return a}function a_(a){a=a|0;a=463032;while(1){a=pb(a+ -12|0);if((a|0)!=463008){continue}break}}function Zl(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b+ -1|0;a=(a|0)==2?b:a}else{a=1}return a}function ZZ(a){a=a|0;a=463064;while(1){a=yc(a+ -12|0);if((a|0)!=463040){continue}break}}function Yha(a,b){a=a|0;b=b|0;a=Ti(a);if(!a){return 1}return m[p[p[a>>2]+68>>2]](a,b)|0}function Wja(a,b){var c=0;c=fb-16|0;fb=c;p[Ic(c+8|0,Uja(a,p[Ic(c,b)>>2]))>>2];fb=c+16|0}function Tb(a,b){var c=0,d=0;p[a>>2]=p[b>>2];c=a,d=p[b>>2]+zb(b)|0,p[c+4>>2]=d;return a}function Re(a,b){var c=0;Ek(a,b);c=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=c;return a}function Qs(a,b,c){var d=0;p[a>>2]=p[b>>2];d=p[b>>2];p[a+8>>2]=b;p[a+4>>2]=c+d;return a}function Or(a,b){if(!(p[a+480180>>2]==8?n[b+872|0]&1:0)){cx(a,b,0);cx(a,b,1);cx(a,b,2)}}function Nd(a,b){var c=0;dW(a,b);c=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=c;return a}function LX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return m[a|0](b,c,d,e,f)|0}function KP(a,b,c){a=a|0;b=b|0;c=c|0;a=r[c>>1]|r[c+2>>1]<<16;o[b>>1]=a;o[b+2>>1]=a>>>16}function KL(a,b){var c=0;b=ub(b);c=a;a=p[a>>2];p[c>>2]=a<<8^p[((b^a>>>24)<<2)+87568>>2]}function ID(a,b){var c=0;c=fb-16|0;fb=c;p[c+12>>2]=b;a=MD(a,62352,b);fb=c+16|0;return a}function BK(a,b){var c=0;c=q[a+872|0];if(c&1){n[a+872|0]=c|8;p[a+876>>2]=p[a+876>>2]+b}}function pC(a,b,c){a=a|0;b=b|0;c=c|0;if((a|0)==(b|0)){n[a+112|0]=0;return}ov(b,c<<2,4)}function oN(a){var b=0;b=44325e5/+(a>>>0);if(b<4294967296&b>=0){return~~b>>>0}return 0}function lS(a,b,c){n[a+2|0]=1;b=b&15;if(c){b=q[b+12336|0]}else{b=(b<<2)+4|0}n[a+4|0]=b}function ge(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=p[Hu(b,a)+8>>2],d=0,n[c|0]=d;fb=b+16|0}function dK(a){Xc(a);Xc(a+12|0);Xc(a+24|0);Xc(a+36|0);Xc(a+48|0);p[a+60>>2]=0;return a}function caa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;xT(c+8|0,b);Nt(a,c+8|0);fb=c+16|0}function cV(a){a=a|0;var b=0;b=p[a+4>>2];return(m[p[p[b>>2]+20>>2]](b)|0)+p[a+12>>2]|0}function Rl(a){var b=0;b=mu(a+4|0);if((b|0)==-1){m[p[p[a>>2]+8>>2]](a)}return(b|0)==-1}function RNa(a){var b=0,c=0;while(1){c=b;if(a){a=a-1&a;b=b+1|0;continue}break}return c}function Qu(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;$Y(a,b,HD(b));fb=c+16|0;return a|0}function PL(a,b){return(a>>>0<=62?63-(v((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function NGa(a){var b=0;b=fb-16|0;fb=b;a=aq(a,b+8|0);fb=b+16|0;return a?t[b+8>>2]:w(0)}function Mb(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;ap(a,b,ve(b));fb=c+16|0;return a|0}function IX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;return m[a|0](b,c,d,e,f)|0}function BQ(a){var b=0;b=fb-16|0;fb=b;p[b+12>>2]=-1;a=$Ga(a,b+12|0);fb=b+16|0;return a}function yj(a,b){a=a|0;b=b|0;n[a|0]=67109634;n[a+1|0]=262147;n[a+2|0]=1024;n[a+3|0]=4}function kva(a){a=a+1|0;if((a&255)>>>0<=5){return p[(a<<24>>24<<2)+18376>>2]}return 0}function V0(a,b,c){a=a|0;b=b|0;c=c|0;c=tv(p[b>>2])<<24;p[a+4>>2]=p[b>>2];n[a|0]=c>>24}function T5(a,b){a=a|0;b=b|0;a=p[a>>2];b=p[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function OAa(a,b){var c=0;c=fb-16|0;fb=c;a=iO(Ed(c+8|0,a),Ed(c,b));fb=c+16|0;return a}function IG(a,b){a=a|0;b=b|0;var c=0;c=Ee(8);AG(c);p[c+4>>2]=b;p[c>>2]=83928;xba(a,c)}function HX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;f=+f;return m[a|0](b,c,d,e,f)|0}function Gha(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=q[b|0];yw(a,d+12|0,c);fb=d+16|0}function Gba(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;xm(c,a);Fba(b,c);gf(c);fb=c+16|0}function Cs(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function z$(a,b){var c=0;c=fb-16|0;fb=c;p[c+12>>2]=b;Je(a,c+12|0);fb=c+16|0;return a}function d$(a,b){a=a|0;b=b|0;if((b|0)>=0){b=p[vq()+((b&255)<<2)>>2]}return b<<24>>24}function ch(a){n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0;jj(a)}function b$(a,b){a=a|0;b=b|0;if((b|0)>=0){b=p[uq()+((b&255)<<2)>>2]}return b<<24>>24}function Ze(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=p[Ic(b+8|0,a)>>2];fb=b+16|0;return a|0}function Eea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return PG(a,b,c,d,0,0,0,0,e)|0}function Bka(a,b,c){if(b){while(1){KI(a,c);a=a+52|0;b=b+ -1|0;if(b){continue}break}}}function z2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return x2(b,c,d,e,f)|0}function w2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return v2(b,c,d,e,f)|0}function u2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return t2(b,c,d,e,f)|0}function s2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return r2(b,c,d,e,f)|0}function q2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return p2(b,c,d,e,f)|0}function pla(a,b){a=a|0;b=b|0;if(b>>>0<=42){return q[p[a+84>>2]+b|0]!=63|0}return 0}function pf(a){a=a|0;var b=0;b=p[a>>2];return(m[p[p[b>>2]+24>>2]](b)|0)-p[a+8>>2]|0}function oNa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Dn(c+8|0,b,a);fb=c+16|0;return d?b:a}function o2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return n2(b,c,d,e,f)|0}function h3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return f3(b,c,d,e,f)|0}function gf(a){var b=0;Bh(a);b=a;if(p[b>>2]){_F(b);Eo(qb(b),p[b>>2],Le(b))}return a}function ena(a,b,c,d){var e=0;e=fb-16|0;fb=e;p[e+8>>2]=d;cna(a,b,c,e+8|0);fb=e+16|0}function eFa(a,b){var c=0;a=SEa(a,b);if(!a){c=fb-16|0;fb=c;PP(b);fb=c+16|0}return a}function d3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return c3(b,c,d,e,f)|0}function bW(a,b){var c=0;c=fb-16|0;fb=c;aW(c+8|0,b);Ql(a,c+8|0);sb(c+8|0);fb=c+16|0}function aKa(a,b){a=a|0;b=b|0;TJa(a,b);n[a+16|0]=6;p[a+12>>2]=2015363072;return a|0}function a3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return $2(b,c,d,e,f)|0}function Z2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return Y2(b,c,d,e,f)|0}function YV(a,b){var c=0;c=fb-16|0;fb=c;p[c+8>>2]=b;rB(a,kh(c,p[c+8>>2]));fb=c+16|0}function X2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return W2(b,c,d,e,f)|0}function V2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return U2(b,c,d,e,f)|0}function S2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return R2(b,c,d,e,f)|0}function Ql(a,b){p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];p[b>>2]=0;p[b+4>>2]=0;return a}function P2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return O2(b,c,d,e,f)|0}function M2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return L2(b,c,d,e,f)|0}function FZ(a,b){if(!(q[a+112|0]|b>>>0>28)){n[a+112|0]=1;return a}return gc(b<<2,4)}function F2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return E2(b,c,d,e,f)|0}function D2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return C2(b,c,d,e,f)|0}function BBa(a){var b=0;b=fb-16|0;fb=b;a=eu(a,b+8|0);fb=b+16|0;return a?u[b+8>>3]:0}function B2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return A2(b,c,d,e,f)|0}function AMa(a){a=a|0;var b=0;b=fb-16|0;fb=b;QS(b+8|0,a);fb=b+16|0;return p[b+8>>2]}function wk(a,b){a=a|0;b=b|0;if(fc(a)>>>0<=b>>>0){bC();E()}return p[a>>2]+(b<<1)|0}function vD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return m[p[p[a>>2]+32>>2]](a,b,c,d)|0}function uP(a){var b=0;b=fb-16|0;fb=b;a=p[Ic(b+8|0,p[a>>2])>>2];fb=b+16|0;return a}function uD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return m[p[p[a>>2]+48>>2]](a,b,c,d)|0}function tU(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Dn(c+8|0,a,b);fb=c+16|0;return d?b:a}function nia(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+(c<<11);return a}function ly(a){if(p[a>>2]){oe(a,p[a>>2]);dya(p[a>>2],(p[qb(a)>>2]-p[a>>2]|0)/9|0)}}function ih(a){var b=0,c=0;b=fb-16|0;fb=b;c=b+8|0;sB(c,a);fb=b+16|0;return p[c>>2]}function gX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=m[a|0](b,c,d)|0;ja(ib|0);return a|0}function gF(a,b){b=p[a+32>>2]+b|0;p[a+32>>2]=b;if(b>>>0>=s[a+40>>2]){p[a+96>>2]=1}}function _ba(a){var b=0;b=fb-16|0;fb=b;p[b+12>>2]=38245;Mb(a,p[b+12>>2]);fb=b+16|0}function _K(a,b){var c=0;c=b&15;if(c){n[a+850|0]=c}b=b&240;if(b){n[a+849|0]=b>>>4}}function ZEa(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+v(c,33);return a}function RI(a,b){a=a|0;b=b|0;if(b>>>0<=15){return q[p[a+88>>2]+b|0]!=63|0}return 0}function GCa(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+v(c,20);return a}function ECa(a){var b=0,c=0;b=fb-16|0;fb=b;c=a;a=Hh(b);hP(c,a,0,0);sb(a);fb=b+16|0}function Cx(a,b){var c=0;n[a|0]=q[b|0];c=p[b+8>>2];p[a+4>>2]=p[b+4>>2];p[a+8>>2]=c}function Aka(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+v(c,52);return a}function vB(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){a=_b(a);Mf(p[a>>2],b,p[a+4>>2])}}function sR(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+v(c,48);return a}function qk(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+v(c,24);return a}function ky(a,b){a=ac(a,b,34);o[a+34>>1]=r[b+34>>1];ac(a+36|0,b+36|0,68);return a}function kB(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){a=_b(a);Gi(p[a>>2],b,p[a+4>>2])}}function hqa(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){Xpa(a,b);return}Wpa(a,b)}function hha(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){eha(a,b);return}dha(a,b)}function gAa(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){$za(a,b);return}_za(a,b)}function eya(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+v(c,9);return a}function dG(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){a=_b(a);sy(p[a>>2],b,p[a+4>>2])}}function cu(a,b){var c=0;p[a>>2]=p[b>>2];c=a;a=p[b+4>>2];p[c+4>>2]=a;if(a){Sl(a)}}function aB(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){a=_b(a);gh(p[a>>2],b,p[a+4>>2])}}function Zka(a,b){var c=0;c=fb-16|0;fb=c;p[c+12>>2]=q[b|0];Nw(a,c+12|0);fb=c+16|0}function Xma(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){Vma(a,b);return}Uma(a,b)}function Sk(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+v(c,12);return a}function RIa(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){BIa(a,b);return}AIa(a,b)}function RGa(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){EGa(a,b);return}DGa(a,b)}function Oz(a,b,c){a=a|0;b=b|0;c=c|0;a=q[c|0]|q[c+1|0]<<8;n[b|0]=a;n[b+1|0]=a>>>8}function Nya(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){Cya(a,b);return}Bya(a,b)}function Fja(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){Dja(a,b);return}Cja(a,b)}function zS(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){MLa(a,b);return}LLa(a,b)}function wd(a){var b=0;b=fb-16|0;fb=b;a=p[Ic(b+8|0,Ib(a))>>2];fb=b+16|0;return a}function tp(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+v(c,6);return a}function toa(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){ooa(a,b);return}noa(a,b)}function pi(a){var b=0;b=fb-16|0;fb=b;a=p[Ic(b+8|0,hj(a))>>2];fb=b+16|0;return a}function nFa(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){MEa(a,b);return}LEa(a,b)}function n7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return wF(a+ -88|0,b,c,d,e)|0}function hj(a){var b=0;b=fb-16|0;fb=b;a=p[Ic(b+8|0,_b(a))>>2];fb=b+16|0;return a}function he(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+(c<<2);return a}function fn(a){var b=0;b=fb-16|0;fb=b;a=p[Ic(b+8|0,uP(a))>>2];fb=b+16|0;return a}function dua(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){bua(a,b);return}aua(a,b)}function cAa(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){Mza(a,b);return}Lza(a,b)}function Wl(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+(c<<4);return a}function WKa(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){IKa(a,b);return}HKa(a,b)}function UJa(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){uJa(a,b);return}tJa(a,b)}function UIa(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){LIa(a,b);return}KIa(a,b)}function Tba(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){Sba(a,b);return}Rba(a,b)}function RG(a,b){var c=0;c=p[a>>2];p[a>>2]=b;if(c){if(c){m[p[p[c>>2]+4>>2]](c)}}}function Mxa(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){Exa(a,b);return}Dxa(a,b)}function MCa(a,b){var c=0;c=fb-16|0;fb=c;pq(a,p[b>>2],p[b>>2]+YO(b)|0);fb=c+16|0}function Kla(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){Ala(a,b);return}zla(a,b)}function Kba(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){Iba(a,b);return}Hba(a,b)}function Gn(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+(c<<5);return a}function Gh(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+(c<<1);return a}function GR(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){WJa(a,b);return}VJa(a,b)}function Eja(a,b){var c=0;c=fb-16|0;fb=c;kI(c+8|0,Tb(c,b));YR(a,c+8|0);fb=c+16|0}function Aja(a,b){var c=0;c=fb-16|0;fb=c;pq(a,p[b>>2],p[b>>2]+zb(b)|0);fb=c+16|0}function $p(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+(c<<3);return a}function sY(a,b){var c=0;c=fb-16|0;fb=c;pq(a,p[b>>2],p[b>>2]+eh(b)|0);fb=c+16|0}function oJa(a){var b=0;b=fb-16|0;fb=b;n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;fb=b+16|0}function mL(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){Kra(a,b);return}Jra(a,b)}function l3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=fb-16|0;fb=b;yD(a,c,d);fb=b+16|0}function jy(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){ewa(a,b);return}Vva(a,b)}function hS(a,b){a=a|0;b=b|0;return p[b+8>>2]==p[a+8>>2]&p[a+12>>2]==p[b+12>>2]}function eW(a,b){var c=0;c=fb-16|0;fb=c;pq(a,p[b>>2],p[b>>2]+_A(b)|0);fb=c+16|0}function eI(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){Zia(a,b);return}Yia(a,b)}function LO(a,b){var c=0;eCa(a,b);c=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=c}function IV(a){var b=0;b=fb-16|0;fb=b;GV(b+8|0);Ql(a,b+8|0);sb(b+8|0);fb=b+16|0}function tya(a,b){a=a|0;b=b|0;Ri(b);if(p[b>>2]){mN(b);nh(qb(b),p[b>>2],_f(b))}}function ss(a,b){return ek(Kg((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function pX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;m[a|0](b,c,d,e,f)}function hV(a,b,c,d){yp(a);p[a>>2]=77312;Ek(a+4|0,b);p[a+16>>2]=d;p[a+12>>2]=c}function eqa(a){var b=0;if(!(q[a+2|0]|(q[a|0]|q[a+1|0]))){b=!q[a+3|0]}return b}function eCa(a,b){var c=0;c=fb-16|0;fb=c;b=Ek(c+8|0,b);wB(b,a);sb(b);fb=c+16|0}function Rpa(a,b){var c=0;c=fb-16|0;fb=c;a=opa(Zr(a),Zr(b));fb=c+16|0;return a}function RU(a,b){a=a|0;b=b|0;if(p[a+4>>2]!=p[qb(a)>>2]){NU(a,b);return}MU(a,b)}function Ml(a,b){var c=0;Ql(a,b);c=p[b+12>>2];p[a+8>>2]=p[b+8>>2];p[a+12>>2]=c}function MY(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Mb(a,70513);return}Ku(a,c)}function Lfa(a,b){a=a|0;b=b|0;return w((b|0)<=12?t[((b<<2)+a|0)+4208>>2]:w(0))}function LE(a,b,c){var d=0;d=fb-16|0;fb=d;p[d+12>>2]=c;OE(a,b,c,0,0);fb=d+16|0}function KY(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Mb(a,70591);return}Ku(a,c)}function Gs(a){n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0;n[a+4|0]=0;n[a+5|0]=0}function zga(a,b){a=a|0;b=b|0;return w((b|0)<=4?t[((b<<2)+a|0)+4208>>2]:w(0))}function yfa(a,b){a=a|0;b=b|0;return w((b|0)<=2?t[((b<<2)+a|0)+4208>>2]:w(0))}function tNa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=kA(b,a);fb=c+16|0;return d?b:a}function s8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ir(b,c,d,t[a+24>>2]);SF(a,b,c,d)}function rga(a,b){a=a|0;b=b|0;return w((b|0)<=4?t[((b<<2)+a|0)+4220>>2]:w(0))}function rfa(a,b){a=a|0;b=b|0;return w((b|0)<=3?t[((b<<2)+a|0)+4208>>2]:w(0))}function rY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Xf(a,p[b+8>>2],0)){Eu(b,c,d)}}function mDa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fP(a,b);fb=c+16|0;return d?b:a}function kX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return m[a|0](b,c,d,e)|0}function joa(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946300|0:20461)|0}function fZ(a,b){var c=0;c=wb(a);if(c>>>0<b>>>0){Bs(a,b-c|0,0);return}eZ(a,b)}function eN(a){if((q[a+14|0]+ -49&255)>>>0<=3){return!hd(a,17440,14)}return 0}function dW(a,b){var c=0;c=fb-16|0;fb=c;b=Ql(c+8|0,b);wB(b,a);sb(b);fb=c+16|0}function c8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ir(b,c,d,t[a+24>>2]);PF(a,b,c,d)}function bDa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=fP(b,a);fb=c+16|0;return d?b:a}function Yga(a,b){a=a|0;b=b|0;return w((b|0)<=6?t[((b<<2)+a|0)+4208>>2]:w(0))}function Yfa(a,b){a=a|0;b=b|0;return w((b|0)<=1?t[((b<<2)+a|0)+4208>>2]:w(0))}function W8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ir(b,c,d,t[a+28>>2]);WF(a,b,c,d)}function Una(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=kA(a,b);fb=c+16|0;return d?b:a}function Uh(a,b,c){if(p[a+80>>2]){p[a+92>>2]=p[a+92>>2]+(c+7&-8);return}Nb(b)}function PU(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){LU(a,b);return}KU(a,b)}function Nza(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=ZS(a,b);fb=c+16|0;return d?b:a}function Moa(a){var b=0;b=fb-16|0;fb=b;a=p[FJ(b+8|0,a)>>2];fb=b+16|0;return a}function Mga(a,b){a=a|0;b=b|0;return w((b|0)<=5?t[((b<<2)+a|0)+4208>>2]:w(0))}function KLa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=xt(b,a);fb=c+16|0;return d?b:a}function Iga(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=BH(b,a);fb=c+16|0;return d?b:a}function GLa(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=xt(a,b);fb=c+16|0;return d?b:a}function G8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ir(b,c,d,t[a+28>>2]);UF(a,b,c,d)}function F5(a,b){a=a|0;b=b|0;if(s[a+4>>2]<s[qb(a)>>2]){_4(a,b);return}Y4(a,b)}function Ek(a,b){p[a>>2]=p[b>>2];b=p[b+4>>2];p[a+4>>2]=b;if(b){Sl(b)}return a}function Aha(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=BH(a,b);fb=c+16|0;return d?b:a}function yW(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=zd(a,b);fb=c+16|0;return d?b:a}function yG(a,b,c,d){p[a+12>>2]=0;p[a+8>>2]=d;p[a+4>>2]=c;p[a>>2]=b;return a}function y2(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=cC(b,a);fb=c+16|0;return d?b:a}function xl(a){var b=0;b=fb-16|0;fb=b;p[b+8>>2]=a;fb=b+16|0;return p[b+8>>2]}function un(a,b,c,d){a=c-b|0;if((a|0)>=1){ac(p[d>>2],b,a);p[d>>2]=p[d>>2]+a}}function ui(a,b,c,d){a=c-b|0;c=p[d>>2]-a|0;p[d>>2]=c;if((a|0)>=1){ac(c,b,a)}}function ld(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=p[b+8>>2];Sb(b,c);ou(a,b,d,c)}function lL(a){var b=0;b=fb-16|0;fb=b;sB(b+8|0,a);fb=b+16|0;return p[b+8>>2]}function eC(){a:{if(n[463664]&1){break a}if(!nd(463664)){break a}md(463664)}}function dD(a,b){var c=0,d=0;pe(a,Cd(b));b=p[_b(b)>>2];c=_b(a),d=b,p[c>>2]=d}function HV(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=zd(b,a);fb=c+16|0;return d?b:a}function Fi(a,b){a=a|0;b=b|0;if((a|0)!=(b|0)){a=kO(a,Ib(b),wb(b))}return a|0}function Dz(a){a=a+4|0;return q[a|0]|q[a+1|0]<<8|(q[a+2|0]<<16|q[a+3|0]<<24)}function $T(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=cC(a,b);fb=c+16|0;return d?b:a}function gG(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){a=_b(a);a;eG(b,p[a+4>>2])}}function bN(a,b){IN(a,b);n[a+16|0]=q[b+16|0];p[a+12>>2]=p[b+12>>2];return a}function Sn(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;sY(a,kh(c,b));fb=c+16|0}function QI(a,b){a=a|0;b=b|0;return(b>>>0<=15?n[p[a+88>>2]+b|0]:63)<<24>>24}function PI(a,b){a=a|0;b=b|0;return(b>>>0<=42?n[p[a+84>>2]+b|0]:63)<<24>>24}function NW(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;On(a,c+8|0,b);fb=c+16|0}function FB(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;tl(a,c+8|0,b);fb=c+16|0}function Cl(a,b,c){p[a>>2]=b;b=p[b+4>>2];p[a+4>>2]=b;p[a+8>>2]=b+c;return a}function nL(a,b,c){var d=0;d=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=d;XM(a,c)}function nDa(a){a=a|0;t4(a,FH(p[p[a>>2]+ -12>>2]+a|0,10));Qq(a);return a|0}function mS(a,b){a=a|0;b=b|0;a=p[a>>2];return m[p[p[a>>2]+36>>2]](a,0,b)|0}function l$(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=p[vq()+(b<<2)>>2]}return b|0}function jg(a,b){var c=0;c=a;a=p[a+8>>2];b=a-b|0;p[c+8>>2]=b>>>0>a>>>0?0:b}function j$(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=p[uq()+(b<<2)>>2]}return b|0}function iHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=NFa(a,b),p[d>>2]=e}function fHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=MFa(a,b),o[d>>1]=e}function YD(a,b,c,d,e,f,g,h){return m[p[p[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function Hu(a,b){p[a+12>>2]=0;p[a+4>>2]=b;p[a>>2]=b;p[a+8>>2]=b+1;return a}function Hq(a,b,c,d,e,f,g,h){return m[p[p[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function Cm(a,b){a=p[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function Cg(a,b){a=a|0;b=b|0;if(Cp(a,b)){a=Ch(De(a,b))}else{a=0}return a|0}function Bg(a,b,c){p[a+8>>2]=b;p[a+12>>2]=c;p[a>>2]=0;p[a+4>>2]=0;return a}function $sa(a){var b=0;b=fb-288|0;fb=b;a=jta(a,NL(b));fb=b+288|0;return a}function ys(a){hya(a,p[a+4>>2]);if(p[a>>2]){nh(p[a+16>>2],p[a>>2],_n(a))}}function yr(a){bha(a,p[a+4>>2]);if(p[a>>2]){Ie(p[a+16>>2],p[a>>2],eg(a))}}function wA(a,b){var c=0;c=fb-16|0;fb=c;vA(c+8|0,b);Nt(a,c+8|0);fb=c+16|0}function vk(a){mNa(a,p[a+4>>2]);if(p[a>>2]){Cn(p[a+16>>2],p[a>>2],Bn(a))}}function ut(a){tKa(a,p[a+4>>2]);if(p[a>>2]){vn(p[a+16>>2],p[a>>2],Bn(a))}}function pP(a){KDa(a,p[a+4>>2]);if(p[a>>2]){gj(p[a+16>>2],p[a>>2],eg(a))}}function oL(a){Xra(a,p[a+4>>2]);if(p[a>>2]){nh(p[a+16>>2],p[a>>2],_n(a))}}function ns(a){Dta(a,p[a+4>>2]);if(p[a>>2]){gh(p[a+16>>2],p[a>>2],iu(a))}}function nR(a){qJa(a,p[a+4>>2]);if(p[a>>2]){Mf(p[a+16>>2],p[a>>2],Al(a))}}function lK(a){jpa(a,p[a+4>>2]);if(p[a>>2]){Ks(p[a+16>>2],p[a>>2],iu(a))}}function kP(a){BDa(a,p[a+4>>2]);if(p[a>>2]){vn(p[a+16>>2],p[a>>2],Bn(a))}}function hQ(a){eGa(a,p[a+4>>2]);if(p[a>>2]){gj(p[a+16>>2],p[a>>2],eg(a))}}function hN(a){jya(a,p[a+4>>2]);if(p[a>>2]){nh(p[a+16>>2],p[a>>2],_n(a))}}function hJ(a){Jma(a,p[a+4>>2]);if(p[a>>2]){Ie(p[a+16>>2],p[a>>2],eg(a))}}function gs(a){Era(a,p[a+4>>2]);if(p[a>>2]){nh(p[a+16>>2],p[a>>2],_n(a))}}function et(a){wIa(a,p[a+4>>2]);if(p[a>>2]){Gi(p[a+16>>2],p[a>>2],yu(a))}}function eR(a){HIa(a,p[a+4>>2]);if(p[a>>2]){Mf(p[a+16>>2],p[a>>2],Al(a))}}function cI(a){Tia(a,p[a+4>>2]);if(p[a>>2]){Ie(p[a+16>>2],p[a>>2],eg(a))}}function _T(a,b){var c=0;c=fb-16|0;fb=c;Pt(c+8|0,b);Nt(a,c+8|0);fb=c+16|0}function Zj(a,b){var c=0;c=p[b+4>>2];p[a>>2]=p[b>>2];p[a+4>>2]=c;return a}function XN(a){vAa(a,p[a+4>>2]);if(p[a>>2]){gj(p[a+16>>2],p[a>>2],eg(a))}}function Wj(a){Aqa(a,p[a+4>>2]);if(p[a>>2]){Ie(p[a+16>>2],p[a>>2],eg(a))}}function VM(a){txa(a,p[a+4>>2]);if(p[a>>2]){gj(p[a+16>>2],p[a>>2],eg(a))}}function UI(a){xla(a,p[a+4>>2]);if(p[a>>2]){Mf(p[a+16>>2],p[a>>2],Al(a))}}function Tc(a,b,c,d,e){n[a+3|0]=e;n[a+2|0]=d;n[a+1|0]=c;n[a|0]=b;return a}function RO(a,b){n[a+6|0]=255;p[a+16>>2]=b;o[a+4>>1]=0;p[a>>2]=0;return a}function QR(a){BKa(a,p[a+4>>2]);if(p[a>>2]){Mf(p[a+16>>2],p[a>>2],Al(a))}}function MS(a){rMa(a,p[a+4>>2]);if(p[a>>2]){vn(p[a+16>>2],p[a>>2],Bn(a))}}function MN(a){Jza(a,p[a+4>>2]);if(p[a>>2]){Mf(p[a+16>>2],p[a>>2],Al(a))}}function IP(a){EEa(a,p[a+4>>2]);if(p[a>>2]){Mf(p[a+16>>2],p[a>>2],Al(a))}}function Ht(a){VLa(a,p[a+4>>2]);if(p[a>>2]){cg(p[a+16>>2],p[a>>2],bA(a))}}function Hoa(a){kf(a);if(p[a>>2]){Ina(a,p[a>>2]);Ie(qb(a),p[a>>2],rd(a))}}function Er(a){eia(a,p[a+4>>2]);if(p[a>>2]){Ie(p[a+16>>2],p[a>>2],eg(a))}}function Dm(a){yja(a,p[a+4>>2]);if(p[a>>2]){Ie(p[a+16>>2],p[a>>2],eg(a))}}function Dha(a,b){a=a|0;b=b|0;a=p[a+20>>2]+24|0;n[a|0]=q[a|0]&253|(b?2:0)}function DJ(a){yna(a,p[a+4>>2]);if(p[a>>2]){Ie(p[a+16>>2],p[a>>2],eg(a))}}function $ka(a,b,c){a=a|0;b=b|0;c=c|0;if(wb(b)>>>0>c>>>0){ym(b,c)}Wc(a,b)}function yz(a){Bh(a);if(p[a>>2]){OIa(a,p[a>>2]);Mf(qb(a),p[a>>2],Le(a))}}function xW(a){var b=0;b=fb-16|0;fb=b;p[b+8>>2]=53;FW(a,b+8|0);fb=b+16|0}function ww(a){kf(a);if(p[a>>2]){aha(a,p[a>>2]);Ie(qb(a),p[a>>2],rd(a))}}function w1(a,b,c,d,e){b=Nh(b,c,d,e,4);if(!(q[d|0]&4)){p[a>>2]=b+ -1900}}function tE(a,b){b=!p[a+24>>2]|b;p[a+16>>2]=b;if(b&p[a+20>>2]){m4();E()}}function oC(a){yZ(a,p[a+4>>2]);if(p[a>>2]){rC(p[a+16>>2],p[a>>2],eg(a))}}function hX(a,b,c){a=a|0;b=b|0;c=c|0;a=m[a|0](b,c)|0;ja(ib|0);return a|0}function gHa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=vQ(a,b),n[d|0]=e}function ew(a,b){a=a|0;b=b|0;m[b|0](p[p[a>>2]+ -12>>2]+a|0)|0;return a|0}function d1(a,b,c,d,e){b=Mh(b,c,d,e,4);if(!(q[d|0]&4)){p[a>>2]=b+ -1900}}function cq(a){yV(a,p[a+4>>2]);if(p[a>>2]){gh(p[a+16>>2],p[a>>2],iu(a))}}function ck(a){Nl(a);if(p[a>>2]){ZBa(a,p[a>>2]);Ks(qb(a),p[a>>2],hh(a))}}function az(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,p[b>>2],Bb(b)<<2);fb=c+16|0}function _w(a){kf(a);if(p[a>>2]){Lma(a,p[a>>2]);Ie(qb(a),p[a>>2],rd(a))}}function ZS(a,b){return(q[a|0]|q[a+1|0]<<8)>>>0<(q[b|0]|q[b+1|0]<<8)>>>0}function ZF(a){$8(a,p[a+4>>2]);if(p[a>>2]){Eo(p[a+16>>2],p[a>>2],Al(a))}}function Yy(a){Bh(a);if(p[a>>2]){OEa(a,p[a>>2]);Mf(qb(a),p[a>>2],Le(a))}}function Yp(a){FU(a,p[a+4>>2]);if(p[a>>2]){Ie(p[a+16>>2],p[a>>2],eg(a))}}function TJ(a){kf(a);if(p[a>>2]){Ana(a,p[a>>2]);Ie(qb(a),p[a>>2],rd(a))}}function SN(a){PN(a);if(p[a>>2]){Iza(a,p[a>>2]);sy(qb(a),p[a>>2],cn(a))}}function SB(a){$W(a,p[a+4>>2]);if(p[a>>2]){Gi(p[a+16>>2],p[a>>2],yu(a))}}function Qz(a){Bh(a);if(p[a>>2]){JKa(a,p[a>>2]);Mf(qb(a),p[a>>2],Le(a))}}function Qp(a){gU(a,p[a+4>>2]);if(p[a>>2]){cg(p[a+16>>2],p[a>>2],bA(a))}}function NS(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,p[b>>2],fc(b)<<1);fb=c+16|0}function Kq(a){y3(a,p[a+4>>2]);if(p[a>>2]){nh(p[a+16>>2],p[a>>2],_n(a))}}function Kc(a){if(-32768<=(a|0)){return 32767<(a|0)?32767:a}return-32768}function Jl(a,b,c){a=a|0;b=b|0;c=c|0;return m[p[p[a>>2]+48>>2]](a,b,c)|0}function Iz(a){Bh(a);if(p[a>>2]){DJa(a,p[a>>2]);Mf(qb(a),p[a>>2],Le(a))}}function Gj(a,b,c){a=a|0;b=b|0;c=c|0;return m[p[p[a>>2]+12>>2]](a,b,c)|0}function Fh(a){MT(a,p[a+4>>2]);if(p[a>>2]){Kt(p[a+16>>2],p[a>>2],eg(a))}}function F4(a,b,c){a=a|0;b=b|0;c=c|0;return m[p[p[a>>2]+32>>2]](a,b,c)|0}function EQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=vQ(a,b),p[d>>2]=e}function EA(a){eU(a,p[a+4>>2]);if(p[a>>2]){Cn(p[a+16>>2],p[a>>2],Bn(a))}}function CE(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Bg(a,-1,-1)}function $l(a){nX(a,p[a+4>>2]);if(p[a>>2]){cg(p[a+16>>2],p[a>>2],bA(a))}}function $F(a){e9(a,p[a+4>>2]);if(p[a>>2]){Gi(p[a+16>>2],p[a>>2],yu(a))}}function z_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return y_(c,d,e)|0}function zP(a){Ak(a);if(p[a>>2]){lP(a,p[a>>2]);vn(qb(a),p[a>>2],If(a))}}function xO(a){eq(a);if(p[a>>2]){rO(a,p[a>>2]);fu(qb(a),p[a>>2],Di(a))}}function wg(a,b,c){return(c|0)>=0?(r[p[a+8>>2]+((c&255)<<1)>>1]&b)!=0:0}function vP(a){kf(a);if(p[a>>2]){qP(a,p[a>>2]);gj(qb(a),p[a>>2],rd(a))}}function tk(a){Ak(a);if(p[a>>2]){OS(a,p[a>>2]);vn(qb(a),p[a>>2],If(a))}}function qx(a,b){a=a|0;b=b|0;p[a+1074368>>2]=b;nJ(a+1074328|0,b);Eoa(a)}function qi(a){kf(a);if(p[a>>2]){iQ(a,p[a>>2]);gj(qb(a),p[a>>2],rd(a))}}function nN(a){Ri(a);if(p[a>>2]){iN(a,p[a>>2]);nh(qb(a),p[a>>2],_f(a))}}function ic(a,b){var c=0,d=0;p[a>>2]=b;c=a,d=ve(b),p[c+4>>2]=d;return a}function gn(a){UP(a);if(p[a>>2]){RP(a,p[a>>2]);QP(qb(a),p[a>>2],vl(a))}}function _L(a,b){p[a+4>>2]=0;p[a+8>>2]=0;p[a>>2]=b?b:49716;p[a+12>>2]=0}function Xk(a){Ri(a);if(p[a>>2]){i3(a,p[a>>2]);nh(qb(a),p[a>>2],_f(a))}}function WO(a){p[a+8>>2]=0;p[a>>2]=0;p[a+4>>2]=40;o[a+12>>1]=0;return a}function VA(a){kf(a);if(p[a>>2]){GU(a,p[a>>2]);Ie(qb(a),p[a>>2],rd(a))}}function Tu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;p[e>>2]=c;return 3}function QL(a){if(a>>>0<=8){return q[a+20032|0]}return q[a+20023|0]|256}function OA(a){Ak(a);if(p[a>>2]){kU(a,p[a>>2]);Cn(qb(a),p[a>>2],If(a))}}function Iv(a){return((yg(a)+(yg(a)<<8)|0)+(yg(a)<<16)|0)+(yg(a)<<24)|0}function F_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return E_(c,d,e)|0}function FF(a){a=a|0;return+(+s[p[a+32>>2]+480240>>2]*152587890625e-16)}function Epa(a,b,c){a=a|0;b=b|0;c=c|0;Cpa(a,b);p[a+112>>2]=0;return a|0}function EC(a){o[a+12>>1]=0;p[a+8>>2]=-1;p[a>>2]=0;p[a+4>>2]=0;return a}function BX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return w(w(m[a|0](b,c,d)))}function xHa(a){yp(a);p[a>>2]=76456;xi(a+4|0);n[a+20|0]=0;p[a+16>>2]=0}function sc(a,b){if(Bb(a)>>>0<=b>>>0){bC();E()}return p[a>>2]+(b<<2)|0}function sD(a,b,c){var d=0;d=fb-16|0;fb=d;UY(a,b,c);fb=d+16|0;return a}function nd(a){var b=0;b=fb-16|0;fb=b;a=FY(Hu(b,a));fb=b+16|0;return a}function mEa(a){var b=0;b=fb-16|0;fb=b;_Da(a,b+8|0);fb=b+16|0;return a}function jka(a){var b=0;b=fb-16|0;fb=b;hka(a,b+8|0);fb=b+16|0;return a}function bqa(a){var b=0;b=fb-16|0;fb=b;Tpa(a,b+8|0);fb=b+16|0;return a}function ZJ(a,b){var c=0;c=p[a>>2];p[a>>2]=b;if(c){if(c){gg(c);Nb(c)}}}function Ypa(a){var b=0;b=fb-16|0;fb=b;wpa(a,b+8|0);fb=b+16|0;return a}function YR(a,b){Hj(a,ub(p[b>>2]),zb(b));a=p[a+4>>2];ib=a>>31;return a}function XGa(a){var b=0;b=fb-16|0;fb=b;KGa(a,b+8|0);fb=b+16|0;return a}function XA(a){p[a>>2]=0;p[a+4>>2]=0;p[a+8>>2]=0;p[a+12>>2]=0;return a}function X4(a){a=a|0;p[a+16>>2]=p[a+16>>2]|1;if(n[a+20|0]&1){va();E()}}function Ww(a,b){u[a>>3]=u[b>>3]+u[a>>3];u[a+8>>3]=u[b+8>>3]+u[a+8>>3]}function Sua(a){var b=0;b=fb-16|0;fb=b;Pua(a,b+8|0);fb=b+16|0;return a}function Rm(a,b,c){a:{if(a<b){break a}b=c;if(a>b){break a}b=a}return b}function Qma(a){var b=0;b=fb-16|0;fb=b;Oma(a,b+8|0);fb=b+16|0;return a}function M9(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Zka(a,b);fb=c+16|0}function J9(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;Mia(a,b);fb=c+16|0}function Hx(a,b,c){a:{if(a<b){break a}b=c;if(a>b){break a}b=a}return b}function H9(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;zia(a,b);fb=c+16|0}function Cu(a,b,c){if(!(p[a+28>>2]==1|p[a+4>>2]!=(b|0))){p[a+28>>2]=c}}function zoa(a,b){var c=0;c=fb-16|0;fb=c;Dna(a,kh(c+8|0,b));fb=c+16|0}function vu(a){a:{if(s[a+4>>2]<s[qb(a)>>2]){mW(a);break a}lW(a)}qg(a)}function uQ(a,b){var c=0;c=p[a>>2];p[a>>2]=b;if(c){if(c){Nb(tGa(c))}}}function or(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;wO(a,b);fb=c+16|0}function msa(a,b){if(p[a+4>>2]!=p[qb(a)>>2]){gsa(a,b);return}fsa(a,b)}function ki(a,b){return(p[a+4>>2]+(p[a>>2]-p[b>>2]<<3)|0)-p[b+4>>2]|0}function js(a){var b=0;b=fb-16|0;fb=b;Lra(a,b+8|0);fb=b+16|0;return a}function hL(a){if(357913941<a>>>0){tc(20208);E()}return gc(v(a,12),4)}function aC(a){return(p[a>>2]&-256)==1126902528&p[a+4>>2]==1129074247}function _J(a,b){var c=0;c=p[a>>2];p[a>>2]=b;if(c){if(c){Nb(cha(c))}}}function Pka(a,b,c){b=b-a|0;if(b){Ji(c,a,b)}return v((b|0)/6|0,6)+c|0}function OGa(a,b){if(!OFa(a,b)){a=fb-16|0;fb=a;Jb(b,0,128);fb=a+16|0}}function LKa(a,b){if(!KKa(a,b)){a=fb-16|0;fb=a;Jb(b,0,136);fb=a+16|0}}function HG(a,b){var c=0;c=p[a>>2];p[a>>2]=b;if(c){if(c){Nb(Joa(c))}}}function GEa(a,b){p[a>>2]=p[b>>2];o[a+4>>1]=r[b+4>>1];Ml(a+8|0,b+8|0)}function EW(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;MB(a,b);fb=c+16|0}function zB(a,b){var c=0;c=p[a>>2];p[a>>2]=b;if(c){if(c){Nb(eB(c))}}}function xy(a,b){Qb(a,b);Qb(a+4|0,b+4|0);Qb(qb(a),qb(b));qb(a);qb(b)}function wI(a){if(82595524<a>>>0){tc(32271);E()}return gc(v(a,52),4)}function wDa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;vDa(b,p[d>>2])}function v5(a,b){a=a|0;b=b|0;if(!p[114610]){p[114611]=b;p[114610]=a}}function s$(a){a=a|0;var b=0;b=p[115449]+1|0;p[115449]=b;p[a+4>>2]=b}function nma(a,b){var c=0;c=fb-16|0;fb=c;tt(c,1,b);zc(a,c);fb=c+16|0}function hB(a,b){if(134217727<b>>>0){tc(11120);E()}return gc(b<<5,4)}function fpa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dpa(b,p[d>>2])}function fN(a,b){var c=0;c=p[a>>2];p[a>>2]=b;if(c){if(c){Nb(kZ(c))}}}function dQ(a){if(715827882<a>>>0){tc(14480);E()}return gc(v(a,6),1)}function aG(a,b,c){a=a|0;b=b|0;c=c|0;p[b>>2]=p[c>>2];Wc(b+4|0,c+4|0)}function _x(a,b){wn(a);Xc(a+12|0);o[a+28>>1]=0;p[a+24>>2]=b;return a}function _oa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;Yoa(b,p[d>>2])}function WX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;m[a|0](b,c,d,e)}function Qn(a,b,c,d,e){b=Fa(a|0,b|0,c|0,d|0,e|0)|0;ib=H()|0;return b}function Qk(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function Dna(a,b){var c=0;c=fb-16|0;fb=c;rB(a,kh(c+8|0,b));fb=c+16|0}function Cca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;Bca(b,p[d>>2])}function tGa(a){qQ(a+52|0);pb(a+40|0);Ef(a+16|0);Ef(a+4|0);return a}function sd(a,b,c){if(a>>>0>=b>>>0){return a>>>0>c>>>0?c:a}return b}function sT(a){if(2147483647<a>>>0){tc(11932);E()}return gc(a<<1,2)}function sQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;xGa(b,p[d>>2])}function sA(a){if(1073741823<a>>>0){tc(11804);E()}return gc(a<<2,2)}function oT(a,b){if(!IMa(a,b)){a=fb-16|0;fb=a;Jb(b,0,37);fb=a+16|0}}function nu(a,b){var c=0;c=fb-16|0;fb=c;bW(a,kh(c+8|0,b));fb=c+16|0}function lX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return m[a|0](b,c,d)|0}function jI(a){if(1073741823<a>>>0){tc(32398);E()}return gc(a<<2,4)}function gCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fCa(a,b,c,d)|0}function aR(a){ib=0;a=a+47|0;a=(q[a|0]|q[a+1|0]<<8)+ -98|0;return a}function Zm(a){var b=0;b=p[a+20>>2];if(b){Nb(b+ -64|0)}p[a+20>>2]=0}function ZN(a){if(1073741823<a>>>0){tc(16647);E()}return gc(a<<2,1)}function Yn(a,b,c){a=a|0;b=b|0;c=c|0;Je(a,b);Je(a+4|0,c);return a|0}function YJ(a,b,c,d){p[a+12>>2]=0;p[a+8>>2]=d;p[a+4>>2]=c;p[a>>2]=b}function YCa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return OCa(a,b,c,d)|0}function Vy(a){a=a|0;p[a>>2]=76400;Gg(a+28|0);Gg(a+12|0);return a|0}function VB(a,b,c,d,e,f,g){return Ea(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function Rx(a){if(p[a>>2]){Dsa(a,p[a>>2]);qb(a);Bsa(p[a>>2],Di(a))}}function QX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=e|0;m[a|0](b,c,d,e)}function QEa(a,b){if(s[a+4>>2]<s[qb(a)>>2]){LP(a,b);return}PEa(a,b)}function Lk(a){if(1073741823<a>>>0){tc(68216);E()}return gc(a<<2,4)}function DV(a,b,c){a=a|0;b=b|0;c=c|0;yp(a);p[a>>2]=77208;return a|0}function AL(a){if(p[a>>2]){wsa(a,p[a>>2]);qb(a);vsa(p[a>>2],Ih(a))}}function A6(a){a=a|0;var b=0;b=p[a+100>>2];p[a+100>>2]=0;return b|0}function wR(a){if(p[a>>2]){HJa(a,p[a>>2]);mt(qb(a),p[a>>2],ri(a))}}function vC(a,b,c){a=a|0;b=b|0;c=c|0;ws(a);n[a+128|0]=0;return a|0}function um(a,b,c){return p[p[a>>2]+(b<<2)>>2]+(p[a+12>>2]+c<<1)|0}function qX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return jda(a,b,c,d)|0}function kK(a){if(134217727<a>>>0){tc(20320);E()}return gc(a<<5,8)}function g$(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function fL(a){if(1073741823<a>>>0){tc(1447);E()}return gc(a<<2,4)}function eM(a){if(134217727<a>>>0){tc(18584);E()}return gc(a<<5,4)}function bP(a){if(p[a>>2]){JCa(a,p[a>>2]);gj(qb(a),p[a>>2],rd(a))}}function bG(a){if(268435455<a>>>0){tc(39412);E()}return gc(a<<4,4)}function aN(a,b){qy(a,b);n[a+16|0]=q[b+16|0];p[a+12>>2]=p[b+12>>2]}function _e(a,b,c){a=a|0;b=b|0;c=c|0;return Fc(a,v(Qj(a),b)+c|0)|0}function Pb(a,b,c){if((a|0)>=(b|0)){return(a|0)>(c|0)?c:a}return b}function Nj(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){if(b){Nb(gf(b))}}}function MJa(a){a=a|0;return p[a+16>>2]+(p[a+8>>2]-p[a+20>>2]|0)|0}function KS(a){if(268435455<a>>>0){tc(12065);E()}return gc(a<<4,4)}function BD(a,b,c){a=a|0;b=b|0;c=c|0;return Zn(0,a,b,c?c:461600)|0}function AK(a,b){p[a+876>>2]=p[a+876>>2]+b;n[a+872|0]=q[a+872|0]|8}function $m(a,b,c){return p[p[a>>2]+(b<<2)>>2]+(p[a+12>>2]+c<<2)|0}function $O(a){if(p[a>>2]){DCa(a,p[a>>2]);fp(qb(a),p[a>>2],ep(a))}}function yX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return+m[a|0](b,c,d)}function yB(a){if(p[a>>2]){uV(a,p[a>>2]);fu(qb(a),p[a>>2],Di(a))}}function wo(a){a=a|0;return((a+ -65&255)>>>0<26?a+32|0:a)<<24>>24}function uFa(a,b){a=a|0;b=b|0;a=BEa(a,b);if(!a){zEa(b)}return a|0}function lh(a,b){var c=0,d=0;c=a,d=cv(p[b>>2]),p[c>>2]=d;return a}function ita(a,b){a=a|0;b=b|0;a=_sa(a,b);if(!a){Zsa(b)}return a|0}function iMa(a,b){a=a|0;b=b|0;a=CLa(a,b);if(!a){BLa(b)}return a|0}function gv(a,b){a=a|0;b=b|0;return(Sg(a)|0)!=0|(a|32)+ -97>>>0<6}function dj(a){a=p[a+656>>2];if(!a){return 0}return p[a+44>>2]!=0}function c1(a,b){if(s[a+4>>2]<s[qb(a)>>2]){P0(a,b);return}G0(a,b)}function bO(a){if(p[a>>2]){YN(a,p[a>>2]);gj(qb(a),p[a>>2],rd(a))}}function bKa(a,b){a=a|0;b=b|0;a=pJa(a,b);if(!a){oJa(b)}return a|0}function aT(a){if(p[a>>2]){JS(a,p[a>>2]);Gi(qb(a),p[a>>2],Ih(a))}}function _Ia(a,b){a=a|0;b=b|0;a=EIa(a,b);if(!a){DIa(b)}return a|0}function ZJa(a,b){a=a|0;b=b|0;a=nJa(a,b);if(!a){mJa(b)}return a|0}function TA(a){if(p[a>>2]){HU(a,p[a>>2]);nh(qb(a),p[a>>2],_f(a))}}function Qv(a){a=q[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function NA(a){if(p[a>>2]){lU(a,p[a>>2]);cg(qb(a),p[a>>2],Hf(a))}}function MG(a){if(p[a>>2]){j9(a,p[a>>2]);Gi(qb(a),p[a>>2],Ih(a))}}function HBa(a,b){a=a|0;b=b|0;a=lBa(a,b);if(!a){kBa(b)}return a|0}function FJ(a,b){var c=0,d=0;c=a,d=o6(b),p[c>>2]=d;Ho(a);return a}function DF(a){a=a|0;return+(+p[p[a+32>>2]+1074444>>2]*.00390625)}function BN(a){a=a+34|0;a=NNa(q[a|0]|q[a+1|0]<<8,0,80,0);return a}function zw(a){a=a|0;p[a>>2]=79620;Gg(a+4208|0);Ge(a);return a|0}function xr(a){a=a|0;p[a>>2]=80288;Ef(a+4260|0);Ge(a);return a|0}function wX(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;return+m[a|0](b,c,d)}function uw(a){a=a|0;p[a>>2]=80520;Ef(a+4256|0);Ge(a);return a|0}function ub(a){a=a|0;var b=0;b=fb-16|0;fb=b;fb=b+16|0;return a|0}function sw(a){a=a|0;p[a>>2]=80928;Ef(a+4208|0);Ge(a);return a|0}function sEa(a,b){a=a|0;b=b|0;a=HP(a,b);if(!a){JDa(b)}return a|0}function oMa(a,b){var c=0;c=fb-16|0;fb=c;zv(a,b,c+8|0);fb=c+16|0}function kba(a,b,c){a=a|0;b=b|0;c=c|0;return R7(xl(a),xl(b),c)|0}function kI(a,b){var c=0;c=fb-16|0;fb=c;Aja(a,Tb(c,b));fb=c+16|0}function hv(a){if(a>>>0>=4294963201){p[114584]=0-a;a=-1}return a}function eV(a){a=a|0;a=p[a+4>>2];return m[p[p[a>>2]+12>>2]](a)|0}function dta(a,b){a=a|0;b=b|0;LL(a,p[b>>2],p[b+4>>2]);return a|0}function dV(a){a=a|0;a=p[a+4>>2];return m[p[p[a>>2]+16>>2]](a)|0}function VQ(a){a=a|0;a=q[a|0];return Ud(a)^1|(a+ -49&255)>>>0<36}function Ur(a){pb(a+48|0);pb(a+36|0);pb(a+24|0);pb(a+12|0);pb(a)}function Sea(a,b){a=a|0;b=b|0;if(!b){return 3}p[b>>2]=a;return 0}function Qm(a){var b=0;b=fb-16|0;fb=b;fb=b+16|0;return a<<24>>24}function NM(a,b){var c=0;c=p[a>>2];p[a>>2]=b;if(c){if(c){Nb(c)}}}function Js(a,b){a=a|0;b=b|0;a=nBa(a,b);if(!a){mBa(b)}return a|0}function HL(a,b){b=1/(564505.8718779281/b+1);EL(a,b,0,0,b+ -1,0)}function Fw(a){a=a|0;p[a>>2]=79416;Ef(a+4208|0);Ge(a);return a|0}function FA(a){if(4294967295<a>>>0){tc(11736);E()}return gc(a,1)}function EZ(a){a=a|0;var b=0,c=0;b=a,c=de(),p[b>>2]=c;return a|0}function zL(a){Ri(a);if(p[a>>2]){qL(a);nh(qb(a),p[a>>2],_f(a))}}function vH(a){a=a|0;return w(w(w(t[a+4228>>2]*w(198))+w(-99)))}function tr(a,b){a=a|0;b=b|0;k4(a,b);p[a+72>>2]=0;p[a+76>>2]=-1}function sx(a){pR(a);if(p[a>>2]){FR(a);oR(qb(a),p[a>>2],zl(a))}}function sl(a){Bh(a);if(p[a>>2]){NN(a);Mf(qb(a),p[a>>2],Le(a))}}function rx(a){IJ(a);if(p[a>>2]){HJ(a);ix(qb(a),p[a>>2],Wi(a))}}function qT(a){if(!hd(a,12035,25)){return q[a+34|0]<65}return 0}function ps(a){Nl(a);if(p[a>>2]){iM(a);gh(qb(a),p[a>>2],hh(a))}}function ox(a){Nl(a);if(p[a>>2]){AB(a);gh(qb(a),p[a>>2],hh(a))}}function nz(a,b){a=(a+b|0)+ -1|0;return a-((a>>>0)%(b>>>0)|0)|0}function mn(a,b){a=a|0;b=b|0;a=ZFa(a,b);if(!a){gQ(b)}return a|0}function mT(a,b){a=a|0;b=b|0;a=FMa(a,b);if(!a){WS(b)}return a|0}function ij(a,b,c){a=a|0;b=b|0;c=c|0;return sz(xl(a),xl(b),c)|0}function hY(a){a=a|0;if(!a){return 0}return(ZB(a,72024)|0)!=0|0}function hP(a,b,c,d){Re(a,b);o[a+18>>1]=d;o[a+16>>1]=c;return a}function gt(a,b){a=a|0;b=b|0;a=gJa(a,b);if(!a){kR(b)}return a|0}function fl(a){Bh(a);if(p[a>>2]){WI(a);Mf(qb(a),p[a>>2],Le(a))}}function fV(a){a=a|0;a=p[a+4>>2];return m[p[p[a>>2]+8>>2]](a)|0}function ee(a,b,c,d){p[a+8>>2]=d;p[a+4>>2]=c;p[a>>2]=b;return a}function dn(a){kf(a);if(p[a>>2]){MP(a);Kt(qb(a),p[a>>2],rd(a))}}function cA(a,b){a=a|0;b=b|0;a=DLa(a,b);if(!a){tS(b)}return a|0}function ZM(a){kf(a);if(p[a>>2]){YM(a);gj(qb(a),p[a>>2],rd(a))}}function UK(a){Bh(a);if(p[a>>2]){pK(a);Eo(qb(a),p[a>>2],Le(a))}}function Si(a){if(4294967295<a>>>0){tc(1093);E()}return gc(a,1)}function Pd(a){var b=0;b=Rn(ve(a)+1|0,1);if(b){P5(b,a)}return b}function Ef(a){kf(a);if(p[a>>2]){pQ(a);Ie(qb(a),p[a>>2],rd(a))}}function Ds(a,b){a=a|0;b=b|0;a=AAa(a,b);if(!a){aO(b)}return a|0}function DS(a){if(4294967295<a>>>0){tc(1161);E()}return gc(a,1)}function Cr(a){kf(a);if(p[a>>2]){VH(a);Ie(qb(a),p[a>>2],rd(a))}}function Br(a){RH(a);if(p[a>>2]){YH(a);QH(qb(a),p[a>>2],Oj(a))}}function AS(a,b){a=a|0;b=b|0;a=wLa(a,b);if(!a){pS(b)}return a|0}function AN(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,608);fb=b+16|0}



function $z(a,b){a=a|0;b=b|0;a=FLa(a,b);if(!a){uS(b)}return a|0}function $R(a){Ak(a);if(p[a>>2]){VR(a);vn(qb(a),p[a>>2],If(a))}}function zc(a,b){a=a|0;b=b|0;_la(a,q[b+8|0],p[b>>2],p[b+4>>2])}function yM(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){Fua(_b(a),b)}}function vp(a,b){a=a|0;b=b|0;a=aq(a,b);if(!a){mR(b)}return a|0}function su(a,b){a=a|0;b=b|0;a=wV(a,b);if(!a){vV(b)}return a|0}function rr(a){a=a|0;p[a>>2]=76848;pb(a+32|0);Vk(a);return a|0}function rQ(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){vGa(_b(a),b)}}function qj(a){a=a|0;a=p[a>>2];return m[p[p[a>>2]+24>>2]](a)|0}function kL(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){Fra(_b(a),b)}}function jw(a,b,c,d){o[a+4>>1]=c;n[a+6|0]=b;p[a>>2]=d;return a}function jS(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,1954);fb=c+16|0}function jP(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){uDa(_b(a),b)}}function jK(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){cpa(_b(a),b)}}function iX(a,b){a=a|0;b=b|0;a=m[a|0](b)|0;ja(ib|0);return a|0}function iI(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){qja(_b(a),b)}}function hK(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){Xoa(_b(a),b)}}function eJ(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){Dma(_b(a),b)}}function bf(a,b){a=a|0;b=b|0;a=eu(a,b);if(!a){cB(b)}return a|0}function au(a,b){a=a|0;b=b|0;a=IU(a,b);if(!a){SA(b)}return a|0}function _u(a,b){a=a|0;b=b|0;return m[p[p[a>>2]+12>>2]](a,b)|0}function YT(a,b,c){Lc(a,p[b>>2]+(c>>>3&536870908)|0,1<<(c&31))}function Sp(a,b){var c=0;c=b+1|0;p[a>>2]=(c|0)<p[a>>2]?c:b+2|0}function Oba(a,b,c){a=a|0;b=b|0;c=c|0;NJ(a,0,gz(p[b+24>>2]),c)}function Nq(a,b){a=a|0;b=b|0;return m[p[p[a>>2]+44>>2]](a,b)|0}function L0(a,b,c){a=a|0;b=b|0;c=c|0;Lc(a,oE(p[b>>2]),p[b>>2])}function Hh(a){a=a|0;IV(a);p[a+8>>2]=0;p[a+12>>2]=0;return a|0}function GIa(a,b){if(!Kf(a,b)){a=fb-16|0;fb=a;Xe(b);fb=a+16|0}}function EO(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,1024);fb=c+16|0}function CB(a,b){a=a|0;b=b|0;a=OV(a,b);if(!a){qB(b)}return a|0}function Boa(a,b){a=a|0;b=b|0;Lu(a,b);p[a>>2]=71468;return a|0}function Bk(a,b){a=a|0;b=b|0;return m[p[p[a>>2]+28>>2]](a,b)|0}function BB(a,b){a=a|0;b=b|0;a=NV(a,b);if(!a){oB(b)}return a|0}function $y(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,4896);fb=c+16|0}function zN(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,608);fb=c+16|0}function yt(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,192);fb=c+16|0}function vT(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,497);fb=c+16|0}function uO(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,126);fb=c+16|0}function tL(a,b){return p[a>>2]==p[b>>2]&p[a+4>>2]==p[b+4>>2]}function q9(a){a=a|0;var b=0;b=fb-16|0;fb=b;eG(a,1);fb=b+16|0}function mu(a){var b=0;b=a;a=p[a>>2]+ -1|0;p[b>>2]=a;return a}function l9(a){a=a|0;var b=0;b=fb-16|0;fb=b;LN(a,1);fb=b+16|0}function l7(a,b){a=a|0;b=b|0;Lu(a,b);p[a>>2]=71524;return a|0}function kQ(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,674);fb=c+16|0}function jV(a){a=a|0;var b=0;b=fb-16|0;fb=b;fB(a,1);fb=b+16|0}function jN(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,204);fb=c+16|0}function gEa(a,b,c){a=a|0;b=b|0;c=c|0;Wc(a,kC(c,Ib(b),wb(b)))}function af(a,b){return m[p[p[a>>2]+36>>2]](a,p[a+12>>2],b)|0}function Zp(a){a=a|0;a=p[a>>2];return m[p[p[a>>2]+8>>2]](a)|0}function Yta(a,b,c){a=a|0;b=b|0;c=c|0;return ah(a,b,c,1186)|0}function YP(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,128);fb=c+16|0}function Xta(a,b,c){a=a|0;b=b|0;c=c|0;return ah(a,b,c,1187)|0}function Xl(a,b){if(wb(a)>>>0<=b>>>0){Yl();E()}return cc(a,b)}function XV(a){a=a|0;var b=0;b=fb-16|0;fb=b;tB(a,1);fb=b+16|0}function Wka(a,b,c){a=a|0;b=b|0;c=c|0;return ah(a,b,c,1578)|0}function WM(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,263);fb=c+16|0}function Uq(a,b){b=p[b>>2];p[a>>2]=b;p[a+4>>2]=b>>31;return a}function Uo(a,b){a=a|0;b=b|0;if(ne(a)>>>0>b>>>0){n[a+16|0]=b}}function UB(a,b,c){b=Ba(2078,a|0,b|0,c|0)|0;ib=H()|0;return b}function Tz(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,512);fb=c+16|0}function TQ(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,157);fb=c+16|0}function Rta(a,b,c){a=a|0;b=b|0;c=c|0;return ah(a,b,c,1192)|0}function OQ(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,576);fb=c+16|0}function MX(a,b){a=a|0;b=b|0;Lu(a,b);p[a>>2]=71576;return a|0}function Kja(a,b,c){a=a|0;b=b|0;c=c|0;return ah(a,b,c,1614)|0}function Jja(a,b,c){a=a|0;b=b|0;c=c|0;return ah(a,b,c,1615)|0}function JR(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,610);fb=c+16|0}function HO(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,130);fb=c+16|0}function FO(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,600);fb=c+16|0}function Ed(a,b){p[a>>2]=p[b>>2];p[a+4>>2]=p[b+4>>2];return a}function DN(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,146);fb=c+16|0}function CX(a,b,c){a=a|0;b=b|0;c=c|0;return w(w(m[a|0](b,c)))}function CV(a){a=a|0;var b=0;b=fb-16|0;fb=b;OB(a,1);fb=b+16|0}function zz(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,12);fb=c+16|0}function xoa(a,b,c){a=a|0;b=b|0;c=c|0;Cna(a,(b-a|0)/160|0,c)}function tO(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,32);fb=c+16|0}function sS(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,11);fb=c+16|0}function rP(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,52);fb=c+16|0}function pB(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,10);fb=c+16|0}function nB(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,14);fb=c+16|0}function kS(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,1954);fb=b+16|0}function jt(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,66);fb=c+16|0}function fR(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,22);fb=c+16|0}function fQ(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,80);fb=c+16|0}function bna(a,b){a=a|0;b=b|0;Zma(wd(b),jf(b),wd(b));Wc(a,b)}function bK(a){a=a|0;var b=0;b=fb-16|0;fb=b;Koa(a);fb=b+16|0}function bHa(a,b,c){a=a|0;b=b|0;c=c|0;return ah(a,b,c,712)|0}function _B(a){a=p[a>>2]+ -12|0;if((mu(a+8|0)|0)<=-1){Nb(a)}}function ZQ(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,98);fb=c+16|0}function Xy(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,33);fb=c+16|0}function Xp(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,36);fb=c+16|0}function XS(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,38);fb=c+16|0}function XQ(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,48);fb=c+16|0}function Wy(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,18);fb=c+16|0}function VS(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,41);fb=c+16|0}function US(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,16);fb=c+16|0}function SI(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,24);fb=c+16|0}function Qy(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,40);fb=c+16|0}function Mz(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,64);fb=c+16|0}function Kn(a,b,c){if(!b){return 0}return $q(a,og(n[c|0]),b)}function JO(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,30);fb=c+16|0}function JL(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,27);fb=c+16|0}function HF(a){a=a|0;return+(65536/+s[p[a+32>>2]+480244>>2])}function Cw(a){a=a|0;p[a+32>>2]=0;p[a+28>>2]=p[a+28>>2]&-7|2}function CA(a,b){ola(q[a+8|0],p[a>>2],p[a+4>>2],Ib(b),wb(b))}function AV(a,b){Wc(a,b);Ml(a+12|0,b+12|0);zV(a+28|0,b+28|0)}function $N(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,96);fb=c+16|0}function zk(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,2);fb=c+16|0}function xz(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,6);fb=c+16|0}function wT(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,497);fb=b+16|0}function vO(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,126);fb=b+16|0}function raa(a){a=a|0;return s[p[a+24>>2]+1074420>>2]/1e4|0}function rX(a,b){a=a|0;b=b|0;a=pda(a,b);ja(ib|0);return a|0}function md(a){var b=0;b=fb-16|0;fb=b;DY(Hu(b,a));fb=b+16|0}function mZ(a){a=a|0;a=qa(a|0)|0;return co((a|0)==27?0:a)|0}function kN(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,204);fb=b+16|0}function jh(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,4);fb=c+16|0}function jQ(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,192);fb=b+16|0}function iA(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,3);fb=c+16|0}function eta(a,b){a=a|0;b=b|0;ata(a,Ub(b),Vb(b));return a|0}function du(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,8);fb=c+16|0}function dq(a){var b=0;b=fb-16|0;fb=b;p[b+8>>2]=a;fb=b+16|0}function _p(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,1);fb=c+16|0}function Z_(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>-1?b:c)|0}function Xz(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,5);fb=c+16|0}function Uz(a,b){var c=0;c=fb-16|0;fb=c;Zb(a,b,7);fb=c+16|0}function UQ(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,157);fb=b+16|0}function SX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=w(d);m[a|0](b,c,d)}function Rha(a){a=a|0;a=Ti(a);if(a){m[p[p[a>>2]+92>>2]](a)}}function PQ(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,576);fb=b+16|0}function Nba(a){a=a|0;KG(a,2,100);Uo(p[a+24>>2]+484360|0,0)}function Mu(){var a=0;a=W(4)|0;Kk(a);ba(a|0,71348,2008);E()}function KR(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,610);fb=b+16|0}function JI(a,b){if((a|0)!=(b|0)){Ska(a,p[b>>2],p[b+4>>2])}}function IO(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,130);fb=b+16|0}function GO(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,600);fb=b+16|0}function EN(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,146);fb=b+16|0}function wb(a){if(ze(a)){return p[a+4>>2]}return q[a+11|0]}function up(a){if((a|0)>=1){return(a|0)<120?a:120}return 1}function uR(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,66);fb=b+16|0}function sP(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,52);fb=b+16|0}function i4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib=0;return 0}function gaa(a){a=a|0;return bj(Ob(p[a+24>>2]+484360|0))|0}function gQ(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,80);fb=b+16|0}function aO(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,96);fb=b+16|0}function _Q(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,98);fb=b+16|0}function YS(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,38);fb=b+16|0}function YQ(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,48);fb=b+16|0}function XX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;m[a|0](b,c,d)}function WS(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,41);fb=b+16|0}function SA(a){var b=0;b=fb-16|0;fb=b;Jb(a,0,36);fb=b+16|0}function Cf(a,b){a=ONa(p[a>>2],p[a+4>>2],b,b>>31);return a}function Bm(a,b,c,d){p[a+16>>2]=d;p[a+12>>2]=c;p[a+8>>2]=b}function zn(a,b,c){Lc(a,p[b>>2]+(c>>>3&536870908)|0,c&31)}function xU(a){a=a|0;xB(a,11650);p[a>>2]=77388;return a|0}function us(a){if(p[a>>2]){aM(a);Ie(qb(a),p[a>>2],rd(a))}}function ue(a){if(!p[a+20>>2]){return 0}return p[a>>2]!=0}function uT(a){if(p[a>>2]){fT(a);cg(qb(a),p[a>>2],Hf(a))}}function tEa(a,b,c){a=a|0;b=b|0;c=c|0;return cEa(a,b,c)|0}function sm(a,b,c){return p[a>>2]+(v(p[a+4>>2],c)+b<<1)|0}function rFa(a,b,c){a=a|0;b=b|0;c=c|0;return gFa(a,b,c)|0}function qEa(a,b,c){a=a|0;b=b|0;c=c|0;return bEa(a,b,c)|0}function ow(a,b,c){p[a+28>>2]=c;p[a+20>>2]=b;p[a+24>>2]=b}function nEa(a,b,c){a=a|0;b=b|0;c=c|0;return $Da(a,b,c)|0}function mX(a,b,c){a=a|0;b=b|0;c=c|0;return m[a|0](b,c)|0}function lEa(a,b,c){a=a|0;b=b|0;c=c|0;return YDa(a,b,c)|0}function kLa(a,b,c){a=a|0;b=b|0;c=c|0;return UKa(a,b,c)|0}function gMa(a,b,c){a=a|0;b=b|0;c=c|0;return _La(a,b,c)|0}function fW(a){a=a|0;xB(a,11072);p[a>>2]=77044;return a|0}function fMa(a,b,c){a=a|0;b=b|0;c=c|0;return ZLa(a,b,c)|0}function eMa(a,b,c){a=a|0;b=b|0;c=c|0;return YLa(a,b,c)|0}function eF(a){while(1){if((br(a)|0)!=-1){continue}break}}function dja(a,b,c){a=a|0;b=b|0;c=c|0;return bja(a,b,c)|0}function dMa(a,b,c){a=a|0;b=b|0;c=c|0;return XLa(a,b,c)|0}function ce(a){if(p[a>>2]){Ie(qb(a),p[a>>2],p[qb(a)>>2])}}function cLa(a,b,c){a=a|0;b=b|0;c=c|0;return SKa(a,b,c)|0}function bNa(a,b,c){a=a|0;b=b|0;c=c|0;return RMa(a,b,c)|0}function bMa(a,b,c){a=a|0;b=b|0;c=c|0;return WLa(a,b,c)|0}function at(a){if(p[a>>2]){mQ(a);mt(qb(a),p[a>>2],ri(a))}}function _Ma(a,b,c){a=a|0;b=b|0;c=c|0;return PMa(a,b,c)|0}function Zi(a){a=p[a+656>>2];if(!a){return 0}return gi(a)}function XJa(a,b,c){a=a|0;b=b|0;c=c|0;return OJa(a,b,c)|0}function VIa(a,b,c){a=a|0;b=b|0;c=c|0;return PIa(a,b,c)|0}function Tp(a){if(p[a>>2]){JA(a);cg(qb(a),p[a>>2],Hf(a))}}function Tg(a,b,c){return p[a>>2]+(v(p[a+4>>2],c)+b<<3)|0}function SC(a){if(p[a>>2]){RC(a);rC(Nk(a),p[a>>2],Mk(a))}}function Rya(a,b,c){a=a|0;b=b|0;c=c|0;return Fya(a,b,c)|0}function RX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;m[a|0](b,c,d)}function Qxa(a,b,c){a=a|0;b=b|0;c=c|0;return Hxa(a,b,c)|0}function Nv(a,b){return p[((a>>>24^b)<<2)+457312>>2]^a<<8}function Nha(a,b,c){a=a|0;b=b|0;c=c|0;return Lha(a,b,c)|0}function NJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Vna(a,b,c,d)}function Lea(a){a=a|0;return Qd(p[p[a>>2]+ -12>>2]+a|0)|0}function Kxa(a,b,c){a=a|0;b=b|0;c=c|0;return Cxa(a,b,c)|0}function JHa(a,b,c){a=a|0;b=b|0;c=c|0;return pHa(a,b,c)|0}function HAa(a,b,c){a=a|0;b=b|0;c=c|0;return CAa(a,b,c)|0}function GHa(a,b,c){a=a|0;b=b|0;c=c|0;return nHa(a,b,c)|0}function GBa(a,b,c){a=a|0;b=b|0;c=c|0;return xBa(a,b,c)|0}function Bva(a,b,c){a=a|0;b=b|0;c=c|0;dqa(a,b);return a|0}function Bt(a){if(p[a>>2]){SS(a);Cn(qb(a),p[a>>2],If(a))}}function Bf(a,b,c){return p[a>>2]+(v(p[a+4>>2],c)+b<<2)|0}function Bc(a){if(ze(a)){a=Sj(a)+ -1|0}else{a=10}return a}function $ba(a,b,c){a=a|0;b=b|0;c=c|0;Wc(a,kC(c,b,ve(b)))}function zT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Qe(a,c,d,b)}function zFa(a,b,c){a=a|0;b=b|0;c=c|0;return rS(a,b,c)|0}function zC(a){a=a|0;p[a>>2]=62520;pb(a+12|0);return a|0}function yC(a){a=a|0;p[a>>2]=62560;pb(a+16|0);return a|0}function xE(a){a=a|0;return Rq(p[p[a>>2]+ -12>>2]+a|0)|0}function vt(a){n[a|0]=0;n[a+1|0]=0;n[a+2|0]=0;n[a+3|0]=0}function vb(a,b,c){Lc(a,(c>>>3&536870908)+b|0,1<<(c&31))}function tq(a){if(ze(a)){a=Sj(a)+ -1|0}else{a=1}return a}function oW(a,b,c){a=a|0;b=b|0;c=c|0;ou(a,b,p[b+8>>2],c)}function nE(a){a=a|0;return Oq(p[p[a>>2]+ -12>>2]+a|0)|0}function jT(a,b,c){a=a|0;b=b|0;c=c|0;return SMa(a,b,c)|0}function j7(a,b,c){a=a|0;b=b|0;c=c|0;return fd(v(b,c))|0}function h8(a){a=a|0;return ff(p[p[a>>2]+ -12>>2]+a|0)|0}function fG(a){a=a|0;p[a>>2]=83848;Vy(a+12|0);return a|0}function cHa(a,b){a=a|0;b=b|0;Mb(a,b?b:14548);return a|0}function cG(a){a=a|0;p[a>>2]=83888;Uy(a+12|0);return a|0}function ar(a){if(!a6(a)){Wb(a,30);return 0}return bF(a)}function Zq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;S4(a,b,c,d)}function Wfa(a){a=a|0;lH(a);n[a+4202|0]=1;p[a+4224>>2]=0}function Vh(a){return re(a)|re(a)<<8|re(a)<<16|re(a)<<24}function Us(a){dn(a+88|0);dn(a+68|0);dn(a+48|0);return a}function Tx(a,b){u[a>>3]=u[a>>3]*b;u[a+8>>3]=u[a+8>>3]*b}function TB(a,b,c){b=ya(a|0,b|0,c|0)|0;ib=H()|0;return b}function QU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ou(a,b,c,d)}function QQ(a){a=a|0;if(!q[a|0]){return 1}return Sf(a)|0}function QFa(a,b){a=a|0;b=b|0;return uI(a,Ib(b),wb(b))|0}function Mx(a,b,c){a=a|0;b=b|0;c=c|0;return Ura(a,b,c)|0}function LHa(a,b,c){a=a|0;b=b|0;c=c|0;return $q(a,b,c)|0}function Il(a,b,c){a=ONa(p[a>>2],p[a+4>>2],b,c);return a}function GX(a,b,c){a=a|0;b=b|0;c=+c;return m[a|0](b,c)|0}function FC(a,b){Sl(p[b>>2]);Rl(p[a>>2]);p[a>>2]=p[b>>2]}function DQ(a,b,c){a=a|0;b=b|0;c=c|0;return LGa(a,b,c)|0}function BE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Bg(a,-1,-1)}function AFa(a,b,c){a=a|0;b=b|0;c=c|0;return qS(a,b,c)|0}function $A(a){a=a|0;p[a>>2]=77272;bu(a+12|0);return a|0}function zX(a,b,c){a=a|0;b=b|0;c=c|0;return+m[a|0](b,c)}function zD(a,b,c,d){a=AD(a,b,c,0,-2147483648);return a}function z3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return d|0}function sz(a,b,c){b=b-a|0;if(b){Ji(c,a,b)}return b+c|0}function rq(a){a=a|0;p[a>>2]=71388;_B(a+4|0);return a|0}function rF(a,b,c){p[a+4>>2]=0;p[a>>2]=b;p[a+8>>2]=c<<3}function nr(a){a=a|0;p[a>>2]=83720;hw(a+4|0);return a|0}function iqa(a,b){a=a|0;b=b|0;return s[a+12>>2]>b>>>0|0}function iH(a){return w(w(t[a+4208>>2]*w(1e4))+w(-1e4))}function hH(a){return w(w(t[a+4252>>2]*w(19980))+w(20))}function hD(a,b,c){a=a|0;b=b|0;c=c|0;return Q0(a,b,c)|0}function cD(a,b,c){a=a|0;b=b|0;c=c|0;return F0(a,b,c)|0}function bu(a){a=a|0;p[a>>2]=77312;sb(a+4|0);return a|0}function bo(a){a=a|0;p[a>>2]=55760;Gb(a+4|0);return a|0}function _q(a,b,c){return zE(Ib(a),wb(a),Ib(b),c,wb(b))}function Zz(a,b,c){a=a|0;b=b|0;c=c|0;return wS(a,b,c)|0}function WN(a,b,c){a=a|0;b=b|0;c=c|0;return Bs(a,b,c)|0}function Vk(a){a=a|0;p[a>>2]=55696;Gb(a+4|0);return a|0}function Uy(a){a=a|0;p[a>>2]=76456;Gg(a+4|0);return a|0}function Sz(a,b,c){a=a|0;b=b|0;c=c|0;return WR(a,b,c)|0}function S0(a,b,c){a=a|0;b=b|0;c=c|0;return R0(a,b,c)|0}function Oc(a,b,c){a=a|0;b=b|0;c=c|0;Je(a,b);return a|0}function JD(a){return(a|0)!=0&(a|0)!=57888&(a|0)!=57912}function I0(a,b,c){a=a|0;b=b|0;c=c|0;return H0(a,b,c)|0}function HC(a){var b=0;b=p[a>>2];p[a>>2]=0;if(b){Rl(b)}}function Gu(a){a=a|0;p[a>>2]=71368;_B(a+4|0);return a|0}function G3(a,b,c){a=a|0;b=b|0;c=c|0;return H3(a,b,c)|0}function Eaa(a,b){a=a|0;b=b|0;p[p[a+24>>2]+480272>>2]=b}function CS(a){if(q[a+1|0]==2){return q[a|0]<3}return 0}function yg(a){var b=0;b=br(a);p[a+1396>>2]=0;return b}function xX(a,b,c){a=a|0;b=b|0;c=+c;return+m[a|0](b,c)}function tH(a){a=a|0;return ji(w(t[a+4224>>2]*w(4)))|0}function sO(a){var b=0;b=fb-16|0;fb=b;rBa(a);fb=b+16|0}function o3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;di(a,c,d)}function jo(a){return q[a+2|0]&2?(q[a+1|0]&6)==6?4:1:0}function gc(a,b){if(cF(b)){return oZ(a,b)}return Ee(a)}function faa(a){a=a|0;return BI(p[a+24>>2]+484344|0)|0}function ZP(a){var b=0;b=fb-16|0;fb=b;PFa(a);fb=b+16|0}function WL(a,b){o[a+20>>1]=r[a+20>>1]&768|b&255;Wx(a)}function Vs(a){var b=0,c=0;b=a,c=tP(p[a>>2]),p[b>>2]=c}function Oi(a,b){p[a+16>>2]=!p[a+24>>2]|(p[a+16>>2]|b)}function MNa(a){if(a){return 31-y(a+ -1^a)|0}return 32}function Eia(a,b,c){a=a|0;b=b|0;c=c|0;yl(a,b+4260|0,8)}function DO(a){var b=0;b=fb-16|0;fb=b;VBa(a);fb=b+16|0}function CO(a){var b=0;b=fb-16|0;fb=b;RBa(a);fb=b+16|0}function $t(a,b){a=NNa(p[a>>2],p[a+4>>2],b,0);return a}function wca(a){a=a|0;a=p[a+4>>2];return(a?a:38073)|0}function u7(a,b,c){a=a|0;b=b|0;c=c|0;AF(a+ -88|0,b,c)}function saa(a){a=a|0;return p[p[a+24>>2]+1074416>>2]}function r7(a,b,c){a=a|0;b=b|0;c=c|0;yF(a+ -88|0,b,c)}function pb(a){if(ze(a)){cg(a,p[a>>2],Sj(a))}return a}function oaa(a){a=a|0;return p[p[a+24>>2]+1074424>>2]}function nO(a,b){a=a|0;b=b|0;p[a>>2]=b;p[a+4>>2]=b+24}function mc(a,b,c){a=a|0;b=b|0;c=c|0;ws(a);return a|0}function mR(a){var b=0;b=fb-16|0;fb=b;vt(a);fb=b+16|0}function jB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function cB(a){var b=0;b=fb-16|0;fb=b;Ll(a);fb=b+16|0}function _ma(a){a=a|0;t[a+12>>2]=1;nJ(a,4);return a|0}function Zha(a){a=a|0;n[a+4202|0]=1;Dr(a);Aw(a);NH(a)}function Zf(a,b){a=a|0;b=b|0;m[p[p[b>>2]+20>>2]](a,b)}function TW(a,b){a=a|0;b=b|0;p[a>>2]=b;p[a+4>>2]=b+48}function Qga(a){a=a|0;return w(w(t[a+4232>>2]*w(20)))}function Qg(a,b){a=a|0;b=b|0;m[p[p[b>>2]+24>>2]](a,b)}function Qe(a,b,c,d){n[a+8|0]=d;p[a+4>>2]=c;p[a>>2]=b}function Q7(a,b){a=a|0;b=b|0;mL(p[a>>2],b);return a|0}function Pg(a,b){a=a|0;b=b|0;m[p[p[b>>2]+28>>2]](a,b)}function Gia(a,b){a=a|0;b=b|0;x4(a,p[b>>2],p[b+4>>2])}function GW(a,b){a=a|0;b=b|0;p[a>>2]=b;p[a+4>>2]=b+36}function Cp(a,b){a=a|0;b=b|0;return ke(a)>>>0>b>>>0|0}function AO(a,b){a=a|0;b=b|0;p[a>>2]=b;p[a+4>>2]=b+12}function AC(a){var b=0;b=fb-16|0;fb=b;IZ(a);fb=b+16|0}function $Ma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function $Ka(a,b,c){a=a|0;b=b|0;c=c|0;rKa(a,b-a>>2,c)}function w7(a,b,c){a=a|0;b=b|0;c=+c;CF(a+ -88|0,b,c)}function uH(a){a=a|0;return w(w(t[a+4216>>2]*w(10)))}function t7(a,b){a=a|0;b=b|0;return zF(a+ -88|0,b)|0}function q7(a,b){a=a|0;b=b|0;return xF(a+ -88|0,b)|0}function nl(a,b,c){a=a|0;b=b|0;c=c|0;p[b>>2]=p[c>>2]}function naa(a){a=a|0;return r[p[a+24>>2]+480214>>1]}function iV(a,b,c,d){Ic(a,b);Ic(a+4|0,c);Ic(a+8|0,d)}function iR(a){a=a|0;return p[SIa(p[a>>2],hR(a))>>2]}function cm(a,b){return m[p[p[a>>2]+36>>2]](a,b,0)|0}function cIa(a){a=a|0;return OI(q[a+3|0],q[a+5|0])|0}function bm(a,b){return m[p[p[a>>2]+52>>2]](a,b,0)|0}function aga(a){a=a|0;return w(w(t[a+4232>>2]*w(4)))}function Vka(a,b){a=a|0;b=b|0;a=a+24|0;JI(a,b);kx(a)}function TGa(a,b){a=a|0;b=b|0;return uI(a,b,ve(b))|0}function Ph(a){a=a|0;return m[p[p[a>>2]+12>>2]](a)|0}function Oh(a){a=a|0;return m[p[p[a>>2]+16>>2]](a)|0}function Hm(a){a=a|0;return m[p[p[a>>2]+24>>2]](a)|0}function Ep(a,b,c){a=a|0;b=b|0;c=c|0;o[b>>1]=r[c>>1]}function Daa(a){a=a|0;return p[p[a+24>>2]+480272>>2]}function yl(a,b,c){p[a>>2]=b;p[a+4>>2]=b+c;return a}function yc(a){if(ze(a)){Un(p[a>>2],Sj(a))}return a}function vG(a,b){bw(p[p[a>>2]+ -12>>2]+a|0,p[b>>2])}function uua(a){a=a|0;gg(85352);ny(85344);pb(85332)}function lr(a){a=a|0;return r[p[a+24>>2]+480190>>1]}function lN(a,b){return rW(Ib(a),wb(a),Ib(b),wb(b))}function gL(a,b){return cW(Ib(a),wb(a),Ib(b),wb(b))}function cs(a){a=a|0;return $r(q[a+3|0],q[a+5|0])|0}function co(a){if(!a){return 0}p[114584]=a;return-1}function ala(a,b){a=a|0;b=b|0;Fi(a+36|0,b);return 1}function al(a){a=a|0;return r[p[a+24>>2]+480188>>1]}function YC(a){a=a|0;wq(a);p[a>>2]=63532;return a|0}function XC(a){a=a|0;wq(a);p[a>>2]=63628;return a|0}function Wn(a,b){b=p[b>>2];p[a>>2]=b;Sl(b);return a}function Tl(a,b){Re(a,b);Jb(a+16|0,0,1040);return a}function Qd(a){a=a|0;a=kfa(a);xg(a+56|0);return a|0}function Jm(a,b,c){if(!c){return 0}return hd(a,b,c)}function Hn(a){a=a|0;a=a+12|0;m[p[p[a>>2]>>2]](a)|0}function Gx(a){a=a|0;return $r(q[a+2|0],q[a+4|0])|0}function FL(a,b){p[a+8>>2]=0;p[a+12>>2]=0;u[a>>3]=b}function Esa(a,b){a=a|0;b=b|0;p[b>>2]=0;p[b+4>>2]=0}function Ec(a,b){a=a|0;b=b|0;return kO(a,b,ve(b))|0}function Dy(a,b){a=a|0;b=b|0;return Pn(a,b,ve(b))|0}function DX(a,b){a=a|0;b=b|0;return w(w(m[a|0](b)))}function Cd(a){var b=0;b=p[a>>2];p[a>>2]=0;return b}function $k(a){a=a|0;return r[p[a+24>>2]+480192>>1]}function $C(a,b,c){a=a|0;b=b|0;c=c|0;Ib(b);return-1}function zu(a,b,c){a=a|0;b=b|0;c=c|0;n[b|0]=q[c|0]}function wz(a,b,c){return a>>>0<c>>>0&b>>>0<=a>>>0}function v7(a,b){a=a|0;b=b|0;return+BF(a+ -88|0,b)}function tFa(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,16,b)}function sb(a){a=p[a+4>>2];if(a){if(Rl(a)){sZ(a)}}}function pG(a,b){mG(a,74);p[a+4>>2]=p[a+4>>2]|b&74}function pEa(a,b){a=a|0;b=b|0;aEa(a,p[b>>2],hR(b))}function mi(a,b,c){p[a>>2]=p[b>>2];n[a+4|0]=q[c|0]}function jl(a){fi(a+724|0);fi(a+736|0);fi(a+748|0)}function iy(a,b,c){a=a|0;b=b|0;c=c|0;XM(Ed(a,b),c)}function ff(a){a=a|0;a=F8(a);xg(a+60|0);return a|0}function eAa(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,33,b)}function dt(a){return(p[a+480180>>2]&740327453)!=0}function cua(a,b){a=a|0;b=b|0;return ac(a,b,116)|0}function aP(a,b,c){a=a|0;b=b|0;c=c|0;Wc(a,Dy(b,c))}function ZK(a){return p[a+16>>2]!=(0-p[a+20>>2]|0)}function Wza(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,24,b)}function Rp(a,b,c){a=a|0;b=b|0;c=c|0;Wc(a,MO(b,c))}function Osa(a){a=a|0;return+J5(u[a>>3],u[a+8>>3])}function Iaa(a,b){a=a|0;b=b|0;Gaa(a,Haa(Ee(12),b))}function Ez(a,b,c){yl(a,p[b+28>>2]+(c<<12)|0,4096)}function zl(a){return(p[qb(a)>>2]-p[a>>2]|0)/48|0}function yH(a){a=a|0;if(a){m[p[p[a>>2]+4>>2]](a)}}function xn(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,22,b)}function vl(a){return(p[qb(a)>>2]-p[a>>2]|0)/33|0}function uz(a,b){a=mIa(a,b);if(!a){YQ(b)}return a}function tt(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,64,b)}function tb(a){return(p[a+4>>2]&p[p[a>>2]>>2])!=0}function sN(a,b){a=Vya(a,b);if(!a){YQ(b)}return a}function qFa(a,b){a=a|0;b=b|0;return Jr(a,b,17)|0}function pn(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,20,b)}function ol(a,b,c){u[a+8>>3]=c;u[a>>3]=b;return a}function mk(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,12,b)}function me(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function mAa(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,9,b)}function hO(a,b){a=BAa(a,b);if(!a){aO(b)}return a}function ft(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,28,b)}function ep(a){return(p[qb(a)>>2]-p[a>>2]|0)/20|0}function cn(a){return(p[qb(a)>>2]-p[a>>2]|0)/56|0}function cS(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,30,b)}function cMa(a,b){a=a|0;b=b|0;return Jr(a,b,11)|0}function bB(a,b){Ek(a,b);p[a+12>>2]=0;p[a+8>>2]=0}function _n(a){return(p[Xb(a)>>2]-p[a>>2]|0)/12|0}function _f(a){return(p[qb(a)>>2]-p[a>>2]|0)/12|0}function YF(a,b,c,d){dva(a,b,c,zh(w(d*w(65536))))}function Wi(a){return(p[qb(a)>>2]-p[a>>2]|0)/52|0}function UO(a,b){a=$Ba(a,b);if(!a){KO(b)}return a}function Qt(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,26,b)}function QE(a,b){if(!a){return 0}return Jj(a,b,0)}function OT(a,b){a=a|0;b=b|0;n[b+2|0]=0;o[b>>1]=0}function OF(a,b,c){p[a>>2]=b;p[a+4>>2]=c;return a}function Nf(a,b){return zE(Ib(a),wb(a),b,0,ve(b))}function Lz(a,b){a=BJa(a,b);if(!a){uR(b)}return a}function Le(a){return(p[qb(a)>>2]-p[a>>2]|0)/24|0}function Lc(a,b,c){p[a+4>>2]=c;p[a>>2]=b;return a}function Jg(a,b){if(ze(a)){oe(a,b);return}cf(a,b)}function Iy(a,b){a=_Ba(a,b);if(!a){IO(b)}return a}function IR(a,b){a=CJa(a,b);if(!a){uR(b)}return a}function Eg(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,32,b)}function EP(a,b){a=TDa(a,b);if(!a){sP(b)}return a}function Cz(a,b){a=hJa(a,b);if(!a){kR(b)}return a}function Al(a){return(p[Xb(a)>>2]-p[a>>2]|0)/24|0}function A$(){r0();p[115443]=463392;return 461772}function $Q(a,b,c){a=a|0;b=b|0;c=c|0;Qe(a,c,40,b)}function zM(a,b){Ic(a,p[b>>2]);n[a+4|0]=q[b+4|0]}function yh(a){return p[a+8>>2]!=0|p[a+12>>2]!=0}function vka(a,b){a=a|0;b=b|0;hT(a,b);return a|0}function uEa(a,b){a=a|0;b=b|0;return m[b|0](a)|0}function ri(a){return(p[qb(a)>>2]-p[a>>2]|0)/6|0}function ov(a,b,c){a=a|0;b=b|0;c=c|0;cF(c);Nb(a)}function oj(a,b){a=WU(a,b);if(!a){cB(b)}return a}function ms(a){return(a>>>0<9?a:a+ -9|256)&65535}function kp(a,b,c){n[a+2|0]=c;o[a>>1]=b;return a}function jx(a){p[a+4>>2]=0;p[a+8>>2]=-1;n[a|0]=0}function hta(a){a=a|0;p[a>>2]=0;cta();return a|0}function hCa(a,b){a=a|0;b=b|0;return yn(a,b,2)|0}function fh(a){return($e(a)|0)!=(0-$e(a+12|0)|0)}function cga(a){a=a|0;return t[a+4212>>2]<w(1)|0}function YX(a,b,c){a=a|0;b=b|0;c=c|0;m[a|0](b,c)}function Wx(a){p[a+24>>2]=r[a+20>>1]<<r[a+22>>1]}function WA(a,b){a=JU(a,b);if(!a){SA(b)}return a}function Sm(a){p[a>>2]=0;p[a+4>>2]=0;p[a+8>>2]=0}function Sga(a){a=a|0;return t[a+4220>>2]<w(1)|0}function OR(a,b){n[a|0]=q[b|0];n[a+1|0]=q[b+1|0]}function OHa(a,b){a=a|0;b=b|0;return yn(a,b,3)|0}function NI(a,b,c){n[a|0]=q[b|0];n[a+1|0]=q[c|0]}function Mj(a){return(p[a+4>>2]+p[a>>2]|0)+ -1|0}function Ib(a){if(ze(a)){return p[a>>2]}return a}function Hka(a,b){a=a|0;b=b|0;return Jr(a,b,1)|0}function FX(a,b){a=a|0;b=w(b);return m[a|0](b)|0}function Cea(a){a=a|0;TG(p[p[a>>2]+ -12>>2]+a|0)}function CQ(a,b){a=a|0;b=b|0;return Jr(a,b,32)|0}function AJa(a,b,c){a=a|0;b=b|0;c=c|0;ac(b,c,48)}function $Ca(a,b,c){a=a|0;b=b|0;c=c|0;QCa(a,b,c)}function xga(a){a=a|0;n[a+4202|0]=1;pH(a);oH(a)}function wE(a){a=a|0;uv(p[p[a>>2]+ -12>>2]+a|0)}function ul(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function si(a){return(p[a+4>>2]-p[a>>2]|0)/48|0}function p0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461604))}function os(a,b){a=a|0;b=b|0;Uf(a,b);return a|0}function of(a){return(p[a+4>>2]-p[a>>2]|0)/52|0}function o0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461612))}function nc(a){return(p[a+4>>2]-p[a>>2]|0)/12|0}function n0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461808))}function mg(a,b){a=a|0;b=b|0;tE(a,p[a+16>>2]|b)}function mE(a){a=a|0;qv(p[p[a>>2]+ -12>>2]+a|0)}function m0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461800))}function lO(a,b){a=a|0;b=b|0;return yn(a,b,8)|0}function lKa(a,b){a=a|0;b=b|0;return kKa(a,b)|0}function lDa(a,b){a=a|0;b=b|0;return XCa(a,b)|0}function l0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461816))}function j0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461824))}function it(a,b,c){b=b-a|0;if(b){Ji(c-b|0,a,b)}}function i0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461832))}function gta(a,b){a=a|0;b=b|0;return bta(a,b)|0}function gk(a){return(p[a+4>>2]-p[a>>2]|0)/33|0}function gi(a){return(q[a+31|0]+ -1&255)>>>0<17}function g0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461840))}function f0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461848))}function e0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461856))}function d0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461620))}function c0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461628))}function bv(a,b,c,d){a=AD(a,b,c,-1,-1);return a}function b0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461636))}function ak(a){return(p[a+4>>2]-p[a>>2]|0)/56|0}function aJa(a,b){a=a|0;b=b|0;return TIa(a,b)|0}function a0(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461644))}function _$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461684))}function ZMa(a,b){a=a|0;b=b|0;return OMa(a,b)|0}function Z$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461692))}function Y$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461700))}function X$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461708))}function WMa(a,b){a=a|0;b=b|0;return LMa(a,b)|0}function Vi(a,b,c){a=a|0;b=b|0;c=c|0;jna(a,b,c)}function V$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461716))}function T$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461724))}function R$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461732))}function QLa(a,b){a=a|0;b=b|0;return NLa(a,b)|0}function Pr(a,b,c){a=a|0;b=b|0;c=c|0;Ena(a,b,c)}function PX(a,b,c){a=a|0;b=b|0;c=+c;m[a|0](b,c)}function P$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461740))}function O$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461652))}function Ne(a,b,c){a=a|0;b=b|0;c=c|0;zMa(a,b,c)}function NX(a,b){a=a|0;b=b|0;return m[a|0](b)|0}function N$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461660))}function L$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461668))}function Jp(a,b){a=a|0;b=b|0;return _e(a,b,0)|0}function Jga(a){a=a|0;n[a+4202|0]=1;rH(a);sH(a)}function Jfa(a){a=a|0;jH(a);rw(a);n[a+4202|0]=1}function J$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461676))}function Ij(a){a=a|0;return uE(p[a>>2])<<24>>24}function Hea(a,b){a=a|0;b=b|0;return Fea(a,b)|0}function HT(a,b){a=a|0;b=b|0;Gl(a,b);return a|0}function H$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461748))}function G$(a,b){a=a|0;b=b|0;Gd(a,b,Ad(461756))}function EHa(a,b){a=a|0;b=b|0;return lHa(a,b)|0}function Dh(a,b){a=a|0;b=b|0;return yn(a,b,4)|0}function Dd(a){return(p[a+4>>2]-p[a>>2]|0)/24|0}function DHa(a,b){a=a|0;b=b|0;return kHa(a,b)|0}function CBa(a,b){a=a|0;b=b|0;return ABa(a,b)|0}function As(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function $7(a){a=a|0;RF(p[p[a>>2]+ -12>>2]+a|0)}function zka(a,b,c){a=a|0;b=b|0;c=c|0;xka(b,c)}function zO(a,b){a=a|0;b=b|0;return zBa(a,b)|0}function vj(a){return m[p[p[a>>2]+36>>2]](a)|0}function rf(a,b){a=a|0;b=b|0;return oNa(a,b)|0}function oz(a){a=a|0;return(q[a+1|0]==1?1:2)|0}function npa(a,b,c){a=a|0;b=b|0;c=c|0;kpa(b,c)}function mA(a,b){a=a|0;b=b|0;return tNa(a,b)|0}function ln(a,b){a=a|0;b=b|0;return QGa(a,b)|0}function lT(a,b){a=a|0;b=b|0;return UMa(a,b)|0}function jm(a){return m[p[p[a>>2]+28>>2]](a)|0}function iT(a,b){a=a|0;b=b|0;return MMa(a,b)|0}function hk(a,b){n[a+4|0]=0;p[a>>2]=b;return a}function hR(a){return p[a>>2]+(p[a+4>>2]<<2)|0}function cp(a,b){return(v(b,104)+a|0)+484380|0}function _R(a,b){a=a|0;b=b|0;return OKa(a,b)|0}function Zb(a,b,c){a=a|0;b=b|0;c=c|0;yl(a,b,c)}function ZL(a,b){UL(p[a>>2],b);UL(p[a+4>>2],b)}function Yd(a,b){a=a|0;b=b|0;return KLa(a,b)|0}function YIa(a){a=a|0;eKa(a);return p[a+12>>2]}function U9(a,b,c){a=a|0;b=b|0;c=c|0;T9(a,b,c)}function SY(a,b,c){a=a|0;b=b|0;c=c|0;Lc(a,c,b)}function Rf(a){return(p[a+4>>2]-p[a>>2]|0)/6|0}function NL(a){ML(a);Jb(a+27|0,0,255);return a}function Kta(a,b,c){a=a|0;b=b|0;c=c|0;Jta(b,c)}function Kr(a,b){return(p[a>>2]-p[b>>2]|0)/6|0}function In(a){uB(a);p[a+8>>2]=0;p[a>>2]=68420}function Gza(a,b,c){a=a|0;b=b|0;c=c|0;Cza(b,c)}function Gf(a,b){a=a|0;b=b|0;return GLa(a,b)|0}function Fe(a,b,c){if(!(q[a|0]&32)){Au(b,c,a)}}function EX(a,b){a=a|0;b=+b;return m[a|0](b)|0}function zi(a,b){a=a|0;b=b|0;return rT(a,b)|0}function zR(a){n[a+12|0]=q[a+12|0]|2;return a}function zIa(a,b,c){a=a|0;b=b|0;c=c|0;Re(b,c)}function wu(a,b){a=a|0;b=b|0;return Dy(a,b)|0}function vc(a,b){if(s[a>>2]>b>>>0){p[a>>2]=b}}function sGa(a){a=a|0;xQ(a);return p[a+16>>2]}function qaa(a){a=a|0;return nG(p[a+24>>2])|0}function qO(a,b,c){a=a|0;b=b|0;c=c|0;Mha(a,c)}function oi(a,b){a=a|0;b=b|0;return Ab(a,b)|0}function mxa(a){a=a|0;gy(a+288|0);$o(a+800|0)}function mw(a){a=a|0;p[a>>2]=83588;return a|0}function hc(a,b){a=a|0;b=b|0;return y2(a,b)|0}function fk(a,b){if(p[a>>2]>(b|0)){p[a>>2]=b}}function dh(a,b){a=a|0;b=b|0;return $T(a,b)|0}function dM(a,b,c){a=a|0;b=b|0;c=c|0;Gta(b,c)}function dL(a,b){if(!(t[a>>2]<=b)){t[a>>2]=b}}function ao(a,b){a=a|0;b=b|0;return vE(a,b)^1}function _N(a,b){a=a|0;b=b|0;return id(a,b)|0}function XP(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Vta(a,b,c){a=a|0;b=b|0;c=c|0;g3(a,b)}function VK(a){UK(a+20|0);qK(a+8|0);gg(a+4|0)}function Uc(a,b){a=a|0;b=b|0;return yW(a,b)|0}function U4(a,b){a=a|0;b=b|0;return T4(a,b)|0}function QNa(a,b,c,d){a=LNa(a,b,c,d);return a}function Q4(a,b){a=a|0;b=b|0;return P4(a,b)|0}function Pq(a,b){a=a|0;b=b|0;return qE(a,b)^1}function Pi(a,b){a=a|0;b=b|0;return vE(a,b)|0}function On(a,b,c){a=a|0;b=b|0;c=c|0;Vha(a,c)}function Oj(a){return p[qb(a)>>2]-p[a>>2]>>11}function ONa(a,b,c,d){a=JNa(a,b,c,d);return a}function O4(a,b){a=a|0;b=b|0;return N4(a,b)|0}function NNa(a,b,c,d){a=INa(a,b,c,d);return a}function Lg(a,b){if(r[a>>1]>b>>>0){o[a>>1]=b}}function L4(a,b){a=a|0;b=b|0;return K4(a,b)|0}function Jt(a,b){a=a|0;b=b|0;return oA(a,b)|0}function JP(a,b,c){a=a|0;b=b|0;c=c|0;GEa(b,c)}function J4(a,b){a=a|0;b=b|0;return H4(a,b)|0}function Is(a,b){a=a|0;b=b|0;return MO(a,b)|0}function Fj(a,b){a=a|0;b=b|0;return qE(a,b)|0}function Df(a){p[a>>2]=0;p[a+4>>2]=0;return a}function Cb(a,b){a=a|0;b=b|0;return HV(a,b)|0}function Bi(a,b){a=a|0;b=b|0;return tU(a,b)|0}function Ab(a,b){a=a|0;b=b|0;return ll(a,b)^1}function AX(a,b){a=a|0;b=b|0;return+m[a|0](b)}function yu(a){return p[Xb(a)>>2]-p[a>>2]>>4}function wGa(a){a=a|0;xQ(a);return p[a+4>>2]}function vX(a,b){a=a|0;b=+b;return+m[a|0](b)}function tw(a){return w(w(a*w(7900))+w(100))}function tl(a,b,c){a=a|0;b=b|0;c=c|0;Es(a,c)}function rv(a,b,c){a=a|0;b=b|0;c=c|0;Wc(b,c)}function rd(a){return p[qb(a)>>2]-p[a>>2]>>2}function mz(a,b,c){a=a|0;b=b|0;c=c|0;lI(a,c)}function iu(a){return p[Xb(a)>>2]-p[a>>2]>>5}function hh(a){return p[qb(a)>>2]-p[a>>2]>>5}function gga(a,b){a=a|0;b=b|0;return Si(b)|0}function gB(a,b,c){a=a|0;b=b|0;c=c|0;AV(b,c)}function eg(a){return p[Xb(a)>>2]-p[a>>2]>>2}function dI(a,b,c){a=a|0;b=b|0;c=c|0;np(b,c)}function cz(a,b,c){a=a|0;b=b|0;c=c|0;Uf(b,c)}function bga(a){a=a|0;return w(t[a+4220>>2])}function bba(a){a=a|0;mG(a,16384);return a|0}function bGa(a,b){a=a|0;b=b|0;wp(Jb(b,0,48))}function _g(a){return p[p[a+8>>2]>>2]==(a|0)}function Waa(a){a=a|0;bw(a,16384);return a|0}function Rga(a){a=a|0;return w(t[a+4212>>2])}function Mk(a){return p[sq(a)>>2]-p[a>>2]>>2}function Ih(a){return p[qb(a)>>2]-p[a>>2]>>4}function If(a){return p[qb(a)>>2]-p[a>>2]>>1}function Dw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function Di(a){return p[qb(a)>>2]-p[a>>2]>>3}function Bn(a){return p[Xb(a)>>2]-p[a>>2]>>1}function A5(a){a=a|0;return qa(p[a+60>>2])|0}function yka(a,b){a=a|0;b=b|0;y4(a,p[b>>2])}function xia(a,b){a=a|0;b=b|0;n[a+4201|0]=b}function xH(a){a=a|0;return w(t[a+4208>>2])}function wZ(a,b){a=a|0;b=b|0;return Lk(b)|0}function ur(a){YG(a);p[a>>2]=56220;return a}function uja(a,b){a=a|0;b=b|0;pv(a,r[b>>1])}function uha(a,b,c){a=a|0;b=b|0;c=c|0;Df(a)}function u$(){Wn(461784,IC());return 461784}function taa(a){a=a|0;return+SJ(p[a+24>>2])}function sia(a,b){a=a|0;b=b|0;u4(a,u[b>>3])}function rg(a,b,c){return Ga(a|0,b|0,c|0)|0}function rL(a){p[a>>2]=p[a>>2]+ -4;return a}function mG(a,b){p[a+4>>2]=p[a+4>>2]&(b^-1)}function m7(a,b){a=a|0;b=b|0;vF(a+ -88|0,b)}function lm(a){a=a|0;oE(p[a>>2]);return a|0}function kr(a){return 0<=(a|0)&65535>=(a|0)}function jM(a){p[a>>2]=p[a>>2]+ -2;return a}function bA(a){return p[Xb(a)>>2]-p[a>>2]|0}function ai(a,b){a=a|0;b=b|0;return w(w(0))}function ZG(a){return zh(w($G(a)*w(32768)))}function YL(a,b){o[a+22>>1]=b&7;Wx(a);Xx(a)}function Uk(a){a=a|0;tv(p[a>>2]);return a|0}function OJ(a){return 251<=a>>>0&a>>>0<=255}function Ke(a,b){if(q[a|0]>b>>>0){n[a|0]=b}}function Ija(a,b){a=a|0;b=b|0;B4(a,o[b>>1])}function Hf(a){return p[qb(a)>>2]-p[a>>2]|0}function G5(a,b){a=a|0;b=b|0;return Sg(a)|0}function F7(a,b){a=a|0;b=b|0;KF(a+ -88|0,b)}function E7(a,b){a=a|0;b=b|0;JF(a+ -88|0,b)}function $e(a){return p[a+4>>2]-p[a>>2]>>11}function $D(a){YG(a);p[a>>2]=56292;return a}function z7(a,b){a=a|0;b=+b;EF(a+ -88|0,b)}function vy(a){ce(a+24|0);Xd(a+12|0);Xd(a)}function sv(a){a=a|0;return Og(a,461800)|0}function rka(a,b){a=a|0;b=b|0;qfa(a,b+4|0)}function ng(a){return p[a+4>>2]-p[a>>2]>>3}function ne(a){return p[a+4>>2]-p[a>>2]>>5}function mia(a,b){a=a|0;b=b|0;Jb(b,0,2048)}function kv(a){a=a|0;return Og(a,461816)|0}function jv(a){a=a|0;return Og(a,461824)|0}function ju(a){gq(a+28|0);sb(a+12|0);pb(a)}function im(a){return(a|0)==32|a+ -9>>>0<5}function iLa(a,b){a=a|0;b=b|0;Fi(a+12|0,b)}function hl(a){pb(a+36|0);be(a+24|0);wl(a)}function gd(a){return p[a+4>>2]-p[a>>2]>>4}function fc(a){return p[a+4>>2]-p[a>>2]>>1}function fI(a,b){a=a|0;b=b|0;pv(a,p[b>>2])}function dH(a){return w(w(a*w(96))+w(-96))}function _t(a){a=a|0;return Og(a,461808)|0}function _na(a,b){a=a|0;b=b|0;Fi(a+40|0,b)}function _ja(a,b){a=a|0;b=b|0;pv(a,q[b|0])}function Zba(a,b){a=a|0;b=b|0;Yba(a,b+4|0)}function Yu(a){a=a|0;return Og(a,461856)|0}function XL(a,b){n[a+21|0]=b&3;Wx(a);Xx(a)}function WV(a){a=a|0;return p[a+4>>2]!=0|0}function W4(a){a=a|0;return Og(a,461620)|0}function Ts(a,b){return p[a>>2]-p[b>>2]>>2}function Sj(a){return p[a+8>>2]&2147483647}function P9(a,b){a=a|0;b=b|0;return b-a>>3}function J7(a){a=a|0;return Vv(a+ -88|0)|0}function GG(a){return(Ib(a)+wb(a)|0)+ -1|0}function Eka(a,b){a=a|0;b=b|0;Uf(a,b+36|0)}function D7(a,b){a=a|0;b=+b;IF(a+ -88|0,b)}function CD(){return(p[p[21199]>>2]?4:1)|0}function C4(a){a=a|0;return Og(a,461636)|0}function Bqa(a){a=w(a);return sqa($d(a))|0}function Bb(a){return p[a+4>>2]-p[a>>2]>>2}function B7(a,b){a=a|0;b=+b;GF(a+ -88|0,b)}function Ap(a,b){return p[a>>2]-p[b>>2]>>1}function $u(a){a=a|0;return Og(a,461848)|0}function xq(a,b){m[p[p[b>>2]+40>>2]](a,b)}function xj(a,b){m[p[p[b>>2]+44>>2]](a,b)}function wj(a,b){m[p[p[b>>2]+32>>2]](a,b)}function te(a){p[a>>2]=p[a>>2]+2;return a}function t_(a,b){a=a|0;b=b|0;Uf(a,b+16|0)}function rl(a,b){return p[a>>2]+v(b,56)|0}function qc(a,b){a=a|0;b=b|0;Wn(a,b+28|0)}function lG(a,b){a=a|0;b=b|0;Uf(a,b+12|0)}function is(a,b,c){return sxa(b,c)>>>31|0}function id(a,b){return p[a>>2]+v(b,12)|0}function fJ(a,b,c){return Ema(b,c)>>>31|0}function dJ(a,b){ol(a,u[b>>3],-u[b+8>>3])}function cH(a){a=a|0;Jb(a+4296|0,0,81928)}function _l(a,b,c){di(a,b,b+c|0);return a}function Vv(a){a=a|0;mr(a+8|0);return a|0}function VP(a,b){return p[a>>2]+v(b,33)|0}function Rq(a){a=a|0;xg(a+8|0);return a|0}function Rk(a){a=a|0;return pE(p[a>>2])|0}function Rd(a){p[a>>2]=p[a>>2]+4;return a}function Qia(a){a=a|0;ZR(a,80,150,80,255)}function PA(a){return(q[a+24|0]&16)>>>4|0}function Ou(a){a=a|0;HZ(a+8|0);return a|0}function Oq(a){a=a|0;xg(a+4|0);return a|0}function My(a,b){return p[a>>2]+v(b,20)|0}function Mn(a,b){return p[a>>2]-p[b>>2]|0}function MO(a,b){return Pn(a,Ib(b),wb(b))}function Ld(a,b){p[a>>2]=p[b>>2];return a}function Hr(a,b,c){return o[b>>1]<o[c>>1]}function Hl(a,b){return p[a>>2]+(b<<11)|0}function Gc(a,b){return p[a>>2]+v(b,24)|0}function Em(a){return p[p[a+48>>2]+12>>2]}function Efa(a){a=a|0;return p[a+4260>>2]}function Dn(a,b,c){return r[b>>1]<r[c>>1]}function De(a,b){return p[a>>2]+v(b,52)|0}function Cc(a){return p[a+4>>2]-p[a>>2]|0}function B6(a){a=a|0;if(a){kF(a);Od(a,a)}}function zLa(a,b){a=a|0;b=b|0;Lc(a,b,11)}function yba(a){a=a|0;pG(a,2);return a|0}function yEa(a,b){a=a|0;b=b|0;Lc(a,b,17)}function xqa(a){a=+a;return rqa(Id(a))|0}function x7(a){a=a|0;return+DF(a+ -88|0)}function wia(a){a=a|0;return q[a+4201|0]}function wB(a,b){Qb(a,b);Qb(a+4|0,b+4|0)}function via(a){a=a|0;return q[a+4202|0]}function vba(a){a=a|0;pG(a,8);return a|0}function uB(a){p[a+4>>2]=0;p[a>>2]=68364}function tf(a){a=a|0;return!p[a+16>>2]|0}function sg(a,b){p[a+8>>2]=b|-2147483648}function s_(a,b){a=a|0;b=b|0;Mb(a,62592)}function r_(a,b){a=a|0;b=b|0;Qu(a,62600)}function qr(a,b){p[a+24>>2]=p[a+24>>2]+b}function q_(a,b){a=a|0;b=b|0;Mb(a,62620)}function pr(a){if(me(a,-1)){a=0}return a}function p_(a,b){a=a|0;b=b|0;Qu(a,62628)}function ll(a,b){return p[a>>2]==p[b>>2]}function lAa(a,b){a=a|0;b=b|0;Lc(a,b,10)}function lA(a,b){return p[a>>2]+(b<<5)|0}function kc(a,b){return p[a>>2]+(b<<1)|0}function jc(a,b){return p[a>>2]+(b<<4)|0}function ega(a){a=a|0;if(a){xr(a);Nb(a)}}function cd(a){return p[a>>2]==p[a+4>>2]}function Ws(a){a=a|0;return p[a>>2]+14|0}function Wea(a){a=a|0;return(a|0)==277|0}function Ud(a){return(a+ -1&255)>>>0<120}function TNa(a){return a<0?C(a):B(a)}



function Sf(a){a=a|0;return Ud(q[a|0])|0}function Qj(a){return r[Em(a)+480188>>1]}function Pm(a){a=a|0;return TK(q[a|0])|0}function PC(){Bd(463248);p[115812]=65752}function OC(){Bd(463280);p[115820]=66248}function NC(){Bd(463288);p[115822]=66412}function MC(){Bd(463296);p[115824]=66576}function LC(){Bd(463304);p[115826]=66740}function KC(){Bd(463376);p[115844]=66904}function GH(a){return(q[a+24|0]&8)>>>3|0}function Fn(a){return v(Vp(a),le(a))&255}function Fk(a,b){return p[a>>2]+(b<<3)|0}function Fc(a,b){return p[a>>2]+v(b,6)|0}function Fb(a,b){return p[a>>2]+(b<<2)|0}function Db(a){p[p[a>>2]+4>>2]=p[a+4>>2]}function C7(a){a=a|0;return+HF(a+ -88|0)}function AKa(a,b){a=a|0;b=b|0;Lc(a,b,44)}function A7(a){a=a|0;return+FF(a+ -88|0)}function zd(a,b){return s[a>>2]<s[b>>2]}function xt(a,b){return p[a>>2]<p[b>>2]}function xsa(a,b){a=a|0;b=b|0;ol(b,0,0)}function vr(a){a=a|0;if(a){Ge(a);Nb(a)}}function ty(a,b,c){if(b){Jb(a,og(c),b)}}function sh(a,b,c){Wc(a,b);Wc(a+12|0,c)}function qt(a){a=a|0;return Gz(fc(a))|0}function oP(a,b){p[a>>2]=p[a>>2]+(b<<2)}function nfa(a){a=a|0;return-2013527448}function jD(a,b){a=a|0;b=b|0;nj(a,1,45)}function iD(a,b){a=a|0;b=b|0;sD(a,1,45)}function gK(a,b){return u[a>>3]<u[b>>3]}function fi(a){p[a+4>>2]=0;p[a+8>>2]=-1}function Ss(a){a=+a;return UDa(Id(a))|0}function Rca(a){a=a|0;return p[a+16>>2]}function Pt(a,b){a=a|0;b=b|0;Lc(a,b,32)}function Oza(a,b){a=a|0;b=b|0;Lc(a,b,5)}function Od(a,b){if(!p[a+80>>2]){Nb(b)}}function OK(a,b){return($j(a,b)|0)!=255}function HQ(a,b){p[a>>2]=p[a>>2]+v(b,6)}function Caa(a){a=a|0;return+u[a+16>>3]}function BMa(a,b){a=a|0;b=b|0;o[b>>1]=0}function BH(a,b){return t[a>>2]<t[b>>2]}function AA(a,b){a=a|0;b=b|0;return b|0}function xna(a,b){a=a|0;b=b|0;fma(a,b)}function xB(a,b){nC(a,b);p[a>>2]=71628}function vga(a){a=a|0;return-284078960}function vfa(a){a=a|0;return 302837129}function vU(a){a=a|0;return p[a+24>>2]}function uy(a){return p[a+4>>2]+ -24|0}function tca(a,b){a=a|0;b=b|0;pca(a,b)}function sk(a){return v(p[a>>2],Fn(a))}function rA(a){qb(a);return 2147483647}function qg(a){return p[a+4>>2]+ -32|0}function q$(a){a=a|0;xZ(p[p[a>>2]>>2])}function psa(a,b){a=a|0;b=b|0;osa(a,b)}function oxa(a){a=a|0;SM(a);return a|0}function oG(a){return p[a+4>>2]+ -48|0}function nM(a,b){p[a+4>>2]=b;p[a>>2]=b}function mga(a){a=a|0;if(a){Nb(sw(a))}}function lga(a){a=a|0;return-281111764}function le(a){return q[a+34|0]&64?2:1}function lc(a){p[p[a+8>>2]>>2]=p[a>>2]}function iua(a,b){a=a|0;b=b|0;Uta(a,b)}function iFa(a){a=a|0;return q[a+40|0]}function i5(a){a=a|0;return p[a+20>>2]}function hG(a){return a?(a|0)==2?3:2:1}function dga(a){a=a|0;return-271958638}function bw(a,b){p[a+4>>2]=p[a+4>>2]|b}function Zr(a){return(a|0)<=-1?0-a|0:a}function ZX(a,b){a=a|0;b=b|0;m[a|0](b)}function Xsa(a){a=a|0;Wsa();return a|0}function Wr(a){a=a|0;return 2147483647}function WIa(a,b){a=a|0;b=b|0;vIa(b,a)}function Vfa(a){a=a|0;return-620920304}function Ui(a,b){return Ib(a)+(b<<2)|0}function Uea(a,b){a=a|0;b=b|0;return 3}function UU(a){a=a|0;return p[a+12>>2]}function Tga(a){a=a|0;return-270114148}function Tea(a,b){a=a|0;b=b|0;return 2}function TN(a){return p[a+4>>2]+ -56|0}function PGa(a){a=a|0;return w(NGa(a))}function OX(a){a=a|0;return m[a|0]()|0}function Msa(a){a=a|0;Isa();return a|0}function Jha(a){a=a|0;if(a){Nb(zw(a))}}function Iha(a){a=a|0;return 542066252}function Gga(a){a=a|0;if(a){Nb(uw(a))}}function Gfa(a){a=a|0;if(a){Nb(qw(a))}}function Fga(a){a=a|0;return-285139079}function Ffa(a){a=a|0;return-275227023}function FQ(a,b){a=a|0;b=b|0;Pr(a,0,b)}function FAa(a,b){a=a|0;b=b|0;tAa(b,a)}function Bia(a){a=a|0;if(a){Nb(Fw(a))}}function xg(a){a=a|0;vv(a);return a|0}function wt(a){return(q[a+16|0]&5)!=0}function vE(a,b){return hE(a)^hE(b)^1}function tha(a,b,c){a=a|0;b=b|0;c=c|0}function rt(a){a=a|0;return p[a+4>>2]}function qE(a,b){return gE(a)^gE(b)^1}function nn(a,b){o[a+8>>1]=b;return a}function nG(a){return r[a+1074438>>1]}function jp(a){a=a|0;Vs(a);return a|0}function jk(a){a=a|0;ct(a);return a|0}function jha(a,b){a=a|0;b=b|0;os(a,b)}function jC(a){return cZ(Ib(a),wb(a))}function ig(a,b){a=a|0;b=b|0;rNa(a,b)}function iE(a){a=a|0;Ju(a);return a|0}function hz(a,b){a=a|0;b=b|0;TFa(a,b)}function gz(a){return p[a+1304496>>2]}function fDa(a){a=a|0;return CCa(a)|0}function ev(a){a=a|0;if(JD(a)){Nb(a)}}function eJa(a){a=a|0;return q[a+8|0]}function cy(a,b,c,d,e){jva(a,b,c,d,e)}function cC(a,b){return q[a|0]<q[b|0]}function _i(a){return p[a+4>>2]+ -4|0}function _3(a){a=a|0;return ZD(a,0)|0}function Ys(a){a=a|0;return Hb(a,1)^1}function Y3(a){a=a|0;return ZD(a,1)|0}function WG(a,b){a=a|0;b=b|0;return 0}function Vp(a){return n[a+34|0]&1?2:1}function V3(a){a=a|0;return WD(a,0)|0}function U3(a){a=a|0;return WD(a,1)|0}function Sq(a,b){a=a|0;b=b|0;return-1}function Soa(a){a=a|0;return Moa(a)|0}function Rua(a){a=a|0;return Cua(a)|0}function PO(a,b){if(!dCa(a,b)){KO(b)}}function PNa(a,b,c){return KNa(a,b,c)}function Oe(a,b){p[a+4>>2]=b;return a}function Ob(a){return lA(a,q[a+16|0])}function MF(a){p[a>>2]=84536;return a}function Ju(a){a=a|0;rq(a);return a|0}function It(a,b){a=a|0;b=b|0;lNa(b,a)}function Ew(a,b){a=a|0;b=b|0;return 1}function Dt(a,b){a=a|0;b=b|0;DMa(b,a)}function Dl(a,b){a=a|0;b=b|0;HMa(b,a)}function Bz(a){a=a|0;return p[a+8>>2]}function BM(a){a=a|0;sO(a);return a|0}function ym(a,b){a=a|0;b=b|0;fZ(a,b)}function xma(a){a=a|0;return vh(a)|0}function v_(a){a=a|0;return n[a+8|0]}function vR(a,b){Cc(a);_S(a,b);gp(a)}function u_(a){a=a|0;return n[a+9|0]}function oya(a,b){a=a|0;b=b|0;mya(b)}function nQ(a,b){Bb(a);RL(a,b);Hg(a)}function lM(a,b){ne(a);hM(a,b);pu(a)}function jLa(a){a=a|0;return zp(a)|0}function iz(a,b){Rf(a);lQ(a,b);aQ(a)}function fLa(a){a=a|0;return Zp(a)|0}function eO(a,b){a=a|0;b=b|0;Wt(a,b)}function dLa(a){a=a|0;return Pz(a)|0}function aHa(a){a=a|0;return gz(a)|0}function aH(a){p[a>>2]=0;p[a+4>>2]=0}function _c(a,b){return Hl(a+12|0,b)}function Xn(a,b){a=a|0;b=b|0;O1(a,b)}function Vt(a,b){Cc(a);IA(a,b);gp(a)}function Ufa(a){a=a|0;p[a+4224>>2]=0}function TK(a){return(a+5&255)>>>0<2}function Sl(a){p[a+4>>2]=p[a+4>>2]+1}function Rt(a,b){Bb(a);tA(a,b);Hg(a)}function QS(a,b){a=a|0;b=b|0;PS(a,b)}function Pza(a){a=a|0;return t9(a)|0}function Ow(a,b,c){return Pka(a,b,c)}function Jw(a,b){Bb(a);oQ(a,b);Hg(a)}function IT(a){a=a|0;return ENa(a)|0}function Gp(a,b){fc(a);tT(a,b);Fp(a)}function Fs(a){return p[qb(a)>>2]<<5}function FCa(a,b){a=a|0;b=b|0;ECa(b)}function Es(a,b){a=a|0;b=b|0;Uf(a,b)}function EI(a,b){of(a);GJ(a,b);AI(a)}function Cra(a){a=a|0;return qj(a)|0}function Bj(a,b){a=a|0;b=b|0;P1(a,b)}function zA(a){return q[a+22|0]&127}function xP(a){a=a|0;return Ws(a)|0}function x5(a){a=a|0;return Y8(a)|0}function uh(a,b,c){if(c){ac(a,b,c)}}function ti(a,b){return v(b,12)+a|0}function qZ(a){a=a|0;return Ee(a)|0}function qW(a){a=a|0;return Lf(a)|0}function qMa(a,b){a=a|0;b=b|0;Hh(b)}function pA(a){a=a|0;return DT(a)|0}function oc(a,b){return p[a>>2]+b|0}function jn(a,b,c){return Dn(a,b,c)}function dsa(a,b){a=a|0;b=b|0;ce(b)}function _r(a){return Ho(a)<<24>>24}function Zra(a,b){a=a|0;b=b|0;Hs(b)}function ZC(a,b){Gl(p[a>>2],n[b|0])}function Ye(a,b,c){return sz(a,b,c)}function YU(a){a=a|0;return td(a)|0}function YEa(a,b){a=a|0;b=b|0;PP(b)}function XB(a){a=a|0;return p[a>>2]}function Vb(a){return Ze(p[a+4>>2])}function Sg(a){return a+ -48>>>0<10}function QW(a){a=a|0;return kG(a)|0}function Pl(a,b,c){if(c){Ji(a,b,c)}}function MA(a){a=a|0;return kg(a)|0}function Lv(a){return!hd(a,84612,6)}function Lta(a,b){a=a|0;b=b|0;pl(b)}function K9(a){a=a|0;return wt(a)|0}function Jna(a,b){a=a|0;b=b|0;hl(b)}function Ira(a,b){a=a|0;b=b|0;Um(b)}function Ic(a,b){p[a>>2]=b;return a}function Hza(a,b){a=a|0;b=b|0;vy(b)}function Hna(a,b){a=a|0;b=b|0;Qf(b)}function He(a){return p[a+24620>>2]}function EBa(a){a=a|0;return+BBa(a)}function DM(a,b){return Yo(a,0-b|0)}function BA(a){return q[a+21|0]&127}function $s(a){a=a|0;return $g(a)|0}function zj(a,b){a=a|0;b=b|0;Lb(a)}function yq(a,b){a=a|0;b=b|0;Ue(a)}function xh(a,b){Lc(a,Ib(b),wb(b))}function wq(a){Bd(a);p[a>>2]=63416}function wm(a,b){p[a+1304560>>2]=b}function vg(a,b){p[a>>2]=p[a>>2]|b}function sn(a,b){a=a|0;b=b|0;Ce(b)}function i7(a,b){a=a|0;b=b|0;Nb(b)}function hy(a,b){a=a|0;b=b|0;ws(b)}function hi(a,b){return(b<<13)+a|0}function fD(a){return Og(a,461692)}function ez(a,b){a=a|0;b=b|0;_s(b)}function eD(a){return Og(a,461684)}function eA(a){n[a|0]=0;n[a+1|0]=0}function dB(a,b){a=a|0;b=b|0;Ll(b)}function bk(a,b){zn(a,b,p[b+4>>2])}function bD(a){return Og(a,461708)}function as(a){return a>>>27^a}



function aX(a,b){a=a|0;b=b|0;EC(b)}function aD(a){return Og(a,461700)}function Zs(a,b){a=a|0;b=b|0;vt(b)}function Xh(a){return cd(a+36|0)^1}function Tv(a){a=a|0;n[a+6152|0]=0}function Sy(a,b){a=a|0;b=b|0;Xe(b)}function RW(a){a=a|0;kq(a,1,10956)}function PV(a,b){a=a|0;b=b|0;ju(b)}function MV(a,b){a=a|0;b=b|0;KV(b)}function LS(a,b){a=a|0;b=b|0;eA(b)}function Kk(a){Am(a);p[a>>2]=71260}function IS(a,b){a=a|0;b=b|0;sb(b)}function Hc(a,b){ws(a);Ic(a+4|0,b)}function Dx(a,b,c){Qpa(a,b-a>>2,c)}function DD(a,b){a=a|0;b=b|0;yb(b)}function Bd(a){uB(a);p[a>>2]=62948}function $h(a){a=a|0;n[a+4202|0]=0}function $g(a){return p[a>>2]+16|0}function ze(a){return n[a+11|0]<0}function yY(a){a=a|0;return 71235}function yA(a){return n[a+22|0]<0}function xY(a){a=a|0;return 71272}function wi(a){p[a>>2]=1;return a}function wN(a,b){return Vz(a,b,4)}function uY(a){a=a|0;return 71784}function tz(a,b){return Md(a,b)^1}function tj(a,b,c){x$(a+24|0,b,c)}function s4(a){a=a|0;return 56008}function rk(a,b){Re(a,b);return a}function on(a){p[a>>2]=2;return a}function ok(a){p[a>>2]=p[a>>2]+24}function nf(a,b){return(b<<2)+a|0}function ml(a){o[a>>1]=0;return a}function lw(a,b){return jJ(a,b)^1}function lk(a){p[a>>2]=0;return a}function kn(a){p[a>>2]=p[a>>2]+12}function ke(a){return of(a)&65535}function ir(a,b,c,d){cva(a,b,c,d)}function hga(a){a=a|0;xr(a);Nb(a)}function hEa(a){a=a|0;Vy(a);Nb(a)}function hAa(a){a=a|0;AP(a,65535)}function dEa(a){a=a|0;Uy(a);Nb(a)}function cw(a){return a+1304500|0}function cc(a,b){return Ib(a)+b|0}function an(a,b,c,d){fva(a,b,c,d)}function Zx(a){p[a>>2]=p[a>>2]+32}function Zt(a){return n[a+24|0]&1}function Yc(a,b){return(b<<1)+a|0}function Ub(a){return Ze(p[a>>2])}function SO(a,b){return yn(a,b,5)}function Qx(a){p[a>>2]=p[a>>2]+52}function Ot(a){return n[a+21|0]<0}function NY(a){a=a|0;return 70505}function Mm(a){return a+1074324|0}function Lr(a,b,c){dla(a,b-a|0,c)}function LY(a){a=a|0;return 70584}function Im(a){Gg(a+4|0);return a}function IH(a){return a+1074328|0}function I7(a){a=a|0;LF(a+ -88|0)}function HS(a,b){return Vz(a,b,7)}function GS(a){return q[a+1|0]==1}function Ff(a){p[a>>2]=p[a>>2]+16}function Fca(a){a=a|0;mw(a);Nb(a)}function ES(a,b){return yn(a,b,7)}function Cy(a,b){Wc(a,b);return a}function Be(a){return p[_b(a)>>2]}function zh(a){return nqa($d(a))}function xw(a,b){return Aha(a,b)}function wv(){return(Va()|0)>0|0}function wr(a){a=a|0;Ge(a);Nb(a)}function wp(a){return Jb(a,0,48)}function vQ(a,b){return LFa(a,b)}function vN(a){return q[a|0]<129}function uk(a){p[a>>2]=p[a>>2]+6}function tK(a){return zpa($d(a))}function rb(a){T(a|0)|0;AY();E()}function qz(a,b){return bDa(a,b)}function pR(a){zl(a);si(a);zl(a)}function lu(a){a=a|0;rq(a);Nb(a)}function kt(a){ri(a);Rf(a);ri(a)}function ks(a){Bb(a);aM(a);Hg(a)}function kf(a){rd(a);Bb(a);rd(a)}function kd(a){return p[a>>2]!=0}function ji(a){return _ua($d(a))}function iK(a,b){return epa(a,b)}function hq(a){ne(a);AB(a);pu(a)}function gP(a){ep(a);ep(a);$O(a)}function fs(a){Cc(a);fT(a);gp(a)}function eq(a){Di(a);ng(a);Di(a)}function ek(a){return NCa(Id(a))}function bl(a,b){return Iga(a,b)}function bi(a){Bb(a);pQ(a);Hg(a)}function bg(a){p[a>>2]=p[a>>2]+1}function bS(a){fc(a);VR(a);Fp(a)}function bI(a){$e(a);YH(a);XH(a)}function ad(a,b){return GNa(a,b)}function _D(a){a=a|0;Vk(a);Nb(a)}function XD(a){a=a|0;bo(a);Nb(a)}function UP(a){vl(a);gk(a);vl(a)}function Sx(a){p[a>>2]=p[a>>2]+8}function Ri(a){_f(a);nc(a);_f(a)}function RH(a){Oj(a);$e(a);Oj(a)}function PN(a){cn(a);ak(a);cn(a)}function OP(a){Bb(a);MP(a);Hg(a)}function Nz(a,b){return uKa(a,b)}function Nl(a){hh(a);ne(a);hh(a)}function NG(a){a=a|0;nw(a);Nb(a)}function Mr(a){return OJ(q[a|0])}function LI(a){Rf(a);mQ(a);aQ(a)}function Kz(a){si(a);FR(a);ER(a)}function KQ(a,b){return mDa(a,b)}function Je(a,b){p[a>>2]=p[b>>2]}function JC(a){Mk(a);Bb(a);Mk(a)}function Ix(a){n[a|0]=0;return a}function IJ(a){Wi(a);of(a);Wi(a)}function Hp(a){Hf(a);Cc(a);Hf(a)}function Hk(a){Ih(a);gd(a);Ih(a)}function GY(a,b){a=a|0;b=b|0;E()}function GT(a,b){return FNa(a,b)}function Fu(a){a=a|0;Gu(a);Nb(a)}function Ey(a,b){return oCa(a,b)}function Bp(a){fc(a);SS(a);Fp(a)}function Bh(a){Le(a);Dd(a);Le(a)}function BP(a,b){ac(a,b+4|0,256)}function At(a,b){return ILa(a,b)}function Ak(a){If(a);fc(a);If(a)}function $H(a){Bb(a);VH(a);Hg(a)}function zq(a){a=a|0;return 127}function zm(a){return a<<24>>24}function yk(a,b){return FT(a,b)}function yi(a,b,c){Qe(a,c,13,b)}function xo(a){o[a+480214>>1]=0}function xca(a){a=a|0;Nb(nw(a))}function uu(a){kW(a,tD(Ee(12)))}function uj(a,b,c){Lc(a,b,1<<c)}function uJ(a,b){return rJ(a,b)}function tC(a,b){return FZ(a,b)}function pl(a){pb(a+12|0);qf(a)}function nga(a){a=a|0;Nb(sw(a))}function li(a,b){return lA(a,b)}function jea(a){a=a|0;Nb(rr(a))}function iO(a,b){return ki(b,a)}function fm(a,b){return l2(a,b)}function fe(a,b){return N5(a,b)}function _d(a){a=a|0;return a|0}function Yi(a){return!p[a+4>>2]}function Xm(a){return cj(Id(a))}function XZ(a){a=a|0;pb(461912)}function VZ(a){a=a|0;yc(461928)}function Um(a){pb(a+12|0);pb(a)}function Uga(a){a=a|0;Nb(xr(a))}function TZ(a){a=a|0;pb(461944)}function Se(a){pb(a+20|0);pb(a)}function SR(a,b){return eu(a,b)}function Ru(a,b){return hf(a,b)}function Rs(a,b){return mP(a,b)}function Rb(a,b){return De(a,b)}function RZ(a){a=a|0;yc(461960)}function PZ(a){a=a|0;pb(461976)}function NZ(a){a=a|0;yc(461992)}function Lp(a,b){return ET(a,b)}function LZ(a){a=a|0;pb(462008)}function Kha(a){a=a|0;Nb(zw(a))}function Kh(a,b){return a>>>b&1}function JZ(a){a=a|0;yc(462024)}function Io(a){be(a+12|0);zL(a)}function Hga(a){a=a|0;Nb(uw(a))}function Hfa(a){a=a|0;Nb(qw(a))}function Fd(a,b){return Hl(a,b)}function Dfa(a){a=a|0;return 13}function Cia(a){a=a|0;Nb(Fw(a))}function Ah(a){return ne(a)&255}function Ae(a,b){return Kf(a,b)}function x_(a){a=a|0;Nb(zC(a))}function wy(a){Uza(a);return a}function w_(a){a=a|0;Nb(yC(a))}function wY(a){a=a|0;Nb(Gu(a))}function wC(a){a=a|0;Nb(Ou(a))}function w$(a){a=a|0;Nb(GC(a))}function vY(a){a=a|0;Nb(rq(a))}function uv(a){a=a|0;Nb(Rq(a))}function uca(){return 19464961}function tJ(a,b,c){Ox(a,b,c,1)}function r9(a){a=a|0;Nb(fG(a))}function qv(a){a=a|0;Nb(Oq(a))}function pp(a){qHa(a);return a}function p4(a){a=a|0;Nb(iE(a))}function n4(a){a=a|0;Nb(vv(a))}function mP(a,b){return b-a>>2}function m9(a){a=a|0;Nb(cG(a))}function kw(a){Jba(a);return a}function kV(a){a=a|0;Nb($A(a))}function gV(a){a=a|0;Nb(bu(a))}function g5(a){a=a|0;Nb(Vk(a))}function e$(a){a=a|0;Nb(DC(a))}function cF(a){return a>>>0>16}function c5(a){a=a|0;Nb(bo(a))}function ae(a,b){n[a|0]=q[b|0]}function Zy(a){lFa(a);return a}function Wb(a,b){p[a+100>>2]=b}function W_(a){a=a|0;Nb(WC(a))}function Vw(a){Fla(a);return a}function TG(a){a=a|0;Nb(Qd(a))}function Rc(a,b){_Y(a,b,HD(b))}function RM(a){return a+4896|0}function RF(a){a=a|0;Nb(ff(a))}function Pj(a){ika(a);return a}function Lx(a,b){return b-a>>1}function LF(a){a=a|0;Nb(Vv(a))}function Kya(a){a=a|0;return 9}function KH(a){sha(a);return a}function JH(a){rha(a);return a}function HY(a){a=a|0;Nb(Ju(a))}function Dga(a){a=a|0;return 6}function DE(a){a=a|0;Nb(xg(a))}function Ct(a){QMa(a);return a}function C9(a){a=a|0;Nb(nr(a))}function $r(a,b){return a<<8|b}function xs(a){return a+256|0}function xi(a){qA(a);return a}function xS(a,b,c){HLa(a,b,c)}function wn(a){fA(a);return a}function wW(a){a=a|0;return 3}function ux(a){bn(a);return a}function tx(a){XA(a);return a}function tD(a){R1(a);return a}function rT(a,b){return b-a|0}function qp(a){cT(a);return a}function mN(a){sya(a,p[a>>2])}function kj(a,b,c){kNa(a,b,c)}function je(a){a=a|0;return 1}function iq(a){a=a|0;return 4}function ie(a){a=a|0;return 2}function gl(a,b){p[a+32>>2]=b}function dr(a,b,c){pga(a,b,c)}function ct(a){lk(a);return a}function bn(a){dy(a);return a}function aj(a){return kd(a)^1}function _X(a){a=a|0;m[a|0]()}function Yz(a,b,c){Ega(a,b,c)}function Yt(a){Xt(a);return a}function Yb(a,b){return a+b|0}function YM(a){yxa(a,p[a>>2])}function YI(a){a=a|0;return 5}function Xg(a){jL(a);return a}function WI(a){Cla(a,p[a>>2])}function Vm(a,b){p[a+36>>2]=b}function VR(a){yKa(a,p[a>>2])}function Tw(a,b,c){fga(a,b,c)}function Ry(a,b,c){VDa(a,b,c)}function Pe(a,b){o[a+28>>1]=b}function NN(a){Rza(a,p[a>>2])}function LM(a,b){Jb(a,0,b<<2)}function Kp(a){return a>>>0<5}function Jq(a,b){p[a+72>>2]=b}function Hv(a){h5(a);return a}function HNa(){E3();h4();iJ()}function Ck(a){return!p[a>>2]}function Ch(a){return cd(a)^1}function CP(a){a=a|0;return 7}function AE(a){a=a|0;return-1}function $b(a){a=a|0;return 0}function yp(a){p[a>>2]=76688}function yI(a,b){Wi(a);Wi(a)}function xD(a,b,c){G2(a,b,c)}function vs(a,b){NM(a,Cd(b))}function vca(){return 327683}function uo(a,b){t[a+8>>2]=b}function tu(a,b){zB(a,Cd(b))}function st(a,b){Le(a);Le(a)}function sq(a){return a+16|0}function so(a,b){t[a+4>>2]=b}function sC(a,b){Mk(a);Mk(a)}function ro(a,b){n[a+36|0]=b}function ql(a,b){qb(b);qb(a)}function qM(a,b){nM(a,Vb(b))}function qL(a){pL(a,p[a>>2])}function pq(a,b,c){Lc(a,b,c)}function pc(a,b){a=a|0;b=b|0}function pQ(a){oQ(a,p[a>>2])}function pM(a,b){nM(a,Ub(b))}function pK(a){oK(a,p[a>>2])}function oe(a,b){p[a+4>>2]=b}function nt(a,b){ri(a);ri(a)}function mQ(a){lQ(a,p[a>>2])}function jr(a){p[a>>2]=84040}function iM(a){hM(a,p[a>>2])}function hn(a,b){p[a+8>>2]=b}function gu(a,b){Di(a);Di(a)}function fT(a){_S(a,p[a>>2])}function dA(a,b){Hf(a);Hf(a)}function cf(a,b){n[a+11|0]=b}function cP(a,b,c){yw(a,b,c)}function bq(a,b){hh(a);hh(a)}function ax(a,b){n[a+37|0]=b}function aM(a){RL(a,p[a>>2])}function _F(a){d9(a,p[a>>2])}function YH(a){SH(a,p[a>>2])}function YG(a){p[a>>2]=56120}function Xb(a){return a+12|0}function Wd(a,b,c){YT(a,b,c)}function Vl(a,b){Ih(a);Ih(a)}function Vj(a,b){rd(a);rd(a)}function VJ(a){return a+80|0}function VH(a){PH(a,p[a>>2])}function Ut(a,b){If(a);If(a)}function SS(a){tT(a,p[a>>2])}function RC(a){qC(a,p[a>>2])}function QN(a,b){Qe(a,b,8,2)}function Nk(a){return a+32|0}function NF(a){p[a>>2]=84512}function MP(a){tA(a,p[a>>2])}function JA(a){IA(a,p[a>>2])}function Iq(a,b){Wn(a,b+4|0)}function Ig(a){return a+20|0}function HJ(a){GJ(a,p[a>>2])}function FR(a){tR(a,p[a>>2])}function Am(a){p[a>>2]=71296}function AG(a){p[a>>2]=83760}function AB(a){QV(a,p[a>>2])}function $w(a,b){n[a+38|0]=b}function $n(a,b){_f(a);_f(a)}function xT(a,b){Lc(a,b,20)}function vn(a,b,c){xMa(b,c)}function vi(a){return a+3|0}function vA(a,b){Lc(a,b,22)}function tg(){tc(70492);E()}function qb(a){return a+8|0}function oy(a){p[a+12>>2]=0}function og(a){return a&255}function oR(a,b,c){wJa(b,c)}function mt(a,b,c){GJa(b,c)}function lj(a,b){n[a+3|0]=b}function ix(a,b,c){Kna(b,c)}function iAa(){return 65534}function gj(a,b,c){lGa(b,c)}function fp(a,b,c){HDa(b,c)}function cK(a){Jb(a,0,1024)}function bC(){Hi(70909);E()}function _b(a){return a+4|0}function Zc(a){return a+1|0}function Yl(){Hi(70492);E()}function Vc(){tc(70909);E()}function Tf(a){return a+2|0}function RE(){return 458336}function QP(a,b,c){UEa(b,c)}function QH(a,b,c){jia(b,c)}function Pc(a){return!wb(a)}function Ks(a,b,c){YBa(b,c)}function Ie(a,b,c){lta(b,c)}function FJa(){return 65535}function Eo(a,b,c){tpa(b,c)}function Do(a){Jb(a,0,8192)}function CY(){return 463668}function $o(a){Jb(a,0,4096)}function zs(a){_f(a);nc(a)}function zf(a){eq(a);Rx(a)}function yR(a){kt(a);wR(a)}function x3(){return 58208}function wl(a){kt(a);at(a)}function wQ(a){n[a+31|0]=0}function w3(){return 58992}function v3(){return 60544}function to(a,b){t[a>>2]=b}function tQ(a){bz(a,Be(a))}function sy(a,b,c){LN(b,c)}function sf(a,b){p[a>>2]=b}function ru(a){eq(a);yB(a)}function qf(a){Ak(a);Bt(a)}function qQ(a){dz(a,Be(a))}function qK(a){Vr(a,Be(a))}function pu(a){hh(a);ne(a)}function nh(a,b,c){D3(b,c)}function lJ(a){Yw(a,Be(a))}function ip(a){Py(a,Be(a))}function hw(a){Hk(a);MG(a)}function hp(a){Oy(a,Be(a))}function gy(a){Jb(a,0,512)}function gp(a){Hf(a);Cc(a)}function gh(a,b,c){fB(b,c)}function gba(){return 2048}function fu(a,b,c){tV(b,c)}function ej(a,b){zn(a,b,0)}function eP(a){kf(a);bP(a)}function dO(a){kf(a);bO(a)}function cg(a,b,c){u5(b,c)}function bp(a){Le(a);Dd(a)}function be(a){kf(a);us(a)}function bd(a){Ri(a);TA(a)}function aQ(a){ri(a);Rf(a)}function Yj(a){Kx(a,Be(a))}function Xd(a){Hp(a);Tp(a)}function XH(a){Oj(a);$e(a)}function Up(a){Hp(a);NA(a)}function UC(a){JC(a);SC(a)}function TS(a,b){kj(a,2,b)}function Qo(a){Hk(a);AL(a)}function QK(a){vx(a,Be(a))}function QC(a){Mk(a);Bb(a)}function QB(a){Ih(a);gd(a)}function Mf(a,b,c){tB(b,c)}function LW(a){a=a|0;Gk(a)}function Kt(a,b,c){NT(b,c)}function Hg(a){rd(a);Bb(a)}function Gi(a,b,c){OB(b,c)}function Gg(a){Hp(a);uT(a)}function Gb(a){Rl(p[a>>2])}function Fp(a){If(a);fc(a)}function ER(a){zl(a);si(a)}function Dc(a){a=a|0;Nb(a)}function Cn(a,b,c){jU(b,c)}function Ac(a){p[a+8>>2]=0}function AI(a){Wi(a);of(a)}function $c(a){Hk(a);aT(a)}function xb(a,b){cCa(a,b)}function uF(a){Jb(a,0,44)}function uA(a){n[a+1|0]=3}function nS(a,b){sLa(a,b)}function hA(a,b){gNa(a,b)}function bE(a){bw(a,8192)}function aY(){return fb|0}function a4(a){a=a|0;b4()}function XO(a,b){ACa(a,b)}function RN(a,b){Qza(a,b)}function PP(a){Jb(a,0,33)}function $X(a){a=a|0;fb=a}function yS(a,b){TH(a,b)}function ws(a){p[a>>2]=0}function wO(a,b){Nw(a,b)}function uc(a){Gg(a+8|0)}function tn(a,b){tE(a,b)}function sL(a,b){pM(a,b)}function sB(a,b){Ic(a,b)}function mh(a,b){Mg(a,b)}function h0(){wq(463144)}function bM(a,b){mf(a,b)}function _s(a){pb(a+4|0)}function Zg(a){a=a|0;E()}function Un(a,b){GZ(a,b)}function Lh(a,b){E0(a,b)}function Ku(a,b){PY(a,b)}function Ce(a){sb(a+8|0)}function Az(a){n[a|0]=16}function Xe(a){n[a|0]=0}function wc(a){pe(a,0)}function th(a){HG(a,0)}function ny(a){fN(a,0)}function gq(a){zB(a,0)}function gg(a){NM(a,0)}function Tr(a){_J(a,0)}function Sr(a){ZJ(a,0)}function Qf(a){uQ(a,0)}function Nc(a){RG(a,0)}function AJ(a){kJ(a,0)}function $$(){PC()}



function yb(a){pb(a)}function xe(a){a=a|0}function gT(a){Rd(a)}function k0(){D$()}function W$(){OC()}function U$(){NC()}function S$(){MC()}function Q$(){LC()}function M$(){C$()}function K$(){B$()}function I$(){KC()}function zY(){E()}
// EMSCRIPTEN_END_FUNCS
m[1]=ul;m[2]=Mb;m[3]=Rp;m[4]=Uf;m[5]=aNa;m[6]=eS;m[7]=$Ha;m[8]=TGa;m[9]=Vi;m[10]=QFa;m[11]=uEa;m[12]=nDa;m[13]=Pr;m[14]=ul;m[15]=Z4;m[16]=rV;m[17]=Kl;m[18]=mg;m[19]=X4;m[20]=V;m[21]=_t;m[22]=Bk;m[23]=l7;m[24]=Gu;m[25]=ov;m[26]=me;m[27]=vU;m[28]=Jl;m[29]=zi;m[30]=gga;m[31]=mc;m[32]=pc;m[33]=Cb;m[34]=zi;m[35]=DKa;m[36]=NR;m[37]=LR;m[38]=Sy;m[39]=AT;m[40]=nA;m[41]=MDa;m[42]=Vy;m[43]=Zg;m[44]=je;m[45]=je;m[46]=eJa;m[47]=YIa;m[48]=rt;m[49]=QIa;m[50]=NP;m[51]=JEa;m[52]=AEa;m[53]=zY;m[54]=Uy;m[55]=Zg;m[56]=je;m[57]=$b;m[58]=je;m[59]=wGa;m[60]=sGa;m[61]=oGa;m[62]=hGa;m[63]=_Fa;m[64]=hEa;m[65]=yFa;m[66]=dEa;m[67]=iFa;m[68]=_Ea;m[69]=_d;m[70]=Zg;m[71]=AO;m[72]=FBa;m[73]=eO;m[74]=_N;m[75]=Is;m[76]=WN;m[77]=qO;m[78]=nO;m[79]=As;m[80]=jza;m[81]=va;m[82]=Yya;m[83]=Oc;m[84]=Oc;m[85]=Mb;m[86]=lZ;m[87]=jy;m[88]=vxa;m[89]=nxa;m[90]=Oc;m[91]=Kva;m[92]=Bva;m[93]=FM;m[94]=mc;m[95]=nl;m[96]=Wg;m[97]=Oc;m[98]=jZ;m[99]=Rua;m[100]=Bza;m[101]=uua;m[102]=xua;m[103]=iua;m[104]=cua;m[105]=xe;m[106]=Epa;m[107]=pc;m[108]=Msa;m[109]=FM;m[110]=Gl;m[111]=Wt;m[112]=gC;m[113]=XY;m[114]=ul;m[115]=upa;m[116]=xna;m[117]=wo;m[118]=Gl;m[119]=Ila;m[120]=Uf;m[121]=rla;m[122]=IC;m[123]=Gka;m[124]=yka;m[125]=rka;m[126]=Pfa;m[127]=Ifa;m[128]=o4;m[129]=zfa;m[130]=_ja;m[131]=Ija;m[132]=uja;m[133]=fI;m[134]=fI;m[135]=Gia;m[136]=sia;m[137]=Ar;m[138]=Rp;m[139]=zr;m[140]=fha;m[141]=Zga;m[142]=zr;m[143]=yba;m[144]=vba;m[145]=bba;m[146]=Waa;m[147]=zr;m[148]=zr;m[149]=ym;m[150]=ul;m[151]=Qd;m[152]=TG;m[153]=Lea;m[154]=Cea;m[155]=Oq;m[156]=qv;m[157]=nE;m[158]=mE;m[159]=rr;m[160]=jea;m[161]=pc;m[162]=ul;m[163]=_da;m[164]=lda;m[165]=$b;m[166]=$b;m[167]=f5;m[168]=ada;m[169]=e5;m[170]=Gca;m[171]=d5;m[172]=gca;m[173]=Q4;m[174]=K9;m[175]=S8;m[176]=M8;m[177]=U4;m[178]=L4;m[179]=J4;m[180]=ew;m[181]=O4;m[182]=w8;m[183]=ff;m[184]=RF;m[185]=h8;m[186]=$7;m[187]=Rq;m[188]=uv;m[189]=xE;m[190]=wE;m[191]=$6;m[192]=Is;m[193]=S6;m[194]=I6;m[195]=hF;m[196]=Pn;m[197]=ul;m[198]=t5;m[199]=Zq;m[200]=Es;m[201]=F5;m[202]=x5;m[203]=mc;m[204]=rv;m[205]=fE;m[206]=DD;m[207]=mc;m[208]=mc;m[209]=nA;m[210]=zu;m[211]=cX;m[212]=bX;m[213]=ZW;m[214]=MX;m[215]=pc;m[216]=aX;m[217]=pc;m[218]=Sy;m[219]=zCa;m[220]=YW;m[221]=XW;m[222]=WW;m[223]=VW;m[224]=tl;m[225]=TW;m[226]=k6;m[227]=Z5;m[228]=SW;m[229]=JB;m[230]=IB;m[231]=RW;m[232]=Zq;m[233]=QW;m[234]=NW;m[235]=wu;m[236]=LW;m[237]=Fi;m[238]=Ec;m[239]=HW;m[240]=On;m[241]=GW;m[242]=EW;m[243]=KW;m[244]=DW;m[245]=CW;m[246]=PW;m[247]=wCa;m[248]=MW;m[249]=GB;m[250]=BW;m[251]=AW;m[252]=FB;m[253]=zW;m[254]=bf;m[255]=qj;m[256]=Jc;m[257]=fq;m[258]=Hb;m[259]=oW;m[260]=pj;m[261]=fq;m[262]=iW;m[263]=hW;m[264]=fW;m[265]=rq;m[266]=MV;m[267]=LV;m[268]=Oc;m[269]=mc;m[270]=dB;m[271]=XB;m[272]=sV;m[273]=_V;m[274]=pg;m[275]=ZV;m[276]=PV;m[277]=Hh;m[278]=Oc;m[279]=EV;m[280]=pg;m[281]=DV;m[282]=Oc;m[283]=pc;m[284]=qV;m[285]=nV;m[286]=pg;m[287]=mV;m[288]=zi;m[289]=lu;m[290]=rt;m[291]=_d;m[292]=Dc;m[293]=Hn;m[294]=WG;m[295]=XV;m[296]=Dc;m[297]=WV;m[298]=je;m[299]=je;m[300]=rt;m[301]=Bz;m[302]=VV;m[303]=NP;m[304]=UV;m[305]=TV;m[306]=_d;m[307]=Dc;m[308]=Hn;m[309]=CV;m[310]=Dc;m[311]=$b;m[312]=je;m[313]=je;m[314]=$b;m[315]=$b;m[316]=jB;m[317]=$A;m[318]=kV;m[319]=Hn;m[320]=jV;m[321]=bu;m[322]=gV;m[323]=fV;m[324]=eV;m[325]=dV;m[326]=cV;m[327]=Rca;m[328]=bV;m[329]=aV;m[330]=$U;m[331]=Tn;m[332]=SU;m[333]=qma;m[334]=RU;m[335]=pma;m[336]=QU;m[337]=Zp;m[338]=Sb;m[339]=xma;m[340]=lB;m[341]=ld;m[342]=PU;m[343]=Wg;m[344]=aZ;m[345]=mc;m[346]=nl;m[347]=gB;m[348]=DD;m[349]=pc;m[350]=YA;m[351]=BU;m[352]=xU;m[353]=lu;m[354]=mc;m[355]=mc;m[356]=mc;m[357]=MA;m[358]=nU;m[359]=mU;m[360]=pc;m[361]=pc;m[362]=pc;m[363]=hU;m[364]=nA;m[365]=Sy;m[366]=zu;m[367]=PT;m[368]=Wg;m[369]=aU;m[370]=UT;m[371]=OT;m[372]=pc;m[373]=MA;m[374]=Jt;m[375]=IT;m[376]=pA;m[377]=HT;m[378]=wNa;m[379]=nNa;m[380]=jA;m[381]=Ep;m[382]=pc;m[383]=dNa;m[384]=kT;m[385]=cNa;m[386]=vd;m[387]=YU;m[388]=jT;m[389]=bNa;m[390]=qW;m[391]=hc;m[392]=Uc;m[393]=_Ma;m[394]=ZMa;m[395]=YMa;m[396]=iT;m[397]=hT;m[398]=XMa;m[399]=WMa;m[400]=fg;m[401]=Pf;m[402]=ag;m[403]=VMa;m[404]=eT;m[405]=dT;m[406]=NMa;m[407]=bT;m[408]=Dp;m[409]=mc;m[410]=CMa;m[411]=nl;m[412]=AMa;m[413]=ub;m[414]=zT;m[415]=zc;m[416]=mc;m[417]=mc;m[418]=qMa;m[419]=mc;m[420]=BMa;m[421]=yMa;m[422]=pc;m[423]=sMa;m[424]=jA;m[425]=LS;m[426]=IS;m[427]=kMa;m[428]=iMa;m[429]=hMa;m[430]=gMa;m[431]=fMa;m[432]=Fg;m[433]=eMa;m[434]=dMa;m[435]=cMa;m[436]=bMa;m[437]=dw;m[438]=NJ;m[439]=ub;m[440]=PM;m[441]=aMa;m[442]=Cg;m[443]=$La;m[444]=gA;m[445]=AS;m[446]=dd;m[447]=xd;m[448]=Fi;m[449]=Xi;m[450]=SLa;m[451]=RLa;m[452]=Bi;m[453]=dh;m[454]=JJ;m[455]=QLa;m[456]=PLa;m[457]=$z;m[458]=rc;m[459]=su;m[460]=OLa;m[461]=zS;m[462]=Yd;m[463]=Zz;m[464]=cA;m[465]=Wo;m[466]=ub;m[467]=Tt;m[468]=dU;m[469]=zLa;m[470]=Op;m[471]=_e;m[472]=Dt;m[473]=mLa;m[474]=gS;m[475]=CB;m[476]=ei;m[477]=rf;m[478]=Eb;m[479]=Ag;m[480]=lLa;m[481]=Sz;m[482]=kLa;m[483]=Ec;m[484]=jLa;m[485]=eua;m[486]=fS;m[487]=iLa;m[488]=hLa;m[489]=Uo;m[490]=fLa;m[491]=dS;m[492]=cS;m[493]=eLa;m[494]=dLa;m[495]=cLa;m[496]=ala;m[497]=Jp;m[498]=Ip;m[499]=el;m[500]=Pw;m[501]=OI;m[502]=aLa;m[503]=_R;m[504]=CH;m[505]=$Ka;m[506]=_Ka;m[507]=ZKa;m[508]=nk;m[509]=Rz;m[510]=YKa;m[511]=XKa;m[512]=Pt;m[513]=XR;m[514]=WKa;m[515]=PKa;m[516]=TR;m[517]=AO;m[518]=NKa;m[519]=AKa;m[520]=mc;m[521]=Oz;m[522]=Oz;m[523]=xKa;m[524]=eO;m[525]=_N;m[526]=Is;m[527]=WN;m[528]=sn;m[529]=rn;m[530]=xp;m[531]=mc;m[532]=pc;m[533]=As;m[534]=nKa;m[535]=mKa;m[536]=lKa;m[537]=dKa;m[538]=cKa;m[539]=Jz;m[540]=vp;m[541]=bKa;m[542]=bf;m[543]=aKa;m[544]=qt;m[545]=$Ja;m[546]=Vo;m[547]=_Ja;m[548]=pf;m[549]=ey;m[550]=ZJa;m[551]=YJa;m[552]=XJa;m[553]=Hz;m[554]=UJa;m[555]=Gf;m[556]=Sf;m[557]=SJa;m[558]=RJa;m[559]=QJa;m[560]=AJa;m[561]=zJa;m[562]=KJa;m[563]=JJa;m[564]=Tt;m[565]=lt;m[566]=xR;m[567]=MJa;m[568]=mc;m[569]=IJa;m[570]=pc;m[571]=zu;m[572]=sn;m[573]=pc;m[574]=rn;m[575]=xp;m[576]=mc;m[577]=fj;m[578]=sp;m[579]=jJa;m[580]=ft;m[581]=iJa;m[582]=bJa;m[583]=gS;m[584]=rp;m[585]=aJa;m[586]=gt;m[587]=fy;m[588]=dS;m[589]=$Ia;m[590]=xn;m[591]=_Ia;m[592]=ZIa;m[593]=iR;m[594]=Vf;m[595]=XIa;m[596]=WIa;m[597]=w5;m[598]=Dl;m[599]=Ms;m[600]=VIa;m[601]=qBa;m[602]=XR;m[603]=UIa;m[604]=RIa;m[605]=Dg;m[606]=cR;m[607]=sn;m[608]=rn;m[609]=xp;m[610]=mc;m[611]=zIa;m[612]=yIa;m[613]=cR;m[614]=VQ;m[615]=RI;m[616]=pla;m[617]=Sw;m[618]=QQ;m[619]=dIa;m[620]=cIa;m[621]=Dh;m[622]=SHa;m[623]=RHa;m[624]=Xna;m[625]=OHa;m[626]=NHa;m[627]=MHa;m[628]=LHa;m[629]=Qt;m[630]=KHa;m[631]=JHa;m[632]=Cb;m[633]=IHa;m[634]=bf;m[635]=ST;m[636]=HHa;m[637]=lxa;m[638]=mxa;m[639]=GHa;m[640]=FHa;m[641]=WHa;m[642]=mn;m[643]=VT;m[644]=EHa;m[645]=Xo;m[646]=TT;m[647]=JQ;m[648]=DHa;m[649]=CHa;m[650]=Goa;m[651]=Uc;m[652]=BHa;m[653]=AHa;m[654]=pz;m[655]=zHa;m[656]=BNa;m[657]=yHa;m[658]=wHa;m[659]=vHa;m[660]=IQ;m[661]=uHa;m[662]=py;m[663]=tHa;m[664]=sHa;m[665]=RT;m[666]=GR;m[667]=THa;m[668]=rHa;m[669]=FQ;m[670]=mHa;m[671]=mz;m[672]=nO;m[673]=GA;m[674]=Mp;m[675]=iHa;m[676]=hHa;m[677]=vm;m[678]=Pna;m[679]=gHa;m[680]=fHa;m[681]=EQ;m[682]=EQ;m[683]=AQ;m[684]=jz;m[685]=Pk;m[686]=cHa;m[687]=a$;m[688]=bHa;m[689]=aHa;m[690]=_Ga;m[691]=ZGa;m[692]=ah;m[693]=$ta;m[694]=ah;m[695]=Cka;m[696]=YGa;m[697]=jja;m[698]=zQ;m[699]=mc;m[700]=cGa;m[701]=fq;m[702]=ln;m[703]=PGa;m[704]=YFa;m[705]=QS;m[706]=Sn;m[707]=di;m[708]=mc;m[709]=eQ;m[710]=XFa;m[711]=WFa;m[712]=yQ;m[713]=WGa;m[714]=VGa;m[715]=mf;m[716]=UGa;m[717]=oi;m[718]=$s;m[719]=kja;m[720]=aoa;m[721]=_ia;m[722]=RGa;m[723]=Rp;m[724]=JGa;m[725]=IGa;m[726]=HGa;m[727]=Oc;m[728]=jk;m[729]=Oc;m[730]=cz;m[731]=_d;m[732]=sQ;m[733]=pg;m[734]=ez;m[735]=_d;m[736]=ez;m[737]=pc;m[738]=qGa;m[739]=pc;m[740]=pc;m[741]=fGa;m[742]=Wg;m[743]=Zs;m[744]=bGa;m[745]=DFa;m[746]=CFa;m[747]=BFa;m[748]=Eg;m[749]=pn;m[750]=AFa;m[751]=zFa;m[752]=xFa;m[753]=BB;m[754]=wFa;m[755]=vFa;m[756]=uFa;m[757]=tFa;m[758]=sFa;m[759]=rFa;m[760]=qFa;m[761]=oFa;m[762]=nFa;m[763]=mc;m[764]=CEa;m[765]=yEa;m[766]=aFa;m[767]=$Ea;m[768]=YEa;m[769]=pc;m[770]=KP;m[771]=sn;m[772]=JP;m[773]=HEa;m[774]=mc;m[775]=DP;m[776]=mn;m[777]=vEa;m[778]=tEa;m[779]=sEa;m[780]=rEa;m[781]=Nua;m[782]=bf;m[783]=qEa;m[784]=pEa;m[785]=oEa;m[786]=nEa;m[787]=$Q;m[788]=AM;m[789]=Ab;m[790]=Ws;m[791]=Ty;m[792]=vz;m[793]=dd;m[794]=pA;m[795]=lEa;m[796]=kEa;m[797]=AP;m[798]=jEa;m[799]=fS;m[800]=vp;m[801]=Gz;m[802]=iEa;m[803]=nj;m[804]=gEa;m[805]=Rp;m[806]=bf;m[807]=aA;m[808]=bf;m[809]=au;m[810]=It;m[811]=fEa;m[812]=oi;m[813]=xP;m[814]=lua;m[815]=Kw;m[816]=wP;m[817]=jp;m[818]=mc;m[819]=jk;m[820]=Oc;m[821]=mc;m[822]=pc;m[823]=LDa;m[824]=Wg;m[825]=Zs;m[826]=pc;m[827]=_d;m[828]=pc;m[829]=pc;m[830]=CDa;m[831]=jA;m[832]=LS;m[833]=wDa;m[834]=pg;m[835]=rDa;m[836]=Ei;m[837]=qDa;m[838]=pDa;m[839]=Ny;m[840]=Ps;m[841]=oDa;m[842]=lDa;m[843]=kDa;m[844]=jDa;m[845]=iDa;m[846]=hDa;m[847]=mT;m[848]=gDa;m[849]=fDa;m[850]=ub;m[851]=eDa;m[852]=dDa;m[853]=cDa;m[854]=aDa;m[855]=hxa;m[856]=Tra;m[857]=jB;m[858]=$Ca;m[859]=ub;m[860]=Os;m[861]=r6;m[862]=hz;m[863]=y6;m[864]=Os;m[865]=_Ca;m[866]=ZCa;m[867]=A6;m[868]=B6;m[869]=Qna;m[870]=YCa;m[871]=DQ;m[872]=CQ;m[873]=EM;m[874]=tl;m[875]=VCa;m[876]=UCa;m[877]=SCa;m[878]=RCa;m[879]=mc;m[880]=Zs;m[881]=mc;m[882]=FCa;m[883]=zi;m[884]=pc;m[885]=IS;m[886]=pt;m[887]=Ns;m[888]=kk;m[889]=di;m[890]=bf;m[891]=sp;m[892]=hCa;m[893]=gCa;m[894]=yCa;m[895]=Ys;m[896]=pc;m[897]=OBa;m[898]=AS;m[899]=vS;m[900]=NBa;m[901]=Sna;m[902]=MBa;m[903]=LBa;m[904]=CI;m[905]=ln;m[906]=KBa;m[907]=zO;m[908]=JBa;m[909]=IBa;m[910]=Mt;m[911]=Lt;m[912]=Js;m[913]=pqa;m[914]=HBa;m[915]=GBa;m[916]=rs;m[917]=EBa;m[918]=Cp;m[919]=DBa;m[920]=CBa;m[921]=Ay;m[922]=Gt;m[923]=mc;m[924]=pc;m[925]=eBa;m[926]=dBa;m[927]=dB;m[928]=bf;m[929]=VAa;m[930]=ig;m[931]=UAa;m[932]=Oc;m[933]=TAa;m[934]=SAa;m[935]=jO;m[936]=Oc;m[937]=Np;m[938]=RAa;m[939]=HAa;m[940]=GAa;m[941]=mk;m[942]=Ym;m[943]=Js;m[944]=FAa;m[945]=lla;m[946]=DAa;m[947]=cO;m[948]=mc;m[949]=Zs;m[950]=pc;m[951]=wAa;m[952]=Wg;m[953]=qAa;m[954]=pAa;m[955]=Jz;m[956]=lO;m[957]=UN;m[958]=cA;m[959]=oAa;m[960]=mAa;m[961]=lAa;m[962]=kAa;m[963]=jAa;m[964]=FJa;m[965]=iAa;m[966]=hAa;m[967]=gAa;m[968]=Ds;m[969]=fAa;m[970]=eAa;m[971]=Ds;m[972]=dAa;m[973]=mS;m[974]=Hz;m[975]=cAa;m[976]=ZT;m[977]=mc;m[978]=Pza;m[979]=Gza;m[980]=Dza;m[981]=sp;m[982]=Xza;m[983]=Wza;m[984]=Vza;m[985]=mc;m[986]=sn;m[987]=Oza;m[988]=rn;m[989]=xp;m[990]=Hza;m[991]=JN;m[992]=IN;m[993]=ry;m[994]=mc;m[995]=qza;m[996]=mn;m[997]=oza;m[998]=iza;m[999]=SM;m[1e3]=zO;m[1001]=mn;m[1002]=Wra;m[1003]=Vra;m[1004]=cza;m[1005]=Sya;m[1006]=Rya;m[1007]=su;m[1008]=Qya;m[1009]=Pya;m[1010]=Oya;m[1011]=Nya;m[1012]=Mya;m[1013]=Ss;m[1014]=Lya;m[1015]=Jya;m[1016]=Iya;m[1017]=Dya;m[1018]=yya;m[1019]=mc;m[1020]=qya;m[1021]=pya;m[1022]=gya;m[1023]=tya;m[1024]=pc;m[1025]=oya;m[1026]=mc;m[1027]=mc;m[1028]=aP;m[1029]=Zxa;m[1030]=zy;m[1031]=Wxa;m[1032]=Vxa;m[1033]=nua;m[1034]=Rxa;m[1035]=Qxa;m[1036]=cma;m[1037]=Pxa;m[1038]=Oxa;m[1039]=Nxa;m[1040]=ama;m[1041]=Mxa;m[1042]=bma;m[1043]=dma;m[1044]=Lxa;m[1045]=Kxa;m[1046]=Jxa;m[1047]=UW;m[1048]=MB;m[1049]=tua;m[1050]=Hy;m[1051]=goa;m[1052]=doa;m[1053]=iy;m[1054]=Gxa;m[1055]=Fxa;m[1056]=mc;m[1057]=hy;m[1058]=wxa;m[1059]=Wg;m[1060]=pc;m[1061]=TM;m[1062]=pxa;m[1063]=fxa;m[1064]=exa;m[1065]=dxa;m[1066]=cxa;m[1067]=bxa;m[1068]=axa;m[1069]=$wa;m[1070]=_wa;m[1071]=Zwa;m[1072]=Ywa;m[1073]=Xwa;m[1074]=Wwa;m[1075]=Vwa;m[1076]=Uwa;m[1077]=Swa;m[1078]=Rwa;m[1079]=Qwa;m[1080]=Pwa;m[1081]=Owa;m[1082]=Nwa;m[1083]=Mwa;m[1084]=Lwa;m[1085]=Kwa;m[1086]=Jwa;m[1087]=Iwa;m[1088]=Hwa;m[1089]=Gwa;m[1090]=Fwa;m[1091]=Ewa;m[1092]=Dwa;m[1093]=Cwa;m[1094]=Bwa;m[1095]=Awa;m[1096]=zwa;m[1097]=ywa;m[1098]=xwa;m[1099]=wwa;m[1100]=vwa;m[1101]=uwa;m[1102]=twa;m[1103]=swa;m[1104]=rwa;m[1105]=qwa;m[1106]=pwa;m[1107]=owa;m[1108]=nwa;m[1109]=mwa;m[1110]=lwa;m[1111]=kwa;m[1112]=jwa;m[1113]=iwa;m[1114]=hwa;m[1115]=gwa;m[1116]=fwa;m[1117]=dwa;m[1118]=cwa;m[1119]=bwa;m[1120]=awa;m[1121]=$va;m[1122]=_va;m[1123]=Zva;m[1124]=Yva;m[1125]=Xva;m[1126]=Wva;m[1127]=Uva;m[1128]=Tva;m[1129]=Sva;m[1130]=Rva;m[1131]=Qva;m[1132]=Pva;m[1133]=Ova;m[1134]=Nva;m[1135]=Mva;m[1136]=Lva;m[1137]=Jva;m[1138]=Iva;m[1139]=Hva;m[1140]=Gva;m[1141]=Fva;m[1142]=Eva;m[1143]=Dva;m[1144]=Cva;m[1145]=Ava;m[1146]=zva;m[1147]=yva;m[1148]=xva;m[1149]=wva;m[1150]=vva;m[1151]=uva;m[1152]=tva;m[1153]=sva;m[1154]=rva;m[1155]=pva;m[1156]=ova;m[1157]=nva;m[1158]=mva;m[1159]=lva;m[1160]=Yua;m[1161]=Xua;m[1162]=Lua;m[1163]=BM;m[1164]=Qua;m[1165]=jk;m[1166]=Oc;m[1167]=mc;m[1168]=Ep;m[1169]=pg;m[1170]=Mta;m[1171]=wk;m[1172]=qua;m[1173]=sua;m[1174]=RS;m[1175]=mM;m[1176]=hua;m[1177]=mc;m[1178]=Kta;m[1179]=dua;m[1180]=dM;m[1181]=Hta;m[1182]=_ta;m[1183]=Yta;m[1184]=Xta;m[1185]=Wta;m[1186]=Vta;m[1187]=kM;m[1188]=Rta;m[1189]=Qta;m[1190]=Pta;m[1191]=Ota;m[1192]=yQ;m[1193]=os;m[1194]=Bta;m[1195]=Lta;m[1196]=fM;m[1197]=mc;m[1198]=TL;m[1199]=Oc;m[1200]=zta;m[1201]=Oc;m[1202]=ita;m[1203]=hta;m[1204]=gta;m[1205]=LL;m[1206]=eta;m[1207]=PS;m[1208]=dta;m[1209]=XB;m[1210]=Xsa;m[1211]=IL;m[1212]=Cma;m[1213]=Ssa;m[1214]=Rsa;m[1215]=Nr;m[1216]=Ama;m[1217]=Osa;m[1218]=zma;m[1219]=yma;m[1220]=Nsa;m[1221]=Ksa;m[1222]=Jsa;m[1223]=Fsa;m[1224]=zsa;m[1225]=ysa;m[1226]=mc;m[1227]=mc;m[1228]=Esa;m[1229]=pc;m[1230]=mc;m[1231]=xsa;m[1232]=pc;m[1233]=$i;m[1234]=mc;m[1235]=$ra;m[1236]=_ra;m[1237]=dsa;m[1238]=Zra;m[1239]=Tv;m[1240]=e7;m[1241]=Mx;m[1242]=Sra;m[1243]=boa;m[1244]=ij;m[1245]=Eua;m[1246]=$x;m[1247]=Pra;m[1248]=TR;m[1249]=Ep;m[1250]=Ep;m[1251]=Is;m[1252]=FB;m[1253]=jk;m[1254]=Oc;m[1255]=rv;m[1256]=fE;m[1257]=_d;m[1258]=Ira;m[1259]=pg;m[1260]=mc;m[1261]=oz;m[1262]=Sd;m[1263]=lT;m[1264]=oU;m[1265]=Ne;m[1266]=JLa;m[1267]=Dra;m[1268]=Cra;m[1269]=ub;m[1270]=NJa;m[1271]=Bra;m[1272]=Ara;m[1273]=zra;m[1274]=yra;m[1275]=xra;m[1276]=wra;m[1277]=vra;m[1278]=ura;m[1279]=tra;m[1280]=sra;m[1281]=rra;m[1282]=qra;m[1283]=pra;m[1284]=ora;m[1285]=nra;m[1286]=mra;m[1287]=lra;m[1288]=kra;m[1289]=jra;m[1290]=ira;m[1291]=hra;m[1292]=gra;m[1293]=fra;m[1294]=era;m[1295]=dra;m[1296]=cra;m[1297]=bra;m[1298]=ara;m[1299]=$qa;m[1300]=_qa;m[1301]=Zqa;m[1302]=Yqa;m[1303]=Xqa;m[1304]=Wqa;m[1305]=Vqa;m[1306]=Uqa;m[1307]=Tqa;m[1308]=Sqa;m[1309]=Rqa;m[1310]=Qqa;m[1311]=Pqa;m[1312]=Oqa;m[1313]=Nqa;m[1314]=Mqa;m[1315]=Lqa;m[1316]=Kqa;m[1317]=Jqa;m[1318]=Iqa;m[1319]=Hqa;m[1320]=Gqa;m[1321]=Fqa;m[1322]=Eqa;m[1323]=Dqa;m[1324]=Cqa;m[1325]=Bqa;m[1326]=zqa;m[1327]=yqa;m[1328]=xqa;m[1329]=wqa;m[1330]=vqa;m[1331]=uqa;m[1332]=tqa;m[1333]=lqa;m[1334]=usa;m[1335]=kqa;m[1336]=jqa;m[1337]=iqa;m[1338]=vL;m[1339]=uL;m[1340]=hqa;m[1341]=gqa;m[1342]=Pm;m[1343]=cs;m[1344]=Gx;m[1345]=fqa;m[1346]=cL;m[1347]=ts;m[1348]=IM;m[1349]=No;m[1350]=bL;m[1351]=xJ;m[1352]=KJ;m[1353]=fx;m[1354]=Mo;m[1355]=bs;m[1356]=Lo;m[1357]=cqa;m[1358]=XK;m[1359]=aqa;m[1360]=$pa;m[1361]=oi;m[1362]=$s;m[1363]=jp;m[1364]=SL;m[1365]=oi;m[1366]=xP;m[1367]=_pa;m[1368]=jp;m[1369]=psa;m[1370]=mc;m[1371]=npa;m[1372]=lpa;m[1373]=jk;m[1374]=Oc;m[1375]=Oc;m[1376]=jk;m[1377]=Oc;m[1378]=mc;m[1379]=pc;m[1380]=_d;m[1381]=pc;m[1382]=mK;m[1383]=fpa;m[1384]=pg;m[1385]=_d;m[1386]=pc;m[1387]=_oa;m[1388]=pg;m[1389]=Uoa;m[1390]=kua;m[1391]=oxa;m[1392]=eK;m[1393]=oM;m[1394]=Soa;m[1395]=_ma;m[1396]=Roa;m[1397]=bK;m[1398]=Ee;m[1399]=Oc;m[1400]=Oc;m[1401]=mc;m[1402]=Ioa;m[1403]=Boa;m[1404]=tW;m[1405]=_U;m[1406]=VU;m[1407]=EU;m[1408]=xoa;m[1409]=CU;m[1410]=ZU;m[1411]=sW;m[1412]=TU;m[1413]=pha;m[1414]=toa;m[1415]=UJ;m[1416]=qx;m[1417]=oma;m[1418]=mc;m[1419]=sta;m[1420]=mc;m[1421]=nl;m[1422]=Wg;m[1423]=Oc;m[1424]=foa;m[1425]=coa;m[1426]=Xja;m[1427]=kka;m[1428]=_na;m[1429]=bka;m[1430]=Pja;m[1431]=Oc;m[1432]=Oc;m[1433]=Dy;m[1434]=Yna;m[1435]=CM;m[1436]=mc;m[1437]=mc;m[1438]=Jna;m[1439]=Hna;m[1440]=pc;m[1441]=Txa;m[1442]=Sxa;m[1443]=QHa;m[1444]=PHa;m[1445]=lza;m[1446]=kza;m[1447]=Zya;m[1448]=Xya;m[1449]=xEa;m[1450]=wEa;m[1451]=aBa;m[1452]=$Aa;m[1453]=FFa;m[1454]=EFa;m[1455]=oLa;m[1456]=nLa;m[1457]=uIa;m[1458]=sIa;m[1459]=mMa;m[1460]=lMa;m[1461]=ULa;m[1462]=TLa;m[1463]=XAa;m[1464]=WAa;m[1465]=sza;m[1466]=rza;m[1467]=cya;m[1468]=bya;m[1469]=gKa;m[1470]=fKa;m[1471]=lJa;m[1472]=kJa;m[1473]=jNa;m[1474]=iNa;m[1475]=fNa;m[1476]=eNa;m[1477]=sAa;m[1478]=rAa;m[1479]=Zza;m[1480]=Yza;m[1481]=QBa;m[1482]=PBa;m[1483]=IFa;m[1484]=XP;m[1485]=lIa;m[1486]=kIa;m[1487]=fIa;m[1488]=eIa;m[1489]=pKa;m[1490]=oKa;m[1491]=dJa;m[1492]=cJa;m[1493]=KAa;m[1494]=JAa;m[1495]=$la;m[1496]=Zla;m[1497]=Hla;m[1498]=Gla;m[1499]=jCa;m[1500]=iCa;m[1501]=fza;m[1502]=eza;m[1503]=Uya;m[1504]=Tya;m[1505]=BCa;m[1506]=nCa;m[1507]=lCa;m[1508]=ANa;m[1509]=zNa;m[1510]=uLa;m[1511]=tLa;m[1512]=tDa;m[1513]=sDa;m[1514]=uCa;m[1515]=qCa;m[1516]=Xma;m[1517]=mc;m[1518]=nl;m[1519]=Wg;m[1520]=Pma;m[1521]=jk;m[1522]=Oc;m[1523]=fK;m[1524]=pc;m[1525]=DD;m[1526]=cz;m[1527]=pg;m[1528]=TM;m[1529]=Bma;m[1530]=Xw;m[1531]=Bs;m[1532]=rma;m[1533]=tma;m[1534]=mL;m[1535]=Yla;m[1536]=Xla;m[1537]=Jz;m[1538]=Wla;m[1539]=tt;m[1540]=Vla;m[1541]=UN;m[1542]=Ula;m[1543]=Tla;m[1544]=Sla;m[1545]=sp;m[1546]=Rla;m[1547]=Qla;m[1548]=bf;m[1549]=Pla;m[1550]=Ola;m[1551]=Nla;m[1552]=Mla;m[1553]=Lla;m[1554]=Hz;m[1555]=Kla;m[1556]=k7;m[1557]=g7;m[1558]=f7;m[1559]=mc;m[1560]=sn;m[1561]=rn;m[1562]=xp;m[1563]=kla;m[1564]=jla;m[1565]=hla;m[1566]=eQ;m[1567]=$ka;m[1568]=Tka;m[1569]=ah;m[1570]=Xka;m[1571]=Wka;m[1572]=ah;m[1573]=lz;m[1574]=Vka;m[1575]=tf;m[1576]=Mg;m[1577]=Tk;m[1578]=Uka;m[1579]=Nka;m[1580]=Lka;m[1581]=zka;m[1582]=Ika;m[1583]=ela;m[1584]=Hka;m[1585]=tka;m[1586]=ska;m[1587]=Dka;m[1588]=Yka;m[1589]=vka;m[1590]=Mw;m[1591]=mc;m[1592]=tI;m[1593]=mc;m[1594]=jk;m[1595]=Oc;m[1596]=zja;m[1597]=Wg;m[1598]=wja;m[1599]=Hw;m[1600]=oi;m[1601]=$s;m[1602]=Zja;m[1603]=bna;m[1604]=nl;m[1605]=Nja;m[1606]=Mja;m[1607]=ah;m[1608]=Lja;m[1609]=Kja;m[1610]=Jja;m[1611]=rI;m[1612]=fka;m[1613]=qo;m[1614]=kM;m[1615]=Hja;m[1616]=mf;m[1617]=qI;m[1618]=Fja;m[1619]=sj;m[1620]=Mg;m[1621]=hy;m[1622]=sQ;m[1623]=pg;m[1624]=hja;m[1625]=gja;m[1626]=fja;m[1627]=eja;m[1628]=dja;m[1629]=cja;m[1630]=Ki;m[1631]=$ia;m[1632]=eI;m[1633]=Gja;m[1634]=Oja;m[1635]=dI;m[1636]=Wia;m[1637]=Ria;m[1638]=Qia;m[1639]=Pia;m[1640]=Fha;m[1641]=Oia;m[1642]=Nia;m[1643]=WH;m[1644]=ria;m[1645]=UH;m[1646]=Wg;m[1647]=pI;m[1648]=oia;m[1649]=fia;m[1650]=mia;m[1651]=pc;m[1652]=hy;m[1653]=pc;m[1654]=Fw;m[1655]=Cia;m[1656]=Bia;m[1657]=Aia;m[1658]=$b;m[1659]=xe;m[1660]=$b;m[1661]=$b;m[1662]=$b;m[1663]=pc;m[1664]=iq;m[1665]=Hia;m[1666]=Iia;m[1667]=Kia;m[1668]=Jia;m[1669]=Lia;m[1670]=ai;m[1671]=Ew;m[1672]=Ew;m[1673]=Dw;m[1674]=Dw;m[1675]=Dw;m[1676]=$Ma;m[1677]=xe;m[1678]=XP;m[1679]=yia;m[1680]=xia;m[1681]=wia;m[1682]=via;m[1683]=Fia;m[1684]=$h;m[1685]=ZH;m[1686]=Dha;m[1687]=$b;m[1688]=$b;m[1689]=je;m[1690]=Cw;m[1691]=ie;m[1692]=ie;m[1693]=je;m[1694]=Eia;m[1695]=Dia;m[1696]=pc;m[1697]=xe;m[1698]=pc;m[1699]=xe;m[1700]=cia;m[1701]=Nha;m[1702]=zw;m[1703]=Kha;m[1704]=Jha;m[1705]=Iha;m[1706]=$b;m[1707]=xe;m[1708]=$b;m[1709]=$b;m[1710]=$b;m[1711]=pc;m[1712]=Kya;m[1713]=OH;m[1714]=_ha;m[1715]=Pha;m[1716]=Oha;m[1717]=bia;m[1718]=ai;m[1719]=Yha;m[1720]=Xha;m[1721]=Wha;m[1722]=Uha;m[1723]=Tha;m[1724]=Sha;m[1725]=Rha;m[1726]=Qha;m[1727]=Zha;m[1728]=$h;m[1729]=NH;m[1730]=$b;m[1731]=$b;m[1732]=je;m[1733]=ie;m[1734]=ie;m[1735]=je;m[1736]=MH;m[1737]=LH;m[1738]=Ei;m[1739]=yha;m[1740]=xha;m[1741]=EH;m[1742]=mc;m[1743]=mc;m[1744]=Ge;m[1745]=Zg;m[1746]=zha;m[1747]=DH;m[1748]=Cha;m[1749]=$b;m[1750]=uha;m[1751]=tha;m[1752]=mha;m[1753]=Es;m[1754]=kha;m[1755]=jha;m[1756]=iha;m[1757]=hha;m[1758]=Oc;m[1759]=Wg;m[1760]=os;m[1761]=mc;m[1762]=nl;m[1763]=pc;m[1764]=$ga;m[1765]=Pga;m[1766]=Cga;m[1767]=uga;m[1768]=kga;m[1769]=$fa;m[1770]=Rfa;m[1771]=Cfa;m[1772]=ufa;m[1773]=Sia;m[1774]=dia;m[1775]=zH;m[1776]=xr;m[1777]=Uga;m[1778]=yH;m[1779]=Tga;m[1780]=$b;m[1781]=xe;m[1782]=$b;m[1783]=$b;m[1784]=$b;m[1785]=pc;m[1786]=CP;m[1787]=Xga;m[1788]=Yga;m[1789]=_ga;m[1790]=ai;m[1791]=Wga;m[1792]=$h;m[1793]=Vga;m[1794]=$b;m[1795]=$b;m[1796]=je;m[1797]=ie;m[1798]=ie;m[1799]=pc;m[1800]=xe;m[1801]=xH;m[1802]=Sga;m[1803]=Rga;m[1804]=vH;m[1805]=Qga;m[1806]=uH;m[1807]=tH;m[1808]=Oga;m[1809]=uw;m[1810]=Hga;m[1811]=Gga;m[1812]=Fga;m[1813]=$b;m[1814]=xe;m[1815]=$b;m[1816]=$b;m[1817]=$b;m[1818]=pc;m[1819]=Dga;m[1820]=Kga;m[1821]=Mga;m[1822]=Nga;m[1823]=ai;m[1824]=Jga;m[1825]=$h;m[1826]=rH;m[1827]=$b;m[1828]=$b;m[1829]=je;m[1830]=ie;m[1831]=ie;m[1832]=Bga;m[1833]=wr;m[1834]=vr;m[1835]=vga;m[1836]=$b;m[1837]=xe;m[1838]=$b;m[1839]=$b;m[1840]=$b;m[1841]=pc;m[1842]=YI;m[1843]=yga;m[1844]=zga;m[1845]=Aga;m[1846]=ai;m[1847]=xga;m[1848]=$h;m[1849]=oH;m[1850]=$b;m[1851]=$b;m[1852]=je;m[1853]=ie;m[1854]=ie;m[1855]=tga;m[1856]=sw;m[1857]=nga;m[1858]=mga;m[1859]=lga;m[1860]=$b;m[1861]=xe;m[1862]=$b;m[1863]=$b;m[1864]=$b;m[1865]=pc;m[1866]=YI;m[1867]=qga;m[1868]=rga;m[1869]=sga;m[1870]=ai;m[1871]=oga;m[1872]=$h;m[1873]=mH;m[1874]=$b;m[1875]=$b;m[1876]=je;m[1877]=ie;m[1878]=ie;m[1879]=jga;m[1880]=hga;m[1881]=ega;m[1882]=dga;m[1883]=CP;m[1884]=iga;m[1885]=xH;m[1886]=cga;m[1887]=bga;m[1888]=vH;m[1889]=aga;m[1890]=uH;m[1891]=tH;m[1892]=_fa;m[1893]=wr;m[1894]=vr;m[1895]=Vfa;m[1896]=$b;m[1897]=xe;m[1898]=$b;m[1899]=$b;m[1900]=$b;m[1901]=pc;m[1902]=ie;m[1903]=Xfa;m[1904]=Yfa;m[1905]=Zfa;m[1906]=ai;m[1907]=Wfa;m[1908]=$h;m[1909]=Ufa;m[1910]=$b;m[1911]=$b;m[1912]=je;m[1913]=ie;m[1914]=ie;m[1915]=Qfa;m[1916]=Tfa;m[1917]=qw;m[1918]=Hfa;m[1919]=Gfa;m[1920]=Ffa;m[1921]=$b;m[1922]=xe;m[1923]=$b;m[1924]=$b;m[1925]=Efa;m[1926]=pc;m[1927]=Dfa;m[1928]=Kfa;m[1929]=Lfa;m[1930]=Ofa;m[1931]=ai;m[1932]=Jfa;m[1933]=$h;m[1934]=rw;m[1935]=$b;m[1936]=$b;m[1937]=je;m[1938]=ie;m[1939]=ie;m[1940]=pc;m[1941]=xe;m[1942]=Bfa;m[1943]=wr;m[1944]=vr;m[1945]=vfa;m[1946]=$b;m[1947]=xe;m[1948]=$b;m[1949]=$b;m[1950]=$b;m[1951]=pc;m[1952]=wW;m[1953]=xfa;m[1954]=yfa;m[1955]=Afa;m[1956]=ai;m[1957]=wfa;m[1958]=$h;m[1959]=fH;m[1960]=$b;m[1961]=$b;m[1962]=je;m[1963]=ie;m[1964]=ie;m[1965]=tfa;m[1966]=wr;m[1967]=vr;m[1968]=nfa;m[1969]=$b;m[1970]=xe;m[1971]=$b;m[1972]=$b;m[1973]=$b;m[1974]=pc;m[1975]=iq;m[1976]=pfa;m[1977]=rfa;m[1978]=sfa;m[1979]=ai;m[1980]=ofa;m[1981]=$h;m[1982]=cH;m[1983]=$b;m[1984]=$b;m[1985]=je;m[1986]=ie;m[1987]=ie;m[1988]=vca;m[1989]=$ea;m[1990]=Ica;m[1991]=Qba;m[1992]=uca;m[1993]=tca;m[1994]=lba;m[1995]=wu;m[1996]=jba;m[1997]=sr;m[1998]=SG;m[1999]=fba;m[2e3]=Rea;m[2001]=Qea;m[2002]=Oc;m[2003]=Oc;m[2004]=gba;m[2005]=cba;m[2006]=aba;m[2007]=$aa;m[2008]=_d;m[2009]=ba;m[2010]=Iea;m[2011]=Hea;m[2012]=SG;m[2013]=_aa;m[2014]=Yaa;m[2015]=OG;m[2016]=Bea;m[2017]=nw;m[2018]=qG;m[2019]=Bz;m[2020]=Eaa;m[2021]=Daa;m[2022]=Jaa;m[2023]=Baa;m[2024]=Caa;m[2025]=Faa;m[2026]=pw;m[2027]=Xaa;m[2028]=lea;m[2029]=KG;m[2030]=Taa;m[2031]=Saa;m[2032]=Raa;m[2033]=Qaa;m[2034]=Paa;m[2035]=Oaa;m[2036]=Naa;m[2037]=Maa;m[2038]=Laa;m[2039]=Kaa;m[2040]=Aaa;m[2041]=pw;m[2042]=uaa;m[2043]=taa;m[2044]=saa;m[2045]=raa;m[2046]=qaa;m[2047]=paa;m[2048]=oaa;m[2049]=naa;m[2050]=maa;m[2051]=laa;m[2052]=kaa;m[2053]=jaa;m[2054]=iaa;m[2055]=haa;m[2056]=al;m[2057]=gaa;m[2058]=faa;m[2059]=$k;m[2060]=lr;m[2061]=eaa;m[2062]=nC;m[2063]=daa;m[2064]=baa;m[2065]=aaa;m[2066]=$9;m[2067]=_9;m[2068]=Z9;m[2069]=Y9;m[2070]=aw;m[2071]=W9;m[2072]=V9;m[2073]=S9;m[2074]=R9;m[2075]=Q9;m[2076]=O9;m[2077]=N9;m[2078]=L9;m[2079]=I9;m[2080]=G9;m[2081]=Cba;m[2082]=EG;m[2083]=DG;m[2084]=CG;m[2085]=BG;m[2086]=M7;m[2087]=L7;m[2088]=OG;m[2089]=pw;m[2090]=Lca;m[2091]=Kca;m[2092]=Nca;m[2093]=Oca;m[2094]=Pca;m[2095]=Qca;m[2096]=Sca;m[2097]=Tca;m[2098]=Uca;m[2099]=Vca;m[2100]=Wca;m[2101]=Xca;m[2102]=Yca;m[2103]=Zca;m[2104]=_ca;m[2105]=$ca;m[2106]=bda;m[2107]=cda;m[2108]=Cca;m[2109]=mw;m[2110]=Fca;m[2111]=Eca;m[2112]=NG;m[2113]=wca;m[2114]=NG;m[2115]=xca;m[2116]=eS;m[2117]=HB;m[2118]=or;m[2119]=$ba;m[2120]=Nra;m[2121]=jq;m[2122]=Wba;m[2123]=Vba;m[2124]=mc;m[2125]=k9;m[2126]=Tba;m[2127]=aG;m[2128]=h9;m[2129]=ds;m[2130]=Kba;m[2131]=mc;m[2132]=mK;m[2133]=b9;m[2134]=Voa;m[2135]=Aba;m[2136]=fC;m[2137]=aP;m[2138]=Oc;m[2139]=Oc;m[2140]=Oc;m[2141]=M9;m[2142]=F9;m[2143]=J9;m[2144]=H9;m[2145]=yoa;m[2146]=Gba;m[2147]=Zba;m[2148]=Pba;m[2149]=ku;m[2150]=oi;m[2151]=$s;m[2152]=jp;m[2153]=mA;m[2154]=tba;m[2155]=una;m[2156]=Yma;m[2157]=kba;m[2158]=JG;m[2159]=IG;m[2160]=hba;m[2161]=iba;m[2162]=Oc;m[2163]=x9;m[2164]=v9;m[2165]=Eba;m[2166]=uG;m[2167]=wba;m[2168]=Nba;m[2169]=Oc;m[2170]=Oc;m[2171]=Oc;m[2172]=ub;m[2173]=Zb;m[2174]=Zaa;m[2175]=Iaa;m[2176]=Oc;m[2177]=Oc;m[2178]=RJ;m[2179]=zaa;m[2180]=yaa;m[2181]=xaa;m[2182]=O7;m[2183]=ioa;m[2184]=joa;m[2185]=Oba;m[2186]=Wna;m[2187]=waa;m[2188]=vaa;m[2189]=xm;m[2190]=lG;m[2191]=caa;m[2192]=bj;m[2193]=Eka;m[2194]=BI;m[2195]=U9;m[2196]=_e;m[2197]=MJ;m[2198]=QI;m[2199]=PI;m[2200]=P9;m[2201]=mc;m[2202]=pg;m[2203]=u9;m[2204]=pg;m[2205]=p9;m[2206]=ez;m[2207]=pc;m[2208]=Q7;m[2209]=mc;m[2210]=Zg;m[2211]=nr;m[2212]=C9;m[2213]=Uba;m[2214]=_d;m[2215]=Zg;m[2216]=_d;m[2217]=Dc;m[2218]=A9;m[2219]=z9;m[2220]=Zg;m[2221]=fG;m[2222]=r9;m[2223]=Hn;m[2224]=q9;m[2225]=cG;m[2226]=m9;m[2227]=Hn;m[2228]=l9;m[2229]=Dc;m[2230]=Z8;m[2231]=_d;m[2232]=Dc;m[2233]=X8;m[2234]=W8;m[2235]=Dc;m[2236]=XF;m[2237]=WF;m[2238]=Zg;m[2239]=Dc;m[2240]=H8;m[2241]=G8;m[2242]=Dc;m[2243]=VF;m[2244]=UF;m[2245]=Dc;m[2246]=t8;m[2247]=s8;m[2248]=Dc;m[2249]=TF;m[2250]=SF;m[2251]=Dc;m[2252]=d8;m[2253]=c8;m[2254]=Dc;m[2255]=QF;m[2256]=PF;m[2257]=Vv;m[2258]=LF;m[2259]=H7;m[2260]=G7;m[2261]=KF;m[2262]=JF;m[2263]=IF;m[2264]=HF;m[2265]=GF;m[2266]=FF;m[2267]=EF;m[2268]=DF;m[2269]=CF;m[2270]=BF;m[2271]=AF;m[2272]=zF;m[2273]=yF;m[2274]=xF;m[2275]=wF;m[2276]=vF;m[2277]=J7;m[2278]=I7;m[2279]=F7;m[2280]=E7;m[2281]=D7;m[2282]=C7;m[2283]=B7;m[2284]=A7;m[2285]=z7;m[2286]=x7;m[2287]=w7;m[2288]=v7;m[2289]=u7;m[2290]=t7;m[2291]=r7;m[2292]=q7;m[2293]=n7;m[2294]=m7;m[2295]=_d;m[2296]=Zg;m[2297]=_d;m[2298]=Zg;m[2299]=j7;m[2300]=i7;m[2301]=h6;m[2302]=T5;m[2303]=C5;m[2304]=B5;m[2305]=A5;m[2306]=y5;m[2307]=z5;m[2308]=Wa;m[2309]=RE;m[2310]=Iu;m[2311]=q5;m[2312]=n5;m[2313]=j5;m[2314]=EE;m[2315]=Hm;m[2316]=W4;m[2317]=R4;m[2318]=i5;m[2319]=V4;m[2320]=M4;m[2321]=w4;m[2322]=G4;m[2323]=tv;m[2324]=F4;m[2325]=gLa;m[2326]=bLa;m[2327]=hS;m[2328]=E4;m[2329]=Hm;m[2330]=mg;m[2331]=C4;m[2332]=A4;m[2333]=z4;m[2334]=w4;m[2335]=v4;m[2336]=lE;m[2337]=xe;m[2338]=q4;m[2339]=iE;m[2340]=Vk;m[2341]=g5;m[2342]=CE;m[2343]=BE;m[2344]=AE;m[2345]=Sq;m[2346]=Sq;m[2347]=bo;m[2348]=c5;m[2349]=pc;m[2350]=ul;m[2351]=CE;m[2352]=BE;m[2353]=$b;m[2354]=$b;m[2355]=b5;m[2356]=AE;m[2357]=a5;m[2358]=Sq;m[2359]=$4;m[2360]=Sq;m[2361]=Rq;m[2362]=uv;m[2363]=xE;m[2364]=wE;m[2365]=Oq;m[2366]=qv;m[2367]=nE;m[2368]=mE;m[2369]=_d;m[2370]=Dc;m[2371]=s4;m[2372]=SY;m[2373]=RY;m[2374]=QY;m[2375]=r4;m[2376]=p4;m[2377]=vv;m[2378]=n4;m[2379]=xg;m[2380]=DE;m[2381]=xg;m[2382]=DE;m[2383]=j4;m[2384]=$b;m[2385]=i4;m[2386]=g4;m[2387]=a4;m[2388]=tr;m[2389]=tr;m[2390]=kv;m[2391]=jv;m[2392]=Qq;m[2393]=sE;m[2394]=_D;m[2395]=$3;m[2396]=_3;m[2397]=Y3;m[2398]=X3;m[2399]=XD;m[2400]=W3;m[2401]=V3;m[2402]=U3;m[2403]=T3;m[2404]=_D;m[2405]=S3;m[2406]=VD;m[2407]=R3;m[2408]=Q3;m[2409]=XD;m[2410]=P3;m[2411]=VD;m[2412]=O3;m[2413]=N3;m[2414]=G3;m[2415]=B3;m[2416]=$u;m[2417]=Qg;m[2418]=Pg;m[2419]=Eq;m[2420]=Nb;m[2421]=Mu;m[2422]=ao;m[2423]=Pi;m[2424]=Ij;m[2425]=_u;m[2426]=Uk;m[2427]=Yn;m[2428]=Ej;m[2429]=e3;m[2430]=we;m[2431]=Oh;m[2432]=Zf;m[2433]=b3;m[2434]=_2;m[2435]=wD;m[2436]=wD;m[2437]=T2;m[2438]=Dq;m[2439]=Q2;m[2440]=vD;m[2441]=Ph;m[2442]=N2;m[2443]=K2;m[2444]=qc;m[2445]=de;m[2446]=I2;m[2447]=C3;m[2448]=cv;m[2449]=sv;m[2450]=Yu;m[2451]=Qg;m[2452]=Pg;m[2453]=Cq;m[2454]=Pq;m[2455]=Fj;m[2456]=Rk;m[2457]=Bk;m[2458]=lm;m[2459]=Dj;m[2460]=Oh;m[2461]=Zf;m[2462]=Bq;m[2463]=uD;m[2464]=Ph;m[2465]=h2;m[2466]=Bj;m[2467]=c2;m[2468]=b2;m[2469]=Yn;m[2470]=A3;m[2471]=gv;m[2472]=G5;m[2473]=kE;m[2474]=Y1;m[2475]=Nq;m[2476]=Xn;m[2477]=Jl;m[2478]=T1;m[2479]=dm;m[2480]=Yn;m[2481]=dv;m[2482]=xe;m[2483]=X0;m[2484]=am;m[2485]=W0;m[2486]=V0;m[2487]=hD;m[2488]=U0;m[2489]=gD;m[2490]=Yn;m[2491]=S0;m[2492]=Pn;m[2493]=N0;m[2494]=M0;m[2495]=Gj;m[2496]=L0;m[2497]=cD;m[2498]=gD;m[2499]=I0;m[2500]=WY;m[2501]=C0;m[2502]=B0;m[2503]=y0;m[2504]=x0;m[2505]=Ze;m[2506]=_C;m[2507]=z3;m[2508]=_C;m[2509]=YC;m[2510]=t0;m[2511]=XC;m[2512]=Ze;m[2513]=s0;m[2514]=ev;m[2515]=q0;m[2516]=p0;m[2517]=o0;m[2518]=n0;m[2519]=m0;m[2520]=l0;m[2521]=k0;m[2522]=j0;m[2523]=i0;m[2524]=h0;m[2525]=g0;m[2526]=f0;m[2527]=e0;m[2528]=d0;m[2529]=c0;m[2530]=b0;m[2531]=a0;m[2532]=$$;m[2533]=_$;m[2534]=Z$;m[2535]=Y$;m[2536]=X$;m[2537]=W$;m[2538]=V$;m[2539]=U$;m[2540]=T$;m[2541]=S$;m[2542]=R$;m[2543]=Q$;m[2544]=P$;m[2545]=O$;m[2546]=N$;m[2547]=M$;m[2548]=L$;m[2549]=K$;m[2550]=J$;m[2551]=I$;m[2552]=H$;m[2553]=G$;m[2554]=E$;m[2555]=TC;m[2556]=vC;m[2557]=hy;m[2558]=s$;m[2559]=y$;m[2560]=EZ;m[2561]=A$;m[2562]=AZ;m[2563]=zZ;m[2564]=_d;m[2565]=u$;m[2566]=t$;m[2567]=q$;m[2568]=x3;m[2569]=w3;m[2570]=v3;m[2571]=GD;m[2572]=Jj;m[2573]=FD;m[2574]=Zn;m[2575]=O_;m[2576]=N_;m[2577]=ED;m[2578]=CD;m[2579]=BD;m[2580]=n_;m[2581]=m_;m[2582]=k_;m[2583]=j_;m[2584]=h_;m[2585]=g_;m[2586]=e_;m[2587]=d_;m[2588]=b_;m[2589]=a_;m[2590]=_Z;m[2591]=ZZ;m[2592]=XZ;m[2593]=Qu;m[2594]=VZ;m[2595]=TZ;m[2596]=RZ;m[2597]=PZ;m[2598]=NZ;m[2599]=LZ;m[2600]=JZ;m[2601]=pC;m[2602]=pc;m[2603]=GC;m[2604]=w$;m[2605]=yH;m[2606]=DC;m[2607]=e$;m[2608]=d$;m[2609]=c$;m[2610]=b$;m[2611]=$_;m[2612]=AA;m[2613]=__;m[2614]=Z_;m[2615]=Y_;m[2616]=WC;m[2617]=W_;m[2618]=V_;m[2619]=S_;m[2620]=Q_;m[2621]=P_;m[2622]=$b;m[2623]=M_;m[2624]=K_;m[2625]=zC;m[2626]=x_;m[2627]=v_;m[2628]=u_;m[2629]=lG;m[2630]=s_;m[2631]=q_;m[2632]=yC;m[2633]=w_;m[2634]=Bz;m[2635]=UU;m[2636]=t_;m[2637]=r_;m[2638]=p_;m[2639]=_d;m[2640]=Dc;m[2641]=Dc;m[2642]=p$;m[2643]=o$;m[2644]=n$;m[2645]=m$;m[2646]=l$;m[2647]=k$;m[2648]=j$;m[2649]=i$;m[2650]=AA;m[2651]=h$;m[2652]=g$;m[2653]=f$;m[2654]=Dc;m[2655]=CC;m[2656]=CC;m[2657]=Tu;m[2658]=je;m[2659]=je;m[2660]=X_;m[2661]=je;m[2662]=Dc;m[2663]=J_;m[2664]=H_;m[2665]=Tu;m[2666]=$b;m[2667]=$b;m[2668]=F_;m[2669]=iq;m[2670]=Dc;m[2671]=D_;m[2672]=B_;m[2673]=Tu;m[2674]=$b;m[2675]=$b;m[2676]=z_;m[2677]=iq;m[2678]=Dc;m[2679]=Dc;m[2680]=_d;m[2681]=Dc;m[2682]=p3;m[2683]=o3;m[2684]=n3;m[2685]=_d;m[2686]=Dc;m[2687]=m3;m[2688]=l3;m[2689]=k3;m[2690]=Dc;m[2691]=j3;m[2692]=h3;m[2693]=d3;m[2694]=a3;m[2695]=Z2;m[2696]=X2;m[2697]=V2;m[2698]=S2;m[2699]=P2;m[2700]=M2;m[2701]=J2;m[2702]=Dc;m[2703]=H2;m[2704]=F2;m[2705]=D2;m[2706]=B2;m[2707]=z2;m[2708]=w2;m[2709]=u2;m[2710]=s2;m[2711]=q2;m[2712]=o2;m[2713]=m2;m[2714]=Dc;m[2715]=j2;m[2716]=i2;m[2717]=g2;m[2718]=f2;m[2719]=e2;m[2720]=d2;m[2721]=a2;m[2722]=$1;m[2723]=Dc;m[2724]=_1;m[2725]=Z1;m[2726]=X1;m[2727]=W1;m[2728]=V1;m[2729]=U1;m[2730]=S1;m[2731]=Q1;m[2732]=_d;m[2733]=Dc;m[2734]=ie;m[2735]=N1;m[2736]=M1;m[2737]=L1;m[2738]=K1;m[2739]=I1;m[2740]=H1;m[2741]=o_;m[2742]=i_;m[2743]=c_;m[2744]=QZ;m[2745]=MZ;m[2746]=YZ;m[2747]=UZ;m[2748]=_d;m[2749]=Dc;m[2750]=ie;m[2751]=u1;m[2752]=s1;m[2753]=r1;m[2754]=q1;m[2755]=p1;m[2756]=o1;m[2757]=l_;m[2758]=f_;m[2759]=$Z;m[2760]=OZ;m[2761]=KZ;m[2762]=WZ;m[2763]=SZ;m[2764]=Ou;m[2765]=wC;m[2766]=a1;m[2767]=Ou;m[2768]=wC;m[2769]=$0;m[2770]=Dc;m[2771]=zq;m[2772]=zq;m[2773]=zj;m[2774]=zj;m[2775]=zj;m[2776]=jD;m[2777]=$b;m[2778]=yj;m[2779]=yj;m[2780]=Dc;m[2781]=zq;m[2782]=zq;m[2783]=zj;m[2784]=zj;m[2785]=zj;m[2786]=jD;m[2787]=$b;m[2788]=yj;m[2789]=yj;m[2790]=Dc;m[2791]=Wr;m[2792]=Wr;m[2793]=zj;m[2794]=yq;m[2795]=yq;m[2796]=iD;m[2797]=$b;m[2798]=yj;m[2799]=yj;m[2800]=Dc;m[2801]=Wr;m[2802]=Wr;m[2803]=zj;m[2804]=yq;m[2805]=yq;m[2806]=iD;m[2807]=$b;m[2808]=yj;m[2809]=yj;m[2810]=Dc;m[2811]=Y0;m[2812]=T0;m[2813]=Dc;m[2814]=O0;m[2815]=K0;m[2816]=Dc;m[2817]=D0;m[2818]=A0;m[2819]=Dc;m[2820]=z0;m[2821]=w0;m[2822]=Dc;m[2823]=$C;m[2824]=v0;m[2825]=pc;m[2826]=Dc;m[2827]=$C;m[2828]=u0;m[2829]=pc;m[2830]=_d;m[2831]=Zg;m[2832]=Zg;m[2833]=$b;m[2834]=$b;m[2835]=$b;m[2836]=qZ;m[2837]=mZ;m[2838]=iZ;m[2839]=lC;m[2840]=mC;m[2841]=wZ;m[2842]=hF;m[2843]=IY;m[2844]=hZ;m[2845]=dC;m[2846]=Ju;m[2847]=Dc;m[2848]=NY;m[2849]=MY;m[2850]=Dc;m[2851]=LY;m[2852]=JY;m[2853]=KY;m[2854]=HY;m[2855]=BY;m[2856]=CY;m[2857]=GY;m[2858]=Dc;m[2859]=xY;m[2860]=Dc;m[2861]=yY;m[2862]=wY;m[2863]=rt;m[2864]=vY;m[2865]=Fu;m[2866]=Fu;m[2867]=Fu;m[2868]=lu;m[2869]=Dc;m[2870]=uY;m[2871]=_d;m[2872]=Dc;m[2873]=xe;m[2874]=xe;m[2875]=tY;m[2876]=jY;m[2877]=mY;m[2878]=rY;m[2879]=Dc;m[2880]=kY;m[2881]=nY;m[2882]=qY;m[2883]=Dc;m[2884]=lY;m[2885]=oY;m[2886]=pY;function jb(){return buffer.byteLength/65536|0}function kb(pagesToAdd){pagesToAdd=pagesToAdd|0;var lb=jb()|0;var mb=lb+pagesToAdd|0;if(lb<mb&&mb<65536){var nb=new ArrayBuffer(v(mb,65536));var ob=new global.Int8Array(nb);ob.set(n);n=ob;n=new global.Int8Array(nb);o=new global.Int16Array(nb);p=new global.Int32Array(nb);q=new global.Uint8Array(nb);r=new global.Uint16Array(nb);s=new global.Uint32Array(nb);t=new global.Float32Array(nb);u=new global.Float64Array(nb);buffer=nb;l.buffer=nb}return lb}return{"Aa":HNa,"Ba":afa,"Ca":_ea,"Da":Dc,"Ea":Nb,"Fa":Zea,"Ga":Yea,"Ha":Xea,"Ia":sr,"Ja":pc,"Ka":Wea,"La":Vea,"Ma":Uea,"Na":Ew,"Oa":Tea,"Pa":WG,"Qa":Sea,"Ra":_d,"Sa":VG,"Ta":UG,"Ua":VG,"Va":Oea,"Wa":uX,"Xa":tX,"Ya":sX,"Za":Jea,"_a":QG,"$a":Eea,"ab":PG,"bb":Dea,"cb":Aea,"db":zea,"eb":yea,"fb":xea,"gb":wea,"hb":vea,"ib":uea,"jb":tea,"kb":sea,"lb":rea,"mb":qea,"nb":pea,"ob":oea,"pb":nea,"qb":mea,"rb":kea,"sb":iea,"tb":hea,"ub":gea,"vb":fea,"wb":eea,"xb":dea,"yb":cea,"zb":bea,"Ab":aea,"Bb":$da,"Cb":Zda,"Db":Yda,"Eb":Xda,"Fb":Wda,"Gb":Vda,"Hb":Uda,"Ib":Tda,"Jb":Sda,"Kb":Rda,"Lb":Qda,"Mb":Pda,"Nb":Oda,"Ob":Nda,"Pb":Mda,"Qb":Lda,"Rb":Kda,"Sb":Jda,"Tb":Ida,"Ub":Hda,"Vb":Gda,"Wb":Fda,"Xb":Eda,"Yb":Dda,"Zb":Cda,"_b":Bda,"$b":Ada,"ac":zda,"bc":yda,"cc":xda,"dc":wda,"ec":vda,"fc":uda,"gc":tda,"hc":sda,"ic":rda,"jc":qda,"kc":rX,"lc":oda,"mc":nda,"nc":mda,"oc":kda,"pc":qX,"qc":ida,"rc":hda,"sc":gda,"tc":fda,"uc":eda,"vc":dda,"wc":Mca,"xc":fd,"yc":RE,"zc":v5,"Ac":aY,"Bc":$X,"Cc":wv,"Dc":iY,"Ec":hY,"Fc":_X,"Gc":ZX,"Hc":YX,"Ic":XX,"Jc":WX,"Kc":pX,"Lc":oX,"Mc":VX,"Nc":UX,"Oc":TX,"Pc":pX,"Qc":oX,"Rc":SX,"Sc":RX,"Tc":QX,"Uc":PX,"Vc":OX,"Wc":NX,"Xc":mX,"Yc":lX,"Zc":kX,"_c":LX,"$c":jX,"ad":KX,"bd":JX,"cd":jX,"dd":IX,"ed":HX,"fd":GX,"gd":mX,"hd":lX,"id":kX,"jd":jX,"kd":FX,"ld":EX,"md":iX,"nd":hX,"od":gX,"pd":fX,"qd":DX,"rd":CX,"sd":BX,"td":AX,"ud":zX,"vd":yX,"wd":xX,"xd":wX,"yd":vX}}return k({"Int8Array":Int8Array,"Int16Array":Int16Array,"Int32Array":Int32Array,"Uint8Array":Uint8Array,"Uint16Array":Uint16Array,"Uint32Array":Uint32Array,"Float32Array":Float32Array,"Float64Array":Float64Array,"NaN":NaN,"Infinity":Infinity,"Math":Math},asmLibraryArg,wasmMemory.buffer)}


// EMSCRIPTEN_END_ASM




)(asmLibraryArg, wasmMemory, wasmTable);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


